@@ -1,14 +1,17 @@
 # (c) 2020 Ansible Project
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 DOCUMENTATION = """
     author:
       - Ansible Networking Team (@ansible-network)
     name: libssh
-    short_description: (Tech preview) Run tasks using libssh for ssh connection
+    short_description: Run tasks using libssh for ssh connection
     description:
         - Use the ansible-pylibssh python bindings to connect to targets
         - The python bindings use libssh C library (https://www.libssh.org/) to connect to targets
@@ -18,8 +21,10 @@ DOCUMENTATION = """
       remote_addr:
         description:
             - Address of the remote target
+        type: string
         default: inventory_hostname
         vars:
+            - name: inventory_hostname
             - name: ansible_host
             - name: ansible_ssh_host
             - name: ansible_libssh_host
@@ -27,6 +32,7 @@ DOCUMENTATION = """
         description:
             - User to login/authenticate as
             - Can be set from the CLI via the C(--user) or C(-u) options.
+        type: string
         vars:
             - name: ansible_user
             - name: ansible_ssh_user
@@ -43,12 +49,22 @@ DOCUMENTATION = """
         description:
           - Secret used to either login the ssh server or as a passphrase for ssh keys that require it
           - Can be set from the CLI via the C(--ask-pass) option.
+        type: string
         vars:
             - name: ansible_password
             - name: ansible_ssh_pass
             - name: ansible_ssh_password
             - name: ansible_libssh_pass
             - name: ansible_libssh_password
+      password_prompt:
+        description:
+          - Text to match when using keyboard-interactive authentication to determine if the prompt is
+            for the password.
+          - Requires ansible-pylibssh version >= 1.0.0
+        type: string
+        vars:
+          - name: ansible_libssh_password_prompt
+        version_added: 3.1.0
       host_key_auto_add:
         description: 'TODO: write it'
         env: [{name: ANSIBLE_LIBSSH_HOST_KEY_AUTO_ADD}]
@@ -67,6 +83,7 @@ DOCUMENTATION = """
         description:
             - Proxy information for running the connection via a jumphost.
             - Also this plugin will scan 'ssh_args', 'ssh_extra_args' and 'ssh_common_args' from the 'ssh' plugin settings for proxy information if set.
+        type: string
         env:
           - name: ANSIBLE_LIBSSH_PROXY_COMMAND
         ini:
@@ -83,6 +100,27 @@ DOCUMENTATION = """
           - section: libssh_connection
             key: pty
         type: boolean
+      publickey_accepted_algorithms:
+        default: ''
+        description:
+            - List of algorithms to forward to SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES.
+        type: string
+        env:
+          - name: ANSIBLE_LIBSSH_PUBLICKEY_ALGORITHMS
+        ini:
+          - {key: publickey_algorithms, section: libssh_connection}
+        vars:
+          - name: ansible_libssh_publickey_algorithms
+      hostkeys:
+        default: ''
+        description: Set the preferred server host key types as a comma-separated list (e.g., ssh-rsa,ssh-dss,ecdh-sha2-nistp256).
+        type: string
+        env:
+          - name: ANSIBLE_LIBSSH_HOSTKEYS
+        ini:
+          - {key: hostkeys, section: libssh_connection}
+        vars:
+          - name: ansible_libssh_hostkeys
       host_key_checking:
         description: 'Set this to "False" if you want to avoid host key checking by the underlying tools Ansible uses to connect to the host'
         type: boolean
@@ -109,33 +147,91 @@ DOCUMENTATION = """
         ini:
           - section: defaults
             key: use_persistent_connections
+      ssh_args:
+          version_added: 3.2.0
+          description:
+           - Arguments to pass to all ssh CLI tools.
+           - ProxyCommand is the only supported argument.
+           - This option is deprecated in favor of I(proxy_command) and will be removed
+             in a release after 2026-01-01.
+          type: string
+          ini:
+              - section: 'ssh_connection'
+                key: 'ssh_args'
+          env:
+              - name: ANSIBLE_SSH_ARGS
+          vars:
+              - name: ansible_ssh_args
+          cli:
+              - name: ssh_args
+      ssh_common_args:
+          version_added: 3.2.0
+          description:
+           - Common extra arguments for all ssh CLI tools.
+           - ProxyCommand is the only supported argument.
+           - This option is deprecated in favor of I(proxy_command) and will be removed
+             in a release after 2026-01-01.
+          type: string
+          ini:
+              - section: 'ssh_connection'
+                key: 'ssh_common_args'
+          env:
+              - name: ANSIBLE_SSH_COMMON_ARGS
+          vars:
+              - name: ansible_ssh_common_args
+          cli:
+              - name: ssh_common_args
+      ssh_extra_args:
+          version_added: 3.2.0
+          description:
+           - Extra arguments exclusive to the 'ssh' CLI tool.
+           - ProxyCommand is the only supported argument.
+           - This option is deprecated in favor of I(proxy_command) and will be removed
+             in a release after 2026-01-01.
+          type: string
+          vars:
+              - name: ansible_ssh_extra_args
+          env:
+            - name: ANSIBLE_SSH_EXTRA_ARGS
+          ini:
+            - key: ssh_extra_args
+              section: ssh_connection
+          cli:
+            - name: ssh_extra_args
+      config_file:
+        version_added: 5.1.0
+        description: Alternate SSH config file location
+        type: path
+        env:
+          - name: ANSIBLE_LIBSSH_CONFIG_FILE
+        ini:
+          - section: libssh_connection
+            key: config_file
+        vars:
+          - name: ansible_libssh_config_file
 # TODO:
 #timeout=self._play_context.timeout,
 """
+import logging
 import os
-import socket
 import re
-import sys
+import socket
 
-from termios import tcflush, TCIFLUSH
-
-from ansible.errors import (
-    AnsibleConnectionFailure,
-    AnsibleError,
-    AnsibleFileNotFound,
-)
-from ansible.module_utils.six.moves import input
-from ansible.plugins.connection import ConnectionBase
-from ansible.utils.display import Display
+from ansible.errors import AnsibleConnectionFailure, AnsibleError, AnsibleFileNotFound
 from ansible.module_utils._text import to_bytes, to_native, to_text
 from ansible.module_utils.basic import missing_required_lib
-import logging
+from ansible.plugins.connection import ConnectionBase
+from ansible.utils.display import Display
+
+from ansible_collections.ansible.netcommon.plugins.plugin_utils.version import Version
+
 
 display = Display()
 
 try:
+    from pylibsshext import __version__ as PYLIBSSH_VERSION
+    from pylibsshext.errors import LibsshSCPException, LibsshSessionException
     from pylibsshext.session import Session
-    from pylibsshext.errors import LibsshSessionException, LibsshSCPException
 
     HAS_PYLIBSSH = True
 except ImportError:
@@ -162,22 +258,17 @@ class MyAddPolicy(object):
     local L{HostKeys} object, and saving it.  This is used by L{SSHClient}.
     """
 
-    def __init__(self, new_stdin, connection):
-        self._new_stdin = new_stdin
+    def __init__(self, connection):
         self.connection = connection
         self._options = connection._options
 
-    def missing_host_key(
-        self, session, hostname, username, key_type, fingerprint, message
-    ):
-
+    def missing_host_key(self, session, hostname, username, key_type, fingerprint, message):
         if all(
             (
                 self._options["host_key_checking"],
                 not self._options["host_key_auto_add"],
             )
         ):
-
             if (
                 self.connection.get_option("use_persistent_connections")
                 or self.connection.force_persistence
@@ -185,21 +276,15 @@ class MyAddPolicy(object):
                 # don't print the prompt string since the user cannot respond
                 # to the question anyway
                 raise AnsibleError(
-                    AUTHENTICITY_MSG.rsplit("\n", 2)[0]
-                    % (hostname, message, key_type, fingerprint)
+                    AUTHENTICITY_MSG.rsplit("\n", 2)[0] % (hostname, message, key_type, fingerprint)
                 )
 
-            self.connection.connection_lock()
-            old_stdin = sys.stdin
-            sys.stdin = self._new_stdin
-
-            # clear out any premature input on sys.stdin
-            tcflush(sys.stdin, TCIFLUSH)
-
-            inp = input(
-                AUTHENTICITY_MSG % (hostname, message, key_type, fingerprint)
+            inp = to_text(
+                display.prompt_until(
+                    AUTHENTICITY_MSG % (hostname, message, key_type, fingerprint), private=False
+                ),
+                errors="surrogate_or_strict",
             )
-            sys.stdin = old_stdin
 
             self.connection.connection_unlock()
             if inp not in ["yes", "y", ""]:
@@ -233,9 +318,7 @@ class Connection(ConnectionBase):
         if cache_key in SSH_CONNECTION_CACHE:
             self.ssh = SSH_CONNECTION_CACHE[cache_key]
         else:
-            self.ssh = SSH_CONNECTION_CACHE[
-                cache_key
-            ] = self._connect_uncached()
+            self.ssh = SSH_CONNECTION_CACHE[cache_key] = self._connect_uncached()
         return self
 
     def _set_log_channel(self, name):
@@ -245,12 +328,15 @@ class Connection(ConnectionBase):
         proxy_command = None
         # Parse ansible_ssh_common_args, specifically looking for ProxyCommand
         ssh_args = [
-            getattr(self._play_context, "ssh_extra_args", "") or "",
-            getattr(self._play_context, "ssh_common_args", "") or "",
-            getattr(self._play_context, "ssh_args", "") or "",
+            self.get_option("ssh_extra_args") or "",
+            self.get_option("ssh_common_args") or "",
+            self.get_option("ssh_args") or "",
         ]
 
-        if ssh_args is not None:
+        if any(ssh_args):
+            display.warning(
+                "The ssh_*_args options are deprecated and will be removed in a release after 2026-01-01. Please use the proxy_command option instead."
+            )
             args = self._split_ssh_args(" ".join(ssh_args))
             for i, arg in enumerate(args):
                 if arg.lower() == "proxycommand":
@@ -284,23 +370,25 @@ class Connection(ConnectionBase):
 
         if not HAS_PYLIBSSH:
             raise AnsibleError(missing_required_lib("ansible-pylibssh"))
+        display.vvv(
+            "USING PYLIBSSH VERSION %s" % PYLIBSSH_VERSION,
+            host=self._play_context.remote_addr,
+        )
 
         ssh_connect_kwargs = {}
 
+        remote_user = self.get_option("remote_user")
+        remote_addr = self.get_option("remote_addr")
         port = self._play_context.port or 22
         display.vvv(
             "ESTABLISH LIBSSH CONNECTION FOR USER: %s on PORT %s TO %s"
-            % (
-                self._play_context.remote_user,
-                port,
-                self._play_context.remote_addr,
-            ),
-            host=self._play_context.remote_addr,
+            % (remote_user, port, remote_addr),
+            host=remote_addr,
         )
 
         self.ssh = Session()
 
-        if self._play_context.verbosity > 3:
+        if display.verbosity > 3:
             self.ssh.set_log_level(logging.INFO)
 
         self.keyfile = os.path.expanduser("~/.ssh/known_hosts")
@@ -310,31 +398,43 @@ class Connection(ConnectionBase):
         try:
             private_key = None
             if self._play_context.private_key_file:
-                with open(
-                    os.path.expanduser(self._play_context.private_key_file)
-                ) as fp:
+                with open(os.path.expanduser(self._play_context.private_key_file)) as fp:
                     b_content = fp.read()
-                    private_key = to_bytes(
-                        b_content, errors="surrogate_or_strict"
-                    )
+                    private_key = to_bytes(b_content, errors="surrogate_or_strict")
 
             if proxy_command:
                 ssh_connect_kwargs["proxycommand"] = proxy_command
 
-            self.ssh.set_missing_host_key_policy(
-                MyAddPolicy(self._new_stdin, self)
-            )
+            if self.get_option("config_file"):
+                ssh_connect_kwargs["config_file"] = self.get_option("config_file")
+
+            if self.get_option("password_prompt") and (Version(PYLIBSSH_VERSION) < "1.0.0"):
+                raise AnsibleError(
+                    "Configuring password prompt is not supported in ansible-pylibssh version %s. "
+                    "Please upgrade to ansible-pylibssh 1.0.0 or newer." % PYLIBSSH_VERSION
+                )
+
+            if self.get_option("publickey_accepted_algorithms"):
+                ssh_connect_kwargs["publickey_accepted_algorithms"] = self.get_option(
+                    "publickey_accepted_algorithms"
+                )
+
+            if self.get_option("hostkeys"):
+                ssh_connect_kwargs["hostkeys"] = self.get_option("hostkeys")
+
+            self.ssh.set_missing_host_key_policy(MyAddPolicy(self))
 
             self.ssh.connect(
-                host=self._play_context.remote_addr.lower(),
-                user=self._play_context.remote_user,
+                host=remote_addr.lower(),
+                user=remote_user,
                 look_for_keys=self.get_option("look_for_keys"),
                 host_key_checking=self.get_option("host_key_checking"),
-                password=self._play_context.password,
+                password=self.get_option("password"),
+                password_prompt=self.get_option("password_prompt"),
                 private_key=private_key,
                 timeout=self._play_context.timeout,
                 port=port,
-                **ssh_connect_kwargs
+                **ssh_connect_kwargs,
             )
         except LibsshSessionException as e:
             msg = "ssh connection failed: " + to_text(e)
@@ -348,9 +448,7 @@ class Connection(ConnectionBase):
     def exec_command(self, cmd, in_data=None, sudoable=True):
         """run a command on the remote host"""
 
-        super(Connection, self).exec_command(
-            cmd, in_data=in_data, sudoable=sudoable
-        )
+        super(Connection, self).exec_command(cmd, in_data=in_data, sudoable=sudoable)
 
         if in_data:
             raise AnsibleError(
@@ -405,9 +503,7 @@ class Connection(ConnectionBase):
                                     playcontext=self._play_context,
                                 )
                             )
-                            raise AnsibleError(
-                                "user %s does not exist" % n_become_user
-                            )
+                            raise AnsibleError("user %s does not exist" % n_become_user)
                         else:
                             break
                             # raise AnsibleError('ssh connection closed waiting for password prompt')
@@ -427,25 +523,17 @@ class Connection(ConnectionBase):
                             "become_pass", playcontext=self._play_context
                         )
                         self.chan.sendall(
-                            to_bytes(become_pass, errors="surrogate_or_strict")
-                            + b"\n"
+                            to_bytes(become_pass, errors="surrogate_or_strict") + b"\n"
                         )
                     else:
-                        raise AnsibleError(
-                            "A password is required but none was supplied"
-                        )
+                        raise AnsibleError("A password is required but none was supplied")
                 else:
                     no_prompt_out += become_output
                     no_prompt_err += become_output
             else:
-                result = self.chan.exec_command(
-                    to_text(cmd, errors="surrogate_or_strict")
-                )
+                result = self.chan.exec_command(to_text(cmd, errors="surrogate_or_strict"))
         except socket.timeout:
-            raise AnsibleError(
-                "ssh timed out waiting for privilege escalation.\n"
-                + become_output
-            )
+            raise AnsibleError("ssh timed out waiting for privilege escalation.\n" + become_output)
 
         if result:
             rc = result.returncode
@@ -466,9 +554,7 @@ class Connection(ConnectionBase):
         )
 
         if not os.path.exists(to_bytes(in_path, errors="surrogate_or_strict")):
-            raise AnsibleFileNotFound(
-                "file or module does not exist: %s" % in_path
-            )
+            raise AnsibleFileNotFound("file or module does not exist: %s" % in_path)
 
         if proto == "sftp":
             try:
@@ -488,14 +574,9 @@ class Connection(ConnectionBase):
             try:
                 scp.put(in_path, out_path)
             except LibsshSCPException as exc:
-                raise AnsibleError(
-                    "Error transferring file to %s: %s"
-                    % (out_path, to_text(exc))
-                )
+                raise AnsibleError("Error transferring file to %s: %s" % (out_path, to_text(exc)))
         else:
-            raise AnsibleError(
-                "Don't know how to transfer file over protocol %s" % proto
-            )
+            raise AnsibleError("Don't know how to transfer file over protocol %s" % proto)
 
     def _connect_sftp(self):
         cache_key = "%s__%s__" % (
@@ -505,9 +586,7 @@ class Connection(ConnectionBase):
         if cache_key in SFTP_CONNECTION_CACHE:
             return SFTP_CONNECTION_CACHE[cache_key]
         else:
-            result = SFTP_CONNECTION_CACHE[
-                cache_key
-            ] = self._connect().ssh.sftp()
+            result = SFTP_CONNECTION_CACHE[cache_key] = self._connect().ssh.sftp()
             return result
 
     def fetch_file(self, in_path, out_path, proto="sftp"):
@@ -524,9 +603,7 @@ class Connection(ConnectionBase):
             try:
                 self.sftp = self._connect_sftp()
             except Exception as e:
-                raise AnsibleError(
-                    "failed to open a SFTP connection (%s)" % to_native(e)
-                )
+                raise AnsibleError("failed to open a SFTP connection (%s)" % to_native(e))
 
             try:
                 self.sftp.get(
@@ -538,16 +615,14 @@ class Connection(ConnectionBase):
         elif proto == "scp":
             scp = self.ssh.scp()
             try:
-                scp.get(out_path, in_path)
+                # this abruptly closes the connection when
+                # scp.get fails only when the file is not there
+                # it works fine if the file is actually present
+                scp.get(in_path, out_path)
             except LibsshSCPException as exc:
-                raise AnsibleError(
-                    "Error transferring file from %s: %s"
-                    % (out_path, to_text(exc))
-                )
+                raise AnsibleError("Error transferring file from %s: %s" % (out_path, to_text(exc)))
         else:
-            raise AnsibleError(
-                "Don't know how to transfer file over protocol %s" % proto
-            )
+            raise AnsibleError("Don't know how to transfer file over protocol %s" % proto)
 
     def reset(self):
         self.close()
