@@ -14,15 +14,15 @@ def test_create_token(run_module, admin_user):
         'description': 'barfoo',
         'state': 'present',
         'scope': 'read',
-        'tower_host': None,
-        'tower_username': None,
-        'tower_password': None,
+        'controller_host': None,
+        'controller_username': None,
+        'controller_password': None,
         'validate_certs': None,
-        'tower_oauthtoken': None,
-        'tower_config_file': None,
+        'controller_oauthtoken': None,
+        'controller_config_file': None,
     }
 
-    result = run_module('tower_token', module_args, admin_user)
+    result = run_module('token', module_args, admin_user)
     assert result.get('changed'), result
 
     tokens = OAuth2AccessToken.objects.filter(description='barfoo')
