@@ -180,9 +180,6 @@ class AzureRMRoleDefinitionInfo(AzureRMModuleBase):
 
     def exec_module(self, **kwargs):
         """Main module execution method"""
-        is_old_facts = self.module._name == 'azure_rm_roledefinition_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_roledefinition_facts' module has been renamed to 'azure_rm_roledefinition_info'", version=(2.9, ))
 
         for key in list(self.module_arg_spec.keys()):
             if hasattr(self, key):
@@ -194,8 +191,7 @@ class AzureRMRoleDefinitionInfo(AzureRMModuleBase):
         # get management client
         self._client = self.get_mgmt_svc_client(AuthorizationManagementClient,
                                                 base_url=self._cloud_environment.endpoints.resource_manager,
-                                                is_track2=True,
-                                                api_version="2018-01-01-preview")
+                                                api_version="2022-04-01")
 
         if self.id:
             self.results['roledefinitions'] = self.get_by_id()
