@@ -21,13 +21,16 @@ options:
         description:
             - The name of the resource group.
         required: True
+        type: str
     virtual_network_name:
         description:
             - The name of the virtual network.
         required: True
+        type: str
     name:
         description:
             - The name of the subnet.
+        type: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -38,17 +41,17 @@ author:
 '''
 
 EXAMPLES = '''
-  - name: Get facts of specific subnet
-    azure_rm_subnet_info:
-      resource_group: myResourceGroup
-      virtual_network_name: myVirtualNetwork
-      name: mySubnet
+- name: Get facts of specific subnet
+  azure_rm_subnet_info:
+    resource_group: myResourceGroup
+    virtual_network_name: myVirtualNetwork
+    name: mySubnet
 
-  - name: List facts for all subnets in virtual network
-    azure_rm_subnet_info:
-      resource_group: myResourceGroup
-      virtual_network_name: myVirtualNetwork
-      name: mySubnet
+- name: List facts for all subnets in virtual network
+  azure_rm_subnet_info:
+    resource_group: myResourceGroup
+    virtual_network_name: myVirtualNetwork
+    name: mySubnet
 '''
 
 RETURN = '''
@@ -223,9 +226,6 @@ class AzureRMSubnetInfo(AzureRMModuleBase):
         super(AzureRMSubnetInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False)
 
     def exec_module(self, **kwargs):
-        is_old_facts = self.module._name == 'azure_rm_subnet_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_subnet_facts' module has been renamed to 'azure_rm_subnet_info'", version=(2.9, ))
 
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
@@ -257,15 +257,15 @@ class AzureRMSubnetInfo(AzureRMModuleBase):
         response = None
         results = []
         try:
-            response = self.network_client.subnets.get(resource_group_name=self.resource_group,
-                                                       virtual_network_name=self.virtual_network_name)
+            response = self.network_client.subnets.list(resource_group_name=self.resource_group,
+                                                        virtual_network_name=self.virtual_network_name)
             self.log("Response : {0}".format(response))
         except ResourceNotFoundError as e:
             self.fail('Could not get facts for Subnet.')
 
         if response is not None:
             for item in response:
-                results.append(self.format_item(item))
+                results.append(self.format_response(item))
 
         return results
 
