@@ -1,17 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: application_sets
 short_description: Resource module for Application Sets
 description:
-- Manage operations create and delete of the resource Application Sets.
-- Create new custom application-set/s.
-- Delete existing application-set by it's id.
+  - This module represents an alias of the module application_sets_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -29,26 +25,22 @@ options:
         type: str
     type: list
 requirements:
-- dnacentersdk >= 2.7.1
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Application Policy CreateApplicationSet
-  description: Complete reference of the CreateApplicationSet API.
-  link: https://developer.cisco.com/docs/dna-center/#!create-application-set
-- name: Cisco DNA Center documentation for Application Policy DeleteApplicationSet2
-  description: Complete reference of the DeleteApplicationSet2 API.
-  link: https://developer.cisco.com/docs/dna-center/#!delete-application-set-2
+  - name: Cisco DNA Center documentation for Application Policy CreateApplicationSetV1
+    description: Complete reference of the CreateApplicationSetV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!create-application-set
+  - name: Cisco DNA Center documentation for Application Policy DeleteApplicationSetV1
+    description: Complete reference of the DeleteApplicationSetV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!delete-application-set
 notes:
-  - SDK Method used are
-    application_policy.ApplicationPolicy.create_application_set,
-    application_policy.ApplicationPolicy.delete_application_set2,
-
-  - Paths used are
-    post /dna/intent/api/v1/application-policy-application-set,
-    delete /dna/intent/api/v1/application-policy-application-set,
-
+  - SDK Method used are application_policy.ApplicationPolicy.create_application_set_v1,
+    application_policy.ApplicationPolicy.delete_application_set_v1,
+  - Paths used are post /dna/intent/api/v1/application-policy-application-set, delete
+    /dna/intent/api/v1/application-policy-application-set,
+  - It should be noted that this module is an alias of application_sets_v1
 """
-
 EXAMPLES = r"""
 - name: Delete all
   cisco.dnac.application_sets:
@@ -61,7 +53,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     id: string
-
 - name: Create
   cisco.dnac.application_sets:
     dnac_host: "{{dnac_host}}"
@@ -73,8 +64,7 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: present
     payload:
-    - name: string
-
+      - name: string
 """
 RETURN = r"""
 dnac_response:
