@@ -1,25 +1,18 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: business_sda_hostonboarding_ssid_ippool
 short_description: Resource module for Business Sda Hostonboarding Ssid Ippool
 description:
-- Manage operations create and update of the resource Business Sda Hostonboarding Ssid Ippool.
-- Add SSID to IP Pool Mapping.
-- Update SSID to IP Pool Mapping.
+  - This module represents an alias of the module business_sda_hostonboarding_ssid_ippool_v1
 version_added: '4.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
-  headers:
-    description: Additional headers.
-    type: dict
   scalableGroupName:
     description: Scalable Group Name.
     type: str
@@ -34,26 +27,22 @@ options:
     description: VLAN Name.
     type: str
 requirements:
-- dnacentersdk >= 2.5.5
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Fabric Wireless AddSSIDToIPPoolMapping
-  description: Complete reference of the AddSSIDToIPPoolMapping API.
-  link: https://developer.cisco.com/docs/dna-center/#!add-ssid-to-ip-pool-mapping
-- name: Cisco DNA Center documentation for Fabric Wireless UpdateSSIDToIPPoolMapping
-  description: Complete reference of the UpdateSSIDToIPPoolMapping API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-ssid-to-ip-pool-mapping
+  - name: Cisco DNA Center documentation for Fabric Wireless AddSSIDToIPPoolMappingV1
+    description: Complete reference of the AddSSIDToIPPoolMappingV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!add-ssid-to-ip-pool-mapping
+  - name: Cisco DNA Center documentation for Fabric Wireless UpdateSSIDToIPPoolMappingV1
+    description: Complete reference of the UpdateSSIDToIPPoolMappingV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!update-ssid-to-ip-pool-mapping
 notes:
-  - SDK Method used are
-    fabric_wireless.FabricWireless.add_ssid_to_ip_pool_mapping,
-    fabric_wireless.FabricWireless.update_ssid_to_ip_pool_mapping,
-
-  - Paths used are
-    post /dna/intent/api/v1/business/sda/hostonboarding/ssid-ippool,
+  - SDK Method used are fabric_wireless.FabricWireless.add_ssid_to_ip_pool_mapping_v1,
+    fabric_wireless.FabricWireless.update_ssid_to_ip_pool_mapping_v1,
+  - Paths used are post /dna/intent/api/v1/business/sda/hostonboarding/ssid-ippool,
     put /dna/intent/api/v1/business/sda/hostonboarding/ssid-ippool,
-
+  - It should be noted that this module is an alias of business_sda_hostonboarding_ssid_ippool_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.business_sda_hostonboarding_ssid_ippool:
@@ -65,13 +54,11 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     state: present
-    headers: '{{my_headers | from_json}}'
     scalableGroupName: string
     siteNameHierarchy: string
     ssidNames:
-    - string
+      - string
     vlanName: string
-
 - name: Update all
   cisco.dnac.business_sda_hostonboarding_ssid_ippool:
     dnac_host: "{{dnac_host}}"
@@ -85,22 +72,18 @@ EXAMPLES = r"""
     scalableGroupName: string
     siteNameHierarchy: string
     ssidNames:
-    - string
+      - string
     vlanName: string
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
   returned: always
-  type: list
+  type: dict
   sample: >
-    [
-      {
-        "executionId": "string",
-        "executionStatusURL": "string",
-        "message": "string"
-      }
-    ]
+    {
+      "executionId": "string",
+      "executionStatusUrl": "string",
+      "message": "string"
+    }
 """
