@@ -1,70 +1,60 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: cli_credential
 short_description: Resource module for Cli Credential
 description:
-- Manage operations create and update of the resource Cli Credential.
-- Adds global CLI credential.
-- Updates global CLI credentials.
+  - This module represents an alias of the module cli_credential_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   comments:
-    description: Cli Credential's comments.
+    description: Comments to identify the CLI credential.
     type: str
   credentialType:
-    description: Cli Credential's credentialType.
+    description: Credential type to identify the application that uses the CLI credential.
     type: str
   description:
-    description: Cli Credential's description.
+    description: Description for CLI Credentials.
     type: str
   enablePassword:
-    description: Cli Credential's enablePassword.
+    description: CLI Enable Password.
     type: str
   id:
-    description: Cli Credential's id.
+    description: Id of the CLI Credential in UUID format.
     type: str
   instanceTenantId:
-    description: Cli Credential's instanceTenantId.
+    description: Deprecated.
     type: str
   instanceUuid:
-    description: Cli Credential's instanceUuid.
+    description: Deprecated.
     type: str
   password:
-    description: Cli Credential's password.
+    description: CLI Password.
     type: str
   username:
-    description: Cli Credential's username.
+    description: CLI Username.
     type: str
 requirements:
-- dnacentersdk >= 2.5.0
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Discovery CreateCLICredentials
-  description: Complete reference of the CreateCLICredentials API.
-  link: https://developer.cisco.com/docs/dna-center/#!create-cli-credentials
-- name: Cisco DNA Center documentation for Discovery UpdateCLICredentials
-  description: Complete reference of the UpdateCLICredentials API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-cli-credentials
+  - name: Cisco DNA Center documentation for Discovery CreateCLICredentialsV1
+    description: Complete reference of the CreateCLICredentialsV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!create-cli-credentials
+  - name: Cisco DNA Center documentation for Discovery UpdateCLICredentialsV1
+    description: Complete reference of the UpdateCLICredentialsV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!update-cli-credentials
 notes:
-  - SDK Method used are
-    discovery.Discovery.create_cli_credentials,
-    discovery.Discovery.update_cli_credentials,
-
-  - Paths used are
-    post /dna/intent/api/v1/global-credential/cli,
-    put /dna/intent/api/v1/global-credential/cli,
-
+  - SDK Method used are discovery.Discovery.create_cli_credentials_v1, discovery.Discovery.update_cli_credentials_v1,
+  - Paths used are post /dna/intent/api/v1/global-credential/cli, put /dna/intent/api/v1/global-credential/cli,
+  - It should be noted that this module is an alias of cli_credential_v1
 """
-
 EXAMPLES = r"""
 - name: Update all
   cisco.dnac.cli_credential:
@@ -85,7 +75,6 @@ EXAMPLES = r"""
     instanceUuid: string
     password: string
     username: string
-
 - name: Create
   cisco.dnac.cli_credential:
     dnac_host: "{{dnac_host}}"
@@ -105,9 +94,7 @@ EXAMPLES = r"""
     instanceUuid: string
     password: string
     username: string
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
