@@ -1,18 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: device_enrichment_details_info
-short_description: Information module for Device Enrichment Details
+short_description: Information module for Device Enrichment Details Info
 description:
-- Get all Device Enrichment Details.
-- >
-   Enriches a given network device context device id or device Mac Address or device management IP address with
-   details about the device and neighbor topology.
+  - This module represents an alias of the module device_enrichment_details_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -22,23 +17,19 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.5.5
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices GetDeviceEnrichmentDetails
-  description: Complete reference of the GetDeviceEnrichmentDetails API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-device-enrichment-details
+  - name: Cisco DNA Center documentation for Devices GetDeviceEnrichmentDetailsV1
+    description: Complete reference of the GetDeviceEnrichmentDetailsV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-device-enrichment-details
 notes:
-  - SDK Method used are
-    devices.Devices.get_device_enrichment_details,
-
-  - Paths used are
-    get /dna/intent/api/v1/device-enrichment-details,
-
+  - SDK Method used are devices.Devices.get_device_enrichment_details_v1,
+  - Paths used are get /dna/intent/api/v1/device-enrichment-details,
+  - It should be noted that this module is an alias of device_enrichment_details_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Device Enrichment Details
+- name: Get all Device Enrichment Details Info
   cisco.dnac.device_enrichment_details_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -49,9 +40,7 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
