@@ -1,45 +1,36 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: device_replacement_deploy
 short_description: Resource module for Device Replacement Deploy
 description:
-- Manage operation create of the resource Device Replacement Deploy.
-- >
-   API to trigger RMA workflow that will replace faulty device with replacement device with same configuration and
-   images.
+  - This module represents an alias of the module device_replacement_deploy_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   faultyDeviceSerialNumber:
-    description: Device Replacement Deploy's faultyDeviceSerialNumber.
+    description: Faulty device serial number.
     type: str
   replacementDeviceSerialNumber:
-    description: Device Replacement Deploy's replacementDeviceSerialNumber.
+    description: Replacement device serial number.
     type: str
 requirements:
-- dnacentersdk >= 2.6.0
-- python >= 3.9
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Device Replacement DeployDeviceReplacementWorkflow
-  description: Complete reference of the DeployDeviceReplacementWorkflow API.
-  link: https://developer.cisco.com/docs/dna-center/#!deploy-device-replacement-workflow
+  - name: Cisco DNA Center documentation for Device Replacement DeployDeviceReplacementWorkflowV1
+    description: Complete reference of the DeployDeviceReplacementWorkflowV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!deploy-device-replacement-workflow
 notes:
-  - SDK Method used are
-    device_replacement.DeviceReplacement.deploy_device_replacement_workflow,
-
-  - Paths used are
-    post /dna/intent/api/v1/device-replacement/workflow,
-
+  - SDK Method used are device_replacement.DeviceReplacement.deploy_device_replacement_workflow_v1,
+  - Paths used are post /dna/intent/api/v1/device-replacement/workflow,
+  - It should be noted that this module is an alias of device_replacement_deploy_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.device_replacement_deploy:
@@ -52,9 +43,7 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     faultyDeviceSerialNumber: string
     replacementDeviceSerialNumber: string
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
