@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
-
 DOCUMENTATION = r"""
 ---
 module: dnacaap_management_execution_status_info
 short_description: Information module for Dnacaap Management Execution Status Info
 description:
-- This module represents an alias of the module dnacaap_management_execution_status_v1_info
+  - This module represents an alias of the module dnacaap_management_execution_status_v1_info
 version_added: '4.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,25 +18,20 @@ options:
     type: dict
   executionId:
     description:
-    - ExecutionId path parameter. Execution Id of API.
+      - ExecutionId path parameter. Execution Id of API.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Task GetBusinessAPIExecutionDetailsV1
-  description: Complete reference of the GetBusinessAPIExecutionDetailsV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-business-api-execution-details
+  - name: Cisco DNA Center documentation for Task GetBusinessAPIExecutionDetailsV1
+    description: Complete reference of the GetBusinessAPIExecutionDetailsV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-business-api-execution-details
 notes:
-  - SDK Method used are
-    task.Task.get_business_api_execution_details_v1,
-
-  - Paths used are
-    get /dna/intent/api/v1/dnacaap/management/execution-status/{executionId},
+  - SDK Method used are task.Task.get_business_api_execution_details_v1,
+  - Paths used are get /dna/intent/api/v1/dnacaap/management/execution-status/{executionId},
   - It should be noted that this module is an alias of dnacaap_management_execution_status_v1_info
-
 """
-
 EXAMPLES = r"""
 - name: Get Dnacaap Management Execution Status Info by id
   cisco.dnac.dnacaap_management_execution_status_info:
@@ -53,7 +45,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     executionId: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
@@ -71,6 +62,8 @@ dnac_response:
       "endTimeEpoch": 0,
       "timeDuration": 0,
       "status": "string",
+      "bapiSyncResponse": "string",
+      "bapiSyncResponseJson": {},
       "runtimeInstanceId": "string",
       "bapiError": "string"
     }
