@@ -1,18 +1,14 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: endpoint_analytics_profiling_rules
 short_description: Resource module for Endpoint Analytics Profiling Rules
 description:
-- Manage operations create, update and delete of the resource Endpoint Analytics Profiling Rules.
-- Creates profiling rule from the request body.
-- Deletes the profiling rule for the given 'ruleId'.
-version_added: '4.0.0'
+  - This module represents an alias of the module endpoint_analytics_profiling_rules_v1
+version_added: '6.16.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
@@ -41,7 +37,7 @@ options:
         type: dict
       conditionGroup:
         description: Endpoint Analytics Profiling Rules's conditionGroup.
-        elements: dict
+        elements: str
         type: list
       operator:
         description: Endpoint Analytics Profiling Rules's operator.
@@ -54,8 +50,8 @@ options:
     description: Flag to indicate whether the rule was deleted.
     type: bool
   lastModifiedBy:
-    description: User that last modified the rule. It is read-only, and is ignored if
-      provided as part of input request.
+    description: User that last modified the rule. It is read-only, and is ignored
+      if provided as part of input request.
     type: str
   lastModifiedOn:
     description: Timestamp (in epoch milliseconds) of last modification. It is read-only,
@@ -89,8 +85,9 @@ options:
         type: list
     type: dict
   ruleId:
-    description: Unique identifier for the rule. This is normally generated by the system,
-      and client does not need to provide it for rules that need to be newly created.
+    description: Unique identifier for the rule. This is normally generated by the
+      system, and client does not need to provide it for rules that need to be newly
+      created.
     type: str
   ruleName:
     description: Human readable name for the rule.
@@ -99,8 +96,7 @@ options:
     description: Priority for the rule.
     type: int
   ruleType:
-    description: Type of the rule. Allowed values are 'Cisco Default - Static', 'Cisco
-      Default - Dynamic', 'Custom Rule', 'ML Rule'.
+    description: Type of the rule.
     type: str
   ruleVersion:
     description: Version of the rule.
@@ -114,20 +110,16 @@ options:
     elements: str
     type: list
 requirements:
-- dnacentersdk >= 2.6.0
-- python >= 3.9
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 notes:
-  - SDK Method used are
-    policy.Policy.create_a_profiling_rule,
-    policy.Policy.delete_an_existing_profiling_rule,
-    policy.Policy.update_an_existing_profiling_rule,
-
-  - Paths used are
-    post /dna/intent/api/v1/endpoint-analytics/profiling-rules,
-    delete /dna/intent/api/v1/endpoint-analytics/profiling-rules/{ruleId},
-
+  - SDK Method used are a_i_endpoint_analytics.AIEndpointAnalytics.create_a_profiling_rule_v1,
+    a_i_endpoint_analytics.AIEndpointAnalytics.delete_an_existing_profiling_rule_v1,
+    a_i_endpoint_analytics.AIEndpointAnalytics.update_an_existing_profiling_rule_v1,
+  - Paths used are post /dna/intent/api/v1/endpoint-analytics/profiling-rules, delete
+    /dna/intent/api/v1/endpoint-analytics/profiling-rules/{ruleId}, put /dna/intent/api/v1/endpoint-analytics/profiling-rules/{ruleId},
+  - It should be noted that this module is an alias of endpoint_analytics_profiling_rules_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.endpoint_analytics_profiling_rules:
@@ -147,7 +139,7 @@ EXAMPLES = r"""
         operator: string
         value: string
       conditionGroup:
-      - {}
+        - string
       operator: string
       type: string
     isDeleted: true
@@ -157,13 +149,13 @@ EXAMPLES = r"""
     rejected: true
     result:
       deviceType:
-      - string
+        - string
       hardwareManufacturer:
-      - string
+        - string
       hardwareModel:
-      - string
+        - string
       operatingSystem:
-      - string
+        - string
     ruleId: string
     ruleName: string
     rulePriority: 0
@@ -171,8 +163,7 @@ EXAMPLES = r"""
     ruleVersion: 0
     sourcePriority: 0
     usedAttributes:
-    - string
-
+      - string
 - name: Update by id
   cisco.dnac.endpoint_analytics_profiling_rules:
     dnac_host: "{{dnac_host}}"
@@ -191,7 +182,7 @@ EXAMPLES = r"""
         operator: string
         value: string
       conditionGroup:
-      - {}
+        - string
       operator: string
       type: string
     isDeleted: true
@@ -201,13 +192,13 @@ EXAMPLES = r"""
     rejected: true
     result:
       deviceType:
-      - string
+        - string
       hardwareManufacturer:
-      - string
+        - string
       hardwareModel:
-      - string
+        - string
       operatingSystem:
-      - string
+        - string
     ruleId: string
     ruleName: string
     rulePriority: 0
@@ -215,8 +206,7 @@ EXAMPLES = r"""
     ruleVersion: 0
     sourcePriority: 0
     usedAttributes:
-    - string
-
+      - string
 - name: Delete by id
   cisco.dnac.endpoint_analytics_profiling_rules:
     dnac_host: "{{dnac_host}}"
@@ -228,9 +218,7 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     ruleId: string
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
