@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: event_artifact_count_info
-short_description: Information module for Event Artifact Count
+short_description: Information module for Event Artifact Count Info
 description:
-- Get all Event Artifact Count.
-- Get the count of registered event artifacts.
+  - This module represents an alias of the module event_artifact_count_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -20,23 +17,19 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.7.1
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Event Management EventArtifactCount
-  description: Complete reference of the EventArtifactCount API.
-  link: https://developer.cisco.com/docs/dna-center/#!event-artifact-count
+  - name: Cisco DNA Center documentation for Event Management EventArtifactCountV1
+    description: Complete reference of the EventArtifactCountV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!event-artifact-count
 notes:
-  - SDK Method used are
-    event_management.EventManagement.eventartifact_count,
-
-  - Paths used are
-    get /dna/system/api/v1/event/artifact/count,
-
+  - SDK Method used are event_management.EventManagement.eventartifact_count,
+  - Paths used are get /dna/system/api/v1/event/artifact/count,
+  - It should be noted that this module is an alias of event_artifact_count_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Event Artifact Count
+- name: Get all Event Artifact Count Info
   cisco.dnac.event_artifact_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -47,7 +40,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
   register: result
-
 """
 RETURN = r"""
 dnac_response:
