@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: event_series_count_info
-short_description: Information module for Event Series Count
+short_description: Information module for Event Series Count Info
 description:
-- Get all Event Series Count.
-- Get the Count of Published Notifications.
+  - This module represents an alias of the module event_series_count_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,58 +18,54 @@ options:
     type: dict
   eventIds:
     description:
-    - EventIds query parameter. The registered EventId should be provided.
+      - EventIds query parameter. The registered EventId should be provided.
     type: str
   startTime:
     description:
-    - StartTime query parameter. Start Time in milliseconds.
-    type: int
+      - StartTime query parameter. Start Time in milliseconds.
+    type: float
   endTime:
     description:
-    - EndTime query parameter. End Time in milliseconds.
-    type: int
+      - EndTime query parameter. End Time in milliseconds.
+    type: float
   category:
     description:
-    - Category query parameter.
+      - Category query parameter.
     type: str
   type:
     description:
-    - Type query parameter.
+      - Type query parameter.
     type: str
   severity:
     description:
-    - Severity query parameter.
+      - Severity query parameter.
     type: str
   domain:
     description:
-    - Domain query parameter.
+      - Domain query parameter.
     type: str
   subDomain:
     description:
-    - SubDomain query parameter. Sub Domain.
+      - SubDomain query parameter. Sub Domain.
     type: str
   source:
     description:
-    - Source query parameter.
+      - Source query parameter.
     type: str
 requirements:
-- dnacentersdk >= 2.5.0
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Event Management CountOfNotifications
-  description: Complete reference of the CountOfNotifications API.
-  link: https://developer.cisco.com/docs/dna-center/#!count-of-notifications
+  - name: Cisco DNA Center documentation for Event Management CountOfNotificationsV1
+    description: Complete reference of the CountOfNotificationsV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!count-of-notifications
 notes:
-  - SDK Method used are
-    event_management.EventManagement.count_of_notifications,
-
-  - Paths used are
-    get /dna/intent/api/v1/event/event-series/count,
-
+  - SDK Method used are event_management.EventManagement.count_of_notifications_v1,
+  - Paths used are get /dna/intent/api/v1/event/event-series/count,
+  - It should be noted that this module is an alias of event_series_count_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Event Series Count
+- name: Get all Event Series Count Info
   cisco.dnac.event_series_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -92,9 +85,7 @@ EXAMPLES = r"""
     subDomain: string
     source: string
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
