@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: global_credential_delete
 short_description: Resource module for Global Credential Delete
 description:
-- Manage operation delete of the resource Global Credential Delete.
-- Deletes global credential for the given ID.
+  - This module represents an alias of the module global_credential_delete_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -20,21 +17,17 @@ options:
     description: GlobalCredentialId path parameter. ID of global-credential.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Discovery DeleteGlobalCredentialsById
-  description: Complete reference of the DeleteGlobalCredentialsById API.
-  link: https://developer.cisco.com/docs/dna-center/#!delete-global-credentials-by-id
+  - name: Cisco DNA Center documentation for Discovery DeleteGlobalCredentialsByIdV1
+    description: Complete reference of the DeleteGlobalCredentialsByIdV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!delete-global-credentials-by-id
 notes:
-  - SDK Method used are
-    discovery.Discovery.delete_global_credentials_by_id,
-
-  - Paths used are
-    delete /dna/intent/api/v1/global-credential/{globalCredentialId},
-
+  - SDK Method used are discovery.Discovery.delete_global_credentials_by_id_v1,
+  - Paths used are delete /dna/intent/api/v1/global-credential/{globalCredentialId},
+  - It should be noted that this module is an alias of global_credential_delete_v1
 """
-
 EXAMPLES = r"""
 - name: Delete by id
   cisco.dnac.global_credential_delete:
@@ -46,7 +39,6 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     globalCredentialId: string
-
 """
 RETURN = r"""
 dnac_response:
