@@ -1,18 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: issues_info
-short_description: Information module for Issues
+short_description: Information module for Issues Info
 description:
-- Get all Issues.
-- >
-   Intent API to get a list of global issues, issues for a specific device, or issue for a specific client device's
-   MAC address.
+  - This module represents an alias of the module issues_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -23,58 +18,60 @@ options:
     type: dict
   startTime:
     description:
-    - StartTime query parameter. Starting epoch time in milliseconds of query time window.
+      - StartTime query parameter. Starting epoch time in milliseconds of query time
+        window.
     type: float
   endTime:
     description:
-    - EndTime query parameter. Ending epoch time in milliseconds of query time window.
+      - EndTime query parameter. Ending epoch time in milliseconds of query time window.
     type: float
   siteId:
     description:
-    - SiteId query parameter. Assurance UUID value of the site in the issue content.
+      - SiteId query parameter. Assurance UUID value of the site in the issue content.
     type: str
   deviceId:
     description:
-    - DeviceId query parameter. Assurance UUID value of the device in the issue content.
+      - DeviceId query parameter. Assurance UUID value of the device in the issue
+        content.
     type: str
   macAddress:
     description:
-    - MacAddress query parameter. Client's device MAC address of the issue (format xx xx xx xx xx xx).
+      - MacAddress query parameter. Client's device MAC address of the issue (format
+        xx xx xx xx xx xx).
     type: str
   priority:
     description:
-    - >
-      Priority query parameter. The issue's priority value P1, P2, P3, or P4 (case insensitive) (Use only when
-      macAddress and deviceId are not provided).
+      - >
+        Priority query parameter. The issue's priority value P1, P2, P3, or P4 (case
+        insensitive) (Use only when
+        macAddress and deviceId are not provided).
     type: str
   issueStatus:
     description:
-    - IssueStatus query parameter. The issue's status value ACTIVE, IGNORED, RESOLVED (case insensitive).
+      - IssueStatus query parameter. The issue's status value ACTIVE, IGNORED, RESOLVED
+        (case insensitive).
     type: str
   aiDriven:
     description:
-    - >
-      AiDriven query parameter. The issue's AI driven value YES or NO (case insensitive) (Use only when macAddress
-      and deviceId are not provided).
+      - >
+        AiDriven query parameter. The issue's AI driven value YES or NO (case insensitive)
+        (Use only when macAddress
+        and deviceId are not provided).
     type: str
 requirements:
-- dnacentersdk >= 2.7.1
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Issues Issues
-  description: Complete reference of the Issues API.
-  link: https://developer.cisco.com/docs/dna-center/#!issues-issues
+  - name: Cisco DNA Center documentation for Issues IssuesV1
+    description: Complete reference of the IssuesV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!issues
 notes:
-  - SDK Method used are
-    issues.Issues.issues,
-
-  - Paths used are
-    get /dna/intent/api/v1/issues,
-
+  - SDK Method used are issues.Issues.issues_v1,
+  - Paths used are get /dna/intent/api/v1/issues,
+  - It should be noted that this module is an alias of issues_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Issues
+- name: Get all Issues Info
   cisco.dnac.issues_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -93,7 +90,6 @@ EXAMPLES = r"""
     issueStatus: string
     aiDriven: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
