@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: license_virtual_account_details_info
-short_description: Information module for License Virtual Account Details
+short_description: Information module for License Virtual Account Details Info
 description:
-- Get all License Virtual Account Details.
-- Get virtual account details of a smart account.
+  - This module represents an alias of the module license_virtual_account_details_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,26 +18,22 @@ options:
     type: dict
   smart_account_id:
     description:
-    - Smart_account_id path parameter. Id of smart account.
+      - Smart_account_id path parameter. Id of smart account.
     type: str
 requirements:
-- dnacentersdk >= 2.5.5
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Licenses VirtualAccountDetails
-  description: Complete reference of the VirtualAccountDetails API.
-  link: https://developer.cisco.com/docs/dna-center/#!virtual-account-details
+  - name: Cisco DNA Center documentation for Licenses VirtualAccountDetailsV1
+    description: Complete reference of the VirtualAccountDetailsV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!virtual-account-details
 notes:
-  - SDK Method used are
-    licenses.Licenses.virtual_account_details,
-
-  - Paths used are
-    get /dna/intent/api/v1/licenses/smartAccount/{smart_account_id}/virtualAccounts,
-
+  - SDK Method used are licenses.Licenses.virtual_account_details_v1,
+  - Paths used are get /dna/intent/api/v1/licenses/smartAccount/{smart_account_id}/virtualAccounts,
+  - It should be noted that this module is an alias of license_virtual_account_details_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all License Virtual Account Details
+- name: Get all License Virtual Account Details Info
   cisco.dnac.license_virtual_account_details_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -52,9 +45,7 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     smart_account_id: string
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
