@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: network_device_config_task_info
-short_description: Information module for Network Device Config Task
+short_description: Information module for Network Device Config Task Info
 description:
-- Get all Network Device Config Task.
-- Returns a config task result details by specified id.
+  - This module represents an alias of the module network_device_config_task_v1_info
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,26 +18,22 @@ options:
     type: dict
   parentTaskId:
     description:
-    - ParentTaskId query parameter. Task Id.
+      - ParentTaskId query parameter. Task Id.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Configuration Archive GetConfigTaskDetails
-  description: Complete reference of the GetConfigTaskDetails API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-config-task-details
+  - name: Cisco DNA Center documentation for Configuration Archive GetConfigTaskDetailsV1
+    description: Complete reference of the GetConfigTaskDetailsV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-config-task-details
 notes:
-  - SDK Method used are
-    configuration_archive.ConfigurationArchive.get_config_task_details,
-
-  - Paths used are
-    get /dna/intent/api/v1/network-device-config/task,
-
+  - SDK Method used are configuration_archive.ConfigurationArchive.get_config_task_details_v1,
+  - Paths used are get /dna/intent/api/v1/network-device-config/task,
+  - It should be noted that this module is an alias of network_device_config_task_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Network Device Config Task
+- name: Get all Network Device Config Task Info
   cisco.dnac.network_device_config_task_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -52,7 +45,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     parentTaskId: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
