@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: network_device_summary_info
-short_description: Information module for Network Device Summary
+short_description: Information module for Network Device Summary Info
 description:
-- Get all Network Device Summary.
-- Returns brief summary of device info such as hostname, management IP address for the given device Id.
+  - This module represents an alias of the module network_device_summary_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,26 +18,22 @@ options:
     type: dict
   id:
     description:
-    - Id path parameter. Device ID.
+      - Id path parameter. Device ID.
     type: str
 requirements:
-- dnacentersdk >= 2.5.4
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices GetDeviceSummary
-  description: Complete reference of the GetDeviceSummary API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-device-summary
+  - name: Cisco DNA Center documentation for Devices GetDeviceSummaryV1
+    description: Complete reference of the GetDeviceSummaryV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-device-summary
 notes:
-  - SDK Method used are
-    devices.Devices.get_device_summary,
-
-  - Paths used are
-    get /dna/intent/api/v1/network-device/{id}/brief,
-
+  - SDK Method used are devices.Devices.get_device_summary_v1,
+  - Paths used are get /dna/intent/api/v1/network-device/{id}/brief,
+  - It should be noted that this module is an alias of network_device_summary_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Network Device Summary
+- name: Get all Network Device Summary Info
   cisco.dnac.network_device_summary_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -52,9 +45,7 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     id: string
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
