@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: pnp_device_unclaim
 short_description: Resource module for Pnp Device Unclaim
 description:
-- Manage operation create of the resource Pnp Device Unclaim.
-- Un-Claims one of more devices with specified workflow.
+  - This module represents an alias of the module pnp_device_unclaim_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -21,21 +18,17 @@ options:
     elements: str
     type: list
 requirements:
-- dnacentersdk >= 2.6.0
-- python >= 3.9
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Device Onboarding (PnP) UnClaimDevice
-  description: Complete reference of the UnClaimDevice API.
-  link: https://developer.cisco.com/docs/dna-center/#!un-claim-device
+  - name: Cisco DNA Center documentation for Device Onboarding (PnP) UnClaimDeviceV1
+    description: Complete reference of the UnClaimDeviceV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!un-claim-device
 notes:
-  - SDK Method used are
-    device_onboarding_pnp.DeviceOnboardingPnp.un_claim_device,
-
-  - Paths used are
-    post /dna/intent/api/v1/onboarding/pnp-device/unclaim,
-
+  - SDK Method used are device_onboarding_pnp.DeviceOnboardingPnp.un_claim_device_v1,
+  - Paths used are post /dna/intent/api/v1/onboarding/pnp-device/unclaim,
+  - It should be noted that this module is an alias of pnp_device_unclaim_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.pnp_device_unclaim:
@@ -47,10 +40,8 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     deviceIdList:
-    - string
-
+      - string
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
