@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
-
 DOCUMENTATION = r"""
 ---
 module: pnp_virtual_account_sync_result_info
 short_description: Information module for Pnp Virtual Account Sync Result Info
 description:
-- This module represents an alias of the module pnp_virtual_account_sync_result_v1_info
+  - This module represents an alias of the module pnp_virtual_account_sync_result_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,29 +18,27 @@ options:
     type: dict
   domain:
     description:
-    - Domain path parameter. Smart Account Domain.
+      - Domain path parameter. Smart Account Domain.
     type: str
   name:
     description:
-    - Name path parameter. Virtual Account Name.
+      - Name path parameter. Virtual Account Name.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Device Onboarding (PnP) GetSyncResultForVirtualAccountV1
-  description: Complete reference of the GetSyncResultForVirtualAccountV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-sync-result-for-virtual-account
+  - name: Cisco DNA Center documentation for Device Onboarding (PnP) GetSyncResultForVirtualAccountV1
+    description: Complete reference of the GetSyncResultForVirtualAccountV1 API.
+    link:
+      https://developer.cisco.com/docs/dna-center/#!get-sync-result-for-virtual-account
 notes:
   - SDK Method used are
     device_onboarding_pnp.DeviceOnboardingPnp.get_sync_result_for_virtual_account_v1,
-
-  - Paths used are
-    get /dna/intent/api/v1/onboarding/pnp-device/sacct/{domain}/vacct/{name}/sync-result,
+  - Paths used are get
+    /dna/intent/api/v1/onboarding/pnp-device/sacct/{domain}/vacct/{name}/sync-result,
   - It should be noted that this module is an alias of pnp_virtual_account_sync_result_v1_info
-
 """
-
 EXAMPLES = r"""
 - name: Get all Pnp Virtual Account Sync Result Info
   cisco.dnac.pnp_virtual_account_sync_result_info:
@@ -58,7 +53,6 @@ EXAMPLES = r"""
     domain: string
     name: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
