@@ -1,18 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: pnp_workflow
 short_description: Resource module for Pnp Workflow
 description:
-- Manage operations create, update and delete of the resource Pnp Workflow.
-- Adds a PnP Workflow along with the relevant tasks in the workflow into the PnP database.
-- Deletes a workflow specified by id.
-- Updates an existing workflow.
+  - This module represents an alias of the module pnp_workflow_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -128,31 +123,25 @@ options:
     description: Pnp Workflow's version.
     type: int
 requirements:
-- dnacentersdk >= 2.5.0
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Device Onboarding (PnP) AddAWorkflow
-  description: Complete reference of the AddAWorkflow API.
-  link: https://developer.cisco.com/docs/dna-center/#!add-a-workflow
-- name: Cisco DNA Center documentation for Device Onboarding (PnP) DeleteWorkflowById
-  description: Complete reference of the DeleteWorkflowById API.
-  link: https://developer.cisco.com/docs/dna-center/#!delete-workflow-by-id
-- name: Cisco DNA Center documentation for Device Onboarding (PnP) UpdateWorkflow
-  description: Complete reference of the UpdateWorkflow API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-workflow
+  - name: Cisco DNA Center documentation for Device Onboarding (PnP) AddAWorkflowV1
+    description: Complete reference of the AddAWorkflowV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!add-a-workflow
+  - name: Cisco DNA Center documentation for Device Onboarding (PnP) DeleteWorkflowByIdV1
+    description: Complete reference of the DeleteWorkflowByIdV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!delete-workflow-by-id
+  - name: Cisco DNA Center documentation for Device Onboarding (PnP) UpdateWorkflowV1
+    description: Complete reference of the UpdateWorkflowV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!update-workflow
 notes:
-  - SDK Method used are
-    device_onboarding_pnp.DeviceOnboardingPnp.add_a_workflow,
-    device_onboarding_pnp.DeviceOnboardingPnp.delete_workflow_by_id,
-    device_onboarding_pnp.DeviceOnboardingPnp.update_workflow,
-
-  - Paths used are
-    post /dna/intent/api/v1/onboarding/pnp-workflow,
-    delete /dna/intent/api/v1/onboarding/pnp-workflow/{id},
+  - SDK Method used are device_onboarding_pnp.DeviceOnboardingPnp.add_a_workflow_v1,
+    device_onboarding_pnp.DeviceOnboardingPnp.delete_workflow_by_id_v1, device_onboarding_pnp.DeviceOnboardingPnp.update_workflow_v1,
+  - Paths used are post /dna/intent/api/v1/onboarding/pnp-workflow, delete /dna/intent/api/v1/onboarding/pnp-workflow/{id},
     put /dna/intent/api/v1/onboarding/pnp-workflow/{id},
-
+  - It should be noted that this module is an alias of pnp_workflow_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.pnp_workflow:
@@ -179,26 +168,25 @@ EXAMPLES = r"""
     startTime: 0
     state_: string
     tasks:
-    - currWorkItemIdx: 0
-      endTime: 0
-      name: string
-      startTime: 0
-      state: string
-      taskSeqNo: 0
-      timeTaken: 0
-      type: string
-      workItemList:
-      - command: string
+      - currWorkItemIdx: 0
         endTime: 0
-        outputStr: string
+        name: string
         startTime: 0
         state: string
+        taskSeqNo: 0
         timeTaken: 0
+        type: string
+        workItemList:
+          - command: string
+            endTime: 0
+            outputStr: string
+            startTime: 0
+            state: string
+            timeTaken: 0
     tenantId: string
     type: string
     useState: string
     version: 0
-
 - name: Delete by id
   cisco.dnac.pnp_workflow:
     dnac_host: "{{dnac_host}}"
@@ -210,7 +198,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     id: string
-
 - name: Update by id
   cisco.dnac.pnp_workflow:
     dnac_host: "{{dnac_host}}"
@@ -237,28 +224,26 @@ EXAMPLES = r"""
     startTime: 0
     state_: string
     tasks:
-    - currWorkItemIdx: 0
-      endTime: 0
-      name: string
-      startTime: 0
-      state: string
-      taskSeqNo: 0
-      timeTaken: 0
-      type: string
-      workItemList:
-      - command: string
+      - currWorkItemIdx: 0
         endTime: 0
-        outputStr: string
+        name: string
         startTime: 0
         state: string
+        taskSeqNo: 0
         timeTaken: 0
+        type: string
+        workItemList:
+          - command: string
+            endTime: 0
+            outputStr: string
+            startTime: 0
+            state: string
+            timeTaken: 0
     tenantId: string
     type: string
     useState: string
     version: 0
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
