@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: reserve_ip_subpool_create
 short_description: Resource module for Reserve Ip Subpool Create
 description:
-- Manage operation create of the resource Reserve Ip Subpool Create.
-- API to reserve an ip subpool from the global pool.
+  - This module represents an alias of the module reserve_ip_subpool_create_v1
 version_added: '4.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -90,21 +87,17 @@ options:
     description: Type of the reserve ip sub pool.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Network Settings ReserveIPSubpool
-  description: Complete reference of the ReserveIPSubpool API.
-  link: https://developer.cisco.com/docs/dna-center/#!reserve-ip-subpool
+  - name: Cisco DNA Center documentation for Network Settings ReserveIPSubpoolV1
+    description: Complete reference of the ReserveIPSubpoolV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!reserve-ip-subpool
 notes:
-  - SDK Method used are
-    network_settings.NetworkSettings.reserve_ip_subpool,
-
-  - Paths used are
-    post /dna/intent/api/v1/reserve-ip-subpool/{siteId},
-
+  - SDK Method used are network_settings.NetworkSettings.reserve_ip_subpool_v1,
+  - Paths used are post /dna/intent/api/v1/reserve-ip-subpool/{siteId},
+  - It should be noted that this module is an alias of reserve_ip_subpool_create_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.reserve_ip_subpool_create:
@@ -116,9 +109,9 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     ipv4DhcpServers:
-    - string
+      - string
     ipv4DnsServers:
-    - string
+      - string
     ipv4GateWay: string
     ipv4GlobalPool: string
     ipv4Prefix: true
@@ -127,9 +120,9 @@ EXAMPLES = r"""
     ipv4TotalHost: 0
     ipv6AddressSpace: true
     ipv6DhcpServers:
-    - string
+      - string
     ipv6DnsServers:
-    - string
+      - string
     ipv6GateWay: string
     ipv6GlobalPool: string
     ipv6Prefix: true
@@ -140,7 +133,6 @@ EXAMPLES = r"""
     siteId: string
     slaacSupport: true
     type: string
-
 """
 RETURN = r"""
 dnac_response:
