@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
-
 DOCUMENTATION = r"""
 ---
 module: roles_info
 short_description: Information module for Roles Info
 description:
-- This module represents an alias of the module roles_v1_info
+  - This module represents an alias of the module roles_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -20,22 +17,17 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for User and Roles GetRolesAPIV1
-  description: Complete reference of the GetRolesAPIV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-roles-api
+  - name: Cisco DNA Center documentation for User and Roles GetRolesAPIV1
+    description: Complete reference of the GetRolesAPIV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-roles-api
 notes:
-  - SDK Method used are
-    user_and_roles.UserandRoles.get_roles_api_v1,
-
-  - Paths used are
-    get /dna/system/api/v1/roles,
+  - SDK Method used are user_and_roles.UserandRoles.get_roles_api_v1,
+  - Paths used are get /dna/system/api/v1/roles,
   - It should be noted that this module is an alias of roles_v1_info
-
 """
-
 EXAMPLES = r"""
 - name: Get all Roles Info
   cisco.dnac.roles_info:
@@ -48,7 +40,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
   register: result
-
 """
 RETURN = r"""
 dnac_response:
