@@ -1,33 +1,28 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: sda_anycast_gateways
-short_description: Resource module for Sda Anycastgateways
+short_description: Resource module for Sda Anycast Gateways
 description:
-- Manage operations create, update and delete of the resource Sda Anycastgateways.
-- Adds anycast gateways based on user input.
-- Deletes an anycast gateway based on id.
-- Updates anycast gateways based on user input.
+  - This module represents an alias of the module sda_anycast_gateways_v1
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   id:
-    description: Id path parameter. ID of the anycast gateway to be deleted.
+    description: Id path parameter. ID of the anycast gateway.
     type: str
   payload:
     description: Sda Anycast Gateways's payload.
     elements: dict
     suboptions:
       fabricId:
-        description: ID of the fabric containing this anycast gateway. Updating anycast
-          gateways on fabric zones is not allowed--instead, update the corresponding
+        description: ID of the fabric this anycast gateway is assigned to. Updating
+          anycast gateways on fabric zones is not allowed--instead, update the corresponding
           anycast gateway on the fabric site and the updates will be applied on all
           applicable fabric zones (updating this field is not allowed).
         type: str
@@ -42,6 +37,10 @@ options:
         description: Enable/disable critical VLAN (not applicable to INFRA_VN; updating
           this field is not allowed).
         type: bool
+      isGroupBasedPolicyEnforcementEnabled:
+        description: Enable/disable Group-Based Policy Enforcement (applicable only
+          to INFRA_VN; defaults to false).
+        type: bool
       isIntraSubnetRoutingEnabled:
         description: Enable/disable Intra-Subnet Routing (not applicable to INFRA_VN;
           updating this field is not allowed).
@@ -58,14 +57,14 @@ options:
         type: bool
       isSupplicantBasedExtendedNodeOnboarding:
         description: Enable/disable Supplicant-Based Extended Node Onboarding (applicable
-          only to INFRA_VN; required when poolType is EXTENDED_NODE).
+          only to INFRA_VN requests; must not be null when poolType is EXTENDED_NODE).
         type: bool
       isWirelessPool:
         description: Enable/disable fabric-enabled wireless (not applicable to INFRA_VN).
         type: bool
       poolType:
-        description: The pool type of the anycast gateway (applicable only to INFRA_VN;
-          updating this field is not allowed).
+        description: The pool type of the anycast gateway (required for & applicable
+          only to INFRA_VN; updating this field is not allowed).
         type: str
       securityGroupName:
         description: Name of the associated Security Group (not applicable to INFRA_VN).
@@ -81,40 +80,34 @@ options:
           gateway (updating this field is not allowed).
         type: str
       vlanId:
-        description: ID of the VLAN of the anycast gateway (updating this field is not
-          allowed).
+        description: ID of the VLAN of the anycast gateway (updating this field is
+          not allowed).
         type: int
       vlanName:
-        description: Name of the VLAN of the anycast gateway (updating this field is
-          not allowed).
+        description: Name of the VLAN of the anycast gateway (updating this field
+          is not allowed).
         type: str
     type: list
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for SDA AddAnycastGateways
-  description: Complete reference of the AddAnycastGateways API.
-  link: https://developer.cisco.com/docs/dna-center/#!add-anycast-gateways
-- name: Cisco DNA Center documentation for SDA DeleteAnycastGatewayById
-  description: Complete reference of the DeleteAnycastGatewayById API.
-  link: https://developer.cisco.com/docs/dna-center/#!delete-anycast-gateway-by-id
-- name: Cisco DNA Center documentation for SDA UpdateAnycastGateways
-  description: Complete reference of the UpdateAnycastGateways API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-anycast-gateways
+  - name: Cisco DNA Center documentation for SDA AddAnycastGatewaysV1
+    description: Complete reference of the AddAnycastGatewaysV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!add-anycast-gateways
+  - name: Cisco DNA Center documentation for SDA DeleteAnycastGatewayByIdV1
+    description: Complete reference of the DeleteAnycastGatewayByIdV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!delete-anycast-gateway-by-id
+  - name: Cisco DNA Center documentation for SDA UpdateAnycastGatewaysV1
+    description: Complete reference of the UpdateAnycastGatewaysV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!update-anycast-gateways
 notes:
-  - SDK Method used are
-    sda.Sda.add_anycast_gateways,
-    sda.Sda.delete_anycast_gateway_by_id,
-    sda.Sda.update_anycast_gateways,
-
-  - Paths used are
-    post /dna/intent/api/v1/sda/anycastGateways,
-    delete /dna/intent/api/v1/sda/anycastGateways/{id},
+  - SDK Method used are sda.Sda.add_anycast_gateways_v1, sda.Sda.delete_anycast_gateway_by_id_v1,
+    sda.Sda.update_anycast_gateways_v1,
+  - Paths used are post /dna/intent/api/v1/sda/anycastGateways, delete /dna/intent/api/v1/sda/anycastGateways/{id},
     put /dna/intent/api/v1/sda/anycastGateways,
-
+  - It should be noted that this module is an alias of sda_anycast_gateways_v1
 """
-
 EXAMPLES = r"""
 - name: Update all
   cisco.dnac.sda_anycast_gateways:
@@ -127,26 +120,26 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: present
     payload:
-    - fabricId: string
-      id: string
-      ipPoolName: string
-      isCriticalPool: true
-      isIntraSubnetRoutingEnabled: true
-      isIpDirectedBroadcast: true
-      isLayer2FloodingEnabled: true
-      isMultipleIpToMacAddresses: true
-      isSupplicantBasedExtendedNodeOnboarding: true
-      isWirelessPool: true
-      poolType: string
-      securityGroupName: string
-      tcpMssAdjustment: 0
-      trafficType: string
-      virtualNetworkName: string
-      vlanId: 0
-      vlanName: string
-
+      - fabricId: string
+        id: string
+        ipPoolName: string
+        isCriticalPool: true
+        isGroupBasedPolicyEnforcementEnabled: true
+        isIntraSubnetRoutingEnabled: true
+        isIpDirectedBroadcast: true
+        isLayer2FloodingEnabled: true
+        isMultipleIpToMacAddresses: true
+        isSupplicantBasedExtendedNodeOnboarding: true
+        isWirelessPool: true
+        poolType: string
+        securityGroupName: string
+        tcpMssAdjustment: 0
+        trafficType: string
+        virtualNetworkName: string
+        vlanId: 0
+        vlanName: string
 - name: Create
-  cisco.dnac.sda_anycastGateways:
+  cisco.dnac.sda_anycast_gateways:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
     dnac_password: "{{dnac_password}}"
@@ -156,26 +149,26 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: present
     payload:
-    - autoGenerateVlanName: true
-      fabricId: string
-      ipPoolName: string
-      isCriticalPool: true
-      isIntraSubnetRoutingEnabled: true
-      isIpDirectedBroadcast: true
-      isLayer2FloodingEnabled: true
-      isMultipleIpToMacAddresses: true
-      isSupplicantBasedExtendedNodeOnboarding: true
-      isWirelessPool: true
-      poolType: string
-      securityGroupName: string
-      tcpMssAdjustment: 0
-      trafficType: string
-      virtualNetworkName: string
-      vlanId: 0
-      vlanName: string
-
+      - autoGenerateVlanName: true
+        fabricId: string
+        ipPoolName: string
+        isCriticalPool: true
+        isGroupBasedPolicyEnforcementEnabled: true
+        isIntraSubnetRoutingEnabled: true
+        isIpDirectedBroadcast: true
+        isLayer2FloodingEnabled: true
+        isMultipleIpToMacAddresses: true
+        isSupplicantBasedExtendedNodeOnboarding: true
+        isWirelessPool: true
+        poolType: string
+        securityGroupName: string
+        tcpMssAdjustment: 0
+        trafficType: string
+        virtualNetworkName: string
+        vlanId: 0
+        vlanName: string
 - name: Delete by id
-  cisco.dnac.sda_anycastGateways:
+  cisco.dnac.sda_anycast_gateways:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
     dnac_password: "{{dnac_password}}"
@@ -185,7 +178,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     id: string
-
 """
 RETURN = r"""
 dnac_response:
