@@ -1,18 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: sda_fabric_authentication_profile
 short_description: Resource module for Sda Fabric Authentication Profile
 description:
-- Manage operations create, update and delete of the resource Sda Fabric Authentication Profile.
-- Add default authentication template in SDA Fabric.
-- Delete default authentication profile in SDA Fabric.
-- Update default authentication profile in SDA Fabric.
+  - This module represents an alias of the module sda_fabric_authentication_profile_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -34,31 +29,31 @@ options:
     description: SiteNameHierarchy query parameter.
     type: str
 requirements:
-- dnacentersdk >= 2.5.4
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for SDA AddDefaultAuthenticationTemplateInSDAFabric
-  description: Complete reference of the AddDefaultAuthenticationTemplateInSDAFabric API.
-  link: https://developer.cisco.com/docs/dna-center/#!add-default-authentication-template-in-sda-fabric
-- name: Cisco DNA Center documentation for SDA DeleteDefaultAuthenticationProfileFromSDAFabric
-  description: Complete reference of the DeleteDefaultAuthenticationProfileFromSDAFabric API.
-  link: https://developer.cisco.com/docs/dna-center/#!delete-default-authentication-profile-from-sda-fabric
-- name: Cisco DNA Center documentation for SDA UpdateDefaultAuthenticationProfileInSDAFabric
-  description: Complete reference of the UpdateDefaultAuthenticationProfileInSDAFabric API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-default-authentication-profile-in-sda-fabric
+  - name: Cisco DNA Center documentation for SDA AddDefaultAuthenticationTemplateInSDAFabricV1
+    description: Complete reference of the AddDefaultAuthenticationTemplateInSDAFabricV1
+      API.
+    link:
+      https://developer.cisco.com/docs/dna-center/#!add-default-authentication-template-in-sda-fabric
+  - name: Cisco DNA Center documentation for SDA DeleteDefaultAuthenticationProfileFromSDAFabricV1
+    description: Complete reference of the DeleteDefaultAuthenticationProfileFromSDAFabricV1
+      API.
+    link:
+      https://developer.cisco.com/docs/dna-center/#!delete-default-authentication-profile-from-sda-fabric
+  - name: Cisco DNA Center documentation for SDA UpdateDefaultAuthenticationProfileInSDAFabricV1
+    description: Complete reference of the UpdateDefaultAuthenticationProfileInSDAFabricV1
+      API.
+    link:
+      https://developer.cisco.com/docs/dna-center/#!update-default-authentication-profile-in-sda-fabric
 notes:
-  - SDK Method used are
-    sda.Sda.add_default_authentication_profile,
-    sda.Sda.delete_default_authentication_profile,
+  - SDK Method used are sda.Sda.add_default_authentication_profile, sda.Sda.delete_default_authentication_profile,
     sda.Sda.update_default_authentication_profile,
-
-  - Paths used are
-    post /dna/intent/api/v1/business/sda/authentication-profile,
-    delete /dna/intent/api/v1/business/sda/authentication-profile,
-    put /dna/intent/api/v1/business/sda/authentication-profile,
-
+  - Paths used are post /dna/intent/api/v1/business/sda/authentication-profile, delete
+    /dna/intent/api/v1/business/sda/authentication-profile, put /dna/intent/api/v1/business/sda/authentication-profile,
+  - It should be noted that this module is an alias of sda_fabric_authentication_profile_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.sda_fabric_authentication_profile:
@@ -71,9 +66,8 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: present
     payload:
-    - authenticateTemplateName: string
-      siteNameHierarchy: string
-
+      - authenticateTemplateName: string
+        siteNameHierarchy: string
 - name: Update all
   cisco.dnac.sda_fabric_authentication_profile:
     dnac_host: "{{dnac_host}}"
@@ -85,13 +79,12 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: present
     payload:
-    - authenticateTemplateName: string
-      authenticationOrder: string
-      dot1xToMabFallbackTimeout: string
-      numberOfHosts: string
-      siteNameHierarchy: string
-      wakeOnLan: true
-
+      - authenticateTemplateName: string
+        authenticationOrder: string
+        dot1xToMabFallbackTimeout: string
+        numberOfHosts: string
+        siteNameHierarchy: string
+        wakeOnLan: true
 - name: Delete all
   cisco.dnac.sda_fabric_authentication_profile:
     dnac_host: "{{dnac_host}}"
@@ -103,9 +96,7 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     siteNameHierarchy: string
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
