@@ -1,16 +1,14 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: sda_fabric_devices_layer2_handoffs_sda_transits_count_info
-short_description: Information module for Sda Fabricdevices Layer2handoffs Sdatransits Count
+short_description: Information module for Sda Fabric Devices Layer2 Handoffs Sda Transits
+  Count Info
 description:
-- Get all Sda Fabricdevices Layer2handoffs Sdatransits Count.
-- Returns the count of layer 3 handoffs with sda transit of fabric devices that match the provided query parameters.
+  - This module represents an alias of the module sda_fabric_devices_layer2_handoffs_sda_transits_count_v1_info
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,30 +19,28 @@ options:
     type: dict
   fabricId:
     description:
-    - FabricId query parameter. ID of the fabric this device belongs to.
+      - FabricId query parameter. ID of the fabric this device belongs to.
     type: str
   networkDeviceId:
     description:
-    - NetworkDeviceId query parameter. Network device ID of the fabric device.
+      - NetworkDeviceId query parameter. Network device ID of the fabric device.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for SDA GetFabricDevicesLayer3HandoffsWithSdaTransitCount
-  description: Complete reference of the GetFabricDevicesLayer3HandoffsWithSdaTransitCount API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-fabric-devices-layer-3-handoffs-with-sda-transit-count
+  - name: Cisco DNA Center documentation for SDA GetFabricDevicesLayer3HandoffsWithSdaTransitCountV1
+    description: Complete reference of the GetFabricDevicesLayer3HandoffsWithSdaTransitCountV1
+      API.
+    link:
+      https://developer.cisco.com/docs/dna-center/#!get-fabric-devices-layer-3-handoffs-with-sda-transit-count
 notes:
-  - SDK Method used are
-    sda.Sda.get_fabric_devices_layer3_handoffs_with_sda_transit_count,
-
-  - Paths used are
-    get /dna/intent/api/v1/sda/fabricDevices/layer3Handoffs/sdaTransits/count,
-
+  - SDK Method used are sda.Sda.get_fabric_devices_layer3_handoffs_with_sda_transit_count_v1,
+  - Paths used are get /dna/intent/api/v1/sda/fabricDevices/layer3Handoffs/sdaTransits/count,
+  - It should be noted that this module is an alias of sda_fabric_devices_layer2_handoffs_sda_transits_count_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Sda Fabricdevices Layer2handoffs Sdatransits Count
+- name: Get all Sda Fabric Devices Layer2 Handoffs Sda Transits Count Info
   cisco.dnac.sda_fabric_devices_layer2_handoffs_sda_transits_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -57,7 +53,6 @@ EXAMPLES = r"""
     fabricId: string
     networkDeviceId: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
