@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: service_provider_info
-short_description: Information module for Service Provider
+short_description: Information module for Service Provider Info
 description:
-- Get all Service Provider.
-- API to get service provider details QoS .
+  - This module represents an alias of the module service_provider_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -20,23 +17,19 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Network Settings GetServiceProviderDetails
-  description: Complete reference of the GetServiceProviderDetails API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-service-provider-details
+  - name: Cisco DNA Center documentation for Network Settings GetServiceProviderDetailsV1
+    description: Complete reference of the GetServiceProviderDetailsV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-service-provider-details
 notes:
-  - SDK Method used are
-    network_settings.NetworkSettings.get_service_provider_details,
-
-  - Paths used are
-    get /dna/intent/api/v1/service-provider,
-
+  - SDK Method used are network_settings.NetworkSettings.get_service_provider_details_v1,
+  - Paths used are get /dna/intent/api/v1/service-provider,
+  - It should be noted that this module is an alias of service_provider_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Service Provider
+- name: Get all Service Provider Info
   cisco.dnac.service_provider_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -47,7 +40,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
   register: result
-
 """
 RETURN = r"""
 dnac_response:
