@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: site_update
 short_description: Resource module for Site Update
 description:
-- Manage operation update of the resource Site Update.
-- Update site area/building/floor with specified hierarchy and new values.
+  - This module represents an alias of the module site_update_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -71,6 +68,9 @@ options:
           name:
             description: Floor name.
             type: str
+          parentName:
+            description: Parent hierarchical name (Example Global/USA/CA/SantaClara/Academic).
+            type: str
           rfModel:
             description: RF model (Example Cubes And Walled Offices).
             type: str
@@ -86,21 +86,17 @@ options:
     description: Site type.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Sites UpdateSite
-  description: Complete reference of the UpdateSite API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-site
+  - name: Cisco DNA Center documentation for Sites UpdateSiteV1
+    description: Complete reference of the UpdateSiteV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!update-site
 notes:
-  - SDK Method used are
-    sites.Sites.update_site,
-
-  - Paths used are
-    put /dna/intent/api/v1/site/{siteId},
-
+  - SDK Method used are sites.Sites.update_site_v1,
+  - Paths used are put /dna/intent/api/v1/site/{siteId},
+  - It should be noted that this module is an alias of site_update_v1
 """
-
 EXAMPLES = r"""
 - name: Update by id
   cisco.dnac.site_update:
@@ -128,11 +124,11 @@ EXAMPLES = r"""
         height: 0
         length: 0
         name: string
+        parentName: string
         rfModel: string
         width: 0
     siteId: string
     type: string
-
 """
 RETURN = r"""
 dnac_response:
