@@ -1,17 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: wireless_rf_profile
 short_description: Resource module for Wireless Rf Profile
 description:
-- Manage operations create and delete of the resource Wireless Rf Profile.
-- Create or Update RF profile.
-- Delete RF profiles.
+  - This module represents an alias of the module wireless_rf_profile_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -21,7 +17,7 @@ options:
     description: Channel Width.
     type: str
   defaultRfProfile:
-    description: Default Rf Profile.
+    description: Is Default Rf Profile.
     type: bool
   enableBrownField:
     description: Enable Brown Field.
@@ -45,84 +41,84 @@ options:
     description: Wireless Rf Profile's radioTypeAProperties.
     suboptions:
       dataRates:
-        description: Data Rates.
+        description: Data Rates (Default "6,9,12,18,24,36,48,54").
         type: str
       mandatoryDataRates:
-        description: Mandatory Data Rates.
+        description: Mandatory Data Rates (Default "6,12,24").
         type: str
       maxPowerLevel:
-        description: Max Power Level.
+        description: Max Power Level (Default 30).
         type: float
       minPowerLevel:
-        description: Rx Sop Threshold.
+        description: Rx Sop Threshold (Default -10).
         type: float
       parentProfile:
-        description: Parent Profile.
+        description: Parent Profile (Default CUSTOM).
         type: str
       powerThresholdV1:
-        description: Power Threshold V1.
+        description: Power Threshold V1 ( (Default -70).
         type: float
       radioChannels:
-        description: Radio Channels.
+        description: Radio Channels (Default "36,40,44,48,52,56,60,64,149,153,157,161").
         type: str
       rxSopThreshold:
-        description: Rx Sop Threshold.
+        description: Rx Sop Threshold (Default "AUTO").
         type: str
     type: dict
   radioTypeBProperties:
     description: Wireless Rf Profile's radioTypeBProperties.
     suboptions:
       dataRates:
-        description: Data Rates.
+        description: Data Rates (Default "9,11,12,18,24,36,48,54").
         type: str
       mandatoryDataRates:
-        description: Mandatory Data Rates.
+        description: Mandatory Data Rates (Default "12").
         type: str
       maxPowerLevel:
-        description: Max Power Level.
+        description: Max Power Level (Default 30).
         type: float
       minPowerLevel:
-        description: Min Power Level.
+        description: Min Power Level (Default -10).
         type: float
       parentProfile:
-        description: Parent Profile.
+        description: Parent Profile (Default CUSTOM).
         type: str
       powerThresholdV1:
-        description: Power Threshold V1.
+        description: Power Threshold V1 (Default -70).
         type: float
       radioChannels:
-        description: Radio Channels.
+        description: Radio Channels (Default "9,11,12,18,24,36,48,54").
         type: str
       rxSopThreshold:
-        description: Rx Sop Threshold.
+        description: Rx Sop Threshold (Default "AUTO").
         type: str
     type: dict
   radioTypeCProperties:
     description: Wireless Rf Profile's radioTypeCProperties.
     suboptions:
       dataRates:
-        description: Data Rates.
+        description: Data Rates (Default "6,9,12,18,24,36,48,54").
         type: str
       mandatoryDataRates:
-        description: Mandatory Data Rates.
+        description: Mandatory Data Rates (Default "6,12,24").
         type: str
       maxPowerLevel:
-        description: Max Power Level.
+        description: Max Power Level (Default 30).
         type: float
       minPowerLevel:
-        description: Min Power Level.
+        description: Min Power Level (Default -10).
         type: float
       parentProfile:
-        description: Parent Profile.
+        description: Parent Profile (Default CUSTOM).
         type: str
       powerThresholdV1:
-        description: Power Threshold V1.
+        description: Power Threshold V1 (Default -70).
         type: float
       radioChannels:
-        description: Radio Channels.
+        description: Radio Channels (Default "5,21,37,53,69,85,101,117,133,149,165,181,197,213,229").
         type: str
       rxSopThreshold:
-        description: Rx Sop Threshold.
+        description: Rx Sop Threshold (Default "AUTO").
         type: str
     type: dict
   rfProfileName:
@@ -130,26 +126,20 @@ options:
       *non-custom RF profile cannot be deleted.
     type: str
 requirements:
-- dnacentersdk >= 2.7.1
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Wireless CreateOrUpdateRFProfile
-  description: Complete reference of the CreateOrUpdateRFProfile API.
-  link: https://developer.cisco.com/docs/dna-center/#!create-or-update-rf-profile
-- name: Cisco DNA Center documentation for Wireless DeleteRFProfiles
-  description: Complete reference of the DeleteRFProfiles API.
-  link: https://developer.cisco.com/docs/dna-center/#!delete-rf-profiles
+  - name: Cisco DNA Center documentation for Wireless CreateOrUpdateRFProfileV1
+    description: Complete reference of the CreateOrUpdateRFProfileV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!create-or-update-rf-profile
+  - name: Cisco DNA Center documentation for Wireless DeleteRFProfilesV1
+    description: Complete reference of the DeleteRFProfilesV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!delete-rf-profiles
 notes:
-  - SDK Method used are
-    wireless.Wireless.create_or_update_rf_profile,
-    wireless.Wireless.delete_rf_profiles,
-
-  - Paths used are
-    post /dna/intent/api/v1/wireless/rf-profile,
-    delete /dna/intent/api/v1/wireless/rf-profile/{rfProfileName},
-
+  - SDK Method used are wireless.Wireless.create_or_update_rf_profile_v1, wireless.Wireless.delete_rf_profiles_v1,
+  - Paths used are post /dna/intent/api/v1/wireless/rf-profile, delete /dna/intent/api/v1/wireless/rf-profile/{rfProfileName},
+  - It should be noted that this module is an alias of wireless_rf_profile_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.wireless_rf_profile:
@@ -196,7 +186,6 @@ EXAMPLES = r"""
       powerThresholdV1: 0
       radioChannels: string
       rxSopThreshold: string
-
 - name: Delete by name
   cisco.dnac.wireless_rf_profile:
     dnac_host: "{{dnac_host}}"
@@ -208,7 +197,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     rfProfileName: string
-
 """
 RETURN = r"""
 dnac_response:
