@@ -30,11 +30,17 @@
 # Author: Matthew Garrett
 # Contributors: David Soper, Chris Gascoigne, John McDonough
 
+from __future__ import (absolute_import, division, print_function)
+
+__metaclass__ = type
+
 from base64 import b64encode
 from email.utils import formatdate
 import re
 import json
 import hashlib
+from typing import Optional
+
 from ansible.module_utils.six import iteritems
 from ansible.module_utils.six.moves.urllib.parse import urlparse, urlencode
 from ansible.module_utils.urls import fetch_url
@@ -44,12 +50,14 @@ try:
     from cryptography.hazmat.primitives import serialization, hashes
     from cryptography.hazmat.primitives.asymmetric import padding, ec
     from cryptography.hazmat.backends import default_backend
+
     HAS_CRYPTOGRAPHY = True
 except ImportError:
     HAS_CRYPTOGRAPHY = False
 
 intersight_argument_spec = dict(
-    api_private_key=dict(fallback=(env_fallback, ['INTERSIGHT_API_PRIVATE_KEY']), type='path', required=True, no_log=True),
+    api_private_key=dict(fallback=(env_fallback, ['INTERSIGHT_API_PRIVATE_KEY']), type='path', required=True,
+                         no_log=True),
     api_uri=dict(fallback=(env_fallback, ['INTERSIGHT_API_URI']), type='str', default='https://intersight.com/api/v1'),
     api_key_id=dict(fallback=(env_fallback, ['INTERSIGHT_API_KEY_ID']), type='str', required=True),
     validate_certs=dict(type='bool', default=True),
@@ -129,6 +137,16 @@ def compare_values(expected, actual):
         # loop complete with all items matching
         return True
     except (AttributeError, TypeError):
+        # Handle Intersight object references: when expected is a MOID string and actual is an object reference
+        if (isinstance(expected, str) and isinstance(actual, dict) and 'Moid' in actual and actual.get('ClassId') == 'mo.MoRef'):
+            # Compare the MOID string against the Moid field in the object reference
+            if actual['Moid'] == expected:
+                return True
+        # Handle case where expected is a string and actual is an object reference
+        elif (isinstance(expected, str) and isinstance(actual, dict) and
+              'Name' in actual and actual.get('ObjectType') == 'organization.Organization'):
+            if actual['Name'] == expected:
+                return True
         # if expected and actual != expected:
         if actual != expected:
             return False
@@ -147,10 +165,11 @@ class IntersightModule():
         try:
             with open(self.module.params['api_private_key'], 'r') as f:
                 self.private_key = f.read()
-        except FileNotFoundError:
+        except (FileNotFoundError, OSError):
             self.private_key = self.module.params['api_private_key']
         self.digest_algorithm = ''
         self.response_list = []
+        self.update_method = ''
 
     def get_sig_b64encode(self, data):
         """
@@ -200,33 +219,6 @@ class IntersightModule():
 
         return auth_str
 
-    def get_moid_by_name(self, resource_path, target_name):
-        """
-        Retrieve an Intersight object moid by name
-
-        :param resource_path: intersight resource path e.g. '/ntp/Policies'
-        :param target_name: intersight object name
-        :return: json http response object
-        """
-        query_params = {
-            "$filter": "Name eq '{0}'".format(target_name)
-        }
-
-        options = {
-            "http_method": "GET",
-            "resource_path": resource_path,
-            "query_params": query_params
-        }
-
-        get_moid = self.intersight_call(**options)
-
-        if get_moid.json()['Results'] is not None:
-            located_moid = get_moid.json()['Results'][0]['Moid']
-        else:
-            raise KeyError('Intersight object with name "{0}" not found!'.format(target_name))
-
-        return located_moid
-
     def call_api(self, **options):
         """
         Call the Intersight API and check for success status
@@ -239,7 +231,7 @@ class IntersightModule():
             if not re.match(r'2..', str(info['status'])):
                 raise RuntimeError(info['status'], info['msg'], info['body'])
         except Exception as e:
-            self.module.fail_json(msg="API error: %s " % str(e))
+            self.module.fail_json(msg="Code exception: %s " % str(e))
 
         response_data = response.read()
         if len(response_data) > 0:
@@ -267,21 +259,24 @@ class IntersightModule():
         bodyString = ""
 
         # Verify an accepted HTTP verb was chosen
-        if(method not in ['GET', 'POST', 'PATCH', 'DELETE']):
+        if (method not in ['GET', 'POST', 'PATCH', 'DELETE']):
             raise ValueError('Please select a valid HTTP verb (GET/POST/PATCH/DELETE)')
 
         # Verify the resource path isn't empy & is a valid <str> object
-        if(resource_path != "" and not (resource_path, str)):
+        if (resource_path != "" and not (resource_path, str)):
             raise TypeError('The *resource_path* value is required and must be of type "<str>"')
 
         # Verify the query parameters isn't empy & is a valid <dict> object
-        if(query_params is not None and not isinstance(query_params, dict)):
+        if (query_params is not None and not isinstance(query_params, dict)):
             raise TypeError('The *query_params* value must be of type "<dict>"')
 
         # Verify the MOID is not null & of proper length
-        if(moid is not None and len(moid.encode('utf-8')) != 24):
+        if (moid is not None and len(moid.encode('utf-8')) != 24):
             raise ValueError('Invalid *moid* value!')
 
+        if (method != 'PATCH' and self.update_method == 'json-patch'):
+            raise ValueError('json-patch is only supported with PATCH on existing resource')
+
         # Check for query_params, encode, and concatenate onto URL
         if query_params:
             query_path = "?" + urlencode(query_params)
@@ -328,22 +323,28 @@ class IntersightModule():
         auth_header = self.get_auth_header(auth_header, b64_signed_msg)
 
         # Generate the HTTP requests header
+        if self.update_method == 'json-patch':
+            content_type = 'application/json-patch+json'
+        else:
+            content_type = 'application/json'
         request_header = {
             'Accept': 'application/json',
-            'Content-Type': 'application/json',
+            'Content-Type': content_type,
             'Host': '{0}'.format(target_host),
             'Date': '{0}'.format(cdate),
             'Digest': 'SHA-256={0}'.format(b64_body_digest.decode('ascii')),
             'Authorization': '{0}'.format(auth_header),
         }
 
-        response, info = fetch_url(self.module, target_url, data=bodyString, headers=request_header, method=method, use_proxy=self.module.params['use_proxy'])
+        response, info = fetch_url(self.module, target_url, data=bodyString, headers=request_header, method=method,
+                                   use_proxy=self.module.params['use_proxy'])
 
         return response, info
 
     def get_resource(self, resource_path, query_params, return_list=False):
         '''
         GET a resource and return the 1st element found or the full Results list
+        If return_list is False and more than 1 element is returned, a warning is raised
         '''
         options = {
             'http_method': 'get',
@@ -355,11 +356,15 @@ class IntersightModule():
             if return_list:
                 self.result['api_response'] = response['Results']
             else:
+                if len(response['Results']) > 1:
+                    self.module.warn('More than 1 resource found, returning the 1st one')
                 # return the 1st list element
                 self.result['api_response'] = response['Results'][0]
+        self.result['count'] = response.get('Count')
         self.result['trace_id'] = response.get('trace_id')
 
     def configure_resource(self, moid, resource_path, body, query_params, update_method=''):
+        self.update_method = update_method
         if not self.module.check_mode:
             if moid and update_method != 'post':
                 # update the resource - user has to specify all the props they want updated
@@ -409,18 +414,7 @@ class IntersightModule():
 
     def configure_policy_or_profile(self, resource_path):
         # Configure (create, update, or delete) the policy or profile
-        organization_moid = None
-        # GET Organization Moid
-        self.get_resource(
-            resource_path='/organization/Organizations',
-            query_params={
-                '$filter': "Name eq '" + self.module.params['organization'] + "'",
-                '$select': 'Moid',
-            },
-        )
-        if self.result['api_response'].get('Moid'):
-            # resource exists and moid was returned
-            organization_moid = self.result['api_response']['Moid']
+        organization_moid = self.get_moid_by_name(resource_path='/organization/Organizations', resource_name=self.module.params['organization'])
 
         self.result['api_response'] = {}
         # Get the current state of the resource
@@ -469,3 +463,82 @@ class IntersightModule():
                 moid = self.result['api_response']['Moid']
 
         return moid
+
+    def configure_secondary_resource(self, resource_path, resource_name, state):
+        # Configure (create, update, or delete) resources
+        # This method is used to configure secondery resources that are part of a policy or profile (e.g. VLANs)
+
+        self.result['api_response'] = {}
+        # Get the current state of the resource
+        filter_str = "Name eq '" + resource_name + "'"
+        self.get_resource(
+            resource_path=resource_path,
+            query_params={
+                '$filter': filter_str
+            }
+        )
+
+        moid = None
+        resource_values_match = False
+        if self.result['api_response'].get('Moid'):
+            # resource exists and moid was returned
+            moid = self.result['api_response']['Moid']
+            if state == 'present':
+                resource_values_match = compare_values(self.api_body, self.result['api_response'])
+            else:  # state == 'absent'
+                self.delete_resource(
+                    moid=moid,
+                    resource_path=resource_path,
+                )
+                moid = None
+
+        if state == 'present' and not resource_values_match:
+            self.configure_resource(
+                moid=moid,
+                resource_path=resource_path,
+                body=self.api_body,
+                query_params={
+                    '$filter': filter_str
+                }
+            )
+            if self.result['api_response'].get('Moid'):
+                # resource exists and moid was returned
+                moid = self.result['api_response']['Moid']
+
+        return moid
+
+    def get_moid_by_name(self, resource_path, resource_name) -> Optional[str]:
+        '''
+        Get the moid of the resource by the value of the resource
+        '''
+        organization_moid = None
+        # GET Moid of the resource
+        self.get_resource(
+            resource_path=resource_path,
+            query_params={
+                '$filter': "Name eq '" + resource_name + "'",
+                '$select': 'Moid',
+            },
+        )
+        if self.result['api_response'].get('Moid'):
+            # resource exists and moid was returned
+            return self.result['api_response']['Moid']
+        return None
+
+    def set_query_params(self) -> dict:
+        filter_conditions = []
+
+        name_to_filter = self.module.params.get('name')
+        org_to_filter = self.module.params.get('organization')
+
+        if name_to_filter:
+            filter_conditions.append(f"Name eq '{name_to_filter}'")
+
+        if org_to_filter:
+            org_moid = self.get_moid_by_name(resource_path='/organization/Organizations', resource_name=org_to_filter)
+            filter_conditions.append(f"Organization.Moid eq '{org_moid}'")
+
+        query_params = {}
+        if filter_conditions:
+            query_params["$filter"] = " and ".join(filter_conditions)
+        return query_params
