@@ -26,15 +26,17 @@ from ansible_collections.cisco.ise.plugins.plugin_utils.ise import (
 # Get common arguements specification
 argument_spec = ise_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-    id=dict(type="str"),
-    page=dict(type="int"),
-    size=dict(type="int"),
-    sortasc=dict(type="str"),
-    sortdsc=dict(type="str"),
-    filter=dict(type="list"),
-    filterType=dict(type="str"),
-))
+argument_spec.update(
+    dict(
+        id=dict(type="str"),
+        page=dict(type="int"),
+        size=dict(type="int"),
+        sortasc=dict(type="str"),
+        sortdsc=dict(type="str"),
+        filter=dict(type="list"),
+        filterType=dict(type="str"),
+    )
+)
 
 required_if = []
 required_one_of = []
@@ -45,7 +47,9 @@ required_together = []
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = True
@@ -96,9 +100,9 @@ class ActionModule(ActionBase):
         if id:
             response = ise.exec(
                 family="hotspot_portal",
-                function='get_hotspot_portal_by_id',
-                params=self.get_object(self._task.args)
-            ).response['HotspotPortal']
+                function="get_hotspot_portal_by_id",
+                params=self.get_object(self._task.args),
+            ).response["HotspotPortal"]
             self._result.update(dict(ise_response=response))
             self._result.update(ise.exit_json())
             return self._result
@@ -106,12 +110,12 @@ class ActionModule(ActionBase):
             responses = []
             generator = ise.exec(
                 family="hotspot_portal",
-                function='get_hotspot_portal_generator',
+                function="get_hotspot_portal_generator",
                 params=self.get_object(self._task.args),
             )
             try:
                 for item in generator:
-                    tmp_response = item.response['SearchResult']['resources']
+                    tmp_response = item.response["SearchResult"]["resources"]
                     if isinstance(tmp_response, list):
                         responses += tmp_response
                     else:
