@@ -5,40 +5,38 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
----
 module: device_administration_conditions
 short_description: Resource module for Device Administration Conditions
 description:
-- Manage operations create, update and delete of the resource Device Administration Conditions.
-- Device Admin - Creates a library condition.
-- Device Admin - Delete a library condition.
-- NDevice Admin - Delete a library condition using condition Name.
-- Device Admin - Update library condition using condition name.
-- Device Admin - Update library condition.
+  - Manage operations create, update and delete of the resource Device Administration Conditions.
+  - Device Admin - Creates a library condition.
+  - Device Admin - Delete a library condition.
+  - NDevice Admin - Delete a library condition using condition Name.
+  - Device Admin - Update library condition using condition name.
+  - Device Admin - Update library condition.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
+  attributeId:
+    description: Dictionary attribute id (Optional), used for additional verification.
+    type: str
   attributeName:
     description: Dictionary attribute name.
     type: str
   attributeValue:
-    description: <ul><li>Attribute value for condition</li> <li>Value type is specified
-      in dictionary object</li> <li>if multiple values allowed is specified in dictionary
-      object</li></ul>.
+    description: <ul><li>Attribute value for condition</li> <li>Value type is specified in dictionary object</li> <li>if multiple values allowed
+      is specified in dictionary object</li></ul>.
     type: str
   children:
-    description: In case type is andBlock or orBlock addtional conditions will be aggregated
-      under this logical (OR/AND) condition.
+    description: In case type is andBlock or orBlock addtional conditions will be aggregated under this logical (OR/AND) condition.
     elements: dict
     suboptions:
       conditionType:
-        description: <ul><li>Inidicates whether the record is the condition itself(data)
-          or a logical(or,and) aggregation</li> <li>Data type enum(reference,single)
-          indicates than "conditonId" OR "ConditionAttrs" fields should contain condition
-          data but not both</li> <li>Logical aggreation(and,or) enum indicates that
-          additional conditions are present under the children field</li></ul>.
+        description: <ul><li>Inidicates whether the record is the condition itself(data) or a logical(or,and) aggregation</li> <li>Data type
+          num(reference,single) indicates than "conditonId" OR "ConditionAttrs" fields should contain condition data but not both</li>
+          <li>Logical aggreation(and,or) enum indicates that additional conditions are present under the children field</li></ul>.
         type: str
       isNegate:
         description: Indicates whereas this condition is in negate mode.
@@ -58,18 +56,14 @@ options:
         type: dict
     type: list
   conditionType:
-    description: <ul><li>Inidicates whether the record is the condition itself(data)
-      or a logical(or,and) aggregation</li> <li>Data type enum(reference,single) indicates
-      than "conditonId" OR "ConditionAttrs" fields should contain condition data but
-      not both</li> <li>Logical aggreation(and,or) enum indicates that additional conditions
-      are present under the children field</li></ul>.
+    description: <ul><li>Inidicates whether the record is the condition itself(data) or a logical(or,and) aggregation</li> <li>Data type enum(reference,single)
+      indicates than "conditonId" OR "ConditionAttrs" fields should contain condition data but not both</li> <li>Logical aggreation(and,or) enum
+      indicates that additional conditions are present under the children field</li></ul>.
     type: str
   datesRange:
-    description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
-      Options are - Date range, for specific date, the same date should be used for
-      start/end date <br> Default - no specific dates<br> In order to reset the dates
-      to have no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
-      = year)</p>.
+    description: <p>Defines for which date/s TimeAndDate condition will be matched or NOT matched if used in exceptionDates prooperty<br> Options
+      are - Date range, for specific date, the same date should be used for start/end date <br> Default - no specific dates<br> In order to reset
+      the dates to have no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy = year)</p>.
     suboptions:
       endDate:
         description: Device Administration Conditions's endDate.
@@ -79,11 +73,9 @@ options:
         type: str
     type: dict
   datesRangeException:
-    description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
-      Options are - Date range, for specific date, the same date should be used for
-      start/end date <br> Default - no specific dates<br> In order to reset the dates
-      to have no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
-      = year)</p>.
+    description: <p>Defines for which date/s TimeAndDate condition will be matched or NOT matched if used in exceptionDates prooperty<br> Options
+      are - Date range, for specific date, the same date should be used for start/end date <br> Default - no specific dates<br> In order to reset
+      the dates to have no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy = year)</p>.
     suboptions:
       endDate:
         description: Device Administration Conditions's endDate.
@@ -102,8 +94,8 @@ options:
     description: Dictionary value.
     type: str
   hoursRange:
-    description: <p>Defines for which hours a TimeAndDate condition will be matched<br>
-      Time format - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
+    description: <p>Defines for which hours a TimeAndDate condition will be matched or not matched if used in exceptionHours property<br> Time
+      foramt - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
     suboptions:
       endTime:
         description: Device Administration Conditions's endTime.
@@ -113,8 +105,8 @@ options:
         type: str
     type: dict
   hoursRangeException:
-    description: <p>Defines for which hours a TimeAndDate condition will be matched<br>
-      Time format - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
+    description: <p>Defines for which hours a TimeAndDate condition will be matched or not matched if used in exceptionHours property<br> Time
+      foramt - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
     suboptions:
       endTime:
         description: Device Administration Conditions's endTime.
@@ -149,22 +141,21 @@ options:
     description: Equality operator.
     type: str
   weekDays:
-    description: <p>Defines for which days this condition will be matched<br> Days format
-      - Arrays of WeekDay enums <br> Default - List of All week days</p>.
+    description: <p>Defines for which days this condition will be matched<br> Days format - Arrays of WeekDay enums <br> Default - List of All
+      week days</p>.
     elements: str
     type: list
   weekDaysException:
-    description: <p>Defines for which days this condition will NOT be matched<br> Days
-      format - Arrays of WeekDay enums <br> Default - Not enabled</p>.
+    description: <p>Defines for which days this condition will NOT be matched<br> Days format - Arrays of WeekDay enums <br> Default - Not enabled</p>.
     elements: str
     type: list
 requirements:
-- ciscoisesdk >= 2.0.1
-- python >= 3.5
+  - ciscoisesdk >= 2.2.3
+  - python >= 3.5
 seealso:
-- name: Cisco ISE documentation for Device Administration - Conditions
-  description: Complete reference of the Device Administration - Conditions API.
-  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+  - name: Cisco ISE documentation for Device Administration - Conditions
+    description: Complete reference of the Device Administration - Conditions API.
+    link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
 notes:
   - SDK Method used are
     device_administration_conditions.DeviceAdministrationConditions.create_device_admin_condition,
@@ -172,14 +163,12 @@ notes:
     device_administration_conditions.DeviceAdministrationConditions.delete_device_admin_condition_by_name,
     device_administration_conditions.DeviceAdministrationConditions.update_device_admin_condition_by_id,
     device_administration_conditions.DeviceAdministrationConditions.update_device_admin_condition_by_name,
-
   - Paths used are
     post /device-admin/condition,
     delete /device-admin/condition/condition-by-name/{name},
     delete /device-admin/condition/{id},
     put /device-admin/condition/condition-by-name/{name},
     put /device-admin/condition/{id},
-
 """
 
 EXAMPLES = r"""
@@ -190,15 +179,16 @@ EXAMPLES = r"""
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
     state: present
+    attributeId: string
     attributeName: string
     attributeValue: string
     children:
-    - conditionType: string
-      isNegate: true
-      link:
-        href: string
-        rel: string
-        type: string
+      - conditionType: string
+        isNegate: true
+        link:
+          href: string
+          rel: string
+          type: string
     conditionType: string
     datesRange:
       endDate: string
@@ -224,10 +214,9 @@ EXAMPLES = r"""
     name: string
     operator: string
     weekDays:
-    - string
+      - string
     weekDaysException:
-    - string
-
+      - string
 - name: Update by name
   cisco.ise.device_administration_conditions:
     ise_hostname: "{{ise_hostname}}"
@@ -235,15 +224,16 @@ EXAMPLES = r"""
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
     state: present
+    attributeId: string
     attributeName: string
     attributeValue: string
     children:
-    - conditionType: string
-      isNegate: true
-      link:
-        href: string
-        rel: string
-        type: string
+      - conditionType: string
+        isNegate: true
+        link:
+          href: string
+          rel: string
+          type: string
     conditionType: string
     datesRange:
       endDate: string
@@ -269,10 +259,9 @@ EXAMPLES = r"""
     name: string
     operator: string
     weekDays:
-    - string
+      - string
     weekDaysException:
-    - string
-
+      - string
 - name: Delete by name
   cisco.ise.device_administration_conditions:
     ise_hostname: "{{ise_hostname}}"
@@ -281,7 +270,6 @@ EXAMPLES = r"""
     ise_verify: "{{ise_verify}}"
     state: absent
     name: string
-
 - name: Update by id
   cisco.ise.device_administration_conditions:
     ise_hostname: "{{ise_hostname}}"
@@ -289,15 +277,16 @@ EXAMPLES = r"""
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
     state: present
+    attributeId: string
     attributeName: string
     attributeValue: string
     children:
-    - conditionType: string
-      isNegate: true
-      link:
-        href: string
-        rel: string
-        type: string
+      - conditionType: string
+        isNegate: true
+        link:
+          href: string
+          rel: string
+          type: string
     conditionType: string
     datesRange:
       endDate: string
@@ -323,10 +312,9 @@ EXAMPLES = r"""
     name: string
     operator: string
     weekDays:
-    - string
+      - string
     weekDaysException:
-    - string
-
+      - string
 - name: Delete by id
   cisco.ise.device_administration_conditions:
     ise_hostname: "{{ise_hostname}}"
@@ -335,7 +323,6 @@ EXAMPLES = r"""
     ise_verify: "{{ise_verify}}"
     state: absent
     id: string
-
 """
 
 RETURN = r"""
@@ -356,6 +343,7 @@ ise_response:
       "id": "string",
       "name": "string",
       "attributeName": "string",
+      "attributeId": "string",
       "attributeValue": "string",
       "dictionaryName": "string",
       "dictionaryValue": "string",
@@ -394,7 +382,6 @@ ise_response:
         "string"
       ]
     }
-
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
@@ -414,6 +401,7 @@ ise_update_response:
         "id": "string",
         "name": "string",
         "attributeName": "string",
+        "attributeId": "string",
         "attributeValue": "string",
         "dictionaryName": "string",
         "dictionaryValue": "string",
