@@ -5,11 +5,10 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
----
 module: mnt_session_by_ip_info
-short_description: Information module for Mnt Session By Ip
+short_description: Information module for MNT Session By Ip
 description:
-- Get Mnt Session By Ip by id.
+  - Get MNT Session By Ip by id.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -17,20 +16,20 @@ author: Rafael Campos (@racampos)
 options:
   endpoint_ipv4:
     description:
-    - Endpoint_ipv4 path parameter.
+      - Endpoint_ipv4 path parameter.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
-- python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Mnt Session By Ip reference
-  description: Complete reference of the Mnt Session By Ip object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+  - ciscoisesdk >= 2.2.3
+  - python >= 3.5
+notes:
+  - SDK Method used are
+    misc.Misc.get_sessions_by_endpoint_ip,
+  - Paths used are
+    get /Session/EndPointIPAddress/{endpoint_ipv4},
 """
 
 EXAMPLES = r"""
-- name: Get Mnt Session By Ip by id
+- name: Get MNT Session By Ip by id
   cisco.ise.mnt_session_by_ip_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -38,7 +37,6 @@ EXAMPLES = r"""
     ise_verify: "{{ise_verify}}"
     endpoint_ipv4: string
   register: result
-
 """
 
 RETURN = r"""
@@ -46,6 +44,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
