@@ -5,31 +5,28 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
----
 module: network_access_conditions_for_authorization_rule_info
 short_description: Information module for Network Access Conditions For Authorization Rule
 description:
-- Get all Network Access Conditions For Authorization Rule.
-- Network Access - Returns list of library conditions for Authorization rules scope.
+  - Get all Network Access Conditions For Authorization Rule.
+  - Network Access - Returns list of library conditions for Authorization rules scope.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 2.0.1
-- python >= 3.5
+  - ciscoisesdk >= 2.2.3
+  - python >= 3.5
 seealso:
-- name: Cisco ISE documentation for Network Access - Conditions
-  description: Complete reference of the Network Access - Conditions API.
-  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+  - name: Cisco ISE documentation for Network Access - Conditions
+    description: Complete reference of the Network Access - Conditions API.
+    link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
 notes:
   - SDK Method used are
     network_access_conditions.NetworkAccessConditions.get_network_access_conditions_for_authorization_rules,
-
   - Paths used are
     get /network-access/condition/authorization,
-
 """
 
 EXAMPLES = r"""
@@ -40,7 +37,6 @@ EXAMPLES = r"""
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
   register: result
-
 """
 
 RETURN = r"""
@@ -63,6 +59,7 @@ ise_response:
         "id": "string",
         "name": "string",
         "attributeName": "string",
+        "attributeId": "string",
         "attributeValue": "string",
         "dictionaryName": "string",
         "dictionaryValue": "string",
