@@ -3,13 +3,14 @@
 # Copyright: (c) 2018, Dag Wieers (@dagwieers) <dag@wieers.com>
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 
 class ModuleDocFragment(object):
     # Standard files documentation fragment
-    DOCUMENTATION = r'''
+    DOCUMENTATION = r"""
 options:
   host:
     description:
@@ -46,37 +47,38 @@ options:
   timeout:
     description:
     - The socket level timeout in seconds.
+    - The default value is 30 seconds.
     - If the value is not specified in the task, the value of environment variable C(MSO_TIMEOUT) will be used instead.
     type: int
-    default: 30
   use_proxy:
     description:
-    - If C(no), it will not use a proxy, even if one is defined in an environment variable on the target hosts.
+    - If C(false), it will not use a proxy, even if one is defined in an environment variable on the target hosts.
     - If the value is not specified in the task, the value of environment variable C(MSO_USE_PROXY) will be used instead.
-    - The default is C(yes).
+    - The default is C(true).
     type: bool
   use_ssl:
     description:
-    - If C(no), an HTTP connection will be used instead of the default HTTPS connection.
+    - If C(false), an HTTP connection will be used instead of the default HTTPS connection.
     - If the value is not specified in the task, the value of environment variable C(MSO_USE_SSL) will be used instead.
     - When using a HTTPAPI connection plugin the inventory variable C(ansible_httpapi_use_ssl) will be used if this attribute is not specified.
-    - The default is C(no) when using a HTTPAPI connection plugin (mso or nd) and C(yes) when using the legacy connection method (only for mso).
+    - The default is C(false) when using a HTTPAPI connection plugin (mso or nd) and C(true) when using the legacy connection method (only for mso).
     type: bool
   validate_certs:
     description:
-    - If C(no), SSL certificates will not be validated.
-    - This should only set to C(no) when used on personally controlled sites using self-signed certificates.
+    - If C(false), SSL certificates will not be validated.
+    - This should only set to C(false) when used on personally controlled sites using self-signed certificates.
     - If the value is not specified in the task, the value of environment variable C(MSO_VALIDATE_CERTS) will be used instead.
-    - The default is C(yes).
+    - The default is C(true).
     type: bool
   login_domain:
     description:
     - The login domain name to use for authentication.
     - The default value is Local.
     - If the value is not specified in the task, the value of environment variable C(MSO_LOGIN_DOMAIN) will be used instead.
+    - When using a HTTPAPI connection plugin the inventory variable C(ansible_httpapi_login_domain) will be used if this attribute is not specified.
     type: str
 requirements:
 - Multi Site Orchestrator v2.1 or newer
 notes:
 - This module was written to support Multi Site Orchestrator v2.1 or newer. Some or all functionality may not work on earlier versions.
-'''
+"""
