@@ -15,30 +15,36 @@ short_description: Manages floating IPs on the cloudscale.ch IaaS service
 description:
   - Create, assign and delete floating IPs on the cloudscale.ch IaaS service.
 notes:
-  - Idempotency depends on the C(ip) parameter.
   - Once a floating_ip is created, all parameters except C(server), C(reverse_ptr) and C(tags) are read-only.
-  - This module requires the ipaddress python library. This library is included in Python since version 3.3. It is available as a
-    module on PyPI for earlier versions.
 author:
   - Gaudenz Steinlin (@gaudenz)
   - Denis Krienbühl (@href)
+  - René Moser (@resmo)
 version_added: 1.0.0
 options:
+  network:
+    description:
+      - Floating IP address to change.
+      - One of I(network) or I(name) is required to identify the floating IP.
+    aliases: [ ip ]
+    type: str
+  name:
+    description:
+      - Name to identifiy the floating IP address for idempotency.
+      - One of I(network) or I(name) is required to identify the floating IP.
+      - Required for assigning a new floating IP.
+    version_added: 1.3.0
+    type: str
   state:
     description:
       - State of the floating IP.
     default: present
     choices: [ present, absent ]
     type: str
-  ip:
-    description:
-      - Floating IP address to change.
-      - Required to assign the IP to a different server or if I(state) is absent.
-    aliases: [ network ]
-    type: str
   ip_version:
     description:
       - IP protocol version of the floating IP.
+      - Required when assigning a new floating IP.
     choices: [ 4, 6 ]
     type: int
   server:
@@ -53,7 +59,7 @@ options:
     default: regional
   region:
     description:
-      - Region in which the floating IP resides (e.g. C(lgp) or C(rma)).
+      - Region in which the floating IP resides (e.g. C(lpg) or C(rma)).
         If omitted, the region of the project default zone is used.
         This parameter must be omitted if I(type) is set to C(global).
     type: str
@@ -78,30 +84,41 @@ extends_documentation_fragment: cloudscale_ch.cloud.api_parameters
 '''
 
 EXAMPLES = '''
-# Request a new floating IP without server assignment
+# Request a new floating IP without assignment to a server
 - name: Request a floating IP
   cloudscale_ch.cloud.floating_ip:
+    name: IP to my server
     ip_version: 4
+    reverse_ptr: my-server.example.com
     api_token: xxxxxx
 
-# Request a new floating IP
+# Request a new floating IP with assignment
 - name: Request a floating IP
   cloudscale_ch.cloud.floating_ip:
+    name: web
     ip_version: 4
     server: 47cec963-fcd2-482f-bdb6-24461b2d47b1
     reverse_ptr: my-server.example.com
     api_token: xxxxxx
 
-# Assign an existing floating IP to a different server
+# Assign an existing floating IP to a different server by its IP address
 - name: Move floating IP to backup server
   cloudscale_ch.cloud.floating_ip:
     ip: 192.0.2.123
     server: ea3b39a3-77a8-4d0b-881d-0bb00a1e7f48
     api_token: xxxxxx
 
+# Assign an existing floating IP to a different server by name
+- name: Move floating IP to backup server
+  cloudscale_ch.cloud.floating_ip:
+    name: IP to my server
+    server: ea3b39a3-77a8-4d0b-881d-0bb00a1e7f48
+    api_token: xxxxxx
+
 # Request a new floating IPv6 network
 - name: Request a floating IP
   cloudscale_ch.cloud.floating_ip:
+    name: IPv6 to my server
     ip_version: 6
     prefix_length: 56
     server: 47cec963-fcd2-482f-bdb6-24461b2d47b1
@@ -111,19 +128,32 @@ EXAMPLES = '''
 # Assign an existing floating network to a different server
 - name: Move floating IP to backup server
   cloudscale_ch.cloud.floating_ip:
-    ip: '{{ floating_ip.network | ip }}'
+    ip: '{{ floating_ip.ip }}'
     server: ea3b39a3-77a8-4d0b-881d-0bb00a1e7f48
     api_token: xxxxxx
 
-# Release a floating IP
+# Remove a floating IP
 - name: Release floating IP
   cloudscale_ch.cloud.floating_ip:
     ip: 192.0.2.123
     state: absent
     api_token: xxxxxx
+
+# Remove a floating IP by name
+- name: Release floating IP
+  cloudscale_ch.cloud.floating_ip:
+    name: IP to my server
+    state: absent
+    api_token: xxxxxx
 '''
 
 RETURN = '''
+name:
+  description: The name of the floating IP.
+  returned: success
+  type: str
+  sample: my floating ip
+  version_added: 1.3.0
 href:
   description: The API URL to get details about this floating IP.
   returned: success when state == present
@@ -131,7 +161,7 @@ href:
   sample: https://api.cloudscale.ch/v1/floating-ips/2001:db8::cafe
 network:
   description: The CIDR notation of the network that is routed to your server.
-  returned: success when state == present
+  returned: success
   type: str
   sample: 2001:db8::cafe/128
 next_hop:
@@ -150,8 +180,8 @@ server:
   type: str
   sample: 47cec963-fcd2-482f-bdb6-24461b2d47b1
 ip:
-  description: The floating IP address or network. This is always present and used to identify floating IPs after creation.
-  returned: success
+  description: The floating IP address.
+  returned: success when state == present
   type: str
   sample: 185.98.122.176
 region:
@@ -172,100 +202,61 @@ tags:
   version_added: 1.1.0
 '''
 
-import traceback
-
-IPADDRESS_IMP_ERR = None
-try:
-    from ipaddress import ip_network
-    HAS_IPADDRESS = True
-except ImportError:
-    IPADDRESS_IMP_ERR = traceback.format_exc()
-    HAS_IPADDRESS = False
-
-from ansible.module_utils.basic import AnsibleModule, env_fallback, missing_required_lib
+from ansible.module_utils.basic import AnsibleModule
 from ..module_utils.api import (
     AnsibleCloudscaleBase,
     cloudscale_argument_spec,
 )
 
 
-class AnsibleCloudscaleFloatingIP(AnsibleCloudscaleBase):
+class AnsibleCloudscaleFloatingIp(AnsibleCloudscaleBase):
 
     def __init__(self, module):
-        super(AnsibleCloudscaleFloatingIP, self).__init__(module)
+        super(AnsibleCloudscaleFloatingIp, self).__init__(
+            module=module,
+            resource_key_uuid='network',
+            resource_name='floating-ips',
+            resource_create_param_keys=[
+                'ip_version',
+                'server',
+                'prefix_length',
+                'reverse_ptr',
+                'type',
+                'region',
+                'tags',
+            ],
+            resource_update_param_keys=[
+                'server',
+                'reverse_ptr',
+                'tags',
+            ],
+        )
+        self.use_tag_for_name = True
+        self.query_constraint_keys = ['ip_version']
 
-        # Initialize info dict
-        # Set state to absent, will be updated by self.update_info()
-        self.info = {'state': 'absent'}
+    def pre_transform(self, resource):
+        if 'server' in resource and isinstance(resource['server'], dict):
+            resource['server'] = resource['server']['uuid']
+        return resource
 
-        if self._module.params['ip']:
-            self.update_info()
+    def create(self, resource):
+        # Fail when missing params for creation
+        self._module.fail_on_missing_params(['ip_version', 'name'])
+        return super(AnsibleCloudscaleFloatingIp, self).create(resource)
 
-    @staticmethod
-    def _resp2info(resp):
-        # If the API response has some content, the floating IP must exist
-        resp['state'] = 'present'
-
-        # Add the IP address to the response, otherwise handling get's to complicated as this
-        # has to be converted from the network all the time.
-        resp['ip'] = str(ip_network(resp['network']).network_address)
-
-        # Replace the server with just the UUID, the href to the server is useless and just makes
-        # things more complicated
-        if resp['server'] is not None:
-            resp['server'] = resp['server']['uuid']
-
-        return resp
-
-    def update_info(self):
-        resp = self._get('floating-ips/' + self._module.params['ip'])
-        if resp:
-            self.info = self._resp2info(resp)
-        else:
-            self.info = {'ip': self._module.params['ip'],
-                         'state': 'absent'}
-
-    def request_floating_ip(self):
-        params = self._module.params
-
-        # check for required parameters to request a floating IP
-        self._module.fail_on_missing_params(('ip_version',))
-
-        data = {
-            'ip_version': params['ip_version'],
-            'server': params['server'],
-            'prefix_length': params['prefix_length'],
-            'reverse_ptr': params['reverse_ptr'],
-            'type': params['type'],
-            'region': params['region'],
-            'tags': params['tags'],
-        }
-
-        self.info = self._resp2info(self._post('floating-ips', data))
-
-    def release_floating_ip(self):
-        self._delete('floating-ips/%s' % self._module.params['ip'])
-        self.info = {'ip': self.info['ip'], 'state': 'absent'}
-
-    def update_floating_ip(self):
-        params = self._module.params
-
-        if not params['server']:
-            self._module.fail_json(msg='Missing required parameter to update a floating IP: server.')
-
-        data = {
-            'server': params['server'],
-            'tags': params['tags'],
-        }
-
-        self.info = self._resp2info(self._post('floating-ips/%s' % params['ip'], data))
+    def get_result(self, resource):
+        network = resource.get('network')
+        if network:
+            self._result['ip'] = network.split('/')[0]
+        return super(AnsibleCloudscaleFloatingIp, self).get_result(resource)
 
 
 def main():
     argument_spec = cloudscale_argument_spec()
     argument_spec.update(dict(
+        name=dict(type='str'),
         state=dict(default='present', choices=('present', 'absent'), type='str'),
-        ip=dict(aliases=('network', ), type='str'),
+        network=dict(aliases=['ip'], type='str'),
         ip_version=dict(choices=(4, 6), type='int'),
         server=dict(type='str'),
         type=dict(type='str', choices=('regional', 'global'), default='regional'),
@@ -277,36 +268,17 @@ def main():
 
     module = AnsibleModule(
         argument_spec=argument_spec,
-        required_one_of=(('ip', 'ip_version'),),
+        required_one_of=(('network', 'name'),),
         supports_check_mode=True,
     )
 
-    if not HAS_IPADDRESS:
-        module.fail_json(msg=missing_required_lib('ipaddress'), exception=IPADDRESS_IMP_ERR)
+    cloudscale_floating_ip = AnsibleCloudscaleFloatingIp(module)
 
-    target_state = module.params['state']
-    target_server = module.params['server']
-    floating_ip = AnsibleCloudscaleFloatingIP(module)
-    current_state = floating_ip.info['state']
-    current_server = floating_ip.info['server'] if 'server' in floating_ip.info else None
-
-    if module.check_mode:
-        module.exit_json(changed=not target_state == current_state or
-                         (current_state == 'present' and current_server != target_server),
-                         **floating_ip.info)
-
-    changed = False
-    if current_state == 'absent' and target_state == 'present':
-        floating_ip.request_floating_ip()
-        changed = True
-    elif current_state == 'present' and target_state == 'absent':
-        floating_ip.release_floating_ip()
-        changed = True
-    elif current_state == 'present' and current_server != target_server:
-        floating_ip.update_floating_ip()
-        changed = True
-
-    module.exit_json(changed=changed, **floating_ip.info)
+    if module.params['state'] == 'absent':
+        result = cloudscale_floating_ip.absent()
+    else:
+        result = cloudscale_floating_ip.present()
+    module.exit_json(**result)
 
 
 if __name__ == '__main__':
