@@ -6,25 +6,29 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
+
+
 __metaclass__ = type
 
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: crypto_info
 author: "Felix Fontein (@felixfontein)"
 short_description: Retrieve cryptographic capabilities
 version_added: 2.1.0
 description:
-   - Retrieve information on cryptographic capabilities.
-   - The current version retrieves information on the L(Python cryptography library, https://cryptography.io/) available to
-     Ansible modules, and on the OpenSSL binary C(openssl) found in the path.
-notes:
-   - Supports C(check_mode).
+  - Retrieve information on cryptographic capabilities.
+  - The current version retrieves information on the L(Python cryptography library, https://cryptography.io/) available to
+    Ansible modules, and on the OpenSSL binary C(openssl) found in the path.
+extends_documentation_fragment:
+  - community.crypto.attributes
+  - community.crypto.attributes.info_module
+  - community.crypto.attributes.idempotent_not_modify_state
 options: {}
-'''
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
+---
 - name: Retrieve information
   community.crypto.crypto_info:
     account_key_src: /etc/pki/cert/private/account.key
@@ -33,9 +37,9 @@ EXAMPLES = r'''
 - name: Show retrieved information
   ansible.builtin.debug:
     var: crypto_information
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 python_cryptography_installed:
   description: Whether the L(Python cryptography library, https://cryptography.io/) is installed.
   returned: always
@@ -44,12 +48,12 @@ python_cryptography_installed:
 
 python_cryptography_import_error:
   description: Import error when trying to import the L(Python cryptography library, https://cryptography.io/).
-  returned: when I(python_cryptography_installed=false)
+  returned: when RV(python_cryptography_installed=false)
   type: str
 
 python_cryptography_capabilities:
   description: Information on the installed L(Python cryptography library, https://cryptography.io/).
-  returned: when I(python_cryptography_installed=true)
+  returned: when RV(python_cryptography_installed=true)
   type: dict
   contains:
     version:
@@ -135,7 +139,7 @@ openssl_present:
 
 openssl:
   description: Information on the installed OpenSSL binary.
-  returned: when I(openssl_present=true)
+  returned: when RV(openssl_present=true)
   type: dict
   contains:
     path:
@@ -150,34 +154,42 @@ openssl:
       description: The complete output of C(openssl version).
       type: str
       sample: 'OpenSSL 1.1.1m  14 Dec 2021\n'
-'''
+"""
 
 import traceback
 
 from ansible.module_utils.basic import AnsibleModule
-
 from ansible_collections.community.crypto.plugins.module_utils.crypto.basic import (
-    CRYPTOGRAPHY_HAS_EC,
-    CRYPTOGRAPHY_HAS_EC_SIGN,
-    CRYPTOGRAPHY_HAS_ED25519,
-    CRYPTOGRAPHY_HAS_ED25519_SIGN,
-    CRYPTOGRAPHY_HAS_ED448,
-    CRYPTOGRAPHY_HAS_ED448_SIGN,
     CRYPTOGRAPHY_HAS_DSA,
     CRYPTOGRAPHY_HAS_DSA_SIGN,
+    CRYPTOGRAPHY_HAS_EC,
+    CRYPTOGRAPHY_HAS_EC_SIGN,
+    CRYPTOGRAPHY_HAS_ED448,
+    CRYPTOGRAPHY_HAS_ED448_SIGN,
+    CRYPTOGRAPHY_HAS_ED25519,
+    CRYPTOGRAPHY_HAS_ED25519_SIGN,
     CRYPTOGRAPHY_HAS_RSA,
     CRYPTOGRAPHY_HAS_RSA_SIGN,
+    CRYPTOGRAPHY_HAS_X448,
     CRYPTOGRAPHY_HAS_X25519,
     CRYPTOGRAPHY_HAS_X25519_FULL,
-    CRYPTOGRAPHY_HAS_X448,
     HAS_CRYPTOGRAPHY,
 )
 
+
 try:
     import cryptography
     from cryptography.exceptions import UnsupportedAlgorithm
+
+    try:
+        # While UnsupportedAlgorithm got added in cryptography 0.1, InternalError
+        # only got added in 0.2, so let's guard the import
+        from cryptography.exceptions import InternalError as CryptographyInternalError
+    except ImportError:
+        CryptographyInternalError = Exception
 except ImportError:
     UnsupportedAlgorithm = Exception
+    CryptographyInternalError = Exception
     CRYPTOGRAPHY_VERSION = None
     CRYPTOGRAPHY_IMP_ERR = traceback.format_exc()
 else:
@@ -186,40 +198,43 @@ else:
 
 
 CURVES = (
-    ('secp224r1', 'SECP224R1'),
-    ('secp256k1', 'SECP256K1'),
-    ('secp256r1', 'SECP256R1'),
-    ('secp384r1', 'SECP384R1'),
-    ('secp521r1', 'SECP521R1'),
-    ('secp192r1', 'SECP192R1'),
-    ('sect163k1', 'SECT163K1'),
-    ('sect163r2', 'SECT163R2'),
-    ('sect233k1', 'SECT233K1'),
-    ('sect233r1', 'SECT233R1'),
-    ('sect283k1', 'SECT283K1'),
-    ('sect283r1', 'SECT283R1'),
-    ('sect409k1', 'SECT409K1'),
-    ('sect409r1', 'SECT409R1'),
-    ('sect571k1', 'SECT571K1'),
-    ('sect571r1', 'SECT571R1'),
-    ('brainpoolP256r1', 'BrainpoolP256R1'),
-    ('brainpoolP384r1', 'BrainpoolP384R1'),
-    ('brainpoolP512r1', 'BrainpoolP512R1'),
+    ("secp224r1", "SECP224R1"),
+    ("secp256k1", "SECP256K1"),
+    ("secp256r1", "SECP256R1"),
+    ("secp384r1", "SECP384R1"),
+    ("secp521r1", "SECP521R1"),
+    ("secp192r1", "SECP192R1"),
+    ("sect163k1", "SECT163K1"),
+    ("sect163r2", "SECT163R2"),
+    ("sect233k1", "SECT233K1"),
+    ("sect233r1", "SECT233R1"),
+    ("sect283k1", "SECT283K1"),
+    ("sect283r1", "SECT283R1"),
+    ("sect409k1", "SECT409K1"),
+    ("sect409r1", "SECT409R1"),
+    ("sect571k1", "SECT571K1"),
+    ("sect571r1", "SECT571R1"),
+    ("brainpoolP256r1", "BrainpoolP256R1"),
+    ("brainpoolP384r1", "BrainpoolP384R1"),
+    ("brainpoolP512r1", "BrainpoolP512R1"),
 )
 
 
 def add_crypto_information(module):
     result = {}
-    result['python_cryptography_installed'] = HAS_CRYPTOGRAPHY
+    result["python_cryptography_installed"] = HAS_CRYPTOGRAPHY
     if not HAS_CRYPTOGRAPHY:
-        result['python_cryptography_import_error'] = CRYPTOGRAPHY_IMP_ERR
+        result["python_cryptography_import_error"] = CRYPTOGRAPHY_IMP_ERR
         return result
 
     has_ed25519 = CRYPTOGRAPHY_HAS_ED25519
     if has_ed25519:
         try:
-            from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PrivateKey
-            Ed25519PrivateKey.from_private_bytes(b'')
+            from cryptography.hazmat.primitives.asymmetric.ed25519 import (
+                Ed25519PrivateKey,
+            )
+
+            Ed25519PrivateKey.from_private_bytes(b"")
         except ValueError:
             pass
         except UnsupportedAlgorithm:
@@ -229,7 +244,8 @@ def add_crypto_information(module):
     if has_ed448:
         try:
             from cryptography.hazmat.primitives.asymmetric.ed448 import Ed448PrivateKey
-            Ed448PrivateKey.from_private_bytes(b'')
+
+            Ed448PrivateKey.from_private_bytes(b"")
         except ValueError:
             pass
         except UnsupportedAlgorithm:
@@ -238,9 +254,12 @@ def add_crypto_information(module):
     has_x25519 = CRYPTOGRAPHY_HAS_X25519
     if has_x25519:
         try:
-            from cryptography.hazmat.primitives.asymmetric.x25519 import X25519PrivateKey
+            from cryptography.hazmat.primitives.asymmetric.x25519 import (
+                X25519PrivateKey,
+            )
+
             if CRYPTOGRAPHY_HAS_X25519_FULL:
-                X25519PrivateKey.from_private_bytes(b'')
+                X25519PrivateKey.from_private_bytes(b"")
             else:
                 # Some versions do not support serialization and deserialization - use generate() instead
                 X25519PrivateKey.generate()
@@ -253,7 +272,8 @@ def add_crypto_information(module):
     if has_x448:
         try:
             from cryptography.hazmat.primitives.asymmetric.x448 import X448PrivateKey
-            X448PrivateKey.from_private_bytes(b'')
+
+            X448PrivateKey.from_private_bytes(b"")
         except ValueError:
             pass
         except UnsupportedAlgorithm:
@@ -266,54 +286,65 @@ def add_crypto_information(module):
 
         backend = cryptography.hazmat.backends.default_backend()
         for curve_name, constructor_name in CURVES:
-            ecclass = cryptography.hazmat.primitives.asymmetric.ec.__dict__.get(constructor_name)
+            ecclass = cryptography.hazmat.primitives.asymmetric.ec.__dict__.get(
+                constructor_name
+            )
             if ecclass:
                 try:
-                    cryptography.hazmat.primitives.asymmetric.ec.generate_private_key(curve=ecclass(), backend=backend)
+                    cryptography.hazmat.primitives.asymmetric.ec.generate_private_key(
+                        curve=ecclass(), backend=backend
+                    )
                     curves.append(curve_name)
                 except UnsupportedAlgorithm:
                     pass
+                except (  # pylint: disable=duplicate-except,bad-except-order
+                    CryptographyInternalError
+                ):
+                    # On Fedora 41, some curves result in InternalError. This is probably because
+                    # Fedora's cryptography is linked against the system libssl, which has the
+                    # curves removed.
+                    pass
 
     info = {
-        'version': CRYPTOGRAPHY_VERSION,
-        'curves': curves,
-        'has_ec': CRYPTOGRAPHY_HAS_EC,
-        'has_ec_sign': CRYPTOGRAPHY_HAS_EC_SIGN,
-        'has_ed25519': has_ed25519,
-        'has_ed25519_sign': has_ed25519 and CRYPTOGRAPHY_HAS_ED25519_SIGN,
-        'has_ed448': has_ed448,
-        'has_ed448_sign': has_ed448 and CRYPTOGRAPHY_HAS_ED448_SIGN,
-        'has_dsa': CRYPTOGRAPHY_HAS_DSA,
-        'has_dsa_sign': CRYPTOGRAPHY_HAS_DSA_SIGN,
-        'has_rsa': CRYPTOGRAPHY_HAS_RSA,
-        'has_rsa_sign': CRYPTOGRAPHY_HAS_RSA_SIGN,
-        'has_x25519': has_x25519,
-        'has_x25519_serialization': has_x25519 and CRYPTOGRAPHY_HAS_X25519_FULL,
-        'has_x448': has_x448,
+        "version": CRYPTOGRAPHY_VERSION,
+        "curves": curves,
+        "has_ec": CRYPTOGRAPHY_HAS_EC,
+        "has_ec_sign": CRYPTOGRAPHY_HAS_EC_SIGN,
+        "has_ed25519": has_ed25519,
+        "has_ed25519_sign": has_ed25519 and CRYPTOGRAPHY_HAS_ED25519_SIGN,
+        "has_ed448": has_ed448,
+        "has_ed448_sign": has_ed448 and CRYPTOGRAPHY_HAS_ED448_SIGN,
+        "has_dsa": CRYPTOGRAPHY_HAS_DSA,
+        "has_dsa_sign": CRYPTOGRAPHY_HAS_DSA_SIGN,
+        "has_rsa": CRYPTOGRAPHY_HAS_RSA,
+        "has_rsa_sign": CRYPTOGRAPHY_HAS_RSA_SIGN,
+        "has_x25519": has_x25519,
+        "has_x25519_serialization": has_x25519 and CRYPTOGRAPHY_HAS_X25519_FULL,
+        "has_x448": has_x448,
     }
-    result['python_cryptography_capabilities'] = info
+    result["python_cryptography_capabilities"] = info
     return result
 
 
 def add_openssl_information(module):
-    openssl_binary = module.get_bin_path('openssl')
+    openssl_binary = module.get_bin_path("openssl")
     result = {
-        'openssl_present': openssl_binary is not None,
+        "openssl_present": openssl_binary is not None,
     }
     if openssl_binary is None:
         return result
 
     openssl_result = {
-        'path': openssl_binary,
+        "path": openssl_binary,
     }
-    result['openssl'] = openssl_result
+    result["openssl"] = openssl_result
 
-    rc, out, err = module.run_command([openssl_binary, 'version'])
+    rc, out, err = module.run_command([openssl_binary, "version"])
     if rc == 0:
-        openssl_result['version_output'] = out
+        openssl_result["version_output"] = out
         parts = out.split(None, 2)
         if len(parts) > 1:
-            openssl_result['version'] = parts[1]
+            openssl_result["version"] = parts[1]
 
     return result
 
@@ -332,5 +363,5 @@ def main():
     module.exit_json(**result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
