@@ -7,6 +7,7 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 
+import json
 import os
 import re
 import shutil
@@ -16,6 +17,7 @@ from collections import namedtuple
 
 from ansible.module_utils.basic import missing_required_lib
 from ansible.module_utils.common.text.converters import to_native
+from ansible.module_utils.six import string_types
 from ansible.module_utils.six.moves import shlex_quote
 
 from ansible_collections.community.docker.plugins.module_utils.util import DockerBaseClass
@@ -55,6 +57,8 @@ DOCKER_STATUS_DONE = frozenset((
     'Recreated',
     # Extras for pull events
     'Pulled',
+    # Extras for built events
+    'Built',
 ))
 DOCKER_STATUS_WORKING = frozenset((
     'Creating',
@@ -74,6 +78,10 @@ DOCKER_STATUS_PULL = frozenset((
     'Pulled',
     'Pulling',
 ))
+DOCKER_STATUS_BUILD = frozenset((
+    'Built',
+    'Building',
+))
 DOCKER_STATUS_ERROR = frozenset((
     'Error',
 ))
@@ -84,6 +92,7 @@ DOCKER_STATUS_WAITING = frozenset((
     'Waiting',
 ))
 DOCKER_STATUS = frozenset(DOCKER_STATUS_DONE | DOCKER_STATUS_WORKING | DOCKER_STATUS_PULL | DOCKER_STATUS_ERROR | DOCKER_STATUS_WAITING)
+DOCKER_STATUS_AND_WARNING = frozenset(DOCKER_STATUS | DOCKER_STATUS_WARNING)
 
 DOCKER_PULL_PROGRESS_DONE = frozenset((
     'Already exists',
@@ -116,6 +125,7 @@ class ResourceType(object):
             "Image": cls.IMAGE,
             "Volume": cls.VOLUME,
             "Container": cls.CONTAINER,
+            "Service": cls.SERVICE,
         }[resource_type]
 
 
@@ -348,13 +358,135 @@ def _concat_event_msg(event, append_msg):
     )
 
 
-def parse_events(stderr, dry_run=False, warn_function=None):
+_JSON_LEVEL_TO_STATUS_MAP = {
+    'warning': 'Warning',
+    'error': 'Error',
+}
+
+
+def parse_json_events(stderr, warn_function=None):
+    events = []
+    stderr_lines = stderr.splitlines()
+    if stderr_lines and stderr_lines[-1] == b'':
+        del stderr_lines[-1]
+    for line in stderr_lines:
+        line = line.strip()
+        if not line.startswith(b'{') or not line.endswith(b'}'):
+            if line.startswith(b'Warning: '):
+                # This is a bug in Compose that will get fixed by https://github.com/docker/compose/pull/11996
+                event = Event(
+                    ResourceType.UNKNOWN,
+                    None,
+                    'Warning',
+                    to_native(line[len(b'Warning: '):]),
+                )
+                events.append(event)
+                continue
+            if warn_function:
+                warn_function(
+                    'Cannot parse event from non-JSON line: {0!r}. Please report this at '
+                    'https://github.com/ansible-collections/community.docker/issues/new?assignees=&labels=&projects=&template=bug_report.md'
+                    .format(line)
+                )
+            continue
+        try:
+            line_data = json.loads(line)
+        except Exception as exc:
+            if warn_function:
+                warn_function(
+                    'Cannot parse event from line: {0!r}: {1}. Please report this at '
+                    'https://github.com/ansible-collections/community.docker/issues/new?assignees=&labels=&projects=&template=bug_report.md'
+                    .format(line, exc)
+                )
+            continue
+        if line_data.get('tail'):
+            resource_type = ResourceType.UNKNOWN
+            msg = line_data.get('text')
+            status = 'Error'
+            if isinstance(msg, str) and msg.lower().startswith('warning:'):
+                # For some reason, Writer.TailMsgf() is always used for errors *except* in one place,
+                # where its message is prepended with 'WARNING: ' (in pkg/compose/pull.go).
+                status = 'Warning'
+                msg = msg[len('warning:'):].lstrip()
+            event = Event(
+                resource_type,
+                None,
+                status,
+                msg,
+            )
+        elif line_data.get('error'):
+            resource_type = ResourceType.UNKNOWN
+            event = Event(
+                resource_type,
+                line_data.get('id'),
+                'Error',
+                line_data.get('message'),
+            )
+        else:
+            resource_type = ResourceType.UNKNOWN
+            resource_id = line_data.get('id')
+            status = line_data.get('status')
+            text = line_data.get('text')
+            if resource_id == " " and text and text.startswith("build service "):
+                # Example:
+                # {"dry-run":true,"id":" ","text":"build service app"}
+                resource_id = "S" + text[len("build s"):]
+                text = "Building"
+            if isinstance(resource_id, str) and resource_id.endswith("==>") and text and text.startswith("==> writing image "):
+                # Example:
+                # {"dry-run":true,"id":"==>","text":"==> writing image dryRun-7d1043473d55bfa90e8530d35801d4e381bc69f0"}
+                # {"dry-run":true,"id":"ansible-docker-test-dc713f1f-container ==>","text":"==> writing image dryRun-5d9204268db1a73d57bbd24a25afbeacebe2bc02"}
+                # (The longer form happens since Docker Compose 2.39.0)
+                continue
+            if isinstance(resource_id, str) and resource_id.endswith("==> ==>") and text and text.startswith("naming to "):
+                # Example:
+                # {"dry-run":true,"id":"==> ==>","text":"naming to display-app"}
+                # {"dry-run":true,"id":"ansible-docker-test-dc713f1f-container ==> ==>","text":"naming to ansible-docker-test-dc713f1f-image"}
+                # (The longer form happens since Docker Compose 2.39.0)
+                continue
+            if isinstance(resource_id, str) and ' ' in resource_id:
+                resource_type_str, resource_id = resource_id.split(' ', 1)
+                try:
+                    resource_type = ResourceType.from_docker_compose_event(resource_type_str)
+                except KeyError:
+                    if warn_function:
+                        warn_function(
+                            'Unknown resource type {0!r} in line {1!r}. Please report this at '
+                            'https://github.com/ansible-collections/community.docker/issues/new?assignees=&labels=&projects=&template=bug_report.md'
+                            .format(resource_type_str, line)
+                        )
+                    resource_type = ResourceType.UNKNOWN
+            elif text in DOCKER_STATUS_PULL:
+                resource_type = ResourceType.IMAGE
+                status, text = text, status
+            elif text in DOCKER_PULL_PROGRESS_DONE or line_data.get('text') in DOCKER_PULL_PROGRESS_WORKING:
+                resource_type = ResourceType.IMAGE_LAYER
+                status, text = text, status
+            elif status is None and isinstance(text, string_types) and text.startswith('Skipped - '):
+                status, text = text.split(' - ', 1)
+            elif line_data.get('level') in _JSON_LEVEL_TO_STATUS_MAP and 'msg' in line_data:
+                status = _JSON_LEVEL_TO_STATUS_MAP[line_data['level']]
+                text = line_data['msg']
+            if status not in DOCKER_STATUS_AND_WARNING and text in DOCKER_STATUS_AND_WARNING:
+                status, text = text, status
+            event = Event(
+                resource_type,
+                resource_id,
+                status,
+                text,
+            )
+
+        events.append(event)
+    return events
+
+
+def parse_events(stderr, dry_run=False, warn_function=None, nonzero_rc=False):
     events = []
     error_event = None
     stderr_lines = stderr.splitlines()
     if stderr_lines and stderr_lines[-1] == b'':
         del stderr_lines[-1]
-    for line in stderr_lines:
+    for index, line in enumerate(stderr_lines):
         line = to_native(line.strip())
         if not line:
             continue
@@ -385,7 +517,7 @@ def parse_events(stderr, dry_run=False, warn_function=None):
             index_event = _find_last_event_for(events, match.group('resource_id'))
             if index_event is not None:
                 index, event = index_event
-                events[-1] = _concat_event_msg(event, match.group('msg'))
+                events[index] = _concat_event_msg(event, match.group('msg'))
         event, parsed = _extract_logfmt_event(line, warn_function=warn_function)
         if event is not None:
             events.append(event)
@@ -405,7 +537,7 @@ def parse_events(stderr, dry_run=False, warn_function=None):
             )
             events.append(error_event)
             continue
-        if len(stderr_lines) == 1:
+        if len(stderr_lines) == 1 or (nonzero_rc and index == len(stderr_lines) - 1):
             # **Very likely** an error message that is independent of an error event
             error_event = Event(
                 ResourceType.UNKNOWN,
@@ -420,11 +552,13 @@ def parse_events(stderr, dry_run=False, warn_function=None):
     return events
 
 
-def has_changes(events, ignore_service_pull_events=False):
+def has_changes(events, ignore_service_pull_events=False, ignore_build_events=False):
     for event in events:
         if event.status in DOCKER_STATUS_WORKING:
             if ignore_service_pull_events and event.status in DOCKER_STATUS_PULL:
                 continue
+            if ignore_build_events and event.status in DOCKER_STATUS_BUILD:
+                continue
             return True
         if event.resource_type == ResourceType.IMAGE_LAYER and event.status in DOCKER_PULL_PROGRESS_WORKING:
             return True
@@ -456,7 +590,7 @@ def extract_actions(events):
 def emit_warnings(events, warn_function):
     for event in events:
         # If a message is present, assume it is a warning
-        if event.status is None and event.msg is not None:
+        if (event.status is None and event.msg is not None) or event.status in DOCKER_STATUS_WARNING:
             warn_function('Docker compose: {resource_type} {resource_id}: {msg}'.format(
                 resource_type=event.resource_type,
                 resource_id=event.resource_id,
@@ -476,11 +610,15 @@ def update_failed(result, events, args, stdout, stderr, rc, cli):
     errors = []
     for event in events:
         if event.status in DOCKER_STATUS_ERROR:
-            msg = 'Error when processing {resource_type} {resource_id}: '
-            if event.resource_type == 'unknown':
-                msg = 'Error when processing {resource_id}: '
-                if event.resource_id == '':
-                    msg = 'General error: '
+            if event.resource_id is None:
+                if event.resource_type == 'unknown':
+                    msg = 'General error: ' if event.resource_type == 'unknown' else 'Error when processing {resource_type}: '
+            else:
+                msg = 'Error when processing {resource_type} {resource_id}: '
+                if event.resource_type == 'unknown':
+                    msg = 'Error when processing {resource_id}: '
+                    if event.resource_id == '':
+                        msg = 'General error: '
             msg += '{status}' if event.msg is None else '{msg}'
             errors.append(msg.format(
                 resource_type=event.resource_type,
@@ -567,16 +705,7 @@ class BaseComposeManager(DockerBaseClass):
         self.env_files = parameters['env_files']
         self.profiles = parameters['profiles']
 
-        compose = self.client.get_client_plugin_info('compose')
-        if compose is None:
-            self.fail('Docker CLI {0} does not have the compose plugin installed'.format(self.client.get_cli()))
-        if compose['Version'] == 'dev':
-            self.fail(
-                'Docker CLI {0} has a compose plugin installed, but it reports version "dev".'
-                ' Please use a version of the plugin that returns a proper version.'
-                .format(self.client.get_cli())
-            )
-        compose_version = compose['Version'].lstrip('v')
+        compose_version = self.get_compose_version()
         self.compose_version = LooseVersion(compose_version)
         if self.compose_version < LooseVersion(min_version):
             self.fail('Docker CLI {cli} has the compose plugin with version {version}; need version {min_version} or later'.format(
@@ -598,13 +727,46 @@ class BaseComposeManager(DockerBaseClass):
             filenames = ', '.join(DOCKER_COMPOSE_FILES[:-1])
             self.fail('"{0}" does not contain {1}, or {2}'.format(self.project_src, filenames, DOCKER_COMPOSE_FILES[-1]))
 
+        # Support for JSON output was added in Compose 2.29.0 (https://github.com/docker/compose/releases/tag/v2.29.0);
+        # more precisely in https://github.com/docker/compose/pull/11478
+        self.use_json_events = self.compose_version >= LooseVersion('2.29.0')
+
+    def get_compose_version(self):
+        return self.get_compose_version_from_cli() or self.get_compose_version_from_api()
+
+    def get_compose_version_from_cli(self):
+        rc, version_info, stderr = self.client.call_cli('compose', 'version', '--format', 'json')
+        if rc:
+            return None
+        try:
+            version = json.loads(version_info)['version']
+            if version == 'dev':
+                return None
+            return version.lstrip('v')
+        except Exception:
+            return None
+
+    def get_compose_version_from_api(self):
+        compose = self.client.get_client_plugin_info('compose')
+        if compose is None:
+            self.fail('Docker CLI {0} does not have the compose plugin installed'.format(self.client.get_cli()))
+        if compose['Version'] == 'dev':
+            self.fail(
+                'Docker CLI {0} has a compose plugin installed, but it reports version "dev".'
+                ' Please use a version of the plugin that returns a proper version.'
+                .format(self.client.get_cli())
+            )
+        return compose['Version'].lstrip('v')
+
     def fail(self, msg, **kwargs):
         self.cleanup()
         self.client.fail(msg, **kwargs)
 
-    def get_base_args(self):
+    def get_base_args(self, plain_progress=False):
         args = ['compose', '--ansi', 'never']
-        if self.compose_version >= LooseVersion('2.19.0'):
+        if self.use_json_events and not plain_progress:
+            args.extend(['--progress', 'json'])
+        elif self.compose_version >= LooseVersion('2.19.0'):
             # https://github.com/docker/compose/pull/10690
             args.extend(['--progress', 'plain'])
         args.extend(['--project-directory', self.project_src])
@@ -618,17 +780,25 @@ class BaseComposeManager(DockerBaseClass):
             args.extend(['--profile', profile])
         return args
 
+    def _handle_failed_cli_call(self, args, rc, stdout, stderr):
+        events = parse_json_events(stderr, warn_function=self.client.warn)
+        result = {}
+        self.update_failed(result, events, args, stdout, stderr, rc)
+        self.client.module.exit_json(**result)
+
     def list_containers_raw(self):
         args = self.get_base_args() + ['ps', '--format', 'json', '--all']
         if self.compose_version >= LooseVersion('2.23.0'):
             # https://github.com/docker/compose/pull/11038
             args.append('--no-trunc')
-        kwargs = dict(cwd=self.project_src, check_rc=True)
+        kwargs = dict(cwd=self.project_src, check_rc=not self.use_json_events)
         if self.compose_version >= LooseVersion('2.21.0'):
             # Breaking change in 2.21.0: https://github.com/docker/compose/pull/10918
-            dummy, containers, dummy = self.client.call_cli_json_stream(*args, **kwargs)
+            rc, containers, stderr = self.client.call_cli_json_stream(*args, **kwargs)
         else:
-            dummy, containers, dummy = self.client.call_cli_json(*args, **kwargs)
+            rc, containers, stderr = self.client.call_cli_json(*args, **kwargs)
+        if self.use_json_events and rc != 0:
+            self._handle_failed_cli_call(args, rc, containers, stderr)
         return containers
 
     def list_containers(self):
@@ -648,18 +818,39 @@ class BaseComposeManager(DockerBaseClass):
 
     def list_images(self):
         args = self.get_base_args() + ['images', '--format', 'json']
-        kwargs = dict(cwd=self.project_src, check_rc=True)
-        dummy, images, dummy = self.client.call_cli_json(*args, **kwargs)
+        kwargs = dict(cwd=self.project_src, check_rc=not self.use_json_events)
+        rc, images, stderr = self.client.call_cli_json(*args, **kwargs)
+        if self.use_json_events and rc != 0:
+            self._handle_failed_cli_call(args, rc, images, stderr)
+        if isinstance(images, dict):
+            # Handle breaking change in Docker Compose 2.37.0; see
+            # https://github.com/ansible-collections/community.docker/issues/1082
+            # and https://github.com/docker/compose/issues/12916 for details
+            images = list(images.values())
         return images
 
-    def parse_events(self, stderr, dry_run=False):
-        return parse_events(stderr, dry_run=dry_run, warn_function=self.client.warn)
+    def parse_events(self, stderr, dry_run=False, nonzero_rc=False):
+        if self.use_json_events:
+            return parse_json_events(stderr, warn_function=self.client.warn)
+        return parse_events(stderr, dry_run=dry_run, warn_function=self.client.warn, nonzero_rc=nonzero_rc)
 
     def emit_warnings(self, events):
         emit_warnings(events, warn_function=self.client.warn)
 
-    def update_result(self, result, events, stdout, stderr, ignore_service_pull_events=False):
-        result['changed'] = result.get('changed', False) or has_changes(events, ignore_service_pull_events=ignore_service_pull_events)
+    def update_result(
+        self,
+        result,
+        events,
+        stdout,
+        stderr,
+        ignore_service_pull_events=False,
+        ignore_build_events=False,
+    ):
+        result['changed'] = result.get('changed', False) or has_changes(
+            events,
+            ignore_service_pull_events=ignore_service_pull_events,
+            ignore_build_events=ignore_build_events,
+        )
         result['actions'] = result.get('actions', []) + extract_actions(events)
         result['stdout'] = combine_text_output(result.get('stdout'), to_native(stdout))
         result['stderr'] = combine_text_output(result.get('stderr'), to_native(stderr))
@@ -677,7 +868,7 @@ class BaseComposeManager(DockerBaseClass):
 
     def cleanup_result(self, result):
         if not result.get('failed'):
-            # Only return stdout and stderr if it's not empty
+            # Only return stdout and stderr if it is not empty
             for res in ('stdout', 'stderr'):
                 if result.get(res) == '':
                     result.pop(res)
@@ -687,5 +878,5 @@ class BaseComposeManager(DockerBaseClass):
             try:
                 shutil.rmtree(dir, True)
             except Exception:
-                # shouldn't happen, but simply ignore to be on the safe side
+                # should not happen, but simply ignore to be on the safe side
                 pass
