@@ -3,78 +3,80 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import annotations
 
-__metaclass__ = type
 
-DOCUMENTATION = r'''
-    name: scaleway
-    author:
-      - Remy Leone (@remyleone)
-    short_description: Scaleway inventory source
+DOCUMENTATION = r"""
+name: scaleway
+author:
+  - Remy Leone (@remyleone)
+short_description: Scaleway inventory source
+description:
+  - Get inventory hosts from Scaleway.
+requirements:
+  - PyYAML
+options:
+  plugin:
+    description: Token that ensures this is a source file for the 'scaleway' plugin.
+    required: true
+    type: string
+    choices: ['scaleway', 'community.general.scaleway']
+  regions:
+    description: Filter results on a specific Scaleway region.
+    type: list
+    elements: string
+    default:
+      - ams1
+      - par1
+      - par2
+      - waw1
+  tags:
+    description: Filter results on a specific tag.
+    type: list
+    elements: string
+  scw_profile:
     description:
-        - Get inventory hosts from Scaleway.
-    requirements:
-        - PyYAML
-    options:
-        plugin:
-            description: Token that ensures this is a source file for the 'scaleway' plugin.
-            required: true
-            choices: ['scaleway', 'community.general.scaleway']
-        regions:
-            description: Filter results on a specific Scaleway region.
-            type: list
-            elements: string
-            default:
-                - ams1
-                - par1
-                - par2
-                - waw1
-        tags:
-            description: Filter results on a specific tag.
-            type: list
-            elements: string
-        scw_profile:
-            description:
-            - The config profile to use in config file.
-            - By default uses the one specified as C(active_profile) in the config file, or falls back to V(default) if that is not defined.
-            type: string
-            version_added: 4.4.0
-        oauth_token:
-            description:
-            - Scaleway OAuth token.
-            - If not explicitly defined or in environment variables, it will try to lookup in the scaleway-cli configuration file
-              (C($SCW_CONFIG_PATH), C($XDG_CONFIG_HOME/scw/config.yaml), or C(~/.config/scw/config.yaml)).
-            - More details on L(how to generate token, https://www.scaleway.com/en/docs/generate-api-keys/).
-            env:
-                # in order of precedence
-                - name: SCW_TOKEN
-                - name: SCW_API_KEY
-                - name: SCW_OAUTH_TOKEN
-        hostnames:
-            description: List of preference about what to use as an hostname.
-            type: list
-            elements: string
-            default:
-                - public_ipv4
-            choices:
-                - public_ipv4
-                - private_ipv4
-                - public_ipv6
-                - hostname
-                - id
-        variables:
-            description: 'Set individual variables: keys are variable names and
-                          values are templates. Any value returned by the
-                          L(Scaleway API, https://developer.scaleway.com/#servers-server-get)
-                          can be used.'
-            type: dict
-'''
+      - The config profile to use in config file.
+      - By default uses the one specified as C(active_profile) in the config file, or falls back to V(default) if that is not defined.
+    type: string
+    version_added: 4.4.0
+  oauth_token:
+    description:
+      - Scaleway OAuth token.
+      - If not explicitly defined or in environment variables, it will try to lookup in the scaleway-cli configuration file
+        (C($SCW_CONFIG_PATH), C($XDG_CONFIG_HOME/scw/config.yaml), or C(~/.config/scw/config.yaml)).
+      - More details on L(how to generate token, https://www.scaleway.com/en/docs/generate-api-keys/).
+    type: string
+    env:
+      # in order of precedence
+      - name: SCW_TOKEN
+      - name: SCW_API_KEY
+      - name: SCW_OAUTH_TOKEN
+  hostnames:
+    description: List of preference about what to use as an hostname.
+    type: list
+    elements: string
+    default:
+      - public_ipv4
+    choices:
+      - public_ipv4
+      - private_ipv4
+      - public_ipv6
+      - hostname
+      - id
+  variables:
+    description: 'Set individual variables: keys are variable names and
+                  values are templates. Any value returned by the
+                  L(Scaleway API, https://developer.scaleway.com/#servers-server-get)
+                  can be used.'
+    type: dict
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 # scaleway_inventory.yml file in YAML format
 # Example command line: ansible-inventory --list -i scaleway_inventory.yml
 
+---
 # use hostname as inventory_hostname
 # use the private IP address to connect to the host
 plugin: community.general.scaleway
@@ -89,6 +91,7 @@ variables:
   ansible_host: private_ip
   state: state
 
+---
 # use hostname as inventory_hostname and public IP address to connect to the host
 plugin: community.general.scaleway
 hostnames:
@@ -98,6 +101,7 @@ regions:
 variables:
   ansible_host: public_ip.address
 
+---
 # Using static strings as variables
 plugin: community.general.scaleway
 hostnames:
@@ -106,7 +110,7 @@ variables:
   ansible_host: public_ip.address
   ansible_connection: "'ssh'"
   ansible_user: "'admin'"
-'''
+"""
 
 import os
 import json
@@ -121,10 +125,10 @@ else:
 from ansible.errors import AnsibleError
 from ansible.plugins.inventory import BaseInventoryPlugin, Constructable
 from ansible_collections.community.general.plugins.module_utils.scaleway import SCALEWAY_LOCATION, parse_pagination_link
+from ansible_collections.community.general.plugins.plugin_utils.unsafe import make_unsafe
 from ansible.module_utils.urls import open_url
-from ansible.module_utils.common.text.converters import to_native, to_text
+from ansible.module_utils.common.text.converters import to_text
 from ansible.module_utils.six import raise_from
-from ansible.utils.unsafe_proxy import wrap_var as make_unsafe
 
 import ansible.module_utils.six.moves.urllib.parse as urllib_parse
 
@@ -138,7 +142,7 @@ def _fetch_information(token, url):
                                 headers={'X-Auth-Token': token,
                                          'Content-type': 'application/json'})
         except Exception as e:
-            raise AnsibleError("Error while fetching %s: %s" % (url, to_native(e)))
+            raise AnsibleError(f"Error while fetching {url}: {e}")
         try:
             raw_json = json.loads(to_text(response.read()))
         except ValueError:
@@ -159,7 +163,7 @@ def _fetch_information(token, url):
 
 
 def _build_server_url(api_endpoint):
-    return "/".join([api_endpoint, "servers"])
+    return f"{api_endpoint}/servers"
 
 
 def extract_public_ipv4(server_info):
