@@ -6,58 +6,64 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-DOCUMENTATION = '''
-    author: Unknown (!UNKNOWN)
-    name: cyberarkpassword
-    short_description: get secrets from CyberArk AIM
-    requirements:
-      - CyberArk AIM tool installed
+DOCUMENTATION = r"""
+author: Unknown (!UNKNOWN)
+name: cyberarkpassword
+short_description: get secrets from CyberArk AIM
+requirements:
+  - CyberArk AIM tool installed
+description:
+  - Get secrets from CyberArk AIM.
+options:
+  _command:
+    description: Cyberark CLI utility.
+    type: string
+    env:
+      - name: AIM_CLIPASSWORDSDK_CMD
+    default: '/opt/CARKaim/sdk/clipasswordsdk'
+  appid:
+    description: Defines the unique ID of the application that is issuing the password request.
+    type: string
+    required: true
+  query:
+    description: Describes the filter criteria for the password retrieval.
+    type: string
+    required: true
+  output:
     description:
-      - Get secrets from CyberArk AIM.
-    options :
-      _command:
-        description: Cyberark CLI utility.
-        env:
-          - name: AIM_CLIPASSWORDSDK_CMD
-        default: '/opt/CARKaim/sdk/clipasswordsdk'
-      appid:
-        description: Defines the unique ID of the application that is issuing the password request.
-        required: true
-      query:
-        description: Describes the filter criteria for the password retrieval.
-        required: true
-      output:
-        description:
-          - Specifies the desired output fields separated by commas.
-          - "They could be: Password, PassProps.<property>, PasswordChangeInProcess"
-        default: 'password'
-      _extra:
-        description: for extra_params values please check parameters for clipasswordsdk in CyberArk's "Credential Provider and ASCP Implementation Guide"
-    notes:
-      - For Ansible on Windows, please change the -parameters (-p, -d, and -o) to /parameters (/p, /d, and /o) and change the location of CLIPasswordSDK.exe.
-'''
-
-EXAMPLES = """
-  - name: passing options to the lookup
-    ansible.builtin.debug:
-        msg: '{{ lookup("community.general.cyberarkpassword", cyquery) }}'
-    vars:
-      cyquery:
-        appid: "app_ansible"
-        query: "safe=CyberArk_Passwords;folder=root;object=AdminPass"
-        output: "Password,PassProps.UserName,PassProps.Address,PasswordChangeInProcess"
-
-
-  - name: used in a loop
-    ansible.builtin.debug:
-        msg: "{{item}}"
-    with_community.general.cyberarkpassword:
-        appid: 'app_ansible'
-        query: 'safe=CyberArk_Passwords;folder=root;object=AdminPass'
-        output: 'Password,PassProps.UserName,PassProps.Address,PasswordChangeInProcess'
+      - Specifies the desired output fields separated by commas.
+      - 'They could be: Password, PassProps.<property>, PasswordChangeInProcess.'
+    type: string
+    default: 'password'
+  _extra:
+    description: For extra_params values please check parameters for clipasswordsdk in CyberArk's "Credential Provider and
+      ASCP Implementation Guide".
+notes:
+  - For Ansible on Windows, please change the -parameters (C(-p), C(-d), and C(-o)) to /parameters (C(/p), C(/d), and C(/o)) and change the
+    location of C(CLIPasswordSDK.exe).
 """
 
-RETURN = """
+EXAMPLES = r"""
+- name: passing options to the lookup
+  ansible.builtin.debug:
+    msg: '{{ lookup("community.general.cyberarkpassword", cyquery) }}'
+  vars:
+    cyquery:
+      appid: "app_ansible"
+      query: "safe=CyberArk_Passwords;folder=root;object=AdminPass"
+      output: "Password,PassProps.UserName,PassProps.Address,PasswordChangeInProcess"
+
+
+- name: used in a loop
+  ansible.builtin.debug:
+    msg: "{{item}}"
+  with_community.general.cyberarkpassword:
+    appid: 'app_ansible'
+    query: 'safe=CyberArk_Passwords;folder=root;object=AdminPass'
+    output: 'Password,PassProps.UserName,PassProps.Address,PasswordChangeInProcess'
+"""
+
+RETURN = r"""
 _result:
   description: A list containing one dictionary.
   type: list
@@ -65,12 +71,12 @@ _result:
   contains:
     password:
       description:
-        - The actual value stored
+        - The actual value stored.
     passprops:
-      description: properties assigned to the entry
+      description: Properties assigned to the entry.
       type: dictionary
     passwordchangeinprocess:
-      description: did the password change?
+      description: Did the password change?
 """
 
 import os
@@ -80,8 +86,7 @@ from subprocess import Popen
 
 from ansible.errors import AnsibleError
 from ansible.plugins.lookup import LookupBase
-from ansible.parsing.splitter import parse_kv
-from ansible.module_utils.common.text.converters import to_bytes, to_text, to_native
+from ansible.module_utils.common.text.converters import to_bytes, to_native
 from ansible.utils.display import Display
 
 display = Display()
@@ -102,7 +107,7 @@ class CyberarkPassword:
         self.extra_parms = []
         for key, value in kwargs.items():
             self.extra_parms.append('-p')
-            self.extra_parms.append("%s=%s" % (key, value))
+            self.extra_parms.append(f"{key}={value}")
 
         if self.appid is None:
             raise AnsibleError("CyberArk Error: No Application ID specified")
@@ -127,8 +132,8 @@ class CyberarkPassword:
             all_parms = [
                 CLIPASSWORDSDK_CMD,
                 'GetPassword',
-                '-p', 'AppDescs.AppID=%s' % self.appid,
-                '-p', 'Query=%s' % self.query,
+                '-p', f'AppDescs.AppID={self.appid}',
+                '-p', f'Query={self.query}',
                 '-o', self.output,
                 '-d', self.b_delimiter]
             all_parms.extend(self.extra_parms)
@@ -141,7 +146,7 @@ class CyberarkPassword:
                 b_credential = to_bytes(tmp_output)
 
             if tmp_error:
-                raise AnsibleError("ERROR => %s " % (tmp_error))
+                raise AnsibleError(f"ERROR => {tmp_error} ")
 
             if b_credential and b_credential.endswith(b'\n'):
                 b_credential = b_credential[:-1]
@@ -161,7 +166,7 @@ class CyberarkPassword:
         except subprocess.CalledProcessError as e:
             raise AnsibleError(e.output)
         except OSError as e:
-            raise AnsibleError("ERROR - AIM not installed or clipasswordsdk not in standard location. ERROR=(%s) => %s " % (to_text(e.errno), e.strerror))
+            raise AnsibleError(f"ERROR - AIM not installed or clipasswordsdk not in standard location. ERROR=({e.errno}) => {e.strerror} ")
 
         return [result_dict]
 
@@ -174,11 +179,11 @@ class LookupModule(LookupBase):
     """
 
     def run(self, terms, variables=None, **kwargs):
-        display.vvvv("%s" % terms)
+        display.vvvv(f"{terms}")
         if isinstance(terms, list):
             return_values = []
             for term in terms:
-                display.vvvv("Term: %s" % term)
+                display.vvvv(f"Term: {term}")
                 cyberark_conn = CyberarkPassword(**term)
                 return_values.append(cyberark_conn.get())
             return return_values
