@@ -6,35 +6,35 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-DOCUMENTATION = '''
-    name: flattened
-    author: Serge van Ginderachter (!UNKNOWN) <serge@vanginderachter.be>
-    short_description: return single list completely flattened
-    description:
-      - Given one or more lists, this lookup will flatten any list elements found recursively until only 1 list is left.
-    options:
-      _terms:
-        description: lists to flatten
-        type: list
-        elements: raw
-        required: true
-    notes:
-      - Unlike the P(ansible.builtin.items#lookup) lookup which only flattens 1 level,
-        this plugin will continue to flatten until it cannot find lists anymore.
-      - Aka highlander plugin, there can only be one (list).
-'''
+DOCUMENTATION = r"""
+name: flattened
+author: Serge van Ginderachter (!UNKNOWN) <serge@vanginderachter.be>
+short_description: return single list completely flattened
+description:
+  - Given one or more lists, this lookup will flatten any list elements found recursively until only 1 list is left.
+options:
+  _terms:
+    description: Lists to flatten.
+    type: list
+    elements: raw
+    required: true
+notes:
+  - Unlike the P(ansible.builtin.items#lookup) lookup which only flattens 1 level, this plugin will continue to flatten until
+    it cannot find lists anymore.
+  - Aka highlander plugin, there can only be one (list).
+"""
 
-EXAMPLES = """
+EXAMPLES = r"""
 - name: "'unnest' all elements into single list"
   ansible.builtin.debug:
     msg: "all in one list {{lookup('community.general.flattened', [1,2,3,[5,6]], ['a','b','c'], [[5,6,1,3], [34,'a','b','c']])}}"
 """
 
-RETURN = """
-  _raw:
-    description:
-      - flattened list
-    type: list
+RETURN = r"""
+_raw:
+  description:
+    - Flattened list.
+  type: list
 """
 from ansible.errors import AnsibleError
 from ansible.module_utils.six import string_types
@@ -78,7 +78,7 @@ class LookupModule(LookupBase):
                     term = term2
 
             if isinstance(term, list):
-                # if it's a list, check recursively for items that are a list
+                # if it is a list, check recursively for items that are a list
                 term = self._do_flatten(term, variables)
                 ret.extend(term)
             else:
