@@ -9,132 +9,131 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 DOCUMENTATION = r"""
-    name: random_string
-    author:
-      - Abhijeet Kasurde (@Akasurde)
-    short_description: Generates random string
-    version_added: '3.2.0'
+name: random_string
+author:
+  - Abhijeet Kasurde (@Akasurde)
+short_description: Generates random string
+version_added: '3.2.0'
+description:
+  - Generates random string based upon the given constraints.
+  - Uses L(random.SystemRandom,https://docs.python.org/3/library/random.html#random.SystemRandom), so should be strong enough
+    for cryptographic purposes.
+options:
+  length:
+    description: The length of the string.
+    default: 8
+    type: int
+  upper:
     description:
-      - Generates random string based upon the given constraints.
-      - Uses L(random.SystemRandom,https://docs.python.org/3/library/random.html#random.SystemRandom),
-        so should be strong enough for cryptographic purposes.
-    options:
-      length:
-        description: The length of the string.
-        default: 8
-        type: int
-      upper:
-        description:
-        - Include uppercase letters in the string.
-        default: true
-        type: bool
-      lower:
-        description:
-        - Include lowercase letters in the string.
-        default: true
-        type: bool
-      numbers:
-        description:
-        - Include numbers in the string.
-        default: true
-        type: bool
-      special:
-        description:
-        - Include special characters in the string.
-        - Special characters are taken from Python standard library C(string).
-          See L(the documentation of string.punctuation,https://docs.python.org/3/library/string.html#string.punctuation)
-          for which characters will be used.
-        - The choice of special characters can be changed to setting O(override_special).
-        default: true
-        type: bool
-      min_numeric:
-        description:
-        - Minimum number of numeric characters in the string.
-        - If set, overrides O(numbers=false).
-        default: 0
-        type: int
-      min_upper:
-        description:
-        - Minimum number of uppercase alphabets in the string.
-        - If set, overrides O(upper=false).
-        default: 0
-        type: int
-      min_lower:
-        description:
-        - Minimum number of lowercase alphabets in the string.
-        - If set, overrides O(lower=false).
-        default: 0
-        type: int
-      min_special:
-        description:
-        - Minimum number of special character in the string.
-        default: 0
-        type: int
-      override_special:
-        description:
-        - Overide a list of special characters to use in the string.
-        - If set O(min_special) should be set to a non-default value.
-        type: str
-      override_all:
-        description:
-        - Override all values of O(numbers), O(upper), O(lower), and O(special) with
-          the given list of characters.
-        type: str
-      ignore_similar_chars:
-        description:
-        - Ignore similar characters, such as V(l) and V(1), or V(O) and V(0).
-        - These characters can be configured in O(similar_chars).
-        default: false
-        type: bool
-        version_added: 7.5.0
-      similar_chars:
-        description:
-        - Overide a list of characters not to be use in the string.
-        default: "il1LoO0"
-        type: str
-        version_added: 7.5.0
-      base64:
-        description:
-        - Returns base64 encoded string.
-        type: bool
-        default: false
+      - Include uppercase letters in the string.
+    default: true
+    type: bool
+  lower:
+    description:
+      - Include lowercase letters in the string.
+    default: true
+    type: bool
+  numbers:
+    description:
+      - Include numbers in the string.
+    default: true
+    type: bool
+  special:
+    description:
+      - Include special characters in the string.
+      - Special characters are taken from Python standard library C(string).
+        See L(the documentation of string.punctuation,https://docs.python.org/3/library/string.html#string.punctuation)
+        for which characters will be used.
+      - The choice of special characters can be changed to setting O(override_special).
+    default: true
+    type: bool
+  min_numeric:
+    description:
+      - Minimum number of numeric characters in the string.
+      - If set, overrides O(numbers=false).
+    default: 0
+    type: int
+  min_upper:
+    description:
+      - Minimum number of uppercase alphabets in the string.
+      - If set, overrides O(upper=false).
+    default: 0
+    type: int
+  min_lower:
+    description:
+      - Minimum number of lowercase alphabets in the string.
+      - If set, overrides O(lower=false).
+    default: 0
+    type: int
+  min_special:
+    description:
+      - Minimum number of special character in the string.
+    default: 0
+    type: int
+  override_special:
+    description:
+      - Override a list of special characters to use in the string.
+      - If set O(min_special) should be set to a non-default value.
+    type: str
+  override_all:
+    description:
+      - Override all values of O(numbers), O(upper), O(lower), and O(special) with the given list of characters.
+    type: str
+  ignore_similar_chars:
+    description:
+      - Ignore similar characters, such as V(l) and V(1), or V(O) and V(0).
+      - These characters can be configured in O(similar_chars).
+    default: false
+    type: bool
+    version_added: 7.5.0
+  similar_chars:
+    description:
+      - Override a list of characters not to be use in the string.
+    default: "il1LoO0"
+    type: str
+    version_added: 7.5.0
+  base64:
+    description:
+      - Returns base64 encoded string.
+    type: bool
+    default: false
 """
 
 EXAMPLES = r"""
 - name: Generate random string
   ansible.builtin.debug:
     var: lookup('community.general.random_string')
-  # Example result: ['DeadBeeF']
+  # Example result: 'DeadBeeF'
 
 - name: Generate random string with length 12
   ansible.builtin.debug:
     var: lookup('community.general.random_string', length=12)
-  # Example result: ['Uan0hUiX5kVG']
+  # Example result: 'Uan0hUiX5kVG'
 
 - name: Generate base64 encoded random string
   ansible.builtin.debug:
     var: lookup('community.general.random_string', base64=True)
-  # Example result: ['NHZ6eWN5Qk0=']
+  # Example result: 'NHZ6eWN5Qk0='
 
-- name: Generate a random string with 1 lower, 1 upper, 1 number and 1 special char (atleast)
+- name: Generate a random string with 1 lower, 1 upper, 1 number and 1 special char (at least)
   ansible.builtin.debug:
     var: lookup('community.general.random_string', min_lower=1, min_upper=1, min_special=1, min_numeric=1)
-  # Example result: ['&Qw2|E[-']
+  # Example result: '&Qw2|E[-'
 
 - name: Generate a random string with all lower case characters
-  debug:
+  ansible.builtin.debug:
     var: query('community.general.random_string', upper=false, numbers=false, special=false)
   # Example result: ['exolxzyz']
 
 - name: Generate random hexadecimal string
-  debug:
+  ansible.builtin.debug:
     var: query('community.general.random_string', upper=false, lower=false, override_special=hex_chars, numbers=false)
   vars:
     hex_chars: '0123456789ABCDEF'
   # Example result: ['D2A40737']
 
 - name: Generate random hexadecimal string with override_all
-  debug:
+  ansible.builtin.debug:
     var: query('community.general.random_string', override_all=hex_chars)
   vars:
     hex_chars: '0123456789ABCDEF'
@@ -142,10 +141,10 @@ EXAMPLES = r"""
 """
 
 RETURN = r"""
-  _raw:
-    description: A one-element list containing a random string
-    type: list
-    elements: str
+_raw:
+  description: A one-element list containing a random string.
+  type: list
+  elements: str
 """
 
 import base64
