@@ -7,17 +7,17 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = """
----
+DOCUMENTATION = r"""
 module: gio_mime
 author:
-- "Alexei Znamensky (@russoz)"
+  - "Alexei Znamensky (@russoz)"
 short_description: Set default handler for MIME type, for applications using Gnome GIO
 version_added: 7.5.0
 description:
-- This module allows configuring the default handler for a specific MIME type, to be used by applications built with th Gnome GIO API.
+  - This module allows configuring the default handler for a specific MIME type, to be used by applications built with the
+    Gnome GIO API.
 extends_documentation_fragment:
-- community.general.attributes
+  - community.general.attributes
 attributes:
   check_mode:
     support: full
@@ -26,28 +26,27 @@ attributes:
 options:
   mime_type:
     description:
-    - MIME type for which a default handler will be set.
+      - MIME type for which a default handler is set.
     type: str
     required: true
   handler:
     description:
-    - Default handler will be set for the MIME type.
+      - Default handler set for the MIME type.
     type: str
     required: true
 notes:
-- This module is a thin wrapper around the C(gio mime) command (and subcommand).
-- See man gio(1) for more details.
+  - This module is a thin wrapper around the C(gio mime) command (and subcommand).
+  - See man gio(1) for more details.
 seealso:
-- name: C(gio) command manual page
-  description: Manual page for the command.
-  link: https://man.archlinux.org/man/gio.1
-- name: GIO Documentation
-  description: Reference documentation for the GIO API..
-  link: https://docs.gtk.org/gio/
+  - name: C(gio) command manual page
+    description: Manual page for the command.
+    link: https://man.archlinux.org/man/gio.1
+  - name: GIO Documentation
+    description: Reference documentation for the GIO API..
+    link: https://docs.gtk.org/gio/
 """
 
-EXAMPLES = """
----
+EXAMPLES = r"""
 - name: Set chrome as the default handler for https
   community.general.gio_mime:
     mime_type: x-scheme-handler/https
@@ -55,26 +54,13 @@ EXAMPLES = """
   register: result
 """
 
-RETURN = """
----
+RETURN = r"""
 handler:
   description:
-  - The handler set as default.
+    - The handler set as default.
   returned: success
   type: str
   sample: google-chrome.desktop
-stdout:
-  description:
-  - The output of the C(gio) command.
-  returned: success
-  type: str
-  sample: Set google-chrome.desktop as the default for x-scheme-handler/https
-stderr:
-  description:
-  - The error output of the C(gio) command.
-  returned: failure
-  type: str
-  sample: 'gio: Failed to load info for handler "never-existed.desktop"'
 version:
   description: Version of gio.
   type: str
