@@ -7,18 +7,17 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 module: gitlab_project_variable
 short_description: Creates/updates/deletes GitLab Projects Variables
 description:
-  - When a project variable does not exist, it will be created.
-  - When a project variable does exist, its value will be updated when the values are different.
-  - Variables which are untouched in the playbook, but are not untouched in the GitLab project,
-    they stay untouched (O(purge=false)) or will be deleted (O(purge=true)).
+  - When a project variable does not exist, it is created.
+  - When a project variable does exist, its value is updated when the values are different.
+  - Variables which are untouched in the playbook, but are not untouched in the GitLab project, they stay untouched (O(purge=false))
+    or are deleted (O(purge=true)).
 author:
   - "Markus Bergholz (@markuman)"
 requirements:
-  - python >= 2.7
   - python-gitlab python module
 extends_documentation_fragment:
   - community.general.auth_basic
@@ -46,14 +45,14 @@ options:
     type: str
   purge:
     description:
-      - When set to true, all variables which are not untouched in the task will be deleted.
+      - When set to V(true), all variables which are not untouched in the task are deleted.
     default: false
     type: bool
   vars:
     description:
-      - When the list element is a simple key-value pair, masked, raw and protected will be set to false.
-      - When the list element is a dict with the keys C(value), C(masked), C(raw) and C(protected), the user can
-        have full control about whether a value should be masked, raw, protected or both.
+      - When the list element is a simple key-value pair, masked, raw and protected are set to V(false).
+      - When the list element is a dict with the keys C(value), C(masked), C(raw) and C(protected), the user can have full
+        control about whether a value should be masked, raw, protected or both.
       - Support for protected values requires GitLab >= 9.3.
       - Support for masked values requires GitLab >= 11.10.
       - Support for raw values requires GitLab >= 15.7.
@@ -62,8 +61,8 @@ options:
       - A C(value) must be a string or a number.
       - Field C(variable_type) must be a string with either V(env_var), which is the default, or V(file).
       - Field C(environment_scope) must be a string defined by scope environment.
-      - When a value is masked, it must be in Base64 and have a length of at least 8 characters.
-        See GitLab documentation on acceptable values for a masked variable (https://docs.gitlab.com/ce/ci/variables/#masked-variables).
+      - When a value is masked, it must be in Base64 and have a length of at least 8 characters. See GitLab documentation
+        on acceptable values for a masked variable (https://docs.gitlab.com/ce/ci/variables/#masked-variables).
     default: {}
     type: dict
   variables:
@@ -87,26 +86,26 @@ options:
         type: str
       masked:
         description:
-          - Wether variable value is masked or not.
+          - Whether variable value is masked or not.
           - Support for masked values requires GitLab >= 11.10.
         type: bool
         default: false
       protected:
         description:
-          - Wether variable value is protected or not.
+          - Whether variable value is protected or not.
           - Support for protected values requires GitLab >= 9.3.
         type: bool
         default: false
       raw:
         description:
-          - Wether variable value is raw or not.
+          - Whether variable value is raw or not.
           - Support for raw values requires GitLab >= 15.7.
         type: bool
         default: false
         version_added: '7.4.0'
       variable_type:
         description:
-          - Wether a variable is an environment variable (V(env_var)) or a file (V(file)).
+          - Whether a variable is an environment variable (V(env_var)) or a file (V(file)).
           - Support for O(variables[].variable_type) requires GitLab >= 11.11.
         type: str
         choices: ["env_var", "file"]
@@ -117,10 +116,10 @@ options:
           - Support for O(variables[].environment_scope) requires GitLab Premium >= 13.11.
         type: str
         default: '*'
-'''
+"""
 
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Set or update some CI/CD variables
   community.general.gitlab_project_variable:
     api_url: https://gitlab.com
@@ -191,9 +190,9 @@ EXAMPLES = '''
     state: absent
     vars:
       ACCESS_KEY_ID: abc123
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 project_variable:
   description: Four lists of the variablenames which were added, updated, removed or exist.
   returned: always
@@ -203,31 +202,31 @@ project_variable:
       description: A list of variables which were created.
       returned: always
       type: list
-      sample: ['ACCESS_KEY_ID', 'SECRET_ACCESS_KEY']
+      sample: ["ACCESS_KEY_ID", "SECRET_ACCESS_KEY"]
     untouched:
       description: A list of variables which exist.
       returned: always
       type: list
-      sample: ['ACCESS_KEY_ID', 'SECRET_ACCESS_KEY']
+      sample: ["ACCESS_KEY_ID", "SECRET_ACCESS_KEY"]
     removed:
       description: A list of variables which were deleted.
       returned: always
       type: list
-      sample: ['ACCESS_KEY_ID', 'SECRET_ACCESS_KEY']
+      sample: ["ACCESS_KEY_ID", "SECRET_ACCESS_KEY"]
     updated:
       description: A list of variables whose values were changed.
       returned: always
       type: list
-      sample: ['ACCESS_KEY_ID', 'SECRET_ACCESS_KEY']
-'''
+      sample: ["ACCESS_KEY_ID", "SECRET_ACCESS_KEY"]
+"""
 
-from ansible.module_utils.basic import AnsibleModule, missing_required_lib
+from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.api import basic_auth_argument_spec
 
 
 from ansible_collections.community.general.plugins.module_utils.gitlab import (
-    auth_argument_spec, gitlab_authentication, ensure_gitlab_package, filter_returned_variables, vars_to_variables,
-    HAS_GITLAB_PACKAGE, GITLAB_IMP_ERR
+    auth_argument_spec, gitlab_authentication, filter_returned_variables, vars_to_variables,
+    list_all_kwargs
 )
 
 
@@ -242,14 +241,7 @@ class GitlabProjectVariables(object):
         return self.repo.projects.get(project_name)
 
     def list_all_project_variables(self):
-        page_nb = 1
-        variables = []
-        vars_page = self.project.variables.list(page=page_nb)
-        while len(vars_page) > 0:
-            variables += vars_page
-            page_nb += 1
-            vars_page = self.project.variables.list(page=page_nb)
-        return variables
+        return list(self.project.variables.list(**list_all_kwargs))
 
     def create_variable(self, var_obj):
         if self._module.check_mode:
@@ -436,10 +428,9 @@ def main():
         ],
         supports_check_mode=True
     )
-    ensure_gitlab_package(module)
 
-    if not HAS_GITLAB_PACKAGE:
-        module.fail_json(msg=missing_required_lib("python-gitlab"), exception=GITLAB_IMP_ERR)
+    # check prerequisites and connect to gitlab server
+    gitlab_instance = gitlab_authentication(module)
 
     purge = module.params['purge']
     var_list = module.params['vars']
@@ -454,8 +445,6 @@ def main():
         if any(x['value'] is None for x in variables):
             module.fail_json(msg='value parameter is required for all variables in state present')
 
-    gitlab_instance = gitlab_authentication(module)
-
     this_gitlab = GitlabProjectVariables(module=module, gitlab_instance=gitlab_instance)
 
     change, raw_return_value, before, after = native_python_main(this_gitlab, purge, variables, state, module)
