@@ -10,15 +10,14 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: gitlab_user
 short_description: Creates/updates/deletes/blocks/unblocks GitLab Users
 description:
-  - When the user does not exist in GitLab, it will be created.
-  - When the user exists and state=absent, the user will be deleted.
-  - When the user exists and state=blocked, the user will be blocked.
-  - When changes are made to user, the user will be updated.
+  - When the user does not exist in GitLab, it is created.
+  - When the user exists and state=absent, the user is deleted.
+  - When the user exists and state=blocked, the user is blocked.
+  - When changes are made to user, the user is updated.
 notes:
   - From community.general 0.2.0 and onwards, name, email and password are optional while deleting the user.
 author:
@@ -27,7 +26,6 @@ author:
   - Lennert Mertens (@LennertMertens)
   - Stef Graces (@stgrace)
 requirements:
-  - python >= 2.7
   - python-gitlab python module
   - administrator rights on the GitLab server
 extends_documentation_fragment:
@@ -84,18 +82,13 @@ options:
     version_added: 3.1.0
   group:
     description:
-      - Id or Full path of parent group in the form of group/name.
+      - ID or Full path of parent group in the form of group/name.
       - Add user as a member to this group.
     type: str
   access_level:
     description:
-      - The access level to the group. One of the following can be used.
-      - guest
-      - reporter
-      - developer
-      - master (alias for maintainer)
-      - maintainer
-      - owner
+      - The access level to the group.
+      - The value V(master) is an alias for V(maintainer).
     default: guest
     type: str
     choices: ["guest", "reporter", "developer", "master", "maintainer", "owner"]
@@ -129,7 +122,7 @@ options:
     suboptions:
       provider:
         description:
-          - The name of the external identity provider
+          - The name of the external identity provider.
         type: str
       extern_uid:
         description:
@@ -144,14 +137,13 @@ options:
     type: bool
     default: false
     version_added: 3.3.0
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: "Delete GitLab User"
   community.general.gitlab_user:
     api_url: https://gitlab.example.com/
     api_token: "{{ access_token }}"
-    validate_certs: false
     username: myusername
     state: absent
 
@@ -181,8 +173,8 @@ EXAMPLES = '''
     password: mysecretpassword
     email: me@example.com
     identities:
-    - provider: Keycloak
-      extern_uid: f278f95c-12c7-4d51-996f-758cc2eb11bc
+      - provider: Keycloak
+        extern_uid: f278f95c-12c7-4d51-996f-758cc2eb11bc
     state: present
     group: super_group/mon_group
     access_level: owner
@@ -191,7 +183,6 @@ EXAMPLES = '''
   community.general.gitlab_user:
     api_url: https://gitlab.example.com/
     api_token: "{{ access_token }}"
-    validate_certs: false
     username: myusername
     state: blocked
 
@@ -199,34 +190,33 @@ EXAMPLES = '''
   community.general.gitlab_user:
     api_url: https://gitlab.example.com/
     api_token: "{{ access_token }}"
-    validate_certs: false
     username: myusername
     state: unblocked
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 msg:
-  description: Success or failure message
+  description: Success or failure message.
   returned: always
   type: str
   sample: "Success"
 
 result:
-  description: json parsed response from the server
+  description: JSON-parsed response from the server.
   returned: always
   type: dict
 
 error:
-  description: the error message returned by the GitLab API
+  description: The error message returned by the GitLab API.
   returned: failed
   type: str
   sample: "400: path is already in use"
 
 user:
-  description: API object
+  description: API object.
   returned: always
   type: dict
-'''
+"""
 
 
 from ansible.module_utils.api import basic_auth_argument_spec
@@ -234,7 +224,7 @@ from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.common.text.converters import to_native
 
 from ansible_collections.community.general.plugins.module_utils.gitlab import (
-    auth_argument_spec, find_group, gitlab_authentication, gitlab, ensure_gitlab_package
+    auth_argument_spec, find_group, gitlab_authentication, gitlab, list_all_kwargs
 )
 
 
@@ -244,12 +234,12 @@ class GitLabUser(object):
         self._gitlab = gitlab_instance
         self.user_object = None
         self.ACCESS_LEVEL = {
-            'guest': gitlab.GUEST_ACCESS,
-            'reporter': gitlab.REPORTER_ACCESS,
-            'developer': gitlab.DEVELOPER_ACCESS,
-            'master': gitlab.MAINTAINER_ACCESS,
-            'maintainer': gitlab.MAINTAINER_ACCESS,
-            'owner': gitlab.OWNER_ACCESS,
+            'guest': gitlab.const.GUEST_ACCESS,
+            'reporter': gitlab.const.REPORTER_ACCESS,
+            'developer': gitlab.const.DEVELOPER_ACCESS,
+            'master': gitlab.const.MAINTAINER_ACCESS,
+            'maintainer': gitlab.const.MAINTAINER_ACCESS,
+            'owner': gitlab.const.OWNER_ACCESS,
         }
 
     '''
@@ -349,9 +339,10 @@ class GitLabUser(object):
     @param sshkey_name Name of the ssh key
     '''
     def ssh_key_exists(self, user, sshkey_name):
-        keyList = map(lambda k: k.title, user.keys.list(all=True))
-
-        return sshkey_name in keyList
+        return any(
+            k.title == sshkey_name
+            for k in user.keys.list(**list_all_kwargs)
+        )
 
     '''
     @param user User object
@@ -485,7 +476,7 @@ class GitLabUser(object):
 
     '''
     @param user User object
-    @param identites List of identities to be added/updated
+    @param identities List of identities to be added/updated
     @param overwrite_identities Overwrite user identities with identities passed to this module
     '''
     def add_identities(self, user, identities, overwrite_identities=False):
@@ -504,7 +495,7 @@ class GitLabUser(object):
 
     '''
     @param user User object
-    @param identites List of identities to be added/updated
+    @param identities List of identities to be added/updated
     '''
     def delete_identities(self, user, identities):
         changed = False
@@ -519,10 +510,13 @@ class GitLabUser(object):
     @param username Username of the user
     '''
     def find_user(self, username):
-        users = self._gitlab.users.list(search=username, all=True)
-        for user in users:
-            if (user.username == username):
-                return user
+        return next(
+            (
+                user for user in self._gitlab.users.list(search=username, **list_all_kwargs)
+                if user.username == username
+            ),
+            None
+        )
 
     '''
     @param username Username of the user
@@ -616,7 +610,9 @@ def main():
             ('state', 'present', ['name', 'email']),
         )
     )
-    ensure_gitlab_package(module)
+
+    # check prerequisites and connect to gitlab server
+    gitlab_instance = gitlab_authentication(module)
 
     user_name = module.params['name']
     state = module.params['state']
@@ -635,8 +631,6 @@ def main():
     user_identities = module.params['identities']
     overwrite_identities = module.params['overwrite_identities']
 
-    gitlab_instance = gitlab_authentication(module)
-
     gitlab_user = GitLabUser(module, gitlab_instance)
     user_exists = gitlab_user.exists_user(user_username)
     if user_exists:
