@@ -9,13 +9,12 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: hponcfg
 author: Dag Wieers (@dagwieers)
-short_description: Configure HP iLO interface using hponcfg
+short_description: Configure HP iLO interface using C(hponcfg)
 description:
-  - This modules configures the HP iLO interface using hponcfg.
+  - This modules configures the HP iLO interface using C(hponcfg).
 extends_documentation_fragment:
   - community.general.attributes
 attributes:
@@ -26,32 +25,32 @@ attributes:
 options:
   path:
     description:
-     - The XML file as accepted by hponcfg.
+      - The XML file as accepted by C(hponcfg).
     required: true
     aliases: ['src']
     type: path
   minfw:
     description:
-     - The minimum firmware level needed.
+      - The minimum firmware level needed.
     required: false
     type: str
   executable:
     description:
-     - Path to the hponcfg executable (C(hponcfg) which uses $PATH).
+      - Path to the hponcfg executable (C(hponcfg) which uses E(PATH)).
     default: hponcfg
     type: str
   verbose:
     description:
-     - Run hponcfg in verbose mode (-v).
+      - Run C(hponcfg) in verbose mode (-v).
     default: false
     type: bool
 requirements:
- - hponcfg tool
+  - hponcfg tool
 notes:
- - You need a working hponcfg on the target system.
-'''
+  - You need a working C(hponcfg) on the target system.
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 - name: Example hponcfg configuration XML
   ansible.builtin.copy:
     content: |
@@ -78,7 +77,7 @@ EXAMPLES = r'''
   community.general.hponcfg:
     src: /tmp/enable-ssh.xml
     executable: /opt/hp/tools/hponcfg
-'''
+"""
 
 from ansible_collections.community.general.plugins.module_utils.cmd_runner import CmdRunner, cmd_runner_fmt
 from ansible_collections.community.general.plugins.module_utils.module_helper import ModuleHelper
@@ -98,6 +97,7 @@ class HPOnCfg(ModuleHelper):
         verbose=cmd_runner_fmt.as_bool("-v"),
         minfw=cmd_runner_fmt.as_opt_val("-m"),
     )
+    use_old_vardict = False
 
     def __run__(self):
         runner = CmdRunner(
