@@ -9,12 +9,11 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: proxmox_template
 short_description: Management of OS templates in Proxmox VE cluster
 description:
-  - allows you to upload/delete templates in Proxmox VE cluster
+  - Allows you to upload/delete templates in Proxmox VE cluster.
 attributes:
   check_mode:
     support: none
@@ -30,8 +29,14 @@ options:
   src:
     description:
       - Path to uploaded file.
-      - Required only for O(state=present).
+      - Exactly one of O(src) or O(url) is required for O(state=present).
     type: path
+  url:
+    description:
+      - URL to file to download.
+      - Exactly one of O(src) or O(url) is required for O(state=present).
+    type: str
+    version_added: 10.1.0
   template:
     description:
       - The template name.
@@ -62,10 +67,25 @@ options:
     default: false
   state:
     description:
-     - Indicate desired state of the template.
+      - Indicate desired state of the template.
     type: str
     choices: ['present', 'absent']
     default: present
+  checksum_algorithm:
+    description:
+      - Algorithm used to verify the checksum.
+      - If specified, O(checksum) must also be specified.
+    type: str
+    choices: ['md5', 'sha1', 'sha224', 'sha256', 'sha384', 'sha512']
+    version_added: 10.3.0
+  checksum:
+    description:
+      - The checksum to validate against.
+      - Checksums are often provided by software distributors to verify that a download is not corrupted.
+      - Checksums can usually be found on the distributors download page in the form of a file or string.
+      - If specified, O(checksum_algorithm) must also be specified.
+    type: str
+    version_added: 10.3.0
 notes:
   - Requires C(proxmoxer) and C(requests) modules on host. Those modules can be installed with M(ansible.builtin.pip).
   - C(proxmoxer) >= 1.2.0 requires C(requests_toolbelt) to upload files larger than 256 MB.
@@ -74,9 +94,10 @@ extends_documentation_fragment:
   - community.general.proxmox.actiongroup_proxmox
   - community.general.proxmox.documentation
   - community.general.attributes
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
+---
 - name: Upload new openvz template with minimal options
   community.general.proxmox_template:
     node: uk-mc02
@@ -85,6 +106,14 @@ EXAMPLES = '''
     api_host: node1
     src: ~/ubuntu-14.04-x86_64.tar.gz
 
+- name: Pull new openvz template with minimal options
+  community.general.proxmox_template:
+    node: uk-mc02
+    api_user: root@pam
+    api_password: 1q2w3e
+    api_host: node1
+    url: https://ubuntu-mirror/ubuntu-14.04-x86_64.tar.gz
+
 - name: >
     Upload new openvz template with minimal options use environment
     PROXMOX_PASSWORD variable(you should export it before)
@@ -105,6 +134,17 @@ EXAMPLES = '''
     src: ~/ubuntu-14.04-x86_64.tar.gz
     force: true
 
+- name: Pull new openvz template with all options and force overwrite
+  community.general.proxmox_template:
+    node: uk-mc02
+    api_user: root@pam
+    api_password: 1q2w3e
+    api_host: node1
+    storage: local
+    content_type: vztmpl
+    url: https://ubuntu-mirror/ubuntu-14.04-x86_64.tar.gz
+    force: true
+
 - name: Delete template with minimal options
   community.general.proxmox_template:
     node: uk-mc02
@@ -123,7 +163,17 @@ EXAMPLES = '''
     storage: local
     content_type: vztmpl
     template: ubuntu-20.04-standard_20.04-1_amd64.tar.gz
-'''
+
+- name: Download and verify a template's checksum
+  community.general.proxmox_template:
+    node: uk-mc02
+    api_user: root@pam
+    api_password: 1q2w3e
+    api_host: node1
+    url: ubuntu-20.04-standard_20.04-1_amd64.tar.gz
+    checksum_algorithm: sha256
+    checksum: 65d860160bdc9b98abf72407e14ca40b609417de7939897d3b58d55787aaef69
+"""
 
 import os
 import time
@@ -132,6 +182,7 @@ import traceback
 from ansible.module_utils.basic import AnsibleModule, missing_required_lib
 from ansible_collections.community.general.plugins.module_utils.proxmox import (proxmox_auth_argument_spec, ProxmoxAnsible)
 from ansible_collections.community.general.plugins.module_utils.version import LooseVersion
+from ansible.module_utils.six.moves.urllib.parse import urlparse, urlencode
 
 REQUESTS_TOOLBELT_ERR = None
 try:
@@ -158,10 +209,12 @@ class ProxmoxTemplateAnsible(ProxmoxAnsible):
         while timeout:
             if self.api_task_ok(node, taskid):
                 return True
+            elif self.api_task_failed(node, taskid):
+                self.module.fail_json(msg="Task error: %s" % self.proxmox_api.nodes(node).tasks(taskid).status.get()['exitstatus'])
             timeout = timeout - 1
             if timeout == 0:
                 self.module.fail_json(msg='Reached timeout while waiting for uploading/downloading template. Last line in task before timeout: %s' %
-                                      self.proxmox_api.node(node).tasks(taskid).log.get()[:1])
+                                      self.proxmox_api.nodes(node).tasks(taskid).log.get()[:1])
 
             time.sleep(1)
         return False
@@ -179,6 +232,17 @@ class ProxmoxTemplateAnsible(ProxmoxAnsible):
         except Exception as e:
             self.module.fail_json(msg="Uploading template %s failed with error: %s" % (realpath, e))
 
+    def fetch_template(self, node, storage, content_type, url, timeout):
+        """Fetch a template from a web url source using the proxmox download-url endpoint
+        """
+        try:
+            taskid = self.proxmox_api.nodes(node).storage(storage)("download-url").post(
+                url=url, content=content_type, filename=os.path.basename(url)
+            )
+            return self.task_status(node, taskid, timeout)
+        except Exception as e:
+            self.module.fail_json(msg="Fetching template from url %s failed with error: %s" % (url, e))
+
     def download_template(self, node, storage, template, timeout):
         try:
             taskid = self.proxmox_api.nodes(node).aplinfo.post(storage=storage, template=template)
@@ -199,26 +263,45 @@ class ProxmoxTemplateAnsible(ProxmoxAnsible):
             time.sleep(1)
         return False
 
+    def fetch_and_verify(self, node, storage, url, content_type, timeout, checksum, checksum_algorithm):
+        """ Fetch a template from a web url, then verify it using a checksum.
+        """
+        data = {
+            'url': url,
+            'content': content_type,
+            'filename': os.path.basename(url),
+            'checksum': checksum,
+            'checksum-algorithm': checksum_algorithm}
+        try:
+            taskid = self.proxmox_api.nodes(node).storage(storage).post("download-url?{}".format(urlencode(data)))
+            return self.task_status(node, taskid, timeout)
+        except Exception as e:
+            self.module.fail_json(msg="Checksum mismatch: %s" % (e))
+
 
 def main():
     module_args = proxmox_auth_argument_spec()
     template_args = dict(
         node=dict(),
         src=dict(type='path'),
+        url=dict(),
         template=dict(),
         content_type=dict(default='vztmpl', choices=['vztmpl', 'iso']),
         storage=dict(default='local'),
         timeout=dict(type='int', default=30),
         force=dict(type='bool', default=False),
         state=dict(default='present', choices=['present', 'absent']),
+        checksum_algorithm=dict(choices=['md5', 'sha1', 'sha224', 'sha256', 'sha384', 'sha512']),
+        checksum=dict(type='str'),
     )
     module_args.update(template_args)
 
     module = AnsibleModule(
         argument_spec=module_args,
-        required_together=[('api_token_id', 'api_token_secret')],
+        required_together=[('api_token_id', 'api_token_secret'), ('checksum', 'checksum_algorithm')],
         required_one_of=[('api_password', 'api_token_id')],
-        required_if=[('state', 'absent', ['template'])]
+        required_if=[('state', 'absent', ['template'])],
+        mutually_exclusive=[("src", "url")],
     )
 
     proxmox = ProxmoxTemplateAnsible(module)
@@ -227,13 +310,16 @@ def main():
     node = module.params['node']
     storage = module.params['storage']
     timeout = module.params['timeout']
+    checksum = module.params['checksum']
+    checksum_algorithm = module.params['checksum_algorithm']
 
     if state == 'present':
         content_type = module.params['content_type']
         src = module.params['src']
+        url = module.params['url']
 
         # download appliance template
-        if content_type == 'vztmpl' and not src:
+        if content_type == 'vztmpl' and not (src or url):
             template = module.params['template']
 
             if not template:
@@ -245,16 +331,30 @@ def main():
             if proxmox.download_template(node, storage, template, timeout):
                 module.exit_json(changed=True, msg='template with volid=%s:%s/%s downloaded' % (storage, content_type, template))
 
-        template = os.path.basename(src)
-        if proxmox.has_template(node, storage, content_type, template) and not module.params['force']:
-            module.exit_json(changed=False, msg='template with volid=%s:%s/%s is already exists' % (storage, content_type, template))
-        elif not src:
-            module.fail_json(msg='src param to uploading template file is mandatory')
-        elif not (os.path.exists(src) and os.path.isfile(src)):
-            module.fail_json(msg='template file on path %s not exists' % src)
+        if not src and not url:
+            module.fail_json(msg='src or url param for uploading template file is mandatory')
+        elif not url:
+            template = os.path.basename(src)
+            if proxmox.has_template(node, storage, content_type, template) and not module.params['force']:
+                module.exit_json(changed=False, msg='template with volid=%s:%s/%s already exists' % (storage, content_type, template))
+            elif not (os.path.exists(src) and os.path.isfile(src)):
+                module.fail_json(msg='template file on path %s not exists' % src)
 
-        if proxmox.upload_template(node, storage, content_type, src, timeout):
-            module.exit_json(changed=True, msg='template with volid=%s:%s/%s uploaded' % (storage, content_type, template))
+            if proxmox.upload_template(node, storage, content_type, src, timeout):
+                module.exit_json(changed=True, msg='template with volid=%s:%s/%s uploaded' % (storage, content_type, template))
+        elif not src:
+            template = os.path.basename(urlparse(url).path)
+            if proxmox.has_template(node, storage, content_type, template):
+                if not module.params['force']:
+                    module.exit_json(changed=False, msg='template with volid=%s:%s/%s already exists' % (storage, content_type, template))
+                elif not proxmox.delete_template(node, storage, content_type, template, timeout):
+                    module.fail_json(changed=False, msg='failed to delete template with volid=%s:%s/%s' % (storage, content_type, template))
+
+            if checksum:
+                if proxmox.fetch_and_verify(node, storage, url, content_type, timeout, checksum, checksum_algorithm):
+                    module.exit_json(changed=True, msg="Checksum verified, template with volid=%s:%s/%s uploaded" % (storage, content_type, template))
+            if proxmox.fetch_template(node, storage, content_type, url, timeout):
+                module.exit_json(changed=True, msg='template with volid=%s:%s/%s uploaded' % (storage, content_type, template))
 
     elif state == 'absent':
         try:
