@@ -12,30 +12,35 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 module: rocketchat
 short_description: Send notifications to Rocket Chat
 description:
-    - The C(rocketchat) module sends notifications to Rocket Chat via the Incoming WebHook integration
+  - This module sends notifications to Rocket Chat through the Incoming WebHook integration.
 author: "Ramon de la Fuente (@ramondelafuente)"
+extends_documentation_fragment:
+  - community.general.attributes
+attributes:
+  check_mode:
+    support: none
+  diff_mode:
+    support: none
 options:
   domain:
     type: str
     description:
-      - The domain for your environment without protocol. (i.e.
-        C(example.com) or C(chat.example.com))
+      - The domain for your environment without protocol. (For example V(example.com) or V(chat.example.com)).
     required: true
   token:
     type: str
     description:
-      - Rocket Chat Incoming Webhook integration token.  This provides
-        authentication to Rocket Chat's Incoming webhook for posting
-        messages.
+      - Rocket Chat Incoming Webhook integration token. This provides authentication to Rocket Chat's Incoming webhook for
+        posting messages.
     required: true
   protocol:
     type: str
     description:
-      - Specify the protocol used to send notification messages before the webhook url. (i.e. http or https)
+      - Specify the protocol used to send notification messages before the webhook URL (that is, V(http) or V(https)).
     default: https
     choices:
       - 'http'
@@ -47,8 +52,8 @@ options:
   channel:
     type: str
     description:
-      - Channel to send the message to. If absent, the message goes to the channel selected for the I(token)
-        specified during the creation of webhook.
+      - Channel to send the message to. If absent, the message goes to the channel selected for the O(token) specified during
+        the creation of webhook.
   username:
     type: str
     description:
@@ -58,30 +63,32 @@ options:
     type: str
     description:
       - URL for the message sender's icon.
-    default: "https://www.ansible.com/favicon.ico"
+    default: "https://docs.ansible.com/favicon.ico"
   icon_emoji:
     type: str
     description:
-      - Emoji for the message sender. The representation for the available emojis can be
-        got from Rocket Chat. (for example :thumbsup:) (if I(icon_emoji) is set, I(icon_url) will not be used)
+      - Emoji for the message sender. The representation for the available emojis can be got from Rocket Chat.
+      - For example V(:thumbsup:).
+      - If O(icon_emoji) is set, O(icon_url) is not used.
   link_names:
     type: int
     description:
-      - Automatically create links for channels and usernames in I(msg).
+      - Automatically create links for channels and usernames in O(msg).
     default: 1
     choices:
       - 1
       - 0
   validate_certs:
     description:
-      - If C(false), SSL certificates will not be validated. This should only be used
-        on personally controlled sites using self-signed certificates.
+      - If V(false), SSL certificates are not validated. This should only be used on personally controlled sites using self-signed
+        certificates.
     type: bool
     default: true
   color:
     type: str
     description:
-      - Allow text to use default colors - use the default of 'normal' to not send a custom color bar at the start of the message
+      - Allow text to use default colors - use the default of V(normal) to not send a custom color bar at the start of the
+        message.
     default: 'normal'
     choices:
       - 'normal'
@@ -93,28 +100,38 @@ options:
     elements: dict
     description:
       - Define a list of attachments.
-'''
+  is_pre740:
+    description:
+      - If V(true), the payload matches Rocket.Chat prior to 7.4.0 format. This format has been used by the module since its
+        inception, but is no longer supported by Rocket.Chat 7.4.0.
+      - The default value of the option is going to change to V(false) eventually.
+      - This parameter is going to be removed in a future release when Rocket.Chat 7.4.0 becomes the minimum supported version.
+    type: bool
+    default: true
+    version_added: 10.5.0
+"""
 
-EXAMPLES = """
-- name: Send notification message via Rocket Chat
+EXAMPLES = r"""
+- name: Send notification message through Rocket Chat
   community.general.rocketchat:
     token: thetoken/generatedby/rocketchat
     domain: chat.example.com
     msg: '{{ inventory_hostname }} completed'
   delegate_to: localhost
 
-- name: Send notification message via Rocket Chat all options
+- name: Send notification message through Rocket Chat all options
   community.general.rocketchat:
     domain: chat.example.com
     token: thetoken/generatedby/rocketchat
     msg: '{{ inventory_hostname }} completed'
-    channel: #ansible
+    channel: "#ansible"
     username: 'Ansible on {{ inventory_hostname }}'
     icon_url: http://www.example.com/some-image-file.png
     link_names: 0
   delegate_to: localhost
 
-- name: Insert a color bar in front of the message for visibility purposes and use the default webhook icon and name configured in rocketchat
+- name: Insert a color bar in front of the message for visibility purposes and use the default webhook icon and name configured
+    in rocketchat
   community.general.rocketchat:
     token: thetoken/generatedby/rocketchat
     domain: chat.example.com
@@ -130,7 +147,7 @@ EXAMPLES = """
     domain: chat.example.com
     attachments:
       - text: Display my system load on host A and B
-        color: #ff00dd
+        color: "#ff00dd"
         title: System load
         fields:
           - title: System A
@@ -142,13 +159,6 @@ EXAMPLES = """
   delegate_to: localhost
 """
 
-RETURN = """
-changed:
-    description: A flag indicating if any change was made or not.
-    returned: success
-    type: bool
-    sample: false
-"""
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.urls import fetch_url
@@ -157,7 +167,7 @@ from ansible.module_utils.urls import fetch_url
 ROCKETCHAT_INCOMING_WEBHOOK = '%s://%s/hooks/%s'
 
 
-def build_payload_for_rocketchat(module, text, channel, username, icon_url, icon_emoji, link_names, color, attachments):
+def build_payload_for_rocketchat(module, text, channel, username, icon_url, icon_emoji, link_names, color, attachments, is_pre740):
     payload = {}
     if color == "normal" and text is not None:
         payload = dict(text=text)
@@ -187,7 +197,9 @@ def build_payload_for_rocketchat(module, text, channel, username, icon_url, icon
                 attachment['fallback'] = attachment['text']
             payload['attachments'].append(attachment)
 
-    payload = "payload=" + module.jsonify(payload)
+    payload = module.jsonify(payload)
+    if is_pre740:
+        payload = "payload=" + payload
     return payload
 
 
@@ -212,12 +224,13 @@ def main():
             msg=dict(type='str', required=False),
             channel=dict(type='str'),
             username=dict(type='str', default='Ansible'),
-            icon_url=dict(type='str', default='https://www.ansible.com/favicon.ico'),
+            icon_url=dict(type='str', default='https://docs.ansible.com/favicon.ico'),
             icon_emoji=dict(type='str'),
             link_names=dict(type='int', default=1, choices=[0, 1]),
             validate_certs=dict(default=True, type='bool'),
             color=dict(type='str', default='normal', choices=['normal', 'good', 'warning', 'danger']),
-            attachments=dict(type='list', elements='dict', required=False)
+            attachments=dict(type='list', elements='dict', required=False),
+            is_pre740=dict(default=True, type='bool')
         )
     )
 
@@ -232,8 +245,9 @@ def main():
     link_names = module.params['link_names']
     color = module.params['color']
     attachments = module.params['attachments']
+    is_pre740 = module.params['is_pre740']
 
-    payload = build_payload_for_rocketchat(module, text, channel, username, icon_url, icon_emoji, link_names, color, attachments)
+    payload = build_payload_for_rocketchat(module, text, channel, username, icon_url, icon_emoji, link_names, color, attachments, is_pre740)
     do_notify_rocketchat(module, domain, token, protocol, payload)
 
     module.exit_json(msg="OK")
