@@ -11,17 +11,15 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: scaleway_ip
 short_description: Scaleway IP management module
 author: Remy Leone (@remyleone)
 description:
-    - This module manages IP on Scaleway account
-      U(https://developer.scaleway.com)
+  - This module manages IP on Scaleway account U(https://developer.scaleway.com).
 extends_documentation_fragment:
-    - community.general.scaleway
-    - community.general.attributes
+  - community.general.scaleway
+  - community.general.attributes
 
 attributes:
   check_mode:
@@ -33,7 +31,7 @@ options:
   state:
     type: str
     description:
-     - Indicate desired state of the IP.
+      - Indicate desired state of the IP.
     default: present
     choices:
       - present
@@ -42,13 +40,13 @@ options:
   organization:
     type: str
     description:
-      - Scaleway organization identifier
+      - Scaleway organization identifier.
     required: true
 
   region:
     type: str
     description:
-     - Scaleway region to use (for example par1).
+      - Scaleway region to use (for example par1).
     required: true
     choices:
       - ams1
@@ -63,21 +61,19 @@ options:
   id:
     type: str
     description:
-    - id of the Scaleway IP (UUID)
-
+      - ID of the Scaleway IP (UUID).
   server:
     type: str
     description:
-    - id of the server you want to attach an IP to.
-    - To unattach an IP don't specify this option
-
+      - ID of the server you want to attach an IP to.
+      - To unattach an IP do not specify this option.
   reverse:
     type: str
     description:
-    - Reverse to assign to the IP
-'''
+      - Reverse to assign to the IP.
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Create an IP
   community.general.scaleway_ip:
     organization: '{{ scw_org }}'
@@ -90,28 +86,29 @@ EXAMPLES = '''
     id: '{{ ip_creation_task.scaleway_ip.id }}'
     state: absent
     region: par1
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 data:
-    description: This is only present when O(state=present).
-    returned: when O(state=present)
-    type: dict
-    sample: {
+  description: This is only present when O(state=present).
+  returned: when O(state=present)
+  type: dict
+  sample:
+    {
       "ips": [
         {
-            "organization": "951df375-e094-4d26-97c1-ba548eeb9c42",
-            "reverse": null,
-            "id": "dd9e8df6-6775-4863-b517-e0b0ee3d7477",
-            "server": {
-                "id": "3f1568ca-b1a2-4e98-b6f7-31a0588157f1",
-                "name": "ansible_tuto-1"
-            },
-            "address": "212.47.232.136"
+          "organization": "951df375-e094-4d26-97c1-ba548eeb9c42",
+          "reverse": null,
+          "id": "dd9e8df6-6775-4863-b517-e0b0ee3d7477",
+          "server": {
+            "id": "3f1568ca-b1a2-4e98-b6f7-31a0588157f1",
+            "name": "ansible_tuto-1"
+          },
+          "address": "212.47.232.136"
         }
-    ]
+      ]
     }
-'''
+"""
 
 from ansible_collections.community.general.plugins.module_utils.scaleway import SCALEWAY_LOCATION, scaleway_argument_spec, Scaleway
 from ansible.module_utils.basic import AnsibleModule
@@ -145,11 +142,11 @@ def ip_attributes_should_be_changed(api, target_ip, wished_ip):
 
 
 def payload_from_wished_ip(wished_ip):
-    return dict(
-        (k, v)
+    return {
+        k: v
         for k, v in wished_ip.items()
         if k != 'id' and v is not None
-    )
+    }
 
 
 def present_strategy(api, wished_ip):
@@ -161,8 +158,7 @@ def present_strategy(api, wished_ip):
             response.status_code, response.json['message']))
 
     ips_list = response.json["ips"]
-    ip_lookup = dict((ip["id"], ip)
-                     for ip in ips_list)
+    ip_lookup = {ip["id"]: ip for ip in ips_list}
 
     if wished_ip["id"] not in ip_lookup.keys():
         changed = True
@@ -212,8 +208,7 @@ def absent_strategy(api, wished_ip):
         api.module.fail_json(msg='Error getting IPs [{0}: {1}]'.format(
             status_code, response.json['message']))
 
-    ip_lookup = dict((ip["id"], ip)
-                     for ip in ips_list)
+    ip_lookup = {ip["id"]: ip for ip in ips_list}
     if wished_ip["id"] not in ip_lookup.keys():
         return changed, {}
 
