@@ -12,24 +12,28 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: scaleway_security_group
 short_description: Scaleway Security Group management module
 author: Antoine Barbare (@abarbare)
 description:
-    - This module manages Security Group on Scaleway account
-      U(https://developer.scaleway.com).
+  - This module manages Security Group on Scaleway account U(https://developer.scaleway.com).
 extends_documentation_fragment:
-- community.general.scaleway
+  - community.general.scaleway
+  - community.general.attributes
 
+attributes:
+  check_mode:
+    support: full
+  diff_mode:
+    support: none
 
 options:
   state:
     description:
       - Indicate desired state of the Security Group.
     type: str
-    choices: [ absent, present ]
+    choices: [absent, present]
     default: present
 
   organization:
@@ -40,7 +44,7 @@ options:
 
   region:
     description:
-      - Scaleway region to use (for example C(par1)).
+      - Scaleway region to use (for example V(par1)).
     type: str
     required: true
     choices:
@@ -74,21 +78,21 @@ options:
     description:
       - Default policy for incoming traffic.
     type: str
-    choices: [ accept, drop ]
+    choices: [accept, drop]
 
   outbound_default_policy:
     description:
       - Default policy for outcoming traffic.
     type: str
-    choices: [ accept, drop ]
+    choices: [accept, drop]
 
   organization_default:
     description:
       - Create security group to be the default one.
     type: bool
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Create a Security Group
   community.general.scaleway_security_group:
     state: present
@@ -101,28 +105,29 @@ EXAMPLES = '''
     outbound_default_policy: accept
     organization_default: false
   register: security_group_creation_task
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 data:
-    description: This is only present when C(state=present)
-    returned: when C(state=present)
-    type: dict
-    sample: {
-        "scaleway_security_group": {
-            "description": "my security group description",
-            "enable_default_security": true,
-            "id": "0168fb1f-cc46-4f69-b4be-c95d2a19bcae",
-            "inbound_default_policy": "accept",
-            "name": "security_group",
-            "organization": "43a3b6c8-916f-477b-b7ec-ff1898f5fdd9",
-            "organization_default": false,
-            "outbound_default_policy": "accept",
-            "servers": [],
-            "stateful": false
-        }
+  description: This is only present when O(state=present).
+  returned: when O(state=present)
+  type: dict
+  sample:
+    {
+      "scaleway_security_group": {
+        "description": "my security group description",
+        "enable_default_security": true,
+        "id": "0168fb1f-cc46-4f69-b4be-c95d2a19bcae",
+        "inbound_default_policy": "accept",
+        "name": "security_group",
+        "organization": "43a3b6c8-916f-477b-b7ec-ff1898f5fdd9",
+        "organization_default": false,
+        "outbound_default_policy": "accept",
+        "servers": [],
+        "stateful": false
+      }
     }
-'''
+"""
 
 from ansible_collections.community.general.plugins.module_utils.scaleway import SCALEWAY_LOCATION, scaleway_argument_spec, Scaleway
 from ansible.module_utils.basic import AnsibleModule
@@ -130,11 +135,11 @@ from uuid import uuid4
 
 
 def payload_from_security_group(security_group):
-    return dict(
-        (k, v)
+    return {
+        k: v
         for k, v in security_group.items()
         if k != 'id' and v is not None
-    )
+    }
 
 
 def present_strategy(api, security_group):
@@ -144,8 +149,7 @@ def present_strategy(api, security_group):
     if not response.ok:
         api.module.fail_json(msg='Error getting security groups "%s": "%s" (%s)' % (response.info['msg'], response.json['message'], response.json))
 
-    security_group_lookup = dict((sg['name'], sg)
-                                 for sg in response.json['security_groups'])
+    security_group_lookup = {sg['name']: sg for sg in response.json['security_groups']}
 
     if security_group['name'] not in security_group_lookup.keys():
         ret['changed'] = True
@@ -176,8 +180,7 @@ def absent_strategy(api, security_group):
     if not response.ok:
         api.module.fail_json(msg='Error getting security groups "%s": "%s" (%s)' % (response.info['msg'], response.json['message'], response.json))
 
-    security_group_lookup = dict((sg['name'], sg)
-                                 for sg in response.json['security_groups'])
+    security_group_lookup = {sg['name']: sg for sg in response.json['security_groups']}
     if security_group['name'] not in security_group_lookup.keys():
         return ret
 
