@@ -12,18 +12,15 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: scaleway_security_group_rule
 short_description: Scaleway Security Group Rule management module
 author: Antoine Barbare (@abarbare)
 description:
-  - "This module manages Security Group Rule on Scaleway account U(https://developer.scaleway.com)."
+  - This module manages Security Group Rule on Scaleway account U(https://developer.scaleway.com).
 extends_documentation_fragment:
   - community.general.scaleway
   - community.general.attributes
-requirements:
-  - ipaddress
 
 attributes:
   check_mode:
@@ -101,55 +98,45 @@ options:
     description:
       - Security Group unique identifier.
     required: true
-'''
+"""
 
-EXAMPLES = '''
-  - name: Create a Security Group Rule
-    community.general.scaleway_security_group_rule:
-      state: present
-      region: par1
-      protocol: TCP
-      port: 80
-      ip_range: 0.0.0.0/0
-      direction: inbound
-      action: accept
-      security_group: b57210ee-1281-4820-a6db-329f78596ecb
-    register: security_group_rule_creation_task
-'''
+EXAMPLES = r"""
+- name: Create a Security Group Rule
+  community.general.scaleway_security_group_rule:
+    state: present
+    region: par1
+    protocol: TCP
+    port: 80
+    ip_range: 0.0.0.0/0
+    direction: inbound
+    action: accept
+    security_group: b57210ee-1281-4820-a6db-329f78596ecb
+  register: security_group_rule_creation_task
+"""
 
-RETURN = '''
+RETURN = r"""
 data:
-    description: This is only present when O(state=present).
-    returned: when O(state=present)
-    type: dict
-    sample: {
-        "scaleway_security_group_rule": {
-            "direction": "inbound",
-            "protocol": "TCP",
-            "ip_range": "0.0.0.0/0",
-            "dest_port_from": 80,
-            "action": "accept",
-            "position": 2,
-            "dest_port_to": null,
-            "editable": null,
-            "id": "10cb0b9a-80f6-4830-abd7-a31cd828b5e9"
-        }
+  description: This is only present when O(state=present).
+  returned: when O(state=present)
+  type: dict
+  sample:
+    {
+      "scaleway_security_group_rule": {
+        "direction": "inbound",
+        "protocol": "TCP",
+        "ip_range": "0.0.0.0/0",
+        "dest_port_from": 80,
+        "action": "accept",
+        "position": 2,
+        "dest_port_to": null,
+        "editable": null,
+        "id": "10cb0b9a-80f6-4830-abd7-a31cd828b5e9"
+      }
     }
-'''
-
-import traceback
+"""
 
 from ansible_collections.community.general.plugins.module_utils.scaleway import SCALEWAY_LOCATION, scaleway_argument_spec, Scaleway, payload_from_object
-from ansible.module_utils.basic import AnsibleModule, missing_required_lib
-
-try:
-    from ipaddress import ip_network  # noqa: F401, pylint: disable=unused-import
-except ImportError:
-    IPADDRESS_IMP_ERR = traceback.format_exc()
-    HAS_IPADDRESS = False
-else:
-    IPADDRESS_IMP_ERR = None
-    HAS_IPADDRESS = True
+from ansible.module_utils.basic import AnsibleModule
 
 
 def get_sgr_from_api(security_group_rules, security_group_rule):
@@ -272,8 +259,6 @@ def main():
         argument_spec=argument_spec,
         supports_check_mode=True,
     )
-    if not HAS_IPADDRESS:
-        module.fail_json(msg=missing_required_lib('ipaddress'), exception=IPADDRESS_IMP_ERR)
 
     core(module)
 
