@@ -12,23 +12,27 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: scaleway_volume
 short_description: Scaleway volumes management module
 author: Henryk Konsek (@hekonsek)
 description:
-    - This module manages volumes on Scaleway account
-      U(https://developer.scaleway.com)
+  - This module manages volumes on Scaleway account U(https://developer.scaleway.com).
 extends_documentation_fragment:
-- community.general.scaleway
+  - community.general.scaleway
+  - community.general.attributes
 
+attributes:
+  check_mode:
+    support: full
+  diff_mode:
+    support: none
 
 options:
   state:
     type: str
     description:
-     - Indicate desired state of the volume.
+      - Indicate desired state of the volume.
     default: present
     choices:
       - present
@@ -36,7 +40,7 @@ options:
   region:
     type: str
     description:
-     - Scaleway region to use (for example par1).
+      - Scaleway region to use (for example par1).
     required: true
     choices:
       - ams1
@@ -50,28 +54,28 @@ options:
   name:
     type: str
     description:
-     - Name used to identify the volume.
+      - Name used to identify the volume.
     required: true
   project:
     type: str
     description:
-     - Scaleway project ID to which volume belongs.
+      - Scaleway project ID to which volume belongs.
     version_added: 4.3.0
   organization:
     type: str
     description:
-     - ScaleWay organization ID to which volume belongs.
+      - ScaleWay organization ID to which volume belongs.
   size:
     type: int
     description:
-     - Size of the volume in bytes.
+      - Size of the volume in bytes.
   volume_type:
     type: str
     description:
-     - Type of the volume (for example 'l_ssd').
-'''
+      - Type of the volume (for example 'l_ssd').
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Create 10GB volume
   community.general.scaleway_volume:
     name: my-volume
@@ -87,25 +91,26 @@ EXAMPLES = '''
     name: my-volume
     state: absent
     region: par1
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 data:
-    description: This is only present when C(state=present)
-    returned: when C(state=present)
-    type: dict
-    sample: {
+  description: This is only present when O(state=present).
+  returned: when O(state=present)
+  type: dict
+  sample:
+    {
       "volume": {
         "export_uri": null,
         "id": "c675f420-cfeb-48ff-ba2a-9d2a4dbe3fcd",
         "name": "volume-0-3",
         "project": "000a115d-2852-4b0a-9ce8-47f1134ba95a",
-         "server": null,
-         "size": 10000000000,
-         "volume_type": "l_ssd"
-  }
-}
-'''
+        "server": null,
+        "size": 10000000000,
+        "volume_type": "l_ssd"
+      }
+    }
+"""
 
 from ansible_collections.community.general.plugins.module_utils.scaleway import SCALEWAY_LOCATION, scaleway_argument_spec, Scaleway
 from ansible.module_utils.basic import AnsibleModule
