@@ -15,49 +15,47 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: slackpkg
 short_description: Package manager for Slackware >= 12.2
 description:
-    - Manage binary packages for Slackware using 'slackpkg' which
-      is available in versions after 12.2.
+  - Manage binary packages for Slackware using C(slackpkg) which is available in versions after 12.2.
 extends_documentation_fragment:
-    - community.general.attributes
+  - community.general.attributes
 attributes:
-    check_mode:
-        support: full
-    diff_mode:
-        support: none
+  check_mode:
+    support: full
+  diff_mode:
+    support: none
 options:
-    name:
-        description:
-            - name of package to install/remove
-        required: true
-        type: list
-        elements: str
-        aliases: [pkg]
+  name:
+    description:
+      - Name of package to install/remove.
+    required: true
+    type: list
+    elements: str
+    aliases: [pkg]
 
-    state:
-        description:
-            - State of the package, you can use V(installed) as an alias for V(present) and V(removed) as one for V(absent).
-        choices: [ 'present', 'absent', 'latest', 'installed', 'removed' ]
-        required: false
-        default: present
-        type: str
+  state:
+    description:
+      - State of the package, you can use V(installed) as an alias for V(present) and V(removed) as one for V(absent).
+    choices: ['present', 'absent', 'latest', 'installed', 'removed']
+    required: false
+    default: present
+    type: str
 
-    update_cache:
-        description:
-            - update the package database first
-        required: false
-        default: false
-        type: bool
+  update_cache:
+    description:
+      - Update the package database first.
+    required: false
+    default: false
+    type: bool
 
 author: Kim Nørgaard (@KimNorgaard)
-requirements: [ "Slackware >= 12.2" ]
-'''
+requirements: ["Slackware >= 12.2"]
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Install package foo
   community.general.slackpkg:
     name: foo
@@ -72,7 +70,7 @@ EXAMPLES = '''
   community.general.slackpkg:
     name: foo
     state: latest
-'''
+"""
 
 from ansible.module_utils.basic import AnsibleModule
 
