@@ -8,23 +8,18 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: timezone
 short_description: Configure timezone setting
 description:
-  - This module configures the timezone setting, both of the system clock and of the hardware clock.
-    If you want to set up the NTP, use M(ansible.builtin.service) module.
+  - This module configures the timezone setting, both of the system clock and of the hardware clock. If you want to set up
+    the NTP, use M(ansible.builtin.service) module.
   - It is recommended to restart C(crond) after changing the timezone, otherwise the jobs may run at the wrong time.
-  - Several different tools are used depending on the OS/Distribution involved.
-    For Linux it can use C(timedatectl) or edit C(/etc/sysconfig/clock) or C(/etc/timezone) and C(hwclock).
-    On SmartOS, C(sm-set-timezone), for macOS, C(systemsetup), for BSD, C(/etc/localtime) is modified.
-    On AIX, C(chtz) is used.
+  - Several different tools are used depending on the OS/Distribution involved. For Linux it can use C(timedatectl) or edit
+    C(/etc/sysconfig/clock) or C(/etc/timezone) and C(hwclock). On SmartOS, C(sm-set-timezone), for macOS, C(systemsetup),
+    for BSD, C(/etc/localtime) is modified. On AIX, C(chtz) is used.
   - Make sure that the zoneinfo files are installed with the appropriate OS package, like C(tzdata) (usually always installed,
     when not using a minimal installation like Alpine Linux).
-  - As of Ansible 2.3 support was added for SmartOS and BSDs.
-  - As of Ansible 2.4 support was added for macOS.
-  - As of Ansible 2.9 support was added for AIX 6.1+
   - Windows and HPUX are not supported, please let us know if you find any other OS/distro in which this fails.
 extends_documentation_fragment:
   - community.general.attributes
@@ -38,48 +33,36 @@ options:
     description:
       - Name of the timezone for the system clock.
       - Default is to keep current setting.
-      - B(At least one of name and hwclock are required.)
+      - B(At least one) of O(name) and O(hwclock) are required.
     type: str
   hwclock:
     description:
       - Whether the hardware clock is in UTC or in local timezone.
       - Default is to keep current setting.
-      - Note that this option is recommended not to change and may fail
-        to configure, especially on virtual environments such as AWS.
-      - B(At least one of name and hwclock are required.)
-      - I(Only used on Linux.)
+      - Note that this option is recommended not to change and may fail to configure, especially on virtual environments such
+        as AWS.
+      - B(At least one) of O(name) and O(hwclock) are required.
+      - I(Only used on Linux).
     type: str
-    aliases: [ rtc ]
-    choices: [ local, UTC ]
+    aliases: [rtc]
+    choices: [local, UTC]
 notes:
-  - On SmartOS the C(sm-set-timezone) utility (part of the smtools package) is required to set the zone timezone
-  - On AIX only Olson/tz database timezones are usable (POSIX is not supported).
-    - An OS reboot is also required on AIX for the new timezone setting to take effect.
+  - On Ubuntu 24.04 the C(util-linux-extra) package is required to provide the C(hwclock) command.
+  - On SmartOS the C(sm-set-timezone) utility (part of the smtools package) is required to set the zone timezone.
+  - On AIX only Olson/tz database timezones are usable (POSIX is not supported). An OS reboot is also required on AIX for
+    the new timezone setting to take effect. Note that AIX 6.1+ is needed (OS level 61 or newer).
 author:
   - Shinichi TAMURA (@tmshn)
   - Jasper Lievisse Adriaanse (@jasperla)
   - Indrajit Raychaudhuri (@indrajitr)
-'''
+"""
 
-RETURN = r'''
-diff:
-  description: The differences about the given arguments.
-  returned: success
-  type: complex
-  contains:
-    before:
-      description: The values before change
-      type: dict
-    after:
-      description: The values after change
-      type: dict
-'''
-
-EXAMPLES = r'''
+EXAMPLES = r"""
 - name: Set timezone to Asia/Tokyo
+  become: true
   community.general.timezone:
     name: Asia/Tokyo
-'''
+"""
 
 import errno
 import os
@@ -337,7 +320,7 @@ class NosystemdTimezone(Timezone):
         adjtime='/etc/adjtime'
     )
 
-    # It's fine if all tree config files don't exist
+    # It is fine if all tree config files don't exist
     allow_no_file = dict(
         name=True,
         hwclock=True,
@@ -399,7 +382,8 @@ class NosystemdTimezone(Timezone):
             self.conf_files['name'] = '/etc/sysconfig/clock'
             self.conf_files['hwclock'] = '/etc/sysconfig/clock'
             try:
-                f = open(self.conf_files['name'], 'r')
+                with open(self.conf_files['name'], 'r') as f:
+                    sysconfig_clock = f.read()
             except IOError as err:
                 if self._allow_ioerror(err, 'name'):
                     # If the config file doesn't exist detect the distribution and set regexps.
@@ -417,8 +401,6 @@ class NosystemdTimezone(Timezone):
                 # The key for timezone might be `ZONE` or `TIMEZONE`
                 # (the former is used in RHEL/CentOS and the latter is used in SUSE linux).
                 # So check the content of /etc/sysconfig/clock and decide which key to use.
-                sysconfig_clock = f.read()
-                f.close()
                 if re.search(r'^TIMEZONE\s*=', sysconfig_clock, re.MULTILINE):
                     # For SUSE
                     self.regexps['name'] = self.dist_regexps['SuSE']
@@ -451,15 +433,13 @@ class NosystemdTimezone(Timezone):
         """
         # Read the file
         try:
-            file = open(filename, 'r')
+            with open(filename, 'r') as file:
+                lines = file.readlines()
         except IOError as err:
             if self._allow_ioerror(err, key):
                 lines = []
             else:
                 self.abort('tried to configure %s using a file "%s", but could not read it' % (key, filename))
-        else:
-            lines = file.readlines()
-            file.close()
         # Find the all matched lines
         matched_indices = []
         for i, line in enumerate(lines):
@@ -476,18 +456,17 @@ class NosystemdTimezone(Timezone):
         lines.insert(insert_line, value)
         # Write the changes
         try:
-            file = open(filename, 'w')
+            with open(filename, 'w') as file:
+                file.writelines(lines)
         except IOError:
             self.abort('tried to configure %s using a file "%s", but could not write to it' % (key, filename))
-        else:
-            file.writelines(lines)
-            file.close()
         self.msg.append('Added 1 line and deleted %s line(s) on %s' % (len(matched_indices), filename))
 
     def _get_value_from_config(self, key, phase):
         filename = self.conf_files[key]
         try:
-            file = open(filename, mode='r')
+            with open(filename, mode='r') as file:
+                status = file.read()
         except IOError as err:
             if self._allow_ioerror(err, key):
                 if key == 'hwclock':
@@ -499,8 +478,6 @@ class NosystemdTimezone(Timezone):
             else:
                 self.abort('tried to configure %s using a file "%s", but could not read it' % (key, filename))
         else:
-            status = file.read()
-            file.close()
             try:
                 value = self.regexps[key].search(status).group(1)
             except AttributeError:
@@ -549,7 +526,7 @@ class NosystemdTimezone(Timezone):
                     # to set, we need to return the TZ which the symlink points to.
                     if os.path.exists('/etc/localtime'):
                         # We use readlink() because on some distros zone files are symlinks
-                        # to other zone files, so it's hard to get which TZ is actually set
+                        # to other zone files, so it is hard to get which TZ is actually set
                         # if we follow the symlink.
                         path = os.readlink('/etc/localtime')
                         # most linuxes has it in /usr/share/zoneinfo
@@ -631,11 +608,11 @@ class SmartOSTimezone(Timezone):
         """
         if key == 'name':
             try:
-                f = open('/etc/default/init', 'r')
-                for line in f:
-                    m = re.match('^TZ=(.*)$', line.strip())
-                    if m:
-                        return m.groups()[0]
+                with open('/etc/default/init', 'r') as f:
+                    for line in f:
+                        m = re.match('^TZ=(.*)$', line.strip())
+                        if m:
+                            return m.groups()[0]
             except Exception:
                 self.module.fail_json(msg='Failed to read /etc/default/init')
         else:
@@ -814,9 +791,8 @@ class AIXTimezone(Timezone):
     def __get_timezone(self):
         """ Return the current value of TZ= in /etc/environment """
         try:
-            f = open('/etc/environment', 'r')
-            etcenvironment = f.read()
-            f.close()
+            with open('/etc/environment', 'r') as f:
+                etcenvironment = f.read()
         except Exception:
             self.module.fail_json(msg='Issue reading contents of /etc/environment')
 
