@@ -9,61 +9,64 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: utm_ca_host_key_cert
 
 author:
-    - Stephan Schwarz (@stearz)
+  - Stephan Schwarz (@stearz)
 
 short_description: Create, update or destroy ca host_key_cert entry in Sophos UTM
 
 description:
-    - Create, update or destroy a ca host_key_cert entry in SOPHOS UTM.
-    - This module needs to have the REST Ability of the UTM to be activated.
-
+  - Create, update or destroy a ca host_key_cert entry in SOPHOS UTM.
+  - This module needs to have the REST Ability of the UTM to be activated.
+attributes:
+  check_mode:
+    support: none
+  diff_mode:
+    support: none
 
 options:
-    name:
-        description:
-          - The name of the object. Will be used to identify the entry.
-        required: true
-        type: str
-    ca:
-        description:
-          - A reference to an existing utm_ca_signing_ca or utm_ca_verification_ca object.
-        required: true
-        type: str
-    meta:
-        description:
-          - A reference to an existing utm_ca_meta_x509 object.
-        required: true
-        type: str
-    certificate:
-        description:
-          - The certificate in PEM format.
-        required: true
-        type: str
-    comment:
-        description:
-          - Optional comment string.
-        type: str
-    encrypted:
-        description:
-          - Optionally enable encryption.
-        default: false
-        type: bool
-    key:
-        description:
-          - Optional private key in PEM format.
-        type: str
+  name:
+    description:
+      - The name of the object that identifies the entry.
+    required: true
+    type: str
+  ca:
+    description:
+      - A reference to an existing utm_ca_signing_ca or utm_ca_verification_ca object.
+    required: true
+    type: str
+  meta:
+    description:
+      - A reference to an existing utm_ca_meta_x509 object.
+    required: true
+    type: str
+  certificate:
+    description:
+      - The certificate in PEM format.
+    required: true
+    type: str
+  comment:
+    description:
+      - Optional comment string.
+    type: str
+  encrypted:
+    description:
+      - Optionally enable encryption.
+    default: false
+    type: bool
+  key:
+    description:
+      - Optional private key in PEM format.
+    type: str
 
 extends_documentation_fragment:
-- community.general.utm
+  - community.general.utm
+  - community.general.attributes
+"""
 
-'''
-
-EXAMPLES = """
+EXAMPLES = r"""
 - name: Create a ca_host_key_cert entry
   community.general.utm_ca_host_key_cert:
     utm_host: sophos.host.name
@@ -92,45 +95,44 @@ EXAMPLES = """
     utm_token: abcdefghijklmno1234
     name: TestHostKeyCertEntry
     state: info
-
 """
 
-RETURN = """
+RETURN = r"""
 result:
-    description: The utm object that was created
-    returned: success
-    type: complex
-    contains:
-        _ref:
-            description: The reference name of the object
-            type: str
-        _locked:
-            description: Whether or not the object is currently locked
-            type: bool
-        _type:
-            description: The type of the object
-            type: str
-        name:
-            description: The name of the object
-            type: str
-        ca:
-            description: A reference to an existing utm_ca_signing_ca or utm_ca_verification_ca object.
-            type: str
-        meta:
-            description: A reference to an existing utm_ca_meta_x509 object.
-            type: str
-        certificate:
-            description: The certificate in PEM format
-            type: str
-        comment:
-            description: Comment string (may be empty string)
-            type: str
-        encrypted:
-            description: If encryption is enabled
-            type: bool
-        key:
-            description: Private key in PEM format (may be empty string)
-            type: str
+  description: The utm object that was created.
+  returned: success
+  type: complex
+  contains:
+    _ref:
+      description: The reference name of the object.
+      type: str
+    _locked:
+      description: Whether or not the object is currently locked.
+      type: bool
+    _type:
+      description: The type of the object.
+      type: str
+    name:
+      description: The name of the object.
+      type: str
+    ca:
+      description: A reference to an existing utm_ca_signing_ca or utm_ca_verification_ca object.
+      type: str
+    meta:
+      description: A reference to an existing utm_ca_meta_x509 object.
+      type: str
+    certificate:
+      description: The certificate in PEM format.
+      type: str
+    comment:
+      description: Comment string (may be empty string).
+      type: str
+    encrypted:
+      description: If encryption is enabled.
+      type: bool
+    key:
+      description: Private key in PEM format (may be empty string).
+      type: str
 """
 
 from ansible_collections.community.general.plugins.module_utils.utm_utils import UTM, UTMModule
