@@ -74,9 +74,11 @@ class HashiVaultConnectionOptions(HashiVaultOptionGroupBase):
         'status_forcelist': [
             # https://www.vaultproject.io/api#http-status-codes
             # 429 is usually a "too many requests" status, but in Vault it's the default health status response for standby nodes.
-            500,  # Internal server error. An internal error has occurred, try again later. If the error persists, report a bug.
-            502,  # A request to Vault required Vault making a request to a third party; the third party responded with an error of some kind.
-            503,  # Vault is down for maintenance or is currently sealed. Try again later.
+            412,    # Precondition failed. Returned on Enterprise when a request can't be processed yet due to some missing eventually consistent data.
+                    # Should be retried, perhaps with a little backoff.
+            500,    # Internal server error. An internal error has occurred, try again later. If the error persists, report a bug.
+            502,    # A request to Vault required Vault making a request to a third party; the third party responded with an error of some kind.
+            503,    # Vault is down for maintenance or is currently sealed. Try again later.
         ],
         (
             # this field name changed in 1.26.0, and in the interest of supporting a wider range of urllib3 versions
@@ -98,15 +100,16 @@ class HashiVaultConnectionOptions(HashiVaultOptionGroupBase):
 
         # validate_certs is only used to optionally change the value of ca_cert
         def _filter(k, v):
-            return v is not None and k != 'validate_certs'
+            return v is not None and k not in ('validate_certs', 'ca_cert')
 
         # our transformed ca_cert value will become the verify parameter for the hvac client
         hvopts = self._options.get_filtered_options(_filter, *self.OPTIONS)
-        hvopts['verify'] = hvopts.pop('ca_cert')
+        hvopts['verify'] = self._conopt_verify
 
         retry_action = hvopts.pop('retry_action')
         if 'retries' in hvopts:
             hvopts['session'] = self._get_custom_requests_session(new_callback=self._retry_callback_generator(retry_action), **hvopts.pop('retries'))
+            hvopts['session'].verify = self._conopt_verify
 
         return hvopts
 
@@ -253,6 +256,6 @@ class HashiVaultConnectionOptions(HashiVaultOptionGroupBase):
                 validate_certs = True
 
         if not (validate_certs and ca_cert):
-            self._options.set_option('ca_cert', validate_certs)
+            self._conopt_verify = validate_certs
         else:
-            self._options.set_option('ca_cert', to_text(ca_cert, errors='surrogate_or_strict'))
+            self._conopt_verify = to_text(ca_cert, errors='surrogate_or_strict')
