@@ -21,6 +21,10 @@ __metaclass__ = type
 
 DOCUMENTATION = '''
 ---
+deprecated:
+  removed_in: 6.0.0
+  why: This collection and all content in it is unmaintained and deprecated.
+  alternative: Unknown.
 author: Ericsson IPOS OAM team (!UNKNOWN)
 name: eric_eccli
 short_description: Use eccli cliconf to run command on Ericsson ECCLI platform
@@ -53,7 +57,7 @@ class Cliconf(CliconfBase):
     def edit_config(self, candidate=None, commit=True, replace=None, comment=None):
         return
 
-    def get(self, command=None, prompt=None, answer=None, sendonly=False, output=None, newline=True, check_all=False):
+    def get(self, command=None, prompt=None, answer=None, sendonly=False, newline=True, output=None, check_all=False):
         if not command:
             raise ValueError('must provide value of command to execute')
         if output:
