@@ -9,9 +9,16 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
 
+from __future__ import (absolute_import, division, print_function)
+__metaclass__ = type
+
 DOCUMENTATION = '''
 ---
 module: avi_serviceenginegroup
+deprecated:
+  removed_in: 6.0.0
+  why: This collection and all content in it is unmaintained and deprecated.
+  alternative: Unknown.
 author: Gaurav Rastogi (@grastogi23) <grastogi@avinetworks.com>
 
 short_description: Module for setup of ServiceEngineGroup Avi RESTful Object
@@ -956,7 +963,7 @@ def main():
         hardwaresecuritymodulegroup_ref=dict(type='str',),
         heap_minimum_config_memory=dict(type='int',),
         hm_on_standby=dict(type='bool',),
-        host_attribute_key=dict(type='str',),
+        host_attribute_key=dict(type='str', no_log=False),
         host_attribute_value=dict(type='str',),
         host_gateway_monitor=dict(type='bool',),
         hypervisor=dict(type='str',),
