@@ -22,6 +22,10 @@ __metaclass__ = type
 DOCUMENTATION = r'''
 ---
 module: ce_aaa_server
+deprecated:
+  removed_in: 6.0.0
+  why: This collection and all content in it is unmaintained and deprecated.
+  alternative: Unknown.
 short_description: Manages AAA server global configuration on HUAWEI CloudEngine switches.
 description:
     - Manages AAA server global configuration on HUAWEI CloudEngine switches.
