@@ -22,6 +22,10 @@ __metaclass__ = type
 DOCUMENTATION = '''
 ---
 module: ce_vxlan_vap
+deprecated:
+  removed_in: 6.0.0
+  why: This collection and all content in it is unmaintained and deprecated.
+  alternative: Unknown.
 short_description: Manages VXLAN virtual access point on HUAWEI CloudEngine Devices.
 description:
     - Manages VXLAN Virtual access point on HUAWEI CloudEngine Devices.
@@ -70,7 +74,7 @@ EXAMPLES = '''
 - name: Vxlan vap module test
   hosts: ce128
   connection: local
-  gather_facts: no
+  gather_facts: false
 
   tasks:
 
