@@ -5,6 +5,7 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -45,13 +46,14 @@ options:
     - Note that if the provided password string is already in MD5-hashed
       format, then it is used as-is, regardless of I(encrypted) option.
     type: str
-  db:
+  login_db:
     description:
     - Name of database to connect to and where user's permissions are granted.
+    - The V(db) alias is deprecated and will be removed in version 5.0.0.
     type: str
     default: ''
     aliases:
-    - login_db
+    - db
   fail_on_user:
     description:
     - If C(true), fails when the user (role) cannot be removed. Otherwise just log and continue.
@@ -142,6 +144,7 @@ options:
   comment:
     description:
     - Adds a comment on the user (equivalent to the C(COMMENT ON ROLE) statement).
+    - To reset the comment, pass an empty string.
     type: str
     version_added: '0.2.0'
   trust_input:
@@ -152,6 +155,41 @@ options:
     type: bool
     default: true
     version_added: '0.2.0'
+  configuration:
+    description:
+      - Role-specific configuration parameters that would otherwise be set by C(ALTER ROLE user SET variable TO value;).
+      - Takes a dict where the key is the name of the configuration parameter. If the key includes special characters
+        like C(.) and C(-), it needs to be quoted to ensure the YAML is valid.
+      - Sets or updates any parameter in the list that is not present or has the wrong value in the database.
+      - Removes any parameter from the user that is not listed here.
+      - Parameters that are present in the database but are not included in this list will only be reset, if
+        O(reset_unspecified_configuration=true).
+      - Inputs to O(user) as well as keys and values in this parameter are quoted by the module. If you require the
+        user to contain a C("), you need to double it, otherwise the module will fail. C(") and C(') are not allowed in
+        configuration keys and any C(') in the value of a configuration will be escaped by this module.
+        Additionally, parameters and values are checked if O(trust_input) is C(false).
+    type: dict
+    default: {}
+    version_added: '3.5.0'
+  reset_unspecified_configuration:
+    description:
+      - If set to C(true), the user's default configuration parameters will be reset in case they are not included in
+        O(configuration), otherwise existing parameters will not be modified if not included in O(configuration).
+    type: bool
+    default: false
+    version_added: '3.5.0'
+  quote_configuration_values:
+    description:
+      - Automatically quote the values of configuration variables added via I(configuration). The default is C(true)
+        and setting this to C(false) leaves these options open to SQL-injections and makes the user responsible for
+        properly quoting values.
+      - This is required to be C(false) to modify settings like C(search_path), that need to be unquoted.
+      - If this is C(false) you will also need to make sure that strings are properly quoted.
+        For example C("'16MB'") for C(work_mem).
+      - Set this only to C(false) if you know what you are doing!
+    type: bool
+    default: true
+    version_added: '3.11.0'
 notes:
 - The module creates a user (role) with login privilege by default.
   Use C(NOLOGIN) I(role_attr_flags) to change this behaviour.
@@ -160,7 +198,8 @@ notes:
 - SCRAM-SHA-256-hashed passwords (SASL Authentication) require PostgreSQL version 10 or newer.
   On the previous versions the whole hashed string is used as a password.
 - 'Working with SCRAM-SHA-256-hashed passwords, be sure you use the I(environment:) variable
-  C(PGOPTIONS: "-c password_encryption=scram-sha-256") (see the provided example).'
+  C(PGOPTIONS: "-c password_encryption=scram-sha-256") when it is not default
+  for your PostgreSQL version (see the provided example).'
 - On some systems (such as AWS RDS), C(pg_authid) is not accessible, thus, the module cannot compare
   the current and desired C(password). In this case, the module assumes that the passwords are
   different and changes it reporting that the state has been changed.
@@ -194,7 +233,7 @@ EXAMPLES = r'''
 # You should use the 'postgresql_privs' module instead.
 - name: Connect to acme database, create django user, and grant access to database and products table
   community.postgresql.postgresql_user:
-    db: acme
+    login_db: acme
     name: django
     password: ceec4eif7ya
     priv: "CONNECT/products:ALL"
@@ -202,7 +241,7 @@ EXAMPLES = r'''
 
 - name: Add a comment on django user
   community.postgresql.postgresql_user:
-    db: acme
+    login_db: acme
     name: django
     comment: This is a test user
 
@@ -216,14 +255,14 @@ EXAMPLES = r'''
     # password: SCRAM-SHA-256$4096:zFuajwIVdli9mK=NJkcv1Q++$JC4gWIrEHmF6sqRbEiZw5FFW45HUPrpVzNdoM72o730+;fqA4vLN3mCZGbhcbQyvNYY7anCrUTsem1eCh/4YA94=
     role_attr_flags: CREATEDB,NOSUPERUSER
   # When using sha256-hashed password:
-  #environment:
-  #  PGOPTIONS: "-c password_encryption=scram-sha-256"
+  # environment:
+  #   PGOPTIONS: "-c password_encryption=scram-sha-256"
 
 # This example uses the 'priv' argument which is deprecated.
 # You should use the 'postgresql_privs' module instead.
 - name: Connect to acme database and remove test user privileges from there
   community.postgresql.postgresql_user:
-    db: acme
+    login_db: acme
     name: test
     priv: "ALL/products:ALL"
     state: absent
@@ -233,7 +272,7 @@ EXAMPLES = r'''
 # You should use the 'postgresql_privs' module instead.
 - name: Connect to test database, remove test user from cluster
   community.postgresql.postgresql_user:
-    db: test
+    login_db: test
     name: test
     priv: ALL
     state: absent
@@ -242,7 +281,7 @@ EXAMPLES = r'''
 # You should use the 'postgresql_privs' module instead.
 - name: Connect to acme database and set user's password with no expire date
   community.postgresql.postgresql_user:
-    db: acme
+    login_db: acme
     name: django
     password: mysupersecretword
     priv: "CONNECT/products:ALL"
@@ -253,7 +292,7 @@ EXAMPLES = r'''
 
 - name: Connect to test database and remove an existing user's password
   community.postgresql.postgresql_user:
-    db: test
+    login_db: test
     user: test
     password: ""
 
@@ -272,6 +311,30 @@ EXAMPLES = r'''
   community.postgresql.postgresql_user:
     name: monitoring
     priv: 'pg_catalog.pg_stat_database:SELECT'
+
+# Create a user and set a default-configuration that is active when they start a session
+- name: Create a user with config-parameter
+  community.postgresql.postgresql_user:
+    name: appclient
+    password: "secret123"
+    configuration:
+      work_mem: "16MB"
+
+# Make sure user has only specified default configuration parameters
+- name: Clear all configuration that is not explicitly defined for user
+  community.postgresql.postgresql_user:
+    name: appclient
+    password: "secret123"
+    configuration:
+      work_mem: "16MB"
+    reset_unspecified_configuration: true
+
+- name: Set search_path for user
+  community.postgresql.postgresql_user:
+    name: postgres_exporter
+    quote_configuration_values: false
+    configuration:
+      search_path: postgres_exporter, pg_catalog, public
 '''
 
 RETURN = r'''
@@ -282,33 +345,37 @@ queries:
   sample: ['CREATE USER "alice"', 'GRANT CONNECT ON DATABASE "acme" TO "alice"']
 '''
 
+import hmac
 import itertools
 import re
 import traceback
-from hashlib import md5, sha256
-import hmac
 from base64 import b64decode
+from hashlib import md5, sha256
 
+from ansible.module_utils._text import to_bytes, to_native, to_text
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.six import iteritems
-from ansible.module_utils._text import to_bytes, to_native, to_text
-from ansible_collections.community.postgresql.plugins.module_utils.version import LooseVersion
+from ansible_collections.community.postgresql.plugins.module_utils import \
+    saslprep
 from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    pg_quote_identifier,
     SQLParseError,
     check_input,
+    pg_quote_identifier,
 )
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
+    HAS_PSYCOPG,
+    PSYCOPG_VERSION,
     connect_to_db,
     ensure_required_libs,
+    get_comment,
     get_conn_params,
     get_server_version,
     pg_cursor_args,
     postgres_common_argument_spec,
-    HAS_PSYCOPG,
-    PSYCOPG_VERSION
+    set_comment,
 )
-from ansible_collections.community.postgresql.plugins.module_utils import saslprep
+from ansible_collections.community.postgresql.plugins.module_utils.version import \
+    LooseVersion
 
 if HAS_PSYCOPG and PSYCOPG_VERSION < LooseVersion("3.0"):
     import psycopg2 as psycopg
@@ -372,13 +439,13 @@ def user_exists(cursor, user):
     return cursor.rowcount > 0
 
 
-def user_add(cursor, user, password, role_attr_flags, encrypted, expires, conn_limit):
+def user_add(cursor, user, password, role_attr_flags, encrypted, expires, conn_limit, module):
     """Create a new database user (role)."""
     # Note: role_attr_flags escaped by parse_role_attrs and encrypted is a
     # literal
     query_password_data = dict(password=password, expires=expires)
-    query = ['CREATE USER "%(user)s"' %
-             {"user": user}]
+    query = ['CREATE USER %(user)s' %
+             {"user": _pg_quote_user(user, module)}]
     if password is not None and password != '':
         query.append("WITH %(crypt)s" % {"crypt": encrypted})
         query.append("PASSWORD %(password)s")
@@ -393,7 +460,12 @@ def user_add(cursor, user, password, role_attr_flags, encrypted, expires, conn_l
     return True
 
 
-def user_should_we_change_password(current_role_attrs, user, password, encrypted):
+def get_passwd_encryption(cursor):
+    cursor.execute("SHOW password_encryption")
+    return cursor.fetchone()["password_encryption"]
+
+
+def user_should_we_change_password(cursor, current_role_attrs, user, password, encrypted):
     """Check if we should change the user's password.
 
     Compare the proposed password with the existing one, comparing
@@ -409,24 +481,29 @@ def user_should_we_change_password(current_role_attrs, user, password, encrypted
     # Do we actually need to do anything?
     pwchanging = False
     if password is not None:
+        current_password = current_role_attrs['rolpassword']
+        # Handle SQL_ASCII encoded databases
+        if isinstance(current_password, bytes):
+            current_password = current_password.decode('ascii')
+
         # Empty password means that the role shouldn't have a password, which
         # means we need to check if the current password is None.
         if password == '':
-            if current_role_attrs['rolpassword'] is not None:
+            if current_password is not None:
                 pwchanging = True
         # If the provided password is a SCRAM hash, compare it directly to the current password
         elif re.match(SCRAM_SHA256_REGEX, password):
-            if password != current_role_attrs['rolpassword']:
+            if password != current_password:
                 pwchanging = True
 
         # SCRAM hashes are represented as a special object, containing hash data:
         # `SCRAM-SHA-256$<iteration count>:<salt>$<StoredKey>:<ServerKey>`
         # for reference, see https://www.postgresql.org/docs/current/catalog-pg-authid.html
-        elif current_role_attrs['rolpassword'] is not None \
+        elif current_password is not None \
                 and pbkdf2_found \
-                and re.match(SCRAM_SHA256_REGEX, current_role_attrs['rolpassword']):
+                and re.match(SCRAM_SHA256_REGEX, current_password):
 
-            r = re.match(SCRAM_SHA256_REGEX, current_role_attrs['rolpassword'])
+            r = re.match(SCRAM_SHA256_REGEX, current_password)
             try:
                 # extract SCRAM params from rolpassword
                 it = int(r.group(1))
@@ -451,28 +528,137 @@ def user_should_we_change_password(current_role_attrs, user, password, encrypted
                 # or we cannot check it properly, e.g. due to missing dependencies
                 pwchanging = True
 
-        # 32: MD5 hashes are represented as a sequence of 32 hexadecimal digits
-        #  3: The size of the 'md5' prefix
         # When the provided password looks like a MD5-hash, value of
         # 'encrypted' is ignored.
-        elif (password.startswith('md5') and len(password) == 32 + 3) or encrypted == 'UNENCRYPTED':
-            if password != current_role_attrs['rolpassword']:
+        elif is_pg_passwd_md5(password) or encrypted == 'UNENCRYPTED':
+            if password != current_password:
                 pwchanging = True
         elif encrypted == 'ENCRYPTED':
-            hashed_password = 'md5{0}'.format(md5(to_bytes(password) + to_bytes(user)).hexdigest())
-            if hashed_password != current_role_attrs['rolpassword']:
+            default_pw_encryption = get_passwd_encryption(cursor)
+
+            if default_pw_encryption == 'md5':
+                hashed_password = 'md5{0}'.format(md5(to_bytes(password) + to_bytes(user)).hexdigest())
+                if hashed_password != current_password:
+                    pwchanging = True
+            elif default_pw_encryption == 'scram-sha-256':
+                # https://github.com/ansible-collections/community.postgresql/issues/688
+                # When the current password is not none and is not
+                # hashed as scram-sha-256 / not explicitly declared as plain text
+                # (if we are here, these conditions should be met)
+                # but the default password encryption is scram-sha-256, update the password.
+                # Can be relevant when migrating from older version of postgres.
                 pwchanging = True
 
     return pwchanging
 
 
+def is_pg_passwd_md5(password):
+    # 32: MD5 hashes are represented as a sequence of 32 hexadecimal digits
+    #  3: The size of the 'md5' prefix
+    return True if password.startswith('md5') and len(password) == 32 + 3 else False
+
+
+def get_role_attrs(db_connection, module, cursor, user):
+    current_role_attrs = None
+
+    # Let's first try to get the attrs from pg_authid.
+    # Some systems like AWS RDS instances
+    # do not allow user to access pg_authid
+    try:
+        query = "SELECT * FROM pg_authid where rolname=%(user)s"
+        cursor.execute(query, {"user": user})
+        current_role_attrs = cursor.fetchone()
+    except psycopg.ProgrammingError:
+        db_connection.rollback()
+
+    # If we succeeded, return it
+    if current_role_attrs is not None:
+        return current_role_attrs
+
+    # If we haven't succeeded, like in case of AWS RDS,
+    # try to get the attrs from the pg_roles table
+    try:
+        query = "SELECT * FROM pg_roles where rolname=%(user)s"
+        cursor.execute(query, {"user": user})
+        current_role_attrs = cursor.fetchone()
+    except psycopg.ProgrammingError as e:
+        db_connection.rollback()
+        module.fail_json(msg="Failed to get role details for current user %s: %s" % (user, e))
+
+    return current_role_attrs
+
+
+def need_to_change_role_attr_flags(role_attr_flags, current_role_attrs):
+    # Compare the desired role_attr_flags and current ones.
+    # If they don't match, return True which means
+    # they need to be updated, False otherwise.
+
+    role_attr_flags_changing = False
+    if role_attr_flags:
+        role_attr_flags_dict = {}
+        for r in role_attr_flags.split(' '):
+            if r.startswith('NO'):
+                role_attr_flags_dict[r.replace('NO', '', 1)] = False
+            else:
+                role_attr_flags_dict[r] = True
+
+        for role_attr_name, role_attr_value in role_attr_flags_dict.items():
+            if current_role_attrs[PRIV_TO_AUTHID_COLUMN[role_attr_name]] != role_attr_value:
+                role_attr_flags_changing = True
+
+    return role_attr_flags_changing
+
+
+def need_to_change_role_expiration(cursor, expires, current_role_attrs):
+    expires_changing = False
+
+    if expires is not None:
+        cursor.execute("SELECT %s::timestamptz exp_timestamp", (expires,))
+        expires_with_tz = cursor.fetchone()["exp_timestamp"]
+        # If the desired expiration date is not equal to
+        # what is already set for the role, set this to True
+        expires_changing = expires_with_tz != current_role_attrs.get('rolvaliduntil')
+
+    return expires_changing
+
+
+def need_to_change_conn_limit(conn_limit, current_role_attrs):
+    return (conn_limit is not None and conn_limit != current_role_attrs['rolconnlimit'])
+
+
+def exec_alter_user(module, cursor, statement, params=None):
+    changed = False
+
+    if params is None:
+        params = {}
+
+    try:
+        cursor.execute(statement, params)
+        executed_queries.append(statement)
+        changed = True
+    # We could catch psycopg.errors.ReadOnlySqlTransaction directly,
+    # but that was added only in Psycopg 2.8
+    except psycopg.InternalError as e:
+        if e.diag.sqlstate == "25006":
+            # Handle errors due to read-only transactions indicated by pgcode 25006
+            # ERROR:  cannot execute ALTER ROLE in a read-only transaction
+            changed = False
+            module.fail_json(msg=e.diag.message_primary, exception=traceback.format_exc())
+            return changed
+        else:
+            raise psycopg.InternalError(e)
+    except psycopg.NotSupportedError as e:
+        module.fail_json(msg=e.diag.message_primary, exception=traceback.format_exc())
+
+    return changed
+
+
 def user_alter(db_connection, module, user, password, role_attr_flags, encrypted, expires, no_password_changes, conn_limit):
     """Change user password and/or attributes. Return True if changed, False otherwise."""
     changed = False
 
     cursor = db_connection.cursor(**pg_cursor_args)
-    # Note: role_attr_flags escaped by parse_role_attrs and encrypted is a
-    # literal
+    # Note: role_attr_flags escaped by parse_role_attrs and encrypted is a literal
     if user == 'PUBLIC':
         if password is not None:
             module.fail_json(msg="cannot change the password for PUBLIC user")
@@ -483,56 +669,28 @@ def user_alter(db_connection, module, user, password, role_attr_flags, encrypted
 
     # Handle passwords.
     if not no_password_changes and (password is not None or role_attr_flags != '' or expires is not None or conn_limit is not None):
-        # Select password and all flag-like columns in order to verify changes.
-        try:
-            select = "SELECT * FROM pg_authid where rolname=%(user)s"
-            cursor.execute(select, {"user": user})
-            # Grab current role attributes.
-            current_role_attrs = cursor.fetchone()
-        except psycopg.ProgrammingError:
-            current_role_attrs = None
-            db_connection.rollback()
+        # Get role's current attributes to check if they match with the desired state
+        current_role_attrs = get_role_attrs(db_connection, module, cursor, user)
 
-        pwchanging = user_should_we_change_password(current_role_attrs, user, password, encrypted)
+        # Does password need to changed?
+        pwchanging = user_should_we_change_password(cursor, current_role_attrs, user, password, encrypted)
 
-        if current_role_attrs is None:
-            try:
-                # AWS RDS instances does not allow user to access pg_authid
-                # so try to get current_role_attrs from pg_roles tables
-                select = "SELECT * FROM pg_roles where rolname=%(user)s"
-                cursor.execute(select, {"user": user})
-                # Grab current role attributes from pg_roles
-                current_role_attrs = cursor.fetchone()
-            except psycopg.ProgrammingError as e:
-                db_connection.rollback()
-                module.fail_json(msg="Failed to get role details for current user %s: %s" % (user, e))
+        # Do role attributes need to changed?
+        role_attr_flags_changing = need_to_change_role_attr_flags(role_attr_flags, current_role_attrs)
 
-        role_attr_flags_changing = False
-        if role_attr_flags:
-            role_attr_flags_dict = {}
-            for r in role_attr_flags.split(' '):
-                if r.startswith('NO'):
-                    role_attr_flags_dict[r.replace('NO', '', 1)] = False
-                else:
-                    role_attr_flags_dict[r] = True
+        # Does role expiration date need to changed?
+        expires_changing = need_to_change_role_expiration(cursor, expires, current_role_attrs)
 
-            for role_attr_name, role_attr_value in role_attr_flags_dict.items():
-                if current_role_attrs[PRIV_TO_AUTHID_COLUMN[role_attr_name]] != role_attr_value:
-                    role_attr_flags_changing = True
-
-        if expires is not None:
-            cursor.execute("SELECT %s::timestamptz exp_timestamp", (expires,))
-            expires_with_tz = cursor.fetchone()["exp_timestamp"]
-            expires_changing = expires_with_tz != current_role_attrs.get('rolvaliduntil')
-        else:
-            expires_changing = False
-
-        conn_limit_changing = (conn_limit is not None and conn_limit != current_role_attrs['rolconnlimit'])
+        # Does role connection limit need to change?
+        conn_limit_changing = need_to_change_conn_limit(conn_limit, current_role_attrs)
 
+        # Now let's check if anything needs to changed. If nothing, just return False
         if not pwchanging and not role_attr_flags_changing and not expires_changing and not conn_limit_changing:
             return False
 
-        alter = ['ALTER USER "%(user)s"' % {"user": user}]
+        # If we are here, something does need to change.
+        # Compose a statement and execute it
+        alter = ['ALTER USER %(user)s' % {"user": _pg_quote_user(user, module)}]
         if pwchanging:
             if password != '':
                 alter.append("WITH %(crypt)s" % {"crypt": encrypted})
@@ -548,72 +706,30 @@ def user_alter(db_connection, module, user, password, role_attr_flags, encrypted
             alter.append("CONNECTION LIMIT %(conn_limit)s" % {"conn_limit": conn_limit})
 
         query_password_data = dict(password=password, expires=expires)
-        try:
-            statement = ' '.join(alter)
-            cursor.execute(statement, query_password_data)
-            changed = True
-            executed_queries.append(statement)
-        # We could catch psycopg.errors.ReadOnlySqlTransaction directly,
-        # but that was added only in Psycopg 2.8
-        except psycopg.InternalError as e:
-            if e.diag.sqlstate == "25006":
-                # Handle errors due to read-only transactions indicated by pgcode 25006
-                # ERROR:  cannot execute ALTER ROLE in a read-only transaction
-                changed = False
-                module.fail_json(msg=e.diag.message_primary, exception=traceback.format_exc())
-                return changed
-            else:
-                raise psycopg.InternalError(e)
-        except psycopg.NotSupportedError as e:
-            module.fail_json(msg=e.diag.message_primary, exception=traceback.format_exc())
+        statement = ' '.join(alter)
+        changed = exec_alter_user(module, cursor, statement, query_password_data)
 
     elif no_password_changes and role_attr_flags != '':
-        # Grab role information from pg_roles instead of pg_authid
-        select = "SELECT * FROM pg_roles where rolname=%(user)s"
-        cursor.execute(select, {"user": user})
-        # Grab current role attributes.
-        current_role_attrs = cursor.fetchone()
-
-        role_attr_flags_changing = False
-
-        if role_attr_flags:
-            role_attr_flags_dict = {}
-            for r in role_attr_flags.split(' '):
-                if r.startswith('NO'):
-                    role_attr_flags_dict[r.replace('NO', '', 1)] = False
-                else:
-                    role_attr_flags_dict[r] = True
-
-            for role_attr_name, role_attr_value in role_attr_flags_dict.items():
-                if current_role_attrs[PRIV_TO_AUTHID_COLUMN[role_attr_name]] != role_attr_value:
-                    role_attr_flags_changing = True
+        # Get role's current attributes to check if they match with the desired state
+        current_role_attrs = get_role_attrs(db_connection, module, cursor, user)
 
+        # Do role attributes need to changed? If not, just return False right away
+        role_attr_flags_changing = need_to_change_role_attr_flags(role_attr_flags, current_role_attrs)
         if not role_attr_flags_changing:
             return False
 
-        alter = ['ALTER USER "%(user)s"' %
-                 {"user": user}]
+        # If they need, compose a statement and execute
+        alter = ['ALTER USER %(user)s' %
+                 {"user": _pg_quote_user(user, module)}]
         if role_attr_flags:
             alter.append('WITH %s' % role_attr_flags)
 
-        try:
-            statement = ' '.join(alter)
-            cursor.execute(statement)
-            executed_queries.append(statement)
+        statement = ' '.join(alter)
 
-        except psycopg.InternalError as e:
-            if e.diag.sqlstate == "25006":
-                # Handle errors due to read-only transactions indicated by pgcode 25006
-                # ERROR:  cannot execute ALTER ROLE in a read-only transaction
-                changed = False
-                module.fail_json(msg=e.diag.message_primary, exception=traceback.format_exc())
-                return changed
-            else:
-                raise psycopg.InternalError(e)
+        changed = exec_alter_user(module, cursor, statement)
 
-        # Grab new role attributes.
-        cursor.execute(select, {"user": user})
-        new_role_attrs = cursor.fetchone()
+        # Fetch new role attributes.
+        new_role_attrs = get_role_attrs(db_connection, module, cursor, user)
 
         # Detect any differences between current_ and new_role_attrs.
         changed = current_role_attrs != new_role_attrs
@@ -621,11 +737,11 @@ def user_alter(db_connection, module, user, password, role_attr_flags, encrypted
     return changed
 
 
-def user_delete(cursor, user):
+def user_delete(cursor, user, module):
     """Try to remove a user. Returns True if successful otherwise False"""
     cursor.execute("SAVEPOINT ansible_pgsql_user_delete")
     try:
-        query = 'DROP USER "%s"' % user
+        query = 'DROP USER %s' % _pg_quote_user(user, module)
         executed_queries.append(query)
         cursor.execute(query)
     except Exception:
@@ -897,26 +1013,102 @@ def get_valid_flags_by_version(srv_version):
     ]
 
 
-def get_comment(cursor, user):
-    """Get user's comment."""
-    query = ("SELECT pg_catalog.shobj_description(r.oid, 'pg_authid') obj_desc "
-             "FROM pg_catalog.pg_roles r "
-             "WHERE r.rolname = %(user)s")
-    cursor.execute(query, {'user': user})
-    return cursor.fetchone()["obj_desc"]
-
-
-def add_comment(cursor, user, comment):
+def add_comment(cursor, user, comment, check_mode):
     """Add comment on user."""
-    if comment != get_comment(cursor, user):
-        query = 'COMMENT ON ROLE "%s" IS ' % user
-        cursor.execute(query + '%(comment)s', {'comment': comment})
-        executed_queries.append(cursor.mogrify(query + '%(comment)s', {'comment': comment}))
+    current_comment = get_comment(cursor, 'role', user)
+    # For the resetting comment feature (comment: '') to work correctly
+    current_comment = current_comment if current_comment is not None else ''
+    if comment != current_comment:
+        set_comment(cursor, comment, 'role', user, check_mode, executed_queries)
         return True
     else:
         return False
 
 
+def compare_user_configurations(current, desired, reset_unspec_config):
+    """Compares two configurations and returns a list of values to reset as well as a dict of parameters to update."""
+    reset = []
+    update = desired.copy()
+
+    # check each item in the current configuration
+    for key, value in current.items():
+        # we already have the correct setting
+        if key in desired and value == desired[key]:
+            # so we can remove it from the list
+            del update[key]
+        # if the key is not in the list of settings we want, and we reset unspecified parameters
+        elif key not in desired and reset_unspec_config:
+            # we will reset it on the database
+            reset.append(key)
+        # if the setting is not in the db or has the wrong value, it will get updated
+
+    return {"reset": reset, "update": update}
+
+
+def parse_user_configuration(module, configs):
+    """Parses configuration from a list of 'key=value' strings like returned from the database to a dict."""
+    if configs is not None:
+        try:
+            # parses a list of "key=value" strings to a dict
+            return {t[0]: t[1] for t in map(lambda s: s.split("=", 1), configs)}
+        except IndexError:
+            module.fail_json(
+                msg="Expecting a list of strings where each string has the format 'key=value'.")
+    else:
+        return {}
+
+
+def user_configuration(cursor, module, user, configuration, reset_unspec_config, quote_values):
+    """Updates the user's configuration parameters if necessary."""
+    current_config_query = "SELECT rolconfig FROM pg_roles WHERE rolname = %(user)s;"
+    cursor.execute(current_config_query, {"user": user})
+    current_config = cursor.fetchone()
+    changed = False
+
+    if current_config is None:
+        module.fail_json(msg="Can't find user %(user)s in 'pg_roles'" % {"user": user})
+
+    current_config_dict = parse_user_configuration(module, current_config['rolconfig'])
+    config_updates = compare_user_configurations(current_config_dict, configuration, reset_unspec_config)
+
+    try:
+        # It seems psycopg's prepared statements don't work with 'ALTER ROLE' at this point.
+        # This is vulnerable to SQL-injections (added to docs) but I don't see a better way to do this.
+        for item in config_updates["reset"]:
+            query = 'ALTER ROLE %(user)s RESET "%(key)s";' % {"user": _pg_quote_user(user, module), "key": item}
+            executed_queries.append(query)
+            cursor.execute(query)
+            changed = True
+        for key, value in config_updates["update"].items():
+            if quote_values:
+                query = ('ALTER ROLE %(user)s SET "%(key)s" TO \'%(value)s\';' %
+                         {"user": _pg_quote_user(user, module), "key": key, "value": value})
+            else:
+                query = ('ALTER ROLE %(user)s SET "%(key)s" TO %(value)s;' %
+                         {"user": _pg_quote_user(user, module), "key": key, "value": value})
+            executed_queries.append(query)
+            cursor.execute(query)
+            changed = True
+    except psycopg.ProgrammingError as e:
+        module.fail_json("Unable to update configuration for '%(user)s' due to: %(exception)s" %
+                         {"user": user, "exception": e})
+    return changed
+
+
+def _pg_quote_user(user, module):
+    """correctly escape users, pg_quote_identifiers will fail if the user contains a dot but is not pre-quoted"""
+    if user[0] != '"' and user[-1] != '"':
+        # we pre-quote users to make sure pg_quote_identifiers doesn't fail on dots
+        return pg_quote_identifier('"%s"' % user, 'role')
+    elif (user[0] == '"' and user[-1] != '"') or (user[0] != '"' and user[-1] == '"'):
+        module.fail_json("The value of the user-field can't contain a double-quote in the end "
+                         "if it doesn't start with one and vice-versa.")
+    else:
+        # user is already quoted, we run it through pg_quote_identifiers to make sure it doesn't contain any lonely
+        # double-quotes to prevent SQL-injections
+        return pg_quote_identifier(user, 'role')
+
+
 # ===========================================
 # Module execution.
 #
@@ -928,7 +1120,13 @@ def main():
         password=dict(type='str', default=None, no_log=True),
         state=dict(type='str', default='present', choices=['absent', 'present']),
         priv=dict(type='str', default=None, removed_in_version='4.0.0', removed_from_collection='community.postgreql'),
-        db=dict(type='str', default='', aliases=['login_db']),
+        login_db=dict(type='str', default="", aliases=['db'], deprecated_aliases=[
+            {
+                'name': 'db',
+                'version': '4.0.0',
+                'collection_name': 'community.postgresql',
+            }],
+        ),
         fail_on_user=dict(type='bool', default=True, aliases=['fail_on_role']),
         role_attr_flags=dict(type='str', default=''),
         encrypted=dict(type='bool', default=True),
@@ -938,6 +1136,9 @@ def main():
         session_role=dict(type='str'),
         comment=dict(type='str', default=None),
         trust_input=dict(type='bool', default=True),
+        configuration=dict(type='dict', default={}),
+        reset_unspecified_configuration=dict(type='bool', default=False),
+        quote_configuration_values=dict(type='bool', default=True),
     )
     module = AnsibleModule(
         argument_spec=argument_spec,
@@ -949,10 +1150,10 @@ def main():
     state = module.params["state"]
     fail_on_user = module.params["fail_on_user"]
     # WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-    if module.params['db'] == '' and module.params["priv"] is not None:
+    if module.params['login_db'] == '' and module.params["priv"] is not None:
         module.fail_json(msg="privileges require a database to be specified")
     # WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-    privs = parse_privs(module.params["priv"], module.params["db"])
+    privs = parse_privs(module.params["priv"], module.params["login_db"])
     no_password_changes = module.params["no_password_changes"]
     if module.params["encrypted"]:
         encrypted = "ENCRYPTED"
@@ -963,12 +1164,15 @@ def main():
     role_attr_flags = module.params["role_attr_flags"]
     comment = module.params["comment"]
     session_role = module.params['session_role']
+    configuration = module.params['configuration']
+    reset_unspec_config = module.params['reset_unspecified_configuration']
+    quote_configuration_values = module.params['quote_configuration_values']
 
     trust_input = module.params['trust_input']
     if not trust_input:
         # Check input for potentially dangerous elements:
         check_input(module, user, password, privs, expires,
-                    role_attr_flags, comment, session_role)
+                    role_attr_flags, comment, session_role, comment, configuration)
 
     # Ensure psycopg libraries are available before connecting to DB:
     ensure_required_libs(module)
@@ -978,6 +1182,13 @@ def main():
 
     srv_version = get_server_version(db_connection)
 
+    # sanitize configuration
+    if quote_configuration_values:
+        for key, value in configuration.items():
+            if '"' in key or '\'' in key:
+                module.fail_json("The key of a configuration may not contain single or double quotes")
+            configuration[key] = value.replace("'", "''")
+
     try:
         role_attr_flags = parse_role_attrs(role_attr_flags, srv_version)
     except InvalidFlagsError as e:
@@ -997,7 +1208,7 @@ def main():
         else:
             try:
                 changed = user_add(cursor, user, password,
-                                   role_attr_flags, encrypted, expires, conn_limit)
+                                   role_attr_flags, encrypted, expires, conn_limit, module)
             except psycopg.ProgrammingError as e:
                 module.fail_json(msg="Unable to add user with given requirement "
                                      "due to : %s" % to_native(e),
@@ -1012,11 +1223,15 @@ def main():
 
         if comment is not None:
             try:
-                changed = add_comment(cursor, user, comment) or changed
+                changed = add_comment(cursor, user, comment, module.check_mode) or changed
             except Exception as e:
                 module.fail_json(msg='Unable to add comment on role: %s' % to_native(e),
                                  exception=traceback.format_exc())
 
+        # handle user-specific configuration-defaults
+        changed = user_configuration(cursor, module, user, configuration, reset_unspec_config,
+                                     quote_configuration_values) or changed
+
     else:
         if user_exists(cursor, user):
             if module.check_mode:
@@ -1026,7 +1241,7 @@ def main():
                 # WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
                 try:
                     changed = revoke_privileges(cursor, user, privs)
-                    user_removed = user_delete(cursor, user)
+                    user_removed = user_delete(cursor, user, module)
                 except SQLParseError as e:
                     module.fail_json(msg=to_native(e), exception=traceback.format_exc())
                 changed = changed or user_removed
