@@ -14,7 +14,7 @@ DOCUMENTATION = r'''
     description:
       - Use VMware tools to run tasks in, or put/fetch files to guest operating systems running in VMware infrastructure.
       - In case of Windows VMs, set C(ansible_shell_type) to C(powershell).
-      - Does not work with 'become'.
+      - Does not work with C(become).
     requirements:
       - requests (Python library)
     options:
@@ -64,7 +64,7 @@ DOCUMENTATION = r'''
       validate_certs:
         description:
           - Verify SSL for the connection.
-          - "Note: This will validate certs for both C(vmware_host) and the ESXi host running the VM."
+          - "Note: This will validate certs for both O(vmware_host) and the ESXi host running the VM."
         env:
           - name: VMWARE_VALIDATE_CERTS
         vars:
@@ -73,10 +73,10 @@ DOCUMENTATION = r'''
         type: bool
       vm_path:
         description:
-          - Mutually exclusive with vm_uuid
+          - Mutually exclusive with O(vm_uuid)
           - VM path absolute to the connection.
-          - "vCenter Example: C(Datacenter/vm/Discovered virtual machine/testVM)."
-          - "ESXi Host Example: C(ha-datacenter/vm/testVM)."
+          - "vCenter Example: V(Datacenter/vm/Discovered virtual machine/testVM)."
+          - "ESXi Host Example: V(ha-datacenter/vm/testVM)."
           - Must include VM name, appended to 'folder' as would be passed to M(community.vmware.vmware_guest).
           - Needs to include I(vm) between the Datacenter and the rest of the VM path.
           - Datacenter default value for ESXi server is C(ha-datacenter).
@@ -86,9 +86,8 @@ DOCUMENTATION = r'''
         required: false
       vm_uuid:
         description:
-          - Mutually exclusive with vm_path
-          - VM UUID to the connection.
-          - UUID of the virtual machine from property config.uuid of vmware_vm_inventory plugin
+          - UUID of the virtual machine
+          - Mutually exclusive with O(vm_path)
         vars:
           - name: ansible_vmware_guest_uuid
         required: false
@@ -118,7 +117,7 @@ DOCUMENTATION = r'''
       file_chunk_size:
         description:
           - File chunk size.
-          - "(Applicable when writing a file to disk, example: using the C(fetch) module.)"
+          - "(Applicable when writing a file to disk, example: using the M(ansible.builtin.fetch) module.)"
         vars:
           - name: ansible_vmware_tools_file_chunk_size
         default: 128
@@ -458,12 +457,13 @@ class Connection(ConnectionBase):
         Fix url if connection is a host.
 
         The host part of the URL is returned as '*' if the hostname to be used is the name of the server to which the call was made. For example, if the call is
-        made to esx-svr-1.domain1.com, and the file is available for download from http://esx-svr-1.domain1.com/guestFile?id=1&token=1234, the URL returned may
-        be http://*/guestFile?id=1&token=1234. The client replaces the asterisk with the server name on which it invoked the call.
+        made to esx-svr-1.domain1.com and port 443, and the file is available for download from http://esx-svr-1.domain1.com:443/guestFile?id=1&token=1234,
+        the URL returned may be http://*:443/guestFile?id=1&token=1234.
+        The client replaces the asterisk with the server name on which it invoked the call and 443 with the port number.
 
         https://code.vmware.com/apis/358/vsphere#/doc/vim.vm.guest.FileManager.FileTransferInformation.html
         """
-        return url.replace("*", self.vmware_host)
+        return url.replace("*", self.vmware_host).replace("443", self.get_option("vmware_port"))
 
     def _fetch_file_from_vm(self, guestFilePath):
         try:
