@@ -10,6 +10,10 @@ __metaclass__ = type
 
 DOCUMENTATION = r"""
     name: vmware_host_inventory
+    deprecated:
+      removed_in: 7.0.0
+      why: This module has been moved to the L(new vmware.vmware collection,https://forum.ansible.com/t/5880)
+      alternative: Use P(vmware.vmware.esxi_hosts#inventory) instead.
     short_description: VMware ESXi hostsystem inventory source
     author:
       - Abhijeet Kasurde (@Akasurde)
@@ -32,6 +36,7 @@ DOCUMENTATION = r"""
             description:
             - Name of vSphere user.
             - Accepts vault encrypted variable.
+            - Accepts Jinja to template the value
             required: true
             env:
               - name: VMWARE_USER
@@ -40,6 +45,7 @@ DOCUMENTATION = r"""
             description:
             - Password of vSphere user.
             - Accepts vault encrypted variable.
+            - Accepts Jinja to template the value
             required: true
             env:
               - name: VMWARE_PASSWORD
@@ -52,7 +58,7 @@ DOCUMENTATION = r"""
         validate_certs:
             description:
             - Allows connection when SSL certificates are not valid.
-            - Set to C(false) when certificates are not trusted.
+            - Set to V(false) when certificates are not trusted.
             default: true
             type: bool
             env:
@@ -69,7 +75,7 @@ DOCUMENTATION = r"""
             description:
             - A list of templates in order of precedence to compose inventory_hostname.
             - Ignores template if resulted in an empty string or None value.
-            - You can use property specified in I(properties) as variables in the template.
+            - You can use property specified in O(properties) as variables in the template.
             type: list
             elements: string
             default: ['name']
@@ -78,12 +84,12 @@ DOCUMENTATION = r"""
             - Specify the list of VMware schema properties associated with the ESXi hostsystem.
             - These properties will be populated in hostvars of the given ESXi hostsystem.
             - Each value in the list can be a path to a specific property in hostsystem object or a path to a collection of hostsystem objects.
-            - C(summary.runtime.powerState) are required if C(keyed_groups) is set to default.
+            - V(summary.runtime.powerState) are required if O(keyed_groups) is set to default.
             - Please make sure that all the properties that are used in other parameters are included in this options.
             - In addition to ESXi hostsystem's properties, the following are special values
-            - Use C(customValue) to populate ESXi hostsystem's custom attributes. C(customValue) is only supported by vCenter and not by ESXi.
-            - Use C(all) to populate all the properties of the virtual machine.
-              The value C(all) is time consuming operation, do not use unless required absolutely.
+            - Use V(customValue) to populate ESXi hostsystem's custom attributes. V(customValue) is only supported by vCenter and not by ESXi.
+            - Use V(all) to populate all the properties of the virtual machine.
+              The value V(all) is time consuming operation, do not use unless required absolutely.
             type: list
             elements: string
             default: [ 'name', 'customValue', 'summary.runtime.powerState' ]
@@ -110,7 +116,7 @@ DOCUMENTATION = r"""
             description:
             - A list of resources to limit search scope.
             - Each resource item is represented by exactly one C('vim_type_snake_case):C(list of resource names) pair and optional nested I(resources)
-            - Key name is based on snake case of a vim type name; e.g C(host_system) correspond to C(vim.HostSystem)
+            - Key name is based on snake case of a vim type name; e.g V(host_system) correspond to C(vim.HostSystem)
             required: false
             type: list
             elements: dict
@@ -131,7 +137,6 @@ DOCUMENTATION = r"""
           description:
           - Address of a proxy that will receive all HTTPS requests and relay them.
           - The format is a hostname or a IP.
-          - This feature depends on a version of pyvmomi>=v6.7.1.2018.12.
           type: str
           required: false
           env:
@@ -143,6 +148,11 @@ DOCUMENTATION = r"""
           required: false
           env:
             - name: VMWARE_PROXY_PORT
+        enable_backward_compatibility:
+          description:
+          - Flatten the host properties for backward compatibility.
+          type: bool
+          default: true
 """
 
 EXAMPLES = r"""
@@ -155,6 +165,15 @@ EXAMPLES = r"""
     validate_certs: false
     with_tags: true
 
+# Sample configuration file for VMware Guest dynamic inventory using Jinja to template the username and password.
+    plugin: community.vmware.vmware_host_inventory
+    strict: false
+    hostname: 10.65.223.31
+    username: '{{ (lookup("file","~/.config/vmware.yaml") | from_yaml).username }}'
+    password: '{{ (lookup("file","~/.config/vmware.yaml") | from_yaml).password }}'
+    validate_certs: false
+    with_tags: true
+
 # Using compose
     plugin: community.vmware.vmware_host_inventory
     hostname: 10.65.223.31
@@ -226,6 +245,8 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         """
         super(InventoryModule, self).parse(inventory, loader, path, cache=cache)
 
+        cacheable_results = None
+
         cache_key = self.get_cache_key(path)
 
         config_data = self._read_config_data(path)
@@ -236,12 +257,16 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         username = self.get_option("username")
         password = self.get_option("password")
 
-        if isinstance(username, AnsibleVaultEncryptedUnicode):
-            username = username.data
-
-        if isinstance(password, AnsibleVaultEncryptedUnicode):
+        if self.templar.is_template(password):
+            password = self.templar.template(variable=password, disable_lookups=False)
+        elif isinstance(password, AnsibleVaultEncryptedUnicode):
             password = password.data
 
+        if self.templar.is_template(username):
+            username = self.templar.template(variable=username, disable_lookups=False)
+        elif isinstance(username, AnsibleVaultEncryptedUnicode):
+            username = username.data
+
         self.pyv = BaseVMwareInventory(
             hostname=self.get_option("hostname"),
             username=username,
@@ -507,7 +532,9 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                 self.inventory.set_variable(host, k, v)
 
         # For backward compatability
-        host_properties = to_flatten_dict(host_properties)
-        for k, v in host_properties.items():
-            k = self._sanitize_group_name(k) if can_sanitize else k
-            self.inventory.set_variable(host, k, v)
+        backward_compatibility = self.get_option("enable_backward_compatibility")
+        if backward_compatibility:
+            host_properties = to_flatten_dict(host_properties)
+            for k, v in host_properties.items():
+                k = self._sanitize_group_name(k) if can_sanitize else k
+                self.inventory.set_variable(host, k, v)
