@@ -20,11 +20,11 @@ options:
     description:
     - The ESXi hostname on which to change iSCSI settings.
     type: str
-    required: True
+    required: true
   iscsi_config:
     description:
     - The iSCSI configs.
-    - This parameter is required if I(state=present) or I(state=absent).
+    - This parameter is required if O(state=present) or O(state=absent).
     type: dict
     suboptions:
       iscsi_name:
@@ -48,7 +48,7 @@ options:
             description:
             - Whether to enable CHAP authentication.
             type: bool
-            default: False
+            default: false
           chap_authentication_type:
             description:
               - The preference for CHAP or non-CHAP protocol of CHAP if CHAP is enabled.
@@ -95,12 +95,12 @@ options:
         description:
         - Force port bind VMkernels to be removed.
         type: bool
-        default: False
+        default: false
       vmhba_name:
         description:
         - The iSCSI adapter name.
         type: str
-        required: True
+        required: true
       send_target:
         description:
         - The iSCSI dynamic target settings.
@@ -110,7 +110,7 @@ options:
             description:
             - The IP address or hostname of the storage device.
             type: str
-            required: True
+            required: true
           port:
             description:
             - The TCP port of the storage device.
@@ -126,7 +126,7 @@ options:
                 description:
                 - Whether to enable CHAP authentication.
                 type: bool
-                default: False
+                default: false
               chap_authentication_type:
                 description:
                   - The preference for CHAP or non-CHAP protocol of CHAP if CHAP is enabled.
@@ -141,7 +141,7 @@ options:
                 description:
                 - Whether or not to inherit CHAP settings from the parent settings.
                 type: bool
-                default: True
+                default: true
               chap_name:
                 description:
                 - CHAP user name if CHAP is enabled.
@@ -163,7 +163,7 @@ options:
                 description:
                 - Whether or not to inherit Mutual-CHAP settings from the parent settings.
                 type: bool
-                default: True
+                default: true
               mutual_chap_name:
                 description:
                 - The user name that the target needs to use to authenticate with the initiator if Mutual-CHAP is enabled.
@@ -182,12 +182,12 @@ options:
             description:
             - The name of the iSCSI target to connect to.
             type: str
-            required: True
+            required: true
           address:
             description:
             - The IP address or hostname of the storage device.
             type: str
-            required: True
+            required: true
           port:
             description:
             - The TCP port of the storage device.
@@ -203,7 +203,7 @@ options:
                 description:
                 - Whether to enable CHAP authentication.
                 type: bool
-                default: False
+                default: false
               chap_authentication_type:
                 description:
                   - The preference for CHAP or non-CHAP protocol of CHAP if CHAP is enabled.
@@ -218,7 +218,7 @@ options:
                 description:
                 - Whether or not to inherit CHAP settings from the parent settings.
                 type: bool
-                default: True
+                default: true
               chap_name:
                 description:
                 - CHAP user name if CHAP is enabled.
@@ -240,7 +240,7 @@ options:
                 description:
                 - Whether or not to inherit Mutual-CHAP settings from the parent settings.
                 type: bool
-                default: True
+                default: true
               mutual_chap_name:
                 description:
                 - The user name that the target needs to use to authenticate with the initiator if Mutual-CHAP is enabled.
@@ -252,11 +252,11 @@ options:
                 type: str
   state:
     description:
-    - If set to C(present), add the iSCSI target or the bind ports if they are not existing.
-    - If set to C(present), update the iSCSI settings if they already exist and occur change.
-    - If set to C(absent), remove the iSCSI target or the bind ports if they are existing.
-    - If set to (enabled), enable the iSCSI of ESXi if the iSCSI is disabled.
-    - If set to (disabled), disable the iSCSI of ESXi if the iSCSI is enabled.
+    - If set to V(present), add the iSCSI target or the bind ports if they are not existing.
+    - If set to V(present), update the iSCSI settings if they already exist and occur change.
+    - If set to V(absent), remove the iSCSI target or the bind ports if they are existing.
+    - If set to V(enabled), enable the iSCSI of ESXi if the iSCSI is disabled.
+    - If set to V(disabled), disable the iSCSI of ESXi if the iSCSI is enabled.
     type: str
     default: present
     choices:
@@ -378,7 +378,8 @@ except ImportError:
     pass
 
 from ansible.module_utils._text import to_native
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 from ansible.module_utils.basic import AnsibleModule
 from copy import deepcopy
 
@@ -851,7 +852,7 @@ def main():
         mutual_chap_inherited=dict(type='bool', default=True)
     )
 
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         esxi_hostname=dict(type='str', required=True),
         iscsi_config=dict(type='dict',
