@@ -155,6 +155,15 @@ options:
             - SSL verify peer for SMTP.
             - Can be specified when I(smtp_security=STARTTLS) or I(smtp_security=SSL/TLS)
         default: false
+    message_format:
+        type: "str"
+        description:
+            - Can be used when I(type=email).
+        choices:
+            - plaintext
+            - html
+        default: html
+        aliases: ["content_type"]
     message_text_limit:
         type: "str"
         description:
@@ -272,14 +281,14 @@ RETURN = r""" # """
 EXAMPLES = r"""
 # If you want to use Username and Password to be authenticated by Zabbix Server
 - name: Set credentials to access Zabbix Server API
-  set_fact:
+  ansible.builtin.set_fact:
     ansible_user: Admin
     ansible_httpapi_pass: zabbix
 
 # If you want to use API token to be authenticated by Zabbix Server
 # https://www.zabbix.com/documentation/current/en/manual/web_interface/frontend_sections/administration/general#api-tokens
 - name: Set API token
-  set_fact:
+  ansible.builtin.set_fact:
     ansible_zabbix_auth_key: 8ec0d52432c15c91fcafe9888500cf9a607f44091ab554dbee860f6b44fac895
 
 - name: "Create an email mediatype with SMTP authentication"
@@ -525,9 +534,13 @@ class MediaTypeModule(ZabbixBase):
                 smtp_authentication=truths.get(str(self._module.params["smtp_authentication"])),
                 smtp_verify_host=truths.get(str(self._module.params["smtp_verify_host"])),
                 smtp_verify_peer=truths.get(str(self._module.params["smtp_verify_peer"])),
+                message_format={"plaintext": "0", "html": "1"}.get(str(self._module.params["message_format"])),
                 username=self._module.params["username"],
                 passwd=self._module.params["password"]
             ))
+            if LooseVersion(self._zbx_api_version) < LooseVersion("7.0"):
+                parameters["content_type"] = parameters["message_format"]
+                del parameters["message_format"]
             if parameters["smtp_authentication"] == "0":
                 parameters.pop("username")
                 parameters.pop("passwd")
@@ -620,6 +633,12 @@ class MediaTypeModule(ZabbixBase):
 
         existing_mediatype = self._zapi.mediatype.get(get_params)[0]
 
+        if (LooseVersion(self._zbx_api_version) >= LooseVersion("7.0.9")
+                and LooseVersion(self._zbx_api_version) < LooseVersion("7.2")):
+            # A bug starting with 7.0.9. mediatype.get does not return "message_fomat"
+            if "message_format" not in existing_mediatype:
+                existing_mediatype["message_format"] = ""  # Assume it always changes https://support.zabbix.com/browse/ZBX-26057 -(
+
         if existing_mediatype["type"] != kwargs["type"]:
             return kwargs, diff(existing_mediatype, kwargs)
         else:
@@ -693,6 +712,7 @@ def main():
         smtp_authentication=dict(type="bool", default=False, required=False),
         smtp_verify_host=dict(type="bool", default=False, required=False),
         smtp_verify_peer=dict(type="bool", default=False, required=False),
+        message_format=dict(type="str", choices=["plaintext", "html"], default="html", required=False, aliases=["content_type"]),
         # EZ Text
         message_text_limit=dict(type="str", required=False, choices=["USA", "Canada"]),
         # Webhook
