@@ -51,6 +51,20 @@ def remove_matching_defaults(root, default_entry):
                     root.pop(default_entry[0]['name'])
 
 
+def add_config_defaults(root, default_entry):
+    if isinstance(root, list):
+        for list_item in root:
+            add_config_defaults(list_item, default_entry)
+    elif isinstance(root, dict):
+        nextobj = root.get(default_entry[0]['name'])
+        if nextobj is not None:
+            if len(default_entry) > 1:
+                add_config_defaults(nextobj, default_entry[1:])
+        else:
+            if len(default_entry) == 1:
+                root[default_entry[0]['name']] = default_entry[0]['default']
+
+
 def get_diff(base_data, compare_with_data, test_keys=None, is_skeleton=None):
     diff = []
     if is_skeleton is None:
@@ -349,6 +363,28 @@ def remove_empties_from_list(config_list):
     return ret_config
 
 
+def remove_none(config):
+    '''goes through nested dictionary items and removes any keys that have None as value.
+    enables using empty list/dict to specify clear everything for that section and differentiate this
+    'clear everything' case from when no value was given
+    Note: This function is provided as an alternative to the "remove_empties" function in
+    ansible utils because the Ansible 'remove_empties' function will remove empty lists
+    and dicts as well as None'''
+    if isinstance(config, dict):
+        for k, v in list(config.items()):
+            if v is not None:
+                remove_none(v)
+            if v is None:
+                del config[k]
+    elif isinstance(config, list):
+        for item in list(config):
+            if item is not None:
+                remove_none(item)
+            if item is None:
+                config.remove(item)
+    return config
+
+
 def get_device_interface_naming_mode(module):
     intf_naming_mode = ""
     request = {"path": "data/sonic-device-metadata:sonic-device-metadata/DEVICE_METADATA/DEVICE_METADATA_LIST=localhost", "method": GET}
@@ -382,12 +418,18 @@ def find_intf_naming_mode(intf_name):
 
 def validate_intf_naming_mode(intf_name, module):
     global intf_naming_mode
+    compatible_input_naming_modes = {
+        'native': [NATIVE_MODE],
+        'standard': [STANDARD_MODE],
+        'standard-ext': [STANDARD_MODE]
+    }
+
     if intf_naming_mode == "":
         intf_naming_mode = get_device_interface_naming_mode(module)
 
     if intf_naming_mode != "":
         ansible_intf_naming_mode = find_intf_naming_mode(intf_name)
-        if intf_naming_mode != ansible_intf_naming_mode:
+        if ansible_intf_naming_mode not in compatible_input_naming_modes[intf_naming_mode]:
             err = "Interface naming mode configured on switch {naming_mode}, {intf_name} is not valid".format(naming_mode=intf_naming_mode, intf_name=intf_name)
             module.fail_json(msg=err, code=400)
 
@@ -418,7 +460,7 @@ def get_normalize_interface_name(intf_name, module):
     ret_intf_name = re.sub(r"\s+", "", intf_name, flags=re.UNICODE)
     ret_intf_name = ret_intf_name.capitalize()
 
-    # serach the numeric charecter(digit)
+    # search the numeric character(digit)
     match = re.search(r"\d", ret_intf_name)
     if match:
         change_flag = True
@@ -455,14 +497,7 @@ def get_normalize_interface_name(intf_name, module):
 
 
 def get_speed_from_breakout_mode(breakout_mode):
-    speed = None
-    speed_breakout_mode_map = {
-        "4x10G": "SPEED_10GB", "1x100G": "SPEED_100GB", "1x40G": "SPEED_40GB", "4x25G": "SPEED_25GB", "2x50G": "SPEED_50GB",
-        "1x400G": "SPEED_400GB", "4x100G": "SPEED_100GB", "4x50G": "SPEED_50GB", "2x100G": "SPEED_100GB", "2x200G": "SPEED_200GB"
-    }
-    if breakout_mode in speed_breakout_mode_map:
-        speed = speed_breakout_mode_map[breakout_mode]
-    return speed
+    return 'SPEED_' + breakout_mode.split('x')[1].replace('G', 'GB')
 
 
 def get_breakout_mode(module, name):
@@ -478,7 +513,7 @@ def get_breakout_mode(module, name):
     except ConnectionError as exc:
         try:
             json_obj = json.loads(str(exc).replace("'", '"'))
-            if json_obj and type(json_obj) is dict and 404 == json_obj['code']:
+            if json_obj and isinstance(json_obj, dict) and 404 == json_obj['code']:
                 response = None
             else:
                 module.fail_json(msg=str(exc), code=exc.code)
@@ -552,6 +587,8 @@ def send_requests(module, requests):
 def get_replaced_config(new_conf, exist_conf, test_keys=None):
 
     replace_conf = []
+    if not new_conf or not exist_conf:
+        return replace_conf
 
     if isinstance(new_conf, list) and isinstance(exist_conf, list):
 
@@ -599,6 +636,7 @@ def get_replaced_config_dict(new_conf, exist_conf, test_keys=None, key_set=None)
                 trival_exist_key_set.add(key)
 
     common_trival_key_set = trival_new_key_set.intersection(trival_exist_key_set)
+    common_dict_list_key_set = dict_list_new_key_set.intersection(dict_list_exist_key_set)
 
     key_matched_cnt = 0
     common_trival_key_matched = True
@@ -610,6 +648,11 @@ def get_replaced_config_dict(new_conf, exist_conf, test_keys=None, key_set=None)
             if key not in key_set:
                 common_trival_key_matched = False
 
+    for key in common_dict_list_key_set:
+        if new_conf[key] == exist_conf[key]:
+            if key in key_set:
+                key_matched_cnt += 1
+
     key_matched = (key_matched_cnt == len(key_set))
     if key_matched:
         extra_trival_new_key_set = trival_new_key_set - common_trival_key_set
@@ -623,10 +666,12 @@ def get_replaced_config_dict(new_conf, exist_conf, test_keys=None, key_set=None)
         replaced_conf = []
         return replaced_conf
 
+    for key in key_set:
+        common_dict_list_key_set.discard(key)
+
     replace_whole_dict = False
     replace_some_list = False
     replace_some_dict = False
-    common_dict_list_key_set = dict_list_new_key_set.intersection(dict_list_exist_key_set)
     for key in common_dict_list_key_set:
 
         new_value = new_conf[key]
