@@ -53,7 +53,6 @@ class HttpApi(HttpApiBase):
         self._req_id = 0
         self._sid = None
         self._url = "/jsonrpc"
-        self._host = None
         self._tools = FMGRCommon
         self._connected_fmgr = None
         self._last_response_msg = None
@@ -72,26 +71,14 @@ class HttpApi(HttpApiBase):
         self._prelocking_user_params = list()
         self._access_token = None
         self._login_method = None
+        self._status = {}
+        self.customer_options = {}
 
-    def get_forticloud_access_token(self):
-        try:
-            token = self.connection.get_option("forticloud_access_token")
-            return token
-        except Exception as e:
-            return None
-
-    def get_access_token(self):
-        try:
-            token = self.connection.get_option("access_token")
-            return token
-        except Exception as e:
-            return None
+    def set_customer_option(self, key, value):
+        self.customer_options[key] = value
 
     def log(self, msg):
-        try:
-            log_enabled = self.connection.get_option("enable_log")
-        except Exception as e:
-            return
+        log_enabled = self.customer_options.get("enable_log", False)
         if not log_enabled:
             return
         if not self._log:
@@ -119,7 +106,7 @@ class HttpApi(HttpApiBase):
         return None
 
     def forticloud_login(self):
-        login_data = '{"access_token": "%s"}' % (self.get_forticloud_access_token())
+        login_data = '{"access_token": "%s"}' % (self.customer_options.get("forticloud_access_token", None))
         try:
             response, response_data = self.connection.send(
                 path=to_text("/p/forticloud_jsonrpc_login/"),
@@ -142,22 +129,20 @@ class HttpApi(HttpApiBase):
         """
         self.log("login begin, user: %s" % (username))
         self._logged_in_user = username
-        forticloud_access_token = self.get_forticloud_access_token()
-        self._access_token = self.get_access_token()
-        self.log(
-            "forticloud access token: %s"
-            % (forticloud_access_token if forticloud_access_token else "(not set)")
-        )
-        if self._access_token:
+        forticloud_access_token = self.customer_options.get("forticloud_access_token", None)
+        self._access_token = self.customer_options.get("access_token", None)
+        if username is not None and password is not None:
+            self._login_method = 'username_password'
+            self.send_request("exec", self._tools.format_request("exec", "sys/login/user", passwd=password, user=username))
+        elif self._access_token:
             self._login_method = 'access_token'
         elif forticloud_access_token:
             self._login_method = 'forticloud'
             self.forticloud_login()
         else:
-            self._login_method = 'username_password'
-            self.send_request("exec", self._tools.format_request("exec", "sys/login/user", passwd=password, user=username))
+            err_msg = "Please check whether you provide the correct information."
+            raise AssertionError(err_msg)
         self.log('login method: ' + self._login_method)
-        self.log(self)
         if (self.sid or self._access_token) and self.connection._url is not None:
             # If Login worked, then inspect the FortiManager for Workspace Mode, and it's system information.
             self.inspect_fmgr()
@@ -176,13 +161,15 @@ class HttpApi(HttpApiBase):
             self.logout()
             raise FMGBaseException(msg="Error -11 -- the Session ID was likely malformed somehow. Exiting")
         elif rc == 0:
-            self.check_mode()
-            if self._uses_adoms:
-                self.get_adom_list()
-            if self._uses_workspace:
-                self.get_locked_adom_list()
-            self._connected_fmgr = status
-            self._host = self._connected_fmgr["data"]["Hostname"]
+            try:
+                self.check_mode()
+                if self._uses_adoms:
+                    self.get_adom_list()
+                if self._uses_workspace:
+                    self.get_locked_adom_list()
+                self._connected_fmgr = status
+            except Exception as e:
+                self.log("inspect_fmgr exception: %s" % (e))
 
     def logout(self):
         """
@@ -192,11 +179,10 @@ class HttpApi(HttpApiBase):
             "log out, using workspace:%s user: %s sid: %s"
             % (self._uses_workspace, self._logged_in_user, self.sid)
         )
+        # IF WE WERE USING WORKSPACES, THEN CLEAN UP OUR LOCKS IF THEY STILL EXIST
+        if self._uses_workspace:
+            self.run_unlock()
         if self.sid:
-            # IF WE WERE USING WORKSPACES, THEN CLEAN UP OUR LOCKS IF THEY STILL EXIST
-            if self._uses_workspace:
-                # self.get_lock_info()
-                self.run_unlock()
             rc, response = self.send_request("exec", self._tools.format_request("exec", "sys/logout"))
             self.sid = None
             return rc, response
@@ -214,7 +200,7 @@ class HttpApi(HttpApiBase):
         if self.sid is None and params[0]["url"] != "sys/login/user":
             if not self.connection._connected:
                 self.connection._connect()
-        if params[0]["url"] == "sys/login/user" and "passwd" in params[0]["data"]:
+        if params[0]["url"] == "sys/login/user" and "data" in params[0] and "passwd" in params[0]["data"]:
             params[0]["data"]["passwd"] = str(params[0]["data"]["passwd"])
         self._update_request_id()
         json_request = {
@@ -225,19 +211,23 @@ class HttpApi(HttpApiBase):
             "verbose": 1,
         }
         data = json.dumps(json_request, ensure_ascii=False).replace("\\\\", "\\")
+
         # Don't log sensitive information
-        if params[0]["url"] == "sys/login/user" and "passwd" in params[0]["data"]:
+        if params[0]["url"] == "sys/login/user" and "data" in params[0] and "passwd" in params[0]["data"]:
             json_request["params"][0]["data"]["passwd"] = "******"
         if "session" in params[0]:
             json_request["params"][0]["session"] = "******"
         log_data = json.dumps(json_request, ensure_ascii=False).replace("\\\\", "\\")
         self.log("request: %s" % (log_data))
+
         # Sending URL and Data in Unicode, per Ansible Specifications for Connection Plugins
+        access_token_str = ''
         header_data = BASE_HEADERS
         if self._login_method == "access_token":
+            access_token_str = '?access_token=' + self._access_token
             header_data["Authorization"] = "Bearer " + self._access_token
         response, response_data = self.connection.send(
-            path=to_text(self._url), data=to_text(data), headers=header_data
+            path=to_text(self._url) + access_token_str, data=to_text(data), headers=header_data
         )
         # Get Unicode Response - Must convert from StringIO to unicode first so we can do a replace function below
         result = json.loads(to_text(response_data.getvalue()))
@@ -282,8 +272,12 @@ class HttpApi(HttpApiBase):
         Returns the system status page from the FortiManager, for logging and other uses.
         return: status
         """
-        rc, status = self.send_request("get", self._tools.format_request("get", "sys/status"))
-        return rc, status
+        if not self.connection._connected:
+            self.connection._connect()
+        if self._status:
+            return 0, self._status
+        rc, self._status = self.send_request("get", self._tools.format_request("get", "/cli/global/system/status"))
+        return rc, self._status
 
     def process_workspace_locking_internal(self, param):
         if not self._uses_workspace or not self._logged:
@@ -382,10 +376,11 @@ class HttpApi(HttpApiBase):
         """
         url = "/cli/global/system/global"
         rc, resp_obj = self.send_request("get", self._tools.format_request("get", url, fields=["workspace-mode", "adom-status"]))
-        if resp_obj["data"]["adom-status"] in [1, "enable"]:
-            self._uses_adoms = True
-        if resp_obj["data"]["workspace-mode"] in ["workflow", "normal", "per-adom"]:
-            self._uses_workspace = True
+        if "data" in resp_obj and isinstance(resp_obj["data"], dict):
+            if resp_obj["data"].get("adom-status", "") in [1, "enable"]:
+                self._uses_adoms = True
+            if resp_obj["data"].get("workspace-mode", "") in ["workflow", "normal", "per-adom"]:
+                self._uses_workspace = True
         self.log("workspace-mode: %s adom-status: %s" % (self._uses_workspace, self._uses_adoms))
 
     def run_unlock(self):
@@ -399,7 +394,7 @@ class HttpApi(HttpApiBase):
                 self.unlock_adom(adom_locked)
                 self.log("unlock adom: %s with session_id:%s" % (adom_locked, self.sid))
 
-    def lock_adom(self, adom=None, *args, **kwargs):
+    def lock_adom(self, adom=None):
         """
         Locks an ADOM for changes
         """
@@ -415,7 +410,7 @@ class HttpApi(HttpApiBase):
             self.add_adom_to_lock_list(adom)
         return code, respobj
 
-    def unlock_adom(self, adom=None, *args, **kwargs):
+    def unlock_adom(self, adom=None):
         """
         Unlocks an ADOM after changes
         """
@@ -431,7 +426,7 @@ class HttpApi(HttpApiBase):
             self.remove_adom_from_lock_list(adom)
         return code, respobj
 
-    def commit_changes(self, adom=None, aux=False, *args, **kwargs):
+    def commit_changes(self, adom=None, aux=False):
         """
         Commits changes to an ADOM
         """
