@@ -98,12 +98,14 @@ options:
             description:
                 type: str
                 description: Description.
-            from-vlan:
+            from_vlan:
+                aliases: ['from-vlan']
                 type: str
-                description: Deprecated, please rename it to from_vlan. VLAN ID from which the Bonjour service is advertised
-            policy-id:
+                description: VLAN ID from which the Bonjour service is advertised
+            policy_id:
+                aliases: ['policy-id']
                 type: int
-                description: Deprecated, please rename it to policy_id. Policy ID.
+                description: Policy ID.
                 required: true
             services:
                 type: list
@@ -123,15 +125,17 @@ options:
                     - 'chromecast'
                     - 'all'
                     - 'miracast'
-            to-vlan:
+            to_vlan:
+                aliases: ['to-vlan']
                 type: str
-                description: Deprecated, please rename it to to_vlan. VLAN ID to which the Bonjour service is made available
+                description: VLAN ID to which the Bonjour service is made available
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -148,24 +152,24 @@ EXAMPLES = '''
         bonjour_profile: <your own value>
         state: present # <value in [present, absent]>
         bonjourprofile_policylist:
-          description: <string>
-          from_vlan: <string>
-          policy_id: <integer>
-          services:
-            - airplay
-            - afp
-            - bit-torrent
-            - ftp
-            - ichat
-            - itunes
-            - printers
-            - samba
-            - scanners
-            - ssh
-            - chromecast
-            - all
-            - miracast
-          to_vlan: <string>
+          policy_id: 0 # Required variable, integer
+          # description: <string>
+          # from_vlan: <string>
+          # services:
+          #   - "airplay"
+          #   - "afp"
+          #   - "bit-torrent"
+          #   - "ftp"
+          #   - "ichat"
+          #   - "itunes"
+          #   - "printers"
+          #   - "samba"
+          #   - "scanners"
+          #   - "ssh"
+          #   - "chromecast"
+          #   - "all"
+          #   - "miracast"
+          # to_vlan: <string>
 '''
 
 RETURN = '''
@@ -209,23 +213,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/wireless-controller/bonjour-profile/{bonjour-profile}/policy-list',
         '/pm/config/global/obj/wireless-controller/bonjour-profile/{bonjour-profile}/policy-list'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/wireless-controller/bonjour-profile/{bonjour-profile}/policy-list/{policy-list}',
-        '/pm/config/global/obj/wireless-controller/bonjour-profile/{bonjour-profile}/policy-list/{policy-list}'
-    ]
-
     url_params = ['adom', 'bonjour-profile']
     module_primary_key = 'policy-id'
     module_arg_spec = {
@@ -249,7 +245,6 @@ def main():
                 },
                 'to-vlan': {'type': 'str'}
             }
-
         }
     }
 
@@ -258,14 +253,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'bonjourprofile_policylist'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
