@@ -87,50 +87,59 @@ options:
             __change_ip:
                 type: int
                 description: Hidden attribute.
-            access-config:
+            access_config:
+                aliases: ['access-config']
                 type: str
-                description: Deprecated, please rename it to access_config. Enable/disable FortiAnalyzer access to configuration and data.
+                description: Enable/disable FortiAnalyzer access to configuration and data.
                 choices:
                     - 'disable'
                     - 'enable'
             certificate:
                 type: str
                 description: Certificate used to communicate with FortiAnalyzer.
-            conn-timeout:
+            conn_timeout:
+                aliases: ['conn-timeout']
                 type: int
-                description: Deprecated, please rename it to conn_timeout. FortiAnalyzer connection time-out in seconds
-            enc-algorithm:
+                description: FortiAnalyzer connection time-out in seconds
+            enc_algorithm:
+                aliases: ['enc-algorithm']
                 type: str
-                description: Deprecated, please rename it to enc_algorithm. Configure the level of SSL protection for secure communication with FortiAn...
+                description: Configure the level of SSL protection for secure communication with FortiAnalyzer.
                 choices:
                     - 'high'
                     - 'low'
                     - 'high-medium'
                     - 'low-medium'
-            hmac-algorithm:
+            hmac_algorithm:
+                aliases: ['hmac-algorithm']
                 type: str
-                description: Deprecated, please rename it to hmac_algorithm. FortiAnalyzer IPsec tunnel HMAC algorithm.
+                description: FortiAnalyzer IPsec tunnel HMAC algorithm.
                 choices:
                     - 'sha256'
                     - 'sha1'
-            ips-archive:
+            ips_archive:
+                aliases: ['ips-archive']
                 type: str
-                description: Deprecated, please rename it to ips_archive. Enable/disable IPS packet archive logging.
+                description: Enable/disable IPS packet archive logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            monitor-failure-retry-period:
+            monitor_failure_retry_period:
+                aliases: ['monitor-failure-retry-period']
                 type: int
-                description: Deprecated, please rename it to monitor_failure_retry_period. Time between FortiAnalyzer connection retries in seconds
-            monitor-keepalive-period:
+                description: Time between FortiAnalyzer connection retries in seconds
+            monitor_keepalive_period:
+                aliases: ['monitor-keepalive-period']
                 type: int
-                description: Deprecated, please rename it to monitor_keepalive_period. Time between OFTP keepalives in seconds
-            source-ip:
+                description: Time between OFTP keepalives in seconds
+            source_ip:
+                aliases: ['source-ip']
                 type: str
-                description: Deprecated, please rename it to source_ip. Source IPv4 or IPv6 address used to communicate with FortiAnalyzer.
-            ssl-min-proto-version:
+                description: Source IPv4 or IPv6 address used to communicate with FortiAnalyzer.
+            ssl_min_proto_version:
+                aliases: ['ssl-min-proto-version']
                 type: str
-                description: Deprecated, please rename it to ssl_min_proto_version. Minimum supported protocol version for SSL/TLS connections
+                description: Minimum supported protocol version for SSL/TLS connections
                 choices:
                     - 'default'
                     - 'TLSv1-1'
@@ -144,30 +153,35 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            upload-day:
+            upload_day:
+                aliases: ['upload-day']
                 type: str
-                description: Deprecated, please rename it to upload_day. Day of week
-            upload-interval:
+                description: Day of week
+            upload_interval:
+                aliases: ['upload-interval']
                 type: str
-                description: Deprecated, please rename it to upload_interval. Frequency to upload log files to FortiAnalyzer.
+                description: Frequency to upload log files to FortiAnalyzer.
                 choices:
                     - 'daily'
                     - 'weekly'
                     - 'monthly'
-            upload-option:
+            upload_option:
+                aliases: ['upload-option']
                 type: str
-                description: Deprecated, please rename it to upload_option. Enable/disable logging to hard disk and then uploading to FortiAnalyzer.
+                description: Enable/disable logging to hard disk and then uploading to FortiAnalyzer.
                 choices:
                     - 'store-and-upload'
                     - 'realtime'
                     - '1-minute'
                     - '5-minute'
-            upload-time:
+            upload_time:
+                aliases: ['upload-time']
                 type: str
-                description: Deprecated, please rename it to upload_time. Time to upload logs
-            max-log-rate:
+                description: Time to upload logs
+            max_log_rate:
+                aliases: ['max-log-rate']
                 type: int
-                description: Deprecated, please rename it to max_log_rate. FortiAnalyzer maximum log rate in MBps
+                description: FortiAnalyzer maximum log rate in MBps
             priority:
                 type: str
                 description: Set log transmission priority.
@@ -177,31 +191,39 @@ options:
             interface:
                 type: str
                 description: Specify outgoing interface to reach server.
-            interface-select-method:
+            interface_select_method:
+                aliases: ['interface-select-method']
                 type: str
-                description: Deprecated, please rename it to interface_select_method. Specify how to select outgoing interface to reach server.
+                description: Specify how to select outgoing interface to reach server.
                 choices:
                     - 'auto'
                     - 'sdwan'
                     - 'specify'
-            preshared-key:
+            preshared_key:
+                aliases: ['preshared-key']
                 type: str
-                description: Deprecated, please rename it to preshared_key. Preshared-key used for auto-authorization on FortiAnalyzer.
-            certificate-verification:
+                description: Preshared-key used for auto-authorization on FortiAnalyzer.
+            certificate_verification:
+                aliases: ['certificate-verification']
                 type: str
-                description: Deprecated, please rename it to certificate_verification. Enable/disable identity verification of FortiAnalyzer by use of ...
+                description: Enable/disable identity verification of FortiAnalyzer by use of certificate.
                 choices:
                     - 'disable'
                     - 'enable'
             serial:
                 type: raw
                 description: (list) Serial numbers of the FortiAnalyzer.
+            vrf_select:
+                aliases: ['vrf-select']
+                type: int
+                description: VRF ID used for connection to server.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -217,29 +239,30 @@ EXAMPLES = '''
         adom: <your own value>
         devprof: <your own value>
         devprof_log_fortianalyzercloud_setting:
-          __change_ip: <integer>
-          access_config: <value in [disable, enable]>
-          certificate: <string>
-          conn_timeout: <integer>
-          enc_algorithm: <value in [high, low, high-medium, ...]>
-          hmac_algorithm: <value in [sha256, sha1]>
-          ips_archive: <value in [disable, enable]>
-          monitor_failure_retry_period: <integer>
-          monitor_keepalive_period: <integer>
-          source_ip: <string>
-          ssl_min_proto_version: <value in [default, TLSv1-1, TLSv1-2, ...]>
-          status: <value in [disable, enable]>
-          upload_day: <string>
-          upload_interval: <value in [daily, weekly, monthly]>
-          upload_option: <value in [store-and-upload, realtime, 1-minute, ...]>
-          upload_time: <string>
-          max_log_rate: <integer>
-          priority: <value in [low, default]>
-          interface: <string>
-          interface_select_method: <value in [auto, sdwan, specify]>
-          preshared_key: <string>
-          certificate_verification: <value in [disable, enable]>
-          serial: <list or string>
+          # __change_ip: <integer>
+          # access_config: <value in [disable, enable]>
+          # certificate: <string>
+          # conn_timeout: <integer>
+          # enc_algorithm: <value in [high, low, high-medium, ...]>
+          # hmac_algorithm: <value in [sha256, sha1]>
+          # ips_archive: <value in [disable, enable]>
+          # monitor_failure_retry_period: <integer>
+          # monitor_keepalive_period: <integer>
+          # source_ip: <string>
+          # ssl_min_proto_version: <value in [default, TLSv1-1, TLSv1-2, ...]>
+          # status: <value in [disable, enable]>
+          # upload_day: <string>
+          # upload_interval: <value in [daily, weekly, monthly]>
+          # upload_option: <value in [store-and-upload, realtime, 1-minute, ...]>
+          # upload_time: <string>
+          # max_log_rate: <integer>
+          # priority: <value in [low, default]>
+          # interface: <string>
+          # interface_select_method: <value in [auto, sdwan, specify]>
+          # preshared_key: <string>
+          # certificate_verification: <value in [disable, enable]>
+          # serial: <list or string>
+          # vrf_select: <integer>
 '''
 
 RETURN = '''
@@ -283,21 +306,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/devprof/{devprof}/log/fortianalyzer-cloud/setting'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/devprof/{devprof}/log/fortianalyzer-cloud/setting/{setting}'
-    ]
-
     url_params = ['adom', 'devprof']
     module_primary_key = None
     module_arg_spec = {
@@ -341,13 +357,13 @@ def main():
                 'upload-time': {'v_range': [['6.2.1', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
                 'max-log-rate': {'v_range': [['6.2.2', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'int'},
                 'priority': {'v_range': [['6.2.2', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'choices': ['low', 'default'], 'type': 'str'},
-                'interface': {'v_range': [['6.2.7', '6.2.12'], ['6.4.3', '']], 'type': 'str'},
-                'interface-select-method': {'v_range': [['6.2.7', '6.2.12'], ['6.4.3', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'},
+                'interface': {'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '']], 'type': 'str'},
+                'interface-select-method': {'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'},
                 'preshared-key': {'v_range': [['7.0.0', '']], 'no_log': True, 'type': 'str'},
                 'certificate-verification': {'v_range': [['7.0.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'serial': {'v_range': [['7.0.3', '']], 'type': 'raw'}
+                'serial': {'v_range': [['7.0.3', '']], 'type': 'raw'},
+                'vrf-select': {'v_range': [['7.6.2', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -356,14 +372,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'devprof_log_fortianalyzercloud_setting'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
