@@ -92,28 +92,32 @@ options:
             comment:
                 type: str
                 description: Comment.
-            dlp-log:
+            dlp_log:
+                aliases: ['dlp-log']
                 type: str
-                description: Deprecated, please rename it to dlp_log. Enable/disable DLP logging.
+                description: Enable/disable DLP logging.
                 choices:
                     - 'disable'
                     - 'enable'
-            extended-log:
+            extended_log:
+                aliases: ['extended-log']
                 type: str
-                description: Deprecated, please rename it to extended_log. Enable/disable extended logging for data leak prevention.
+                description: Enable/disable extended logging for data leak prevention.
                 choices:
                     - 'disable'
                     - 'enable'
-            feature-set:
+            feature_set:
+                aliases: ['feature-set']
                 type: str
-                description: Deprecated, please rename it to feature_set. Flow/proxy feature set.
+                description: Flow/proxy feature set.
                 choices:
                     - 'flow'
                     - 'proxy'
-            full-archive-proto:
+            full_archive_proto:
+                aliases: ['full-archive-proto']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to full_archive_proto. Protocols to always content archive.
+                description: Protocols to always content archive.
                 choices:
                     - 'smtp'
                     - 'pop3'
@@ -125,9 +129,10 @@ options:
                     - 'mapi'
                     - 'ssh'
                     - 'cifs'
-            nac-quar-log:
+            nac_quar_log:
+                aliases: ['nac-quar-log']
                 type: str
-                description: Deprecated, please rename it to nac_quar_log. Enable/disable NAC quarantine logging.
+                description: Enable/disable NAC quarantine logging.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -135,9 +140,10 @@ options:
                 type: str
                 description: Name of the DLP profile.
                 required: true
-            replacemsg-group:
+            replacemsg_group:
+                aliases: ['replacemsg-group']
                 type: str
-                description: Deprecated, please rename it to replacemsg_group. Replacement message group used by this DLP profile.
+                description: Replacement message group used by this DLP profile.
             rule:
                 type: list
                 elements: dict
@@ -160,30 +166,35 @@ options:
                     expiry:
                         type: str
                         description: Quarantine duration in days, hours, minutes
-                    file-size:
+                    file_size:
+                        aliases: ['file-size']
                         type: int
-                        description: Deprecated, please rename it to file_size. Match files this size or larger
-                    file-type:
+                        description: Match files this size or larger
+                    file_type:
+                        aliases: ['file-type']
                         type: str
-                        description: Deprecated, please rename it to file_type. Select the number of a DLP file pattern table to match.
-                    filter-by:
+                        description: Select the number of a DLP file pattern table to match.
+                    filter_by:
+                        aliases: ['filter-by']
                         type: str
-                        description: Deprecated, please rename it to filter_by. Select the type of content to match.
+                        description: Select the type of content to match.
                         choices:
                             - 'fingerprint'
                             - 'sensor'
                             - 'encrypted'
                             - 'none'
                             - 'mip'
+                            - 'label'
                     id:
                         type: int
                         description: ID.
                     label:
                         type: str
                         description: MIP label dictionary.
-                    match-percentage:
+                    match_percentage:
+                        aliases: ['match-percentage']
                         type: int
-                        description: Deprecated, please rename it to match_percentage. Percentage of fingerprints in the fingerprint databases designat...
+                        description: Percentage of fingerprints in the fingerprint databases designated with the selected sensitivity to match.
                     name:
                         type: str
                         description: Filter name.
@@ -223,10 +234,11 @@ options:
                         choices:
                             - 'file'
                             - 'message'
-            summary-proto:
+            summary_proto:
+                aliases: ['summary-proto']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to summary_proto. Protocols to always log summary.
+                description: Protocols to always log summary.
                 choices:
                     - 'smtp'
                     - 'pop3'
@@ -244,6 +256,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -259,62 +272,61 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         dlp_profile:
-          comment: <string>
-          dlp_log: <value in [disable, enable]>
-          extended_log: <value in [disable, enable]>
-          feature_set: <value in [flow, proxy]>
-          full_archive_proto:
-            - smtp
-            - pop3
-            - imap
-            - http-post
-            - http-get
-            - ftp
-            - nntp
-            - mapi
-            - ssh
-            - cifs
-          nac_quar_log: <value in [disable, enable]>
-          name: <string>
-          replacemsg_group: <string>
-          rule:
-            -
-              action: <value in [log-only, block, quarantine-ip, ...]>
-              archive: <value in [disable, enable]>
-              expiry: <string>
-              file_size: <integer>
-              file_type: <string>
-              filter_by: <value in [fingerprint, sensor, encrypted, ...]>
-              id: <integer>
-              label: <string>
-              match_percentage: <integer>
-              name: <string>
-              proto:
-                - smtp
-                - pop3
-                - imap
-                - http-post
-                - http-get
-                - ftp
-                - nntp
-                - mapi
-                - ssh
-                - cifs
-              sensitivity: <list or string>
-              sensor: <list or string>
-              severity: <value in [info, low, medium, ...]>
-              type: <value in [file, message]>
-          summary_proto:
-            - smtp
-            - pop3
-            - imap
-            - http-post
-            - http-get
-            - ftp
-            - nntp
-            - mapi
-            - ssh
-            - cifs
+          name: "your value" # Required variable, string
+          # comment: <string>
+          # dlp_log: <value in [disable, enable]>
+          # extended_log: <value in [disable, enable]>
+          # feature_set: <value in [flow, proxy]>
+          # full_archive_proto:
+          #   - "smtp"
+          #   - "pop3"
+          #   - "imap"
+          #   - "http-post"
+          #   - "http-get"
+          #   - "ftp"
+          #   - "nntp"
+          #   - "mapi"
+          #   - "ssh"
+          #   - "cifs"
+          # nac_quar_log: <value in [disable, enable]>
+          # replacemsg_group: <string>
+          # rule:
+          #   - action: <value in [log-only, block, quarantine-ip, ...]>
+          #     archive: <value in [disable, enable]>
+          #     expiry: <string>
+          #     file_size: <integer>
+          #     file_type: <string>
+          #     filter_by: <value in [fingerprint, sensor, encrypted, ...]>
+          #     id: <integer>
+          #     label: <string>
+          #     match_percentage: <integer>
+          #     name: <string>
+          #     proto:
+          #       - "smtp"
+          #       - "pop3"
+          #       - "imap"
+          #       - "http-post"
+          #       - "http-get"
+          #       - "ftp"
+          #       - "nntp"
+          #       - "mapi"
+          #       - "ssh"
+          #       - "cifs"
+          #     sensitivity: <list or string>
+          #     sensor: <list or string>
+          #     severity: <value in [info, low, medium, ...]>
+          #     type: <value in [file, message]>
+          # summary_proto:
+          #   - "smtp"
+          #   - "pop3"
+          #   - "imap"
+          #   - "http-post"
+          #   - "http-get"
+          #   - "ftp"
+          #   - "nntp"
+          #   - "mapi"
+          #   - "ssh"
+          #   - "cifs"
 '''
 
 RETURN = '''
@@ -358,23 +370,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/dlp/profile',
         '/pm/config/global/obj/dlp/profile'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/dlp/profile/{profile}',
-        '/pm/config/global/obj/dlp/profile/{profile}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -405,7 +409,11 @@ def main():
                         'expiry': {'v_range': [['7.2.0', '']], 'type': 'str'},
                         'file-size': {'v_range': [['7.2.0', '']], 'type': 'int'},
                         'file-type': {'v_range': [['7.2.0', '']], 'type': 'str'},
-                        'filter-by': {'v_range': [['7.2.0', '']], 'choices': ['fingerprint', 'sensor', 'encrypted', 'none', 'mip'], 'type': 'str'},
+                        'filter-by': {
+                            'v_range': [['7.2.0', '']],
+                            'choices': ['fingerprint', 'sensor', 'encrypted', 'none', 'mip', 'label'],
+                            'type': 'str'
+                        },
                         'id': {'v_range': [['7.2.0', '']], 'type': 'int'},
                         'label': {'v_range': [['7.2.0', '']], 'type': 'str'},
                         'match-percentage': {'v_range': [['7.2.0', '']], 'type': 'int'},
@@ -430,7 +438,6 @@ def main():
                     'elements': 'str'
                 }
             }
-
         }
     }
 
@@ -439,14 +446,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dlp_profile'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
