@@ -105,6 +105,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -120,9 +121,9 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         dvmdb_folder:
-          desc: <string>
-          name: <string>
-          parent: <integer>
+          name: "your value" # Required variable, string
+          # desc: <string>
+          # parent: <integer>
 '''
 
 RETURN = '''
@@ -166,23 +167,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/dvmdb/adom/{adom}/folder',
         '/dvmdb/folder'
     ]
-
-    perobject_jrpc_urls = [
-        '/dvmdb/adom/{adom}/folder/{folder}',
-        '/dvmdb/folder/{folder}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -195,7 +188,6 @@ def main():
                 'name': {'v_range': [['6.4.2', '']], 'required': True, 'type': 'str'},
                 'parent': {'v_range': [['6.4.2', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -209,9 +201,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
