@@ -109,16 +109,18 @@ options:
                     - 'any'
                     - 'incoming'
                     - 'outgoing'
-            file-type:
+            file_type:
+                aliases: ['file-type']
                 type: raw
-                description: (list) Deprecated, please rename it to file_type. Select file type.
+                description: (list) Select file type.
             name:
                 type: str
                 description: File-filter rule name.
                 required: true
-            password-protected:
+            password_protected:
+                aliases: ['password-protected']
                 type: str
-                description: Deprecated, please rename it to password_protected. Match password-protected files.
+                description: Match password-protected files.
                 choices:
                     - 'any'
                     - 'yes'
@@ -141,6 +143,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -157,21 +160,21 @@ EXAMPLES = '''
         profile: <your own value>
         state: present # <value in [present, absent]>
         filefilter_profile_rules:
-          action: <value in [log-only, block]>
-          comment: <string>
-          direction: <value in [any, incoming, outgoing]>
-          file_type: <list or string>
-          name: <string>
-          password_protected: <value in [any, yes]>
-          protocol:
-            - imap
-            - smtp
-            - pop3
-            - http
-            - ftp
-            - mapi
-            - cifs
-            - ssh
+          name: "your value" # Required variable, string
+          # action: <value in [log-only, block]>
+          # comment: <string>
+          # direction: <value in [any, incoming, outgoing]>
+          # file_type: <list or string>
+          # password_protected: <value in [any, yes]>
+          # protocol:
+          #   - "imap"
+          #   - "smtp"
+          #   - "pop3"
+          #   - "http"
+          #   - "ftp"
+          #   - "mapi"
+          #   - "cifs"
+          #   - "ssh"
 '''
 
 RETURN = '''
@@ -215,23 +218,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/file-filter/profile/{profile}/rules',
         '/pm/config/global/obj/file-filter/profile/{profile}/rules'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/file-filter/profile/{profile}/rules/{rules}',
-        '/pm/config/global/obj/file-filter/profile/{profile}/rules/{rules}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -254,7 +249,6 @@ def main():
                     'elements': 'str'
                 }
             }
-
         }
     }
 
@@ -268,9 +262,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
