@@ -84,21 +84,25 @@ options:
         required: false
         type: dict
         suboptions:
-            create-pdp-request:
+            create_pdp_request:
+                aliases: ['create-pdp-request']
                 type: int
-                description: Deprecated, please rename it to create_pdp_request. Rate limit
-            delete-pdp-request:
+                description: Rate limit
+            delete_pdp_request:
+                aliases: ['delete-pdp-request']
                 type: int
-                description: Deprecated, please rename it to delete_pdp_request. Rate limit
-            echo-request:
+                description: Rate limit
+            echo_request:
+                aliases: ['echo-request']
                 type: int
-                description: Deprecated, please rename it to echo_request. Rate limit
+                description: Rate limit
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -114,9 +118,9 @@ EXAMPLES = '''
         adom: <your own value>
         gtp: <your own value>
         firewall_gtp_messageratelimitv1:
-          create_pdp_request: <integer>
-          delete_pdp_request: <integer>
-          echo_request: <integer>
+          # create_pdp_request: <integer>
+          # delete_pdp_request: <integer>
+          # echo_request: <integer>
 '''
 
 RETURN = '''
@@ -160,23 +164,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/gtp/{gtp}/message-rate-limit-v1',
         '/pm/config/global/obj/firewall/gtp/{gtp}/message-rate-limit-v1'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/gtp/{gtp}/message-rate-limit-v1/{message-rate-limit-v1}',
-        '/pm/config/global/obj/firewall/gtp/{gtp}/message-rate-limit-v1/{message-rate-limit-v1}'
-    ]
-
     url_params = ['adom', 'gtp']
     module_primary_key = None
     module_arg_spec = {
@@ -186,7 +182,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'create-pdp-request': {'type': 'int'}, 'delete-pdp-request': {'type': 'int'}, 'echo-request': {'type': 'int'}}
-
         }
     }
 
@@ -200,9 +195,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
