@@ -89,39 +89,46 @@ options:
         required: false
         type: dict
         suboptions:
-            app-category:
+            app_category:
+                aliases: ['app-category']
                 type: raw
-                description: (list or str) Deprecated, please rename it to app_category. App category.
-            app-group:
+                description: (list or str) App category.
+            app_group:
+                aliases: ['app-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to app_group. App group.
+                description: (list or str) App group.
             application:
                 type: raw
                 description: (list) Application.
-            class-id:
+            class_id:
+                aliases: ['class-id']
                 type: raw
-                description: (int or str) Deprecated, please rename it to class_id. Class id.
+                description: (int or str) Class id.
             comment:
                 type: str
                 description: Comment.
-            diffserv-forward:
+            diffserv_forward:
+                aliases: ['diffserv-forward']
                 type: str
-                description: Deprecated, please rename it to diffserv_forward. Diffserv forward.
+                description: Diffserv forward.
                 choices:
                     - 'disable'
                     - 'enable'
-            diffserv-reverse:
+            diffserv_reverse:
+                aliases: ['diffserv-reverse']
                 type: str
-                description: Deprecated, please rename it to diffserv_reverse. Diffserv reverse.
+                description: Diffserv reverse.
                 choices:
                     - 'disable'
                     - 'enable'
-            diffservcode-forward:
+            diffservcode_forward:
+                aliases: ['diffservcode-forward']
                 type: str
-                description: Deprecated, please rename it to diffservcode_forward. Diffservcode forward.
-            diffservcode-rev:
+                description: Diffservcode forward.
+            diffservcode_rev:
+                aliases: ['diffservcode-rev']
                 type: str
-                description: Deprecated, please rename it to diffservcode_rev. Diffservcode rev.
+                description: Diffservcode rev.
             dstaddr:
                 type: raw
                 description: (list or str) Dstaddr.
@@ -138,51 +145,63 @@ options:
                 type: int
                 description: Id.
                 required: true
-            internet-service:
+            internet_service:
+                aliases: ['internet-service']
                 type: str
-                description: Deprecated, please rename it to internet_service. Internet service.
+                description: Internet service.
                 choices:
                     - 'disable'
                     - 'enable'
-            internet-service-custom:
+            internet_service_custom:
+                aliases: ['internet-service-custom']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_custom. Internet service custom.
-            internet-service-custom-group:
+                description: (list or str) Internet service custom.
+            internet_service_custom_group:
+                aliases: ['internet-service-custom-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_custom_group. Internet service custom group.
-            internet-service-group:
+                description: (list or str) Internet service custom group.
+            internet_service_group:
+                aliases: ['internet-service-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_group. Internet service group.
-            internet-service-id:
+                description: (list or str) Internet service group.
+            internet_service_id:
+                aliases: ['internet-service-id']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_id. Internet service id.
-            internet-service-src:
+                description: (list or str) Internet service id.
+            internet_service_src:
+                aliases: ['internet-service-src']
                 type: str
-                description: Deprecated, please rename it to internet_service_src. Internet service src.
+                description: Internet service src.
                 choices:
                     - 'disable'
                     - 'enable'
-            internet-service-src-custom:
+            internet_service_src_custom:
+                aliases: ['internet-service-src-custom']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_custom. Internet service src custom.
-            internet-service-src-custom-group:
+                description: (list or str) Internet service src custom.
+            internet_service_src_custom_group:
+                aliases: ['internet-service-src-custom-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_custom_group. Internet service src custom group.
-            internet-service-src-group:
+                description: (list or str) Internet service src custom group.
+            internet_service_src_group:
+                aliases: ['internet-service-src-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_group. Internet service src group.
-            internet-service-src-id:
+                description: (list or str) Internet service src group.
+            internet_service_src_id:
+                aliases: ['internet-service-src-id']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_id. Internet service src id.
-            ip-version:
+                description: (list or str) Internet service src id.
+            ip_version:
+                aliases: ['ip-version']
                 type: str
-                description: Deprecated, please rename it to ip_version. Ip version.
+                description: Ip version.
                 choices:
                     - '4'
                     - '6'
-            per-ip-shaper:
+            per_ip_shaper:
+                aliases: ['per-ip-shaper']
                 type: str
-                description: Deprecated, please rename it to per_ip_shaper. Per ip shaper.
+                description: Per ip shaper.
             schedule:
                 type: str
                 description: Schedule.
@@ -207,67 +226,87 @@ options:
             tos:
                 type: str
                 description: Tos.
-            tos-mask:
+            tos_mask:
+                aliases: ['tos-mask']
                 type: str
-                description: Deprecated, please rename it to tos_mask. Tos mask.
-            tos-negate:
+                description: Tos mask.
+            tos_negate:
+                aliases: ['tos-negate']
                 type: str
-                description: Deprecated, please rename it to tos_negate. Tos negate.
+                description: Tos negate.
                 choices:
                     - 'disable'
                     - 'enable'
-            traffic-shaper:
+            traffic_shaper:
+                aliases: ['traffic-shaper']
                 type: str
-                description: Deprecated, please rename it to traffic_shaper. Traffic shaper.
-            traffic-shaper-reverse:
+                description: Traffic shaper.
+            traffic_shaper_reverse:
+                aliases: ['traffic-shaper-reverse']
                 type: str
-                description: Deprecated, please rename it to traffic_shaper_reverse. Traffic shaper reverse.
-            url-category:
+                description: Traffic shaper reverse.
+            url_category:
+                aliases: ['url-category']
                 type: raw
-                description: (list or str) Deprecated, please rename it to url_category. Url category.
+                description: (list or str) Url category.
             users:
                 type: raw
                 description: (list or str) Users.
             uuid:
                 type: str
                 description: Uuid.
-            internet-service-name:
+            internet_service_name:
+                aliases: ['internet-service-name']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_name. Internet service name.
-            internet-service-src-name:
+                description: (list or str) Internet service name.
+            internet_service_src_name:
+                aliases: ['internet-service-src-name']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_name. Internet service src name.
-            class-id-reverse:
+                description: (list or str) Internet service src name.
+            class_id_reverse:
+                aliases: ['class-id-reverse']
                 type: int
-                description: Deprecated, please rename it to class_id_reverse. Class id reverse.
-            service-type:
+                description: Class id reverse.
+            service_type:
+                aliases: ['service-type']
                 type: str
-                description: Deprecated, please rename it to service_type. Service type.
+                description: Service type.
                 choices:
                     - 'service'
                     - 'internet-service'
-            uuid-idx:
+            uuid_idx:
+                aliases: ['uuid-idx']
                 type: int
-                description: Deprecated, please rename it to uuid_idx. Uuid idx.
+                description: Uuid idx.
             cos:
                 type: str
                 description: VLAN CoS bit pattern.
-            cos-mask:
+            cos_mask:
+                aliases: ['cos-mask']
                 type: str
-                description: Deprecated, please rename it to cos_mask. VLAN CoS evaluated bits.
-            traffic-type:
+                description: VLAN CoS evaluated bits.
+            traffic_type:
+                aliases: ['traffic-type']
                 type: str
-                description: Deprecated, please rename it to traffic_type. Traffic type.
+                description: Traffic type.
                 choices:
                     - 'forwarding'
                     - 'local-in'
                     - 'local-out'
+            http_response_match:
+                aliases: ['http-response-match']
+                type: str
+                description: Http response match.
+                choices:
+                    - 'disable'
+                    - 'enable'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -283,54 +322,55 @@ EXAMPLES = '''
         pkg: <your own value>
         state: present # <value in [present, absent]>
         pkg_footer_shapingpolicy:
-          app_category: <list or string>
-          app_group: <list or string>
-          application: <list or integer>
-          class_id: <integer or string>
-          comment: <string>
-          diffserv_forward: <value in [disable, enable]>
-          diffserv_reverse: <value in [disable, enable]>
-          diffservcode_forward: <string>
-          diffservcode_rev: <string>
-          dstaddr: <list or string>
-          dstaddr6: <list or string>
-          dstintf: <list or string>
-          groups: <list or string>
-          id: <integer>
-          internet_service: <value in [disable, enable]>
-          internet_service_custom: <list or string>
-          internet_service_custom_group: <list or string>
-          internet_service_group: <list or string>
-          internet_service_id: <list or string>
-          internet_service_src: <value in [disable, enable]>
-          internet_service_src_custom: <list or string>
-          internet_service_src_custom_group: <list or string>
-          internet_service_src_group: <list or string>
-          internet_service_src_id: <list or string>
-          ip_version: <value in [4, 6]>
-          per_ip_shaper: <string>
-          schedule: <string>
-          service: <list or string>
-          srcaddr: <list or string>
-          srcaddr6: <list or string>
-          srcintf: <list or string>
-          status: <value in [disable, enable]>
-          tos: <string>
-          tos_mask: <string>
-          tos_negate: <value in [disable, enable]>
-          traffic_shaper: <string>
-          traffic_shaper_reverse: <string>
-          url_category: <list or string>
-          users: <list or string>
-          uuid: <string>
-          internet_service_name: <list or string>
-          internet_service_src_name: <list or string>
-          class_id_reverse: <integer>
-          service_type: <value in [service, internet-service]>
-          uuid_idx: <integer>
-          cos: <string>
-          cos_mask: <string>
-          traffic_type: <value in [forwarding, local-in, local-out]>
+          id: 0 # Required variable, integer
+          # app_category: <list or string>
+          # app_group: <list or string>
+          # application: <list or integer>
+          # class_id: <integer or string>
+          # comment: <string>
+          # diffserv_forward: <value in [disable, enable]>
+          # diffserv_reverse: <value in [disable, enable]>
+          # diffservcode_forward: <string>
+          # diffservcode_rev: <string>
+          # dstaddr: <list or string>
+          # dstaddr6: <list or string>
+          # dstintf: <list or string>
+          # groups: <list or string>
+          # internet_service: <value in [disable, enable]>
+          # internet_service_custom: <list or string>
+          # internet_service_custom_group: <list or string>
+          # internet_service_group: <list or string>
+          # internet_service_id: <list or string>
+          # internet_service_src: <value in [disable, enable]>
+          # internet_service_src_custom: <list or string>
+          # internet_service_src_custom_group: <list or string>
+          # internet_service_src_group: <list or string>
+          # internet_service_src_id: <list or string>
+          # ip_version: <value in [4, 6]>
+          # per_ip_shaper: <string>
+          # schedule: <string>
+          # service: <list or string>
+          # srcaddr: <list or string>
+          # srcaddr6: <list or string>
+          # srcintf: <list or string>
+          # status: <value in [disable, enable]>
+          # tos: <string>
+          # tos_mask: <string>
+          # tos_negate: <value in [disable, enable]>
+          # traffic_shaper: <string>
+          # traffic_shaper_reverse: <string>
+          # url_category: <list or string>
+          # users: <list or string>
+          # uuid: <string>
+          # internet_service_name: <list or string>
+          # internet_service_src_name: <list or string>
+          # class_id_reverse: <integer>
+          # service_type: <value in [service, internet-service]>
+          # uuid_idx: <integer>
+          # cos: <string>
+          # cos_mask: <string>
+          # traffic_type: <value in [forwarding, local-in, local-out]>
+          # http_response_match: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -374,21 +414,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/global/pkg/{pkg}/global/footer/shaping-policy'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/global/pkg/{pkg}/global/footer/shaping-policy/{shaping-policy}'
-    ]
-
     url_params = ['pkg']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -444,9 +477,9 @@ def main():
                 'uuid-idx': {'v_range': [['7.2.1', '']], 'type': 'int'},
                 'cos': {'v_range': [['7.4.0', '']], 'type': 'str'},
                 'cos-mask': {'v_range': [['7.4.0', '']], 'type': 'str'},
-                'traffic-type': {'v_range': [['7.4.0', '']], 'choices': ['forwarding', 'local-in', 'local-out'], 'type': 'str'}
+                'traffic-type': {'v_range': [['7.4.0', '']], 'choices': ['forwarding', 'local-in', 'local-out'], 'type': 'str'},
+                'http-response-match': {'v_range': [['7.4.7', '7.4.7']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -463,14 +496,15 @@ def main():
 
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pkg_footer_shapingpolicy'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
