@@ -123,21 +123,25 @@ options:
             name:
                 type: str
                 description: SNMP community name.
-            query-v1-port:
+            query_v1_port:
+                aliases: ['query-v1-port']
                 type: int
-                description: Deprecated, please rename it to query_v1_port. SNMP v1 query port
-            query-v1-status:
+                description: SNMP v1 query port
+            query_v1_status:
+                aliases: ['query-v1-status']
                 type: str
-                description: Deprecated, please rename it to query_v1_status. Enable/disable SNMP v1 queries.
+                description: Enable/disable SNMP v1 queries.
                 choices:
                     - 'disable'
                     - 'enable'
-            query-v2c-port:
+            query_v2c_port:
+                aliases: ['query-v2c-port']
                 type: int
-                description: Deprecated, please rename it to query_v2c_port. SNMP v2c query port
-            query-v2c-status:
+                description: SNMP v2c query port
+            query_v2c_status:
+                aliases: ['query-v2c-status']
                 type: str
-                description: Deprecated, please rename it to query_v2c_status. Enable/disable SNMP v2c queries.
+                description: Enable/disable SNMP v2c queries.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -147,27 +151,33 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            trap-v1-lport:
+            trap_v1_lport:
+                aliases: ['trap-v1-lport']
                 type: int
-                description: Deprecated, please rename it to trap_v1_lport. SNMP v2c trap local port
-            trap-v1-rport:
+                description: SNMP v2c trap local port
+            trap_v1_rport:
+                aliases: ['trap-v1-rport']
                 type: int
-                description: Deprecated, please rename it to trap_v1_rport. SNMP v2c trap remote port
-            trap-v1-status:
+                description: SNMP v2c trap remote port
+            trap_v1_status:
+                aliases: ['trap-v1-status']
                 type: str
-                description: Deprecated, please rename it to trap_v1_status. Enable/disable SNMP v1 traps.
+                description: Enable/disable SNMP v1 traps.
                 choices:
                     - 'disable'
                     - 'enable'
-            trap-v2c-lport:
+            trap_v2c_lport:
+                aliases: ['trap-v2c-lport']
                 type: int
-                description: Deprecated, please rename it to trap_v2c_lport. SNMP v2c trap local port
-            trap-v2c-rport:
+                description: SNMP v2c trap local port
+            trap_v2c_rport:
+                aliases: ['trap-v2c-rport']
                 type: int
-                description: Deprecated, please rename it to trap_v2c_rport. SNMP v2c trap remote port
-            trap-v2c-status:
+                description: SNMP v2c trap remote port
+            trap_v2c_status:
+                aliases: ['trap-v2c-status']
                 type: str
-                description: Deprecated, please rename it to trap_v2c_status. Enable/disable SNMP v2c traps.
+                description: Enable/disable SNMP v2c traps.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -177,6 +187,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -193,29 +204,28 @@ EXAMPLES = '''
         managed_switch: <your own value>
         state: present # <value in [present, absent]>
         switchcontroller_managedswitch_snmpcommunity:
-          events:
-            - cpu-high
-            - mem-low
-            - log-full
-            - intf-ip
-            - ent-conf-change
-          hosts:
-            -
-              id: <integer>
-              ip: <string>
-          id: <integer>
-          name: <string>
-          query_v1_port: <integer>
-          query_v1_status: <value in [disable, enable]>
-          query_v2c_port: <integer>
-          query_v2c_status: <value in [disable, enable]>
-          status: <value in [disable, enable]>
-          trap_v1_lport: <integer>
-          trap_v1_rport: <integer>
-          trap_v1_status: <value in [disable, enable]>
-          trap_v2c_lport: <integer>
-          trap_v2c_rport: <integer>
-          trap_v2c_status: <value in [disable, enable]>
+          id: 0 # Required variable, integer
+          # events:
+          #   - "cpu-high"
+          #   - "mem-low"
+          #   - "log-full"
+          #   - "intf-ip"
+          #   - "ent-conf-change"
+          # hosts:
+          #   - id: <integer>
+          #     ip: <string>
+          # name: <string>
+          # query_v1_port: <integer>
+          # query_v1_status: <value in [disable, enable]>
+          # query_v2c_port: <integer>
+          # query_v2c_status: <value in [disable, enable]>
+          # status: <value in [disable, enable]>
+          # trap_v1_lport: <integer>
+          # trap_v1_rport: <integer>
+          # trap_v1_status: <value in [disable, enable]>
+          # trap_v2c_lport: <integer>
+          # trap_v2c_rport: <integer>
+          # trap_v2c_status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -259,23 +269,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/switch-controller/managed-switch/{managed-switch}/snmp-community',
         '/pm/config/global/obj/switch-controller/managed-switch/{managed-switch}/snmp-community'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/switch-controller/managed-switch/{managed-switch}/snmp-community/{snmp-community}',
-        '/pm/config/global/obj/switch-controller/managed-switch/{managed-switch}/snmp-community/{snmp-community}'
-    ]
-
     url_params = ['adom', 'managed-switch']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -312,7 +314,6 @@ def main():
                 'trap-v2c-rport': {'v_range': [['6.2.1', '6.2.3']], 'type': 'int'},
                 'trap-v2c-status': {'v_range': [['6.2.1', '6.2.3']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -321,14 +322,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'switchcontroller_managedswitch_snmpcommunity'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
