@@ -84,6 +84,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -97,9 +98,9 @@ EXAMPLES = '''
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         sys_api_sdnconnector:
-          adom: <string>
-          command: <string>
-          connector_name: <string>
+          # adom: <string>
+          # command: <string>
+          # connector_name: <string>
 '''
 
 RETURN = '''
@@ -143,21 +144,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/sys/api/sdnconnector'
     ]
-
-    perobject_jrpc_urls = [
-        '/sys/api/sdnconnector/{sdnconnector}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -165,7 +159,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'adom': {'type': 'str'}, 'command': {'type': 'str'}, 'connector_name': {'type': 'str'}}
-
         }
     }
 
@@ -174,14 +167,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'sys_api_sdnconnector'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('exec', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_exec(argument_specs=module_arg_spec)
+    fmgr.process_exec()
 
     module.exit_json(meta=module.params)
 
