@@ -89,9 +89,10 @@ options:
         required: false
         type: dict
         suboptions:
-            app-filter-name:
+            app_filter_name:
+                aliases: ['app-filter-name']
                 type: str
-                description: Deprecated, please rename it to app_filter_name. App filter name.
+                description: App filter name.
                 required: true
 '''
 
@@ -99,6 +100,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -114,7 +116,7 @@ EXAMPLES = '''
         user: <your own value>
         state: present # <value in [present, absent]>
         system_admin_user_appfilter:
-          app_filter_name: <string>
+          app_filter_name: "your value" # Required variable, string
 '''
 
 RETURN = '''
@@ -158,21 +160,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/admin/user/{user}/app-filter'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/admin/user/{user}/app-filter/{app-filter}'
-    ]
-
     url_params = ['user']
     module_primary_key = 'app-filter-name'
     module_arg_spec = {
@@ -181,7 +176,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'app-filter-name': {'required': True, 'type': 'str'}}
-
         }
     }
 
@@ -190,14 +184,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_admin_user_appfilter'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
