@@ -89,15 +89,17 @@ options:
         required: false
         type: dict
         suboptions:
-            dev-vdom:
+            dev_vdom:
+                aliases: ['dev-vdom']
                 type: str
-                description: Deprecated, please rename it to dev_vdom. Device or device VDOM.
+                description: Device or device VDOM.
                 required: true
 '''
 
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -171,21 +173,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/admin/user/{user}/restrict-dev-vdom'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/admin/user/{user}/restrict-dev-vdom/{restrict-dev-vdom}'
-    ]
-
     url_params = ['user']
     module_primary_key = 'dev-vdom'
     module_arg_spec = {
@@ -194,7 +189,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '6.2.3'], ['6.4.0', '6.4.0']],
             'options': {'dev-vdom': {'v_range': [['6.0.0', '6.2.3'], ['6.4.0', '6.4.0']], 'required': True, 'type': 'str'}}
-
         }
     }
 
@@ -203,14 +197,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_admin_user_restrictdevvdom'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
