@@ -92,43 +92,50 @@ options:
             description:
                 type: str
                 description: Description.
-            ip-range:
+            ip_range:
+                aliases: ['ip-range']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ip_range. Ip range.
+                description: Ip range.
                 suboptions:
-                    end-ip:
+                    end_ip:
+                        aliases: ['end-ip']
                         type: str
-                        description: Deprecated, please rename it to end_ip. Final IP address, inclusive, of the address range
+                        description: Final IP address, inclusive, of the address range
                     id:
                         type: int
                         description: ID number for individual entry in the IP-Range table.
-                    start-ip:
+                    start_ip:
+                        aliases: ['start-ip']
                         type: str
-                        description: Deprecated, please rename it to start_ip. Starting IP address, inclusive, of the address range
+                        description: Starting IP address, inclusive, of the address range
             name:
                 type: str
                 description: Location name.
                 required: true
-            ip6-range:
+            ip6_range:
+                aliases: ['ip6-range']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ip6_range. Ip6 range.
+                description: Ip6 range.
                 suboptions:
-                    end-ip:
+                    end_ip:
+                        aliases: ['end-ip']
                         type: str
-                        description: Deprecated, please rename it to end_ip. Ending IP address, inclusive, of the address range
+                        description: Ending IP address, inclusive, of the address range
                     id:
                         type: int
                         description: ID of individual entry in the IPv6 range table.
-                    start-ip:
+                    start_ip:
+                        aliases: ['start-ip']
                         type: str
-                        description: Deprecated, please rename it to start_ip. Starting IP address, inclusive, of the address range
+                        description: Starting IP address, inclusive, of the address range
 '''
 
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -195,23 +202,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/geoip-override',
         '/pm/config/global/obj/system/geoip-override'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/geoip-override/{geoip-override}',
-        '/pm/config/global/obj/system/geoip-override/{geoip-override}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -238,7 +237,6 @@ def main():
                     'elements': 'dict'
                 }
             }
-
         }
     }
 
@@ -247,14 +245,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_geoipoverride'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
