@@ -95,12 +95,16 @@ options:
                 type: int
                 description: ID of device logging disable entry.
                 required: true
+            expire:
+                type: str
+                description: Expire.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -115,9 +119,10 @@ EXAMPLES = '''
         # rc_failed: [-2, -3, ...]
         state: present # <value in [present, absent]>
         system_log_devicedisable:
-          TTL: <string>
-          device: <string>
-          id: <integer>
+          id: 0 # Required variable, integer
+          # TTL: <string>
+          # device: <string>
+          # expire: <string>
 '''
 
 RETURN = '''
@@ -161,33 +166,26 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/log/device-disable'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/log/device-disable/{device-disable}'
-    ]
-
     url_params = []
     module_primary_key = 'id'
     module_arg_spec = {
         'system_log_devicedisable': {
             'type': 'dict',
-            'v_range': [['6.4.4', '']],
+            'v_range': [['6.4.4', '7.4.6'], ['7.6.0', '7.6.2']],
             'options': {
-                'TTL': {'v_range': [['6.4.4', '']], 'type': 'str'},
-                'device': {'v_range': [['6.4.4', '']], 'type': 'str'},
-                'id': {'v_range': [['6.4.4', '']], 'required': True, 'type': 'int'}
+                'TTL': {'v_range': [['6.4.4', '7.4.6'], ['7.6.0', '7.6.1']], 'type': 'str'},
+                'device': {'v_range': [['6.4.4', '7.4.6'], ['7.6.0', '7.6.2']], 'type': 'str'},
+                'id': {'v_range': [['6.4.4', '7.4.6'], ['7.6.0', '7.6.2']], 'required': True, 'type': 'int'},
+                'expire': {'v_range': [['7.6.2', '7.6.2']], 'type': 'str'}
             }
-
         }
     }
 
@@ -196,14 +194,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_log_devicedisable'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
