@@ -107,72 +107,88 @@ options:
             ethertype:
                 type: str
                 description: Tcam data ethertype.
-            ext-tag:
+            ext_tag:
+                aliases: ['ext-tag']
                 type: str
-                description: Deprecated, please rename it to ext_tag. Tcam data extension tag.
+                description: Tcam data extension tag.
                 choices:
                     - 'disable'
                     - 'enable'
-            frag-off:
+            frag_off:
+                aliases: ['frag-off']
                 type: int
-                description: Deprecated, please rename it to frag_off. Tcam data ip flag fragment offset.
-            gen-buf-cnt:
+                description: Tcam data ip flag fragment offset.
+            gen_buf_cnt:
+                aliases: ['gen-buf-cnt']
                 type: int
-                description: Deprecated, please rename it to gen_buf_cnt. Tcam data gen info buffer count.
-            gen-iv:
+                description: Tcam data gen info buffer count.
+            gen_iv:
+                aliases: ['gen-iv']
                 type: str
-                description: Deprecated, please rename it to gen_iv. Tcam data gen info iv.
+                description: Tcam data gen info iv.
                 choices:
                     - 'invalid'
                     - 'valid'
-            gen-l3-flags:
+            gen_l3_flags:
+                aliases: ['gen-l3-flags']
                 type: int
-                description: Deprecated, please rename it to gen_l3_flags. Tcam data gen info L3 flags.
-            gen-l4-flags:
+                description: Tcam data gen info L3 flags.
+            gen_l4_flags:
+                aliases: ['gen-l4-flags']
                 type: int
-                description: Deprecated, please rename it to gen_l4_flags. Tcam data gen info L4 flags.
-            gen-pkt-ctrl:
+                description: Tcam data gen info L4 flags.
+            gen_pkt_ctrl:
+                aliases: ['gen-pkt-ctrl']
                 type: int
-                description: Deprecated, please rename it to gen_pkt_ctrl. Tcam data gen info packet control.
-            gen-pri:
+                description: Tcam data gen info packet control.
+            gen_pri:
+                aliases: ['gen-pri']
                 type: int
-                description: Deprecated, please rename it to gen_pri. Tcam data gen info priority.
-            gen-pri-v:
+                description: Tcam data gen info priority.
+            gen_pri_v:
+                aliases: ['gen-pri-v']
                 type: str
-                description: Deprecated, please rename it to gen_pri_v. Tcam data gen info priority valid.
+                description: Tcam data gen info priority valid.
                 choices:
                     - 'invalid'
                     - 'valid'
-            gen-tv:
+            gen_tv:
+                aliases: ['gen-tv']
                 type: str
-                description: Deprecated, please rename it to gen_tv. Tcam data gen info tv.
+                description: Tcam data gen info tv.
                 choices:
                     - 'invalid'
                     - 'valid'
             ihl:
                 type: int
                 description: Tcam data ipv4 IHL.
-            ip4-id:
+            ip4_id:
+                aliases: ['ip4-id']
                 type: int
-                description: Deprecated, please rename it to ip4_id. Tcam data ipv4 id.
-            ip6-fl:
+                description: Tcam data ipv4 id.
+            ip6_fl:
+                aliases: ['ip6-fl']
                 type: int
-                description: Deprecated, please rename it to ip6_fl. Tcam data ipv6 flow label.
+                description: Tcam data ipv6 flow label.
             ipver:
                 type: int
                 description: Tcam data ip header version.
-            l4-wd10:
+            l4_wd10:
+                aliases: ['l4-wd10']
                 type: int
-                description: Deprecated, please rename it to l4_wd10. Tcam data L4 word10.
-            l4-wd11:
+                description: Tcam data L4 word10.
+            l4_wd11:
+                aliases: ['l4-wd11']
                 type: int
-                description: Deprecated, please rename it to l4_wd11. Tcam data L4 word11.
-            l4-wd8:
+                description: Tcam data L4 word11.
+            l4_wd8:
+                aliases: ['l4-wd8']
                 type: int
-                description: Deprecated, please rename it to l4_wd8. Tcam data L4 word8.
-            l4-wd9:
+                description: Tcam data L4 word8.
+            l4_wd9:
+                aliases: ['l4-wd9']
                 type: int
-                description: Deprecated, please rename it to l4_wd9. Tcam data L4 word9.
+                description: Tcam data L4 word9.
             mf:
                 type: str
                 description: Tcam data ip flag mf.
@@ -185,27 +201,31 @@ options:
             slink:
                 type: int
                 description: Tcam data sublink.
-            smac-change:
+            smac_change:
+                aliases: ['smac-change']
                 type: str
-                description: Deprecated, please rename it to smac_change. Tcam data source MAC change.
+                description: Tcam data source MAC change.
                 choices:
                     - 'disable'
                     - 'enable'
             sp:
                 type: int
                 description: Tcam data source port.
-            src-cfi:
+            src_cfi:
+                aliases: ['src-cfi']
                 type: str
-                description: Deprecated, please rename it to src_cfi. Tcam data source cfi.
+                description: Tcam data source cfi.
                 choices:
                     - 'disable'
                     - 'enable'
-            src-prio:
+            src_prio:
+                aliases: ['src-prio']
                 type: int
-                description: Deprecated, please rename it to src_prio. Tcam data source priority.
-            src-updt:
+                description: Tcam data source priority.
+            src_updt:
+                aliases: ['src-updt']
                 type: str
-                description: Deprecated, please rename it to src_updt. Tcam data source update.
+                description: Tcam data source update.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -224,72 +244,84 @@ options:
             svid:
                 type: int
                 description: Tcam data source vid.
-            tcp-ack:
+            tcp_ack:
+                aliases: ['tcp-ack']
                 type: str
-                description: Deprecated, please rename it to tcp_ack. Tcam data tcp flag ack.
+                description: Tcam data tcp flag ack.
                 choices:
                     - 'disable'
                     - 'enable'
-            tcp-cwr:
+            tcp_cwr:
+                aliases: ['tcp-cwr']
                 type: str
-                description: Deprecated, please rename it to tcp_cwr. Tcam data tcp flag cwr.
+                description: Tcam data tcp flag cwr.
                 choices:
                     - 'disable'
                     - 'enable'
-            tcp-ece:
+            tcp_ece:
+                aliases: ['tcp-ece']
                 type: str
-                description: Deprecated, please rename it to tcp_ece. Tcam data tcp flag ece.
+                description: Tcam data tcp flag ece.
                 choices:
                     - 'disable'
                     - 'enable'
-            tcp-fin:
+            tcp_fin:
+                aliases: ['tcp-fin']
                 type: str
-                description: Deprecated, please rename it to tcp_fin. Tcam data tcp flag fin.
+                description: Tcam data tcp flag fin.
                 choices:
                     - 'disable'
                     - 'enable'
-            tcp-push:
+            tcp_push:
+                aliases: ['tcp-push']
                 type: str
-                description: Deprecated, please rename it to tcp_push. Tcam data tcp flag push.
+                description: Tcam data tcp flag push.
                 choices:
                     - 'disable'
                     - 'enable'
-            tcp-rst:
+            tcp_rst:
+                aliases: ['tcp-rst']
                 type: str
-                description: Deprecated, please rename it to tcp_rst. Tcam data tcp flag rst.
+                description: Tcam data tcp flag rst.
                 choices:
                     - 'disable'
                     - 'enable'
-            tcp-syn:
+            tcp_syn:
+                aliases: ['tcp-syn']
                 type: str
-                description: Deprecated, please rename it to tcp_syn. Tcam data tcp flag syn.
+                description: Tcam data tcp flag syn.
                 choices:
                     - 'disable'
                     - 'enable'
-            tcp-urg:
+            tcp_urg:
+                aliases: ['tcp-urg']
                 type: str
-                description: Deprecated, please rename it to tcp_urg. Tcam data tcp flag urg.
+                description: Tcam data tcp flag urg.
                 choices:
                     - 'disable'
                     - 'enable'
-            tgt-cfi:
+            tgt_cfi:
+                aliases: ['tgt-cfi']
                 type: str
-                description: Deprecated, please rename it to tgt_cfi. Tcam data target cfi.
+                description: Tcam data target cfi.
                 choices:
                     - 'disable'
                     - 'enable'
-            tgt-prio:
+            tgt_prio:
+                aliases: ['tgt-prio']
                 type: int
-                description: Deprecated, please rename it to tgt_prio. Tcam data target priority.
-            tgt-updt:
+                description: Tcam data target priority.
+            tgt_updt:
+                aliases: ['tgt-updt']
                 type: str
-                description: Deprecated, please rename it to tgt_updt. Tcam data target port update.
+                description: Tcam data target port update.
                 choices:
                     - 'disable'
                     - 'enable'
-            tgt-v:
+            tgt_v:
+                aliases: ['tgt-v']
                 type: str
-                description: Deprecated, please rename it to tgt_v. Tcam data target valid.
+                description: Tcam data target valid.
                 choices:
                     - 'invalid'
                     - 'valid'
@@ -314,6 +346,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -329,60 +362,60 @@ EXAMPLES = '''
         adom: <your own value>
         npu_tcam: <your own value>
         system_npu_nputcam_data:
-          df: <value in [disable, enable]>
-          dstip: <string>
-          dstipv6: <string>
-          dstmac: <string>
-          dstport: <integer>
-          ethertype: <string>
-          ext_tag: <value in [disable, enable]>
-          frag_off: <integer>
-          gen_buf_cnt: <integer>
-          gen_iv: <value in [invalid, valid]>
-          gen_l3_flags: <integer>
-          gen_l4_flags: <integer>
-          gen_pkt_ctrl: <integer>
-          gen_pri: <integer>
-          gen_pri_v: <value in [invalid, valid]>
-          gen_tv: <value in [invalid, valid]>
-          ihl: <integer>
-          ip4_id: <integer>
-          ip6_fl: <integer>
-          ipver: <integer>
-          l4_wd10: <integer>
-          l4_wd11: <integer>
-          l4_wd8: <integer>
-          l4_wd9: <integer>
-          mf: <value in [disable, enable]>
-          protocol: <integer>
-          slink: <integer>
-          smac_change: <value in [disable, enable]>
-          sp: <integer>
-          src_cfi: <value in [disable, enable]>
-          src_prio: <integer>
-          src_updt: <value in [disable, enable]>
-          srcip: <string>
-          srcipv6: <string>
-          srcmac: <string>
-          srcport: <integer>
-          svid: <integer>
-          tcp_ack: <value in [disable, enable]>
-          tcp_cwr: <value in [disable, enable]>
-          tcp_ece: <value in [disable, enable]>
-          tcp_fin: <value in [disable, enable]>
-          tcp_push: <value in [disable, enable]>
-          tcp_rst: <value in [disable, enable]>
-          tcp_syn: <value in [disable, enable]>
-          tcp_urg: <value in [disable, enable]>
-          tgt_cfi: <value in [disable, enable]>
-          tgt_prio: <integer>
-          tgt_updt: <value in [disable, enable]>
-          tgt_v: <value in [invalid, valid]>
-          tos: <integer>
-          tp: <integer>
-          ttl: <integer>
-          tvid: <integer>
-          vdid: <integer>
+          # df: <value in [disable, enable]>
+          # dstip: <string>
+          # dstipv6: <string>
+          # dstmac: <string>
+          # dstport: <integer>
+          # ethertype: <string>
+          # ext_tag: <value in [disable, enable]>
+          # frag_off: <integer>
+          # gen_buf_cnt: <integer>
+          # gen_iv: <value in [invalid, valid]>
+          # gen_l3_flags: <integer>
+          # gen_l4_flags: <integer>
+          # gen_pkt_ctrl: <integer>
+          # gen_pri: <integer>
+          # gen_pri_v: <value in [invalid, valid]>
+          # gen_tv: <value in [invalid, valid]>
+          # ihl: <integer>
+          # ip4_id: <integer>
+          # ip6_fl: <integer>
+          # ipver: <integer>
+          # l4_wd10: <integer>
+          # l4_wd11: <integer>
+          # l4_wd8: <integer>
+          # l4_wd9: <integer>
+          # mf: <value in [disable, enable]>
+          # protocol: <integer>
+          # slink: <integer>
+          # smac_change: <value in [disable, enable]>
+          # sp: <integer>
+          # src_cfi: <value in [disable, enable]>
+          # src_prio: <integer>
+          # src_updt: <value in [disable, enable]>
+          # srcip: <string>
+          # srcipv6: <string>
+          # srcmac: <string>
+          # srcport: <integer>
+          # svid: <integer>
+          # tcp_ack: <value in [disable, enable]>
+          # tcp_cwr: <value in [disable, enable]>
+          # tcp_ece: <value in [disable, enable]>
+          # tcp_fin: <value in [disable, enable]>
+          # tcp_push: <value in [disable, enable]>
+          # tcp_rst: <value in [disable, enable]>
+          # tcp_syn: <value in [disable, enable]>
+          # tcp_urg: <value in [disable, enable]>
+          # tgt_cfi: <value in [disable, enable]>
+          # tgt_prio: <integer>
+          # tgt_updt: <value in [disable, enable]>
+          # tgt_v: <value in [invalid, valid]>
+          # tos: <integer>
+          # tp: <integer>
+          # ttl: <integer>
+          # tvid: <integer>
+          # vdid: <integer>
 '''
 
 RETURN = '''
@@ -426,23 +459,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/npu/npu-tcam/{npu-tcam}/data',
         '/pm/config/global/obj/system/npu/npu-tcam/{npu-tcam}/data'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/npu/npu-tcam/{npu-tcam}/data/{data}',
-        '/pm/config/global/obj/system/npu/npu-tcam/{npu-tcam}/data/{data}'
-    ]
-
     url_params = ['adom', 'npu-tcam']
     module_primary_key = None
     module_arg_spec = {
@@ -508,7 +533,6 @@ def main():
                 'tvid': {'v_range': [['7.4.2', '']], 'type': 'int'},
                 'vdid': {'v_range': [['7.4.2', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -517,14 +541,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_npu_nputcam_data'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
