@@ -76,35 +76,36 @@ options:
         required: false
         type: dict
         suboptions:
-            background-rebuild:
+            background_rebuild:
+                aliases: ['background-rebuild']
                 type: str
                 description:
-                    - Deprecated, please rename it to background_rebuild.
                     - Disable/Enable rebuild SQL database in the background.
                     - disable - Rebuild SQL database not in the background.
                     - enable - Rebuild SQL database in the background.
                 choices:
                     - 'disable'
                     - 'enable'
-            custom-index:
+            custom_index:
+                aliases: ['custom-index']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to custom_index. Custom index.
+                description: Custom index.
                 suboptions:
-                    case-sensitive:
+                    case_sensitive:
+                        aliases: ['case-sensitive']
                         type: str
                         description:
-                            - Deprecated, please rename it to case_sensitive.
                             - Disable/Enable case sensitive index.
                             - disable - Build a case insensitive index.
                             - enable - Build a case sensitive index.
                         choices:
                             - 'disable'
                             - 'enable'
-                    device-type:
+                    device_type:
+                        aliases: ['device-type']
                         type: str
                         description:
-                            - Deprecated, please rename it to device_type.
                             - Device type.
                             - FortiGate - Device type to FortiGate.
                             - FortiManager - Set device type to FortiManager
@@ -130,13 +131,14 @@ options:
                     id:
                         type: int
                         description: Add or Edit log index fields.
-                    index-field:
+                    index_field:
+                        aliases: ['index-field']
                         type: str
-                        description: Deprecated, please rename it to index_field. Log field name to be indexed.
-                    log-type:
+                        description: Log field name to be indexed.
+                    log_type:
+                        aliases: ['log-type']
                         type: str
                         description:
-                            - Deprecated, please rename it to log_type.
                             - Log type.
                             - none - none
                             - app-ctrl
@@ -189,35 +191,38 @@ options:
                             - 'siem'
                             - 'ztna'
                             - 'security'
-            database-name:
+            database_name:
+                aliases: ['database-name']
                 type: str
-                description: Deprecated, please rename it to database_name. Database name.
-            database-type:
+                description: Database name.
+            database_type:
+                aliases: ['database-type']
                 type: str
                 description:
-                    - Deprecated, please rename it to database_type.
                     - Database type.
                     - mysql - MySQL database.
                     - postgres - PostgreSQL local database.
                 choices:
                     - 'mysql'
                     - 'postgres'
-            device-count-high:
+            device_count_high:
+                aliases: ['device-count-high']
                 type: str
                 description:
-                    - Deprecated, please rename it to device_count_high.
                     - Must set to enable if the count of registered devices is greater than 8000.
                     - disable - Set to disable if device count is less than 8000.
                     - enable - Set to enable if device count is equal to or greater than 8000.
                 choices:
                     - 'disable'
                     - 'enable'
-            event-table-partition-time:
+            event_table_partition_time:
+                aliases: ['event-table-partition-time']
                 type: int
-                description: Deprecated, please rename it to event_table_partition_time. Maximum SQL database table partitioning time range in minute
-            fct-table-partition-time:
+                description: Maximum SQL database table partitioning time range in minute
+            fct_table_partition_time:
+                aliases: ['fct-table-partition-time']
                 type: int
-                description: Deprecated, please rename it to fct_table_partition_time. Maximum SQL database table partitioning time range in minute
+                description: Maximum SQL database table partitioning time range in minute
             logtype:
                 type: list
                 elements: str
@@ -277,35 +282,37 @@ options:
             password:
                 type: raw
                 description: (list) Password for login remote database.
-            prompt-sql-upgrade:
+            prompt_sql_upgrade:
+                aliases: ['prompt-sql-upgrade']
                 type: str
                 description:
-                    - Deprecated, please rename it to prompt_sql_upgrade.
                     - Prompt to convert log database into SQL database at start time on GUI.
                     - disable - Do not prompt to upgrade log database to SQL database at start time on GUI.
                     - enable - Prompt to upgrade log database to SQL database at start time on GUI.
                 choices:
                     - 'disable'
                     - 'enable'
-            rebuild-event:
+            rebuild_event:
+                aliases: ['rebuild-event']
                 type: str
                 description:
-                    - Deprecated, please rename it to rebuild_event.
                     - Disable/Enable rebuild event during SQL database rebuilding.
                     - disable - Do not rebuild event during SQL database rebuilding.
                     - enable - Rebuild event during SQL database rebuilding.
                 choices:
                     - 'disable'
                     - 'enable'
-            rebuild-event-start-time:
+            rebuild_event_start_time:
+                aliases: ['rebuild-event-start-time']
                 type: raw
-                description: (list) Deprecated, please rename it to rebuild_event_start_time. Rebuild event starting date and time
+                description: (list) Rebuild event starting date and time
             server:
                 type: str
                 description: Database IP or hostname.
-            start-time:
+            start_time:
+                aliases: ['start-time']
                 type: raw
-                description: (list) Deprecated, please rename it to start_time. Start date and time
+                description: (list) Start date and time
             status:
                 type: str
                 description:
@@ -315,23 +322,25 @@ options:
                 choices:
                     - 'disable'
                     - 'local'
-            text-search-index:
+            text_search_index:
+                aliases: ['text-search-index']
                 type: str
                 description:
-                    - Deprecated, please rename it to text_search_index.
                     - Disable/Enable text search index.
                     - disable - Do not create text search index.
                     - enable - Create text search index.
                 choices:
                     - 'disable'
                     - 'enable'
-            traffic-table-partition-time:
+            traffic_table_partition_time:
+                aliases: ['traffic-table-partition-time']
                 type: int
-                description: Deprecated, please rename it to traffic_table_partition_time. Maximum SQL database table partitioning time range in minute
-            ts-index-field:
+                description: Maximum SQL database table partitioning time range in minute
+            ts_index_field:
+                aliases: ['ts-index-field']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ts_index_field. Ts index field.
+                description: Ts index field.
                 suboptions:
                     category:
                         type: str
@@ -342,18 +351,20 @@ options:
             username:
                 type: str
                 description: User name for login remote database.
-            utm-table-partition-time:
+            utm_table_partition_time:
+                aliases: ['utm-table-partition-time']
                 type: int
-                description: Deprecated, please rename it to utm_table_partition_time. Maximum SQL database table partitioning time range in minute
-            custom-skipidx:
+                description: Maximum SQL database table partitioning time range in minute
+            custom_skipidx:
+                aliases: ['custom-skipidx']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to custom_skipidx. Custom skipidx.
+                description: Custom skipidx.
                 suboptions:
-                    device-type:
+                    device_type:
+                        aliases: ['device-type']
                         type: str
                         description:
-                            - Deprecated, please rename it to device_type.
                             - Device type.
                             - FortiGate - Set device type to FortiGate.
                             - FortiManager - Set device type to FortiManager
@@ -373,13 +384,14 @@ options:
                     id:
                         type: int
                         description: Add or Edit log index fields.
-                    index-field:
+                    index_field:
+                        aliases: ['index-field']
                         type: str
-                        description: Deprecated, please rename it to index_field. Field to be added to skip index.
-                    log-type:
+                        description: Field to be added to skip index.
+                    log_type:
+                        aliases: ['log-type']
                         type: str
                         description:
-                            - Deprecated, please rename it to log_type.
                             - Log type.
                             - app-ctrl
                             - attack
@@ -432,15 +444,17 @@ options:
                             - 'siem'
                             - 'ztna'
                             - 'security'
-            compress-table-min-age:
+            compress_table_min_age:
+                aliases: ['compress-table-min-age']
                 type: int
-                description: Deprecated, please rename it to compress_table_min_age. Minimum age in days for SQL tables to be compressed.
+                description: Minimum age in days for SQL tables to be compressed.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -454,70 +468,67 @@ EXAMPLES = '''
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_sql:
-          background_rebuild: <value in [disable, enable]>
-          custom_index:
-            -
-              case_sensitive: <value in [disable, enable]>
-              device_type: <value in [FortiGate, FortiManager, FortiClient, ...]>
-              id: <integer>
-              index_field: <string>
-              log_type: <value in [none, app-ctrl, attack, ...]>
-          database_name: <string>
-          database_type: <value in [mysql, postgres]>
-          device_count_high: <value in [disable, enable]>
-          event_table_partition_time: <integer>
-          fct_table_partition_time: <integer>
-          logtype:
-            - none
-            - app-ctrl
-            - attack
-            - content
-            - dlp
-            - emailfilter
-            - event
-            - generic
-            - history
-            - traffic
-            - virus
-            - voip
-            - webfilter
-            - netscan
-            - fct-event
-            - fct-traffic
-            - fct-netscan
-            - waf
-            - gtp
-            - dns
-            - ssh
-            - ssl
-            - file-filter
-            - asset
-            - protocol
-            - siem
-            - ztna
-            - security
-          password: <list or string>
-          prompt_sql_upgrade: <value in [disable, enable]>
-          rebuild_event: <value in [disable, enable]>
-          rebuild_event_start_time: <list or string>
-          server: <string>
-          start_time: <list or string>
-          status: <value in [disable, local]>
-          text_search_index: <value in [disable, enable]>
-          traffic_table_partition_time: <integer>
-          ts_index_field:
-            -
-              category: <string>
-              value: <string>
-          username: <string>
-          utm_table_partition_time: <integer>
-          custom_skipidx:
-            -
-              device_type: <value in [FortiGate, FortiManager, FortiClient, ...]>
-              id: <integer>
-              index_field: <string>
-              log_type: <value in [app-ctrl, attack, content, ...]>
-          compress_table_min_age: <integer>
+          # background_rebuild: <value in [disable, enable]>
+          # custom_index:
+          #   - case_sensitive: <value in [disable, enable]>
+          #     device_type: <value in [FortiGate, FortiManager, FortiClient, ...]>
+          #     id: <integer>
+          #     index_field: <string>
+          #     log_type: <value in [none, app-ctrl, attack, ...]>
+          # database_name: <string>
+          # database_type: <value in [mysql, postgres]>
+          # device_count_high: <value in [disable, enable]>
+          # event_table_partition_time: <integer>
+          # fct_table_partition_time: <integer>
+          # logtype:
+          #   - "none"
+          #   - "app-ctrl"
+          #   - "attack"
+          #   - "content"
+          #   - "dlp"
+          #   - "emailfilter"
+          #   - "event"
+          #   - "generic"
+          #   - "history"
+          #   - "traffic"
+          #   - "virus"
+          #   - "voip"
+          #   - "webfilter"
+          #   - "netscan"
+          #   - "fct-event"
+          #   - "fct-traffic"
+          #   - "fct-netscan"
+          #   - "waf"
+          #   - "gtp"
+          #   - "dns"
+          #   - "ssh"
+          #   - "ssl"
+          #   - "file-filter"
+          #   - "asset"
+          #   - "protocol"
+          #   - "siem"
+          #   - "ztna"
+          #   - "security"
+          # password: <list or string>
+          # prompt_sql_upgrade: <value in [disable, enable]>
+          # rebuild_event: <value in [disable, enable]>
+          # rebuild_event_start_time: <list or string>
+          # server: <string>
+          # start_time: <list or string>
+          # status: <value in [disable, local]>
+          # text_search_index: <value in [disable, enable]>
+          # traffic_table_partition_time: <integer>
+          # ts_index_field:
+          #   - category: <string>
+          #     value: <string>
+          # username: <string>
+          # utm_table_partition_time: <integer>
+          # custom_skipidx:
+          #   - device_type: <value in [FortiGate, FortiManager, FortiClient, ...]>
+          #     id: <integer>
+          #     index_field: <string>
+          #     log_type: <value in [app-ctrl, attack, content, ...]>
+          # compress_table_min_age: <integer>
 '''
 
 RETURN = '''
@@ -561,21 +572,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/sql'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/sql/{sql}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -659,7 +663,6 @@ def main():
                 },
                 'compress-table-min-age': {'v_range': [['6.4.3', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -673,9 +676,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
