@@ -114,6 +114,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -130,9 +131,9 @@ EXAMPLES = '''
         device_access_list: <your own value>
         state: present # <value in [present, absent]>
         user_deviceaccesslist_devicelist:
-          action: <value in [deny, accept]>
-          device: <string>
-          id: <integer>
+          id: 0 # Required variable, integer
+          # action: <value in [deny, accept]>
+          # device: <string>
 '''
 
 RETURN = '''
@@ -176,23 +177,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/device-access-list/{device-access-list}/device-list',
         '/pm/config/global/obj/user/device-access-list/{device-access-list}/device-list'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/device-access-list/{device-access-list}/device-list/{device-list}',
-        '/pm/config/global/obj/user/device-access-list/{device-access-list}/device-list/{device-list}'
-    ]
-
     url_params = ['adom', 'device-access-list']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -207,7 +200,6 @@ def main():
                 'device': {'v_range': [['6.2.2', '7.2.1']], 'type': 'str'},
                 'id': {'v_range': [['6.2.2', '7.2.1']], 'required': True, 'type': 'int'}
             }
-
         }
     }
 
@@ -216,14 +208,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'user_deviceaccesslist_devicelist'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
