@@ -104,15 +104,17 @@ options:
                     vdom:
                         type: str
                         description: Vdom.
-            auth-concurrent-override:
+            auth_concurrent_override:
+                aliases: ['auth-concurrent-override']
                 type: str
-                description: Deprecated, please rename it to auth_concurrent_override. Enable/disable overriding the global number of concurrent authen...
+                description: Enable/disable overriding the global number of concurrent authentication sessions for this user group.
                 choices:
                     - 'disable'
                     - 'enable'
-            auth-concurrent-value:
+            auth_concurrent_value:
+                aliases: ['auth-concurrent-value']
                 type: int
-                description: Deprecated, please rename it to auth_concurrent_value. Maximum number of concurrent authenticated connections per user
+                description: Maximum number of concurrent authenticated connections per user
             authtimeout:
                 type: int
                 description: Authentication timeout in minutes for this user group.
@@ -132,15 +134,17 @@ options:
             expire:
                 type: int
                 description: Time in seconds before guest user accounts expire
-            expire-type:
+            expire_type:
+                aliases: ['expire-type']
                 type: str
-                description: Deprecated, please rename it to expire_type. Determine when the expiration countdown begins.
+                description: Determine when the expiration countdown begins.
                 choices:
                     - 'immediately'
                     - 'first-successful-login'
-            group-type:
+            group_type:
+                aliases: ['group-type']
                 type: str
-                description: Deprecated, please rename it to group_type. Set the group to be for firewall authentication, FSSO, RSSO, or guest users.
+                description: Set the group to be for firewall authentication, FSSO, RSSO, or guest users.
                 choices:
                     - 'firewall'
                     - 'directory-service'
@@ -170,9 +174,10 @@ options:
                     id:
                         type: int
                         description: Guest ID.
-                    mobile-phone:
+                    mobile_phone:
+                        aliases: ['mobile-phone']
                         type: str
-                        description: Deprecated, please rename it to mobile_phone. Mobile phone.
+                        description: Mobile phone.
                     name:
                         type: str
                         description: Guest name.
@@ -182,22 +187,26 @@ options:
                     sponsor:
                         type: str
                         description: Set the action for the sponsor guest user field.
-                    user-id:
+                    user_id:
+                        aliases: ['user-id']
                         type: str
-                        description: Deprecated, please rename it to user_id. Guest ID.
-            http-digest-realm:
+                        description: Guest ID.
+            http_digest_realm:
+                aliases: ['http-digest-realm']
                 type: str
-                description: Deprecated, please rename it to http_digest_realm. Realm attribute for MD5-digest authentication.
+                description: Realm attribute for MD5-digest authentication.
             id:
                 type: int
                 description: Group ID.
                 required: true
-            ldap-memberof:
+            ldap_memberof:
+                aliases: ['ldap-memberof']
                 type: str
-                description: Deprecated, please rename it to ldap_memberof. Ldap memberof.
-            logic-type:
+                description: Ldap memberof.
+            logic_type:
+                aliases: ['logic-type']
                 type: str
-                description: Deprecated, please rename it to logic_type. Logic type.
+                description: Logic type.
                 choices:
                     - 'or'
                     - 'and'
@@ -209,30 +218,35 @@ options:
                     _gui_meta:
                         type: str
                         description: Gui meta.
-                    group-name:
+                    group_name:
+                        aliases: ['group-name']
                         type: str
-                        description: Deprecated, please rename it to group_name. Name of matching user or group on remote authentication server.
+                        description: Name of matching user or group on remote authentication server.
                     id:
                         type: int
                         description: ID.
-                    server-name:
+                    server_name:
+                        aliases: ['server-name']
                         type: str
-                        description: Deprecated, please rename it to server_name. Name of remote auth server.
-            max-accounts:
+                        description: Name of remote auth server.
+            max_accounts:
+                aliases: ['max-accounts']
                 type: int
-                description: Deprecated, please rename it to max_accounts. Maximum number of guest accounts that can be created for this group
+                description: Maximum number of guest accounts that can be created for this group
             member:
                 type: raw
                 description: (list or str) Names of users, peers, LDAP severs, or RADIUS servers to add to the user group.
-            mobile-phone:
+            mobile_phone:
+                aliases: ['mobile-phone']
                 type: str
-                description: Deprecated, please rename it to mobile_phone. Enable/disable the guest user mobile phone number field.
+                description: Enable/disable the guest user mobile phone number field.
                 choices:
                     - 'disable'
                     - 'enable'
-            multiple-guest-add:
+            multiple_guest_add:
+                aliases: ['multiple-guest-add']
                 type: str
-                description: Deprecated, please rename it to multiple_guest_add. Enable/disable addition of multiple guests.
+                description: Enable/disable addition of multiple guests.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -243,15 +257,18 @@ options:
                     - 'auto-generate'
                     - 'specify'
                     - 'disable'
-            redir-url:
+            redir_url:
+                aliases: ['redir-url']
                 type: str
-                description: Deprecated, please rename it to redir_url. Redir url.
-            sms-custom-server:
+                description: Redir url.
+            sms_custom_server:
+                aliases: ['sms-custom-server']
                 type: str
-                description: Deprecated, please rename it to sms_custom_server. SMS server.
-            sms-server:
+                description: SMS server.
+            sms_server:
+                aliases: ['sms-server']
                 type: str
-                description: Deprecated, please rename it to sms_server. Send SMS through FortiGuard or other external server.
+                description: Send SMS through FortiGuard or other external server.
                 choices:
                     - 'fortiguard'
                     - 'custom'
@@ -262,46 +279,53 @@ options:
                     - 'optional'
                     - 'mandatory'
                     - 'disabled'
-            sslvpn-bookmarks-group:
+            sslvpn_bookmarks_group:
+                aliases: ['sslvpn-bookmarks-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to sslvpn_bookmarks_group. Sslvpn bookmarks group.
-            sslvpn-cache-cleaner:
+                description: (list or str) Sslvpn bookmarks group.
+            sslvpn_cache_cleaner:
+                aliases: ['sslvpn-cache-cleaner']
                 type: str
-                description: Deprecated, please rename it to sslvpn_cache_cleaner. Sslvpn cache cleaner.
+                description: Sslvpn cache cleaner.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-client-check:
+            sslvpn_client_check:
+                aliases: ['sslvpn-client-check']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to sslvpn_client_check. Sslvpn client check.
+                description: Sslvpn client check.
                 choices:
                     - 'forticlient'
                     - 'forticlient-av'
                     - 'forticlient-fw'
                     - '3rdAV'
                     - '3rdFW'
-            sslvpn-ftp:
+            sslvpn_ftp:
+                aliases: ['sslvpn-ftp']
                 type: str
-                description: Deprecated, please rename it to sslvpn_ftp. Sslvpn ftp.
+                description: Sslvpn ftp.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-http:
+            sslvpn_http:
+                aliases: ['sslvpn-http']
                 type: str
-                description: Deprecated, please rename it to sslvpn_http. Sslvpn http.
+                description: Sslvpn http.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-os-check:
+            sslvpn_os_check:
+                aliases: ['sslvpn-os-check']
                 type: str
-                description: Deprecated, please rename it to sslvpn_os_check. Sslvpn os check.
+                description: Sslvpn os check.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-os-check-list:
+            sslvpn_os_check_list:
+                aliases: ['sslvpn-os-check-list']
                 type: dict
-                description: Deprecated, please rename it to sslvpn_os_check_list. Sslvpn os check list.
+                description: Sslvpn os check list.
                 suboptions:
                     action:
                         type: str
@@ -310,100 +334,118 @@ options:
                             - 'allow'
                             - 'check-up-to-date'
                             - 'deny'
-                    latest-patch-level:
+                    latest_patch_level:
+                        aliases: ['latest-patch-level']
                         type: str
-                        description: Deprecated, please rename it to latest_patch_level. Latest patch level.
+                        description: Latest patch level.
                     name:
                         type: str
                         description: Name.
                     tolerance:
                         type: int
                         description: Tolerance.
-            sslvpn-portal:
+            sslvpn_portal:
+                aliases: ['sslvpn-portal']
                 type: raw
-                description: (list or str) Deprecated, please rename it to sslvpn_portal. Sslvpn portal.
-            sslvpn-portal-heading:
+                description: (list or str) Sslvpn portal.
+            sslvpn_portal_heading:
+                aliases: ['sslvpn-portal-heading']
                 type: str
-                description: Deprecated, please rename it to sslvpn_portal_heading. Sslvpn portal heading.
-            sslvpn-rdp:
+                description: Sslvpn portal heading.
+            sslvpn_rdp:
+                aliases: ['sslvpn-rdp']
                 type: str
-                description: Deprecated, please rename it to sslvpn_rdp. Sslvpn rdp.
+                description: Sslvpn rdp.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-samba:
+            sslvpn_samba:
+                aliases: ['sslvpn-samba']
                 type: str
-                description: Deprecated, please rename it to sslvpn_samba. Sslvpn samba.
+                description: Sslvpn samba.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-split-tunneling:
+            sslvpn_split_tunneling:
+                aliases: ['sslvpn-split-tunneling']
                 type: str
-                description: Deprecated, please rename it to sslvpn_split_tunneling. Sslvpn split tunneling.
+                description: Sslvpn split tunneling.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-ssh:
+            sslvpn_ssh:
+                aliases: ['sslvpn-ssh']
                 type: str
-                description: Deprecated, please rename it to sslvpn_ssh. Sslvpn ssh.
+                description: Sslvpn ssh.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-telnet:
+            sslvpn_telnet:
+                aliases: ['sslvpn-telnet']
                 type: str
-                description: Deprecated, please rename it to sslvpn_telnet. Sslvpn telnet.
+                description: Sslvpn telnet.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-tunnel:
+            sslvpn_tunnel:
+                aliases: ['sslvpn-tunnel']
                 type: str
-                description: Deprecated, please rename it to sslvpn_tunnel. Sslvpn tunnel.
+                description: Sslvpn tunnel.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-tunnel-endip:
+            sslvpn_tunnel_endip:
+                aliases: ['sslvpn-tunnel-endip']
                 type: str
-                description: Deprecated, please rename it to sslvpn_tunnel_endip. Sslvpn tunnel endip.
-            sslvpn-tunnel-ip-mode:
+                description: Sslvpn tunnel endip.
+            sslvpn_tunnel_ip_mode:
+                aliases: ['sslvpn-tunnel-ip-mode']
                 type: str
-                description: Deprecated, please rename it to sslvpn_tunnel_ip_mode. Sslvpn tunnel ip mode.
+                description: Sslvpn tunnel ip mode.
                 choices:
                     - 'range'
                     - 'usrgrp'
-            sslvpn-tunnel-startip:
+            sslvpn_tunnel_startip:
+                aliases: ['sslvpn-tunnel-startip']
                 type: str
-                description: Deprecated, please rename it to sslvpn_tunnel_startip. Sslvpn tunnel startip.
-            sslvpn-virtual-desktop:
+                description: Sslvpn tunnel startip.
+            sslvpn_virtual_desktop:
+                aliases: ['sslvpn-virtual-desktop']
                 type: str
-                description: Deprecated, please rename it to sslvpn_virtual_desktop. Sslvpn virtual desktop.
+                description: Sslvpn virtual desktop.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-vnc:
+            sslvpn_vnc:
+                aliases: ['sslvpn-vnc']
                 type: str
-                description: Deprecated, please rename it to sslvpn_vnc. Sslvpn vnc.
+                description: Sslvpn vnc.
                 choices:
                     - 'disable'
                     - 'enable'
-            sslvpn-webapp:
+            sslvpn_webapp:
+                aliases: ['sslvpn-webapp']
                 type: str
-                description: Deprecated, please rename it to sslvpn_webapp. Sslvpn webapp.
+                description: Sslvpn webapp.
                 choices:
                     - 'disable'
                     - 'enable'
-            sso-attribute-value:
+            sso_attribute_value:
+                aliases: ['sso-attribute-value']
                 type: str
-                description: Deprecated, please rename it to sso_attribute_value. Name of the RADIUS user group that this local user group represents.
-            user-id:
+                description: Name of the RADIUS user group that this local user group represents.
+            user_id:
+                aliases: ['user-id']
                 type: str
-                description: Deprecated, please rename it to user_id. Guest user ID type.
+                description: Guest user ID type.
                 choices:
                     - 'email'
                     - 'auto-generate'
                     - 'specify'
-            user-name:
+            user_name:
+                aliases: ['user-name']
                 type: str
-                description: Deprecated, please rename it to user_name. Enable/disable the guest user name entry.
+                description: Enable/disable the guest user name entry.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -413,6 +455,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -429,83 +472,80 @@ EXAMPLES = '''
         group: <your own value>
         state: present # <value in [present, absent]>
         user_group_dynamicmapping:
-          _scope:
-            -
-              name: <string>
-              vdom: <string>
-          auth_concurrent_override: <value in [disable, enable]>
-          auth_concurrent_value: <integer>
-          authtimeout: <integer>
-          company: <value in [optional, mandatory, disabled]>
-          email: <value in [disable, enable]>
-          expire: <integer>
-          expire_type: <value in [immediately, first-successful-login]>
-          group_type: <value in [firewall, directory-service, fsso-service, ...]>
-          guest:
-            -
-              comment: <string>
-              company: <string>
-              email: <string>
-              expiration: <string>
-              group: <string>
-              id: <integer>
-              mobile_phone: <string>
-              name: <string>
-              password: <list or string>
-              sponsor: <string>
-              user_id: <string>
-          http_digest_realm: <string>
-          id: <integer>
-          ldap_memberof: <string>
-          logic_type: <value in [or, and]>
-          match:
-            -
-              _gui_meta: <string>
-              group_name: <string>
-              id: <integer>
-              server_name: <string>
-          max_accounts: <integer>
-          member: <list or string>
-          mobile_phone: <value in [disable, enable]>
-          multiple_guest_add: <value in [disable, enable]>
-          password: <value in [auto-generate, specify, disable]>
-          redir_url: <string>
-          sms_custom_server: <string>
-          sms_server: <value in [fortiguard, custom]>
-          sponsor: <value in [optional, mandatory, disabled]>
-          sslvpn_bookmarks_group: <list or string>
-          sslvpn_cache_cleaner: <value in [disable, enable]>
-          sslvpn_client_check:
-            - forticlient
-            - forticlient-av
-            - forticlient-fw
-            - 3rdAV
-            - 3rdFW
-          sslvpn_ftp: <value in [disable, enable]>
-          sslvpn_http: <value in [disable, enable]>
-          sslvpn_os_check: <value in [disable, enable]>
-          sslvpn_os_check_list:
-            action: <value in [allow, check-up-to-date, deny]>
-            latest_patch_level: <string>
-            name: <string>
-            tolerance: <integer>
-          sslvpn_portal: <list or string>
-          sslvpn_portal_heading: <string>
-          sslvpn_rdp: <value in [disable, enable]>
-          sslvpn_samba: <value in [disable, enable]>
-          sslvpn_split_tunneling: <value in [disable, enable]>
-          sslvpn_ssh: <value in [disable, enable]>
-          sslvpn_telnet: <value in [disable, enable]>
-          sslvpn_tunnel: <value in [disable, enable]>
-          sslvpn_tunnel_endip: <string>
-          sslvpn_tunnel_ip_mode: <value in [range, usrgrp]>
-          sslvpn_tunnel_startip: <string>
-          sslvpn_virtual_desktop: <value in [disable, enable]>
-          sslvpn_vnc: <value in [disable, enable]>
-          sslvpn_webapp: <value in [disable, enable]>
-          sso_attribute_value: <string>
-          user_id: <value in [email, auto-generate, specify]>
-          user_name: <value in [disable, enable]>
+          id: 0 # Required variable, integer
+          # _scope:
+          #   - name: <string>
+          #     vdom: <string>
+          # auth_concurrent_override: <value in [disable, enable]>
+          # auth_concurrent_value: <integer>
+          # authtimeout: <integer>
+          # company: <value in [optional, mandatory, disabled]>
+          # email: <value in [disable, enable]>
+          # expire: <integer>
+          # expire_type: <value in [immediately, first-successful-login]>
+          # group_type: <value in [firewall, directory-service, fsso-service, ...]>
+          # guest:
+          #   - comment: <string>
+          #     company: <string>
+          #     email: <string>
+          #     expiration: <string>
+          #     group: <string>
+          #     id: <integer>
+          #     mobile_phone: <string>
+          #     name: <string>
+          #     password: <list or string>
+          #     sponsor: <string>
+          #     user_id: <string>
+          # http_digest_realm: <string>
+          # ldap_memberof: <string>
+          # logic_type: <value in [or, and]>
+          # match:
+          #   - _gui_meta: <string>
+          #     group_name: <string>
+          #     id: <integer>
+          #     server_name: <string>
+          # max_accounts: <integer>
+          # member: <list or string>
+          # mobile_phone: <value in [disable, enable]>
+          # multiple_guest_add: <value in [disable, enable]>
+          # password: <value in [auto-generate, specify, disable]>
+          # redir_url: <string>
+          # sms_custom_server: <string>
+          # sms_server: <value in [fortiguard, custom]>
+          # sponsor: <value in [optional, mandatory, disabled]>
+          # sslvpn_bookmarks_group: <list or string>
+          # sslvpn_cache_cleaner: <value in [disable, enable]>
+          # sslvpn_client_check:
+          #   - "forticlient"
+          #   - "forticlient-av"
+          #   - "forticlient-fw"
+          #   - "3rdAV"
+          #   - "3rdFW"
+          # sslvpn_ftp: <value in [disable, enable]>
+          # sslvpn_http: <value in [disable, enable]>
+          # sslvpn_os_check: <value in [disable, enable]>
+          # sslvpn_os_check_list:
+          #   action: <value in [allow, check-up-to-date, deny]>
+          #   latest_patch_level: <string>
+          #   name: <string>
+          #   tolerance: <integer>
+          # sslvpn_portal: <list or string>
+          # sslvpn_portal_heading: <string>
+          # sslvpn_rdp: <value in [disable, enable]>
+          # sslvpn_samba: <value in [disable, enable]>
+          # sslvpn_split_tunneling: <value in [disable, enable]>
+          # sslvpn_ssh: <value in [disable, enable]>
+          # sslvpn_telnet: <value in [disable, enable]>
+          # sslvpn_tunnel: <value in [disable, enable]>
+          # sslvpn_tunnel_endip: <string>
+          # sslvpn_tunnel_ip_mode: <value in [range, usrgrp]>
+          # sslvpn_tunnel_startip: <string>
+          # sslvpn_virtual_desktop: <value in [disable, enable]>
+          # sslvpn_vnc: <value in [disable, enable]>
+          # sslvpn_webapp: <value in [disable, enable]>
+          # sso_attribute_value: <string>
+          # user_id: <value in [email, auto-generate, specify]>
+          # user_name: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -549,23 +589,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/group/{group}/dynamic_mapping',
         '/pm/config/global/obj/user/group/{group}/dynamic_mapping'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/group/{group}/dynamic_mapping/{dynamic_mapping}',
-        '/pm/config/global/obj/user/group/{group}/dynamic_mapping/{dynamic_mapping}'
-    ]
-
     url_params = ['adom', 'group']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -670,7 +702,6 @@ def main():
                 'user-id': {'v_range': [['7.0.2', '']], 'choices': ['email', 'auto-generate', 'specify'], 'type': 'str'},
                 'user-name': {'v_range': [['7.0.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -679,14 +710,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'user_group_dynamicmapping'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
