@@ -89,12 +89,14 @@ options:
         required: false
         type: dict
         suboptions:
-            ca-cert:
+            ca_cert:
+                aliases: ['ca-cert']
                 type: str
-                description: Deprecated, please rename it to ca_cert. Ca cert.
-            client-cert:
+                description: Ca cert.
+            client_cert:
+                aliases: ['client-cert']
                 type: str
-                description: Deprecated, please rename it to client_cert. Client cert.
+                description: Client cert.
             name:
                 type: str
                 description: Name.
@@ -108,12 +110,17 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
+            secondary_server:
+                aliases: ['secondary-server']
+                type: str
+                description: Secondary server.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -129,11 +136,12 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         user_pxgrid:
-          ca_cert: <string>
-          client_cert: <string>
-          name: <string>
-          server: <string>
-          status: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # ca_cert: <string>
+          # client_cert: <string>
+          # server: <string>
+          # status: <value in [disable, enable]>
+          # secondary_server: <string>
 '''
 
 RETURN = '''
@@ -177,23 +185,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/pxgrid',
         '/pm/config/global/obj/user/pxgrid'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/pxgrid/{pxgrid}',
-        '/pm/config/global/obj/user/pxgrid/{pxgrid}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -206,9 +206,9 @@ def main():
                 'client-cert': {'type': 'str'},
                 'name': {'required': True, 'type': 'str'},
                 'server': {'type': 'str'},
-                'status': {'choices': ['disable', 'enable'], 'type': 'str'}
+                'status': {'choices': ['disable', 'enable'], 'type': 'str'},
+                'secondary-server': {'v_range': [['7.4.7', '7.4.7'], ['7.6.3', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -217,14 +217,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'user_pxgrid'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
