@@ -103,29 +103,34 @@ options:
                 type: int
                 description: SLA ID.
                 required: true
-            jitter-threshold:
+            jitter_threshold:
+                aliases: ['jitter-threshold']
                 type: int
-                description: Deprecated, please rename it to jitter_threshold. Jitter for SLA to make decision in milliseconds.
-            latency-threshold:
+                description: Jitter for SLA to make decision in milliseconds.
+            latency_threshold:
+                aliases: ['latency-threshold']
                 type: int
-                description: Deprecated, please rename it to latency_threshold. Latency for SLA to make decision in milliseconds.
-            link-cost-factor:
+                description: Latency for SLA to make decision in milliseconds.
+            link_cost_factor:
+                aliases: ['link-cost-factor']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to link_cost_factor. Criteria on which to base link selection.
+                description: Criteria on which to base link selection.
                 choices:
                     - 'latency'
                     - 'jitter'
                     - 'packet-loss'
-            packetloss-threshold:
+            packetloss_threshold:
+                aliases: ['packetloss-threshold']
                 type: int
-                description: Deprecated, please rename it to packetloss_threshold. Packet loss for SLA to make decision in percentage.
+                description: Packet loss for SLA to make decision in percentage.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -143,14 +148,14 @@ EXAMPLES = '''
         health_check: <your own value>
         state: present # <value in [present, absent]>
         wanprof_system_virtualwanlink_healthcheck_sla:
-          id: <integer>
-          jitter_threshold: <integer>
-          latency_threshold: <integer>
-          link_cost_factor:
-            - latency
-            - jitter
-            - packet-loss
-          packetloss_threshold: <integer>
+          id: 0 # Required variable, integer
+          # jitter_threshold: <integer>
+          # latency_threshold: <integer>
+          # link_cost_factor:
+          #   - "latency"
+          #   - "jitter"
+          #   - "packet-loss"
+          # packetloss_threshold: <integer>
 '''
 
 RETURN = '''
@@ -194,21 +199,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/wanprof/{wanprof}/system/virtual-wan-link/health-check/{health-check}/sla'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/wanprof/{wanprof}/system/virtual-wan-link/health-check/{health-check}/sla/{sla}'
-    ]
-
     url_params = ['adom', 'wanprof', 'health-check']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -218,15 +216,14 @@ def main():
         'health_check': {'type': 'str'},
         'wanprof_system_virtualwanlink_healthcheck_sla': {
             'type': 'dict',
-            'v_range': [['6.0.0', '']],
+            'v_range': [['6.0.0', '7.6.2']],
             'options': {
-                'id': {'required': True, 'type': 'int'},
-                'jitter-threshold': {'type': 'int'},
-                'latency-threshold': {'type': 'int'},
-                'link-cost-factor': {'type': 'list', 'choices': ['latency', 'jitter', 'packet-loss'], 'elements': 'str'},
-                'packetloss-threshold': {'type': 'int'}
+                'id': {'v_range': [['6.0.0', '7.6.2']], 'required': True, 'type': 'int'},
+                'jitter-threshold': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'latency-threshold': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'link-cost-factor': {'v_range': [['6.0.0', '7.6.2']], 'type': 'list', 'choices': ['latency', 'jitter', 'packet-loss'], 'elements': 'str'},
+                'packetloss-threshold': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'}
             }
-
         }
     }
 
@@ -235,14 +232,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'wanprof_system_virtualwanlink_healthcheck_sla'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
