@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2018-2022, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 '''
@@ -68,7 +68,7 @@ options:
   super_user_security:
     description:
       - List of Read Write access specifications for the rule
-    choices: ['any','none','never','krb5','krb5i','krb5p','ntlm','sys']
+    choices: ['any','none','krb5','krb5i','krb5p','ntlm','sys']
     type: list
     elements: str
 
@@ -146,67 +146,67 @@ options:
 '''
 
 EXAMPLES = """
-    - name: Create ExportPolicyRule
-      netapp.ontap.na_ontap_export_policy_rule:
-        state: present
-        name: default123
-        rule_index: 100
-        vserver: ci_dev
-        client_match: 0.0.0.0/0,1.1.1.0/24
-        ro_rule: krb5,krb5i
-        rw_rule: any
-        protocol: nfs,nfs3
-        super_user_security: any
-        anonymous_user_id: 65534
-        allow_suid: true
-        ntfs_unix_security: ignore
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Create ExportPolicyRule
+  netapp.ontap.na_ontap_export_policy_rule:
+    state: present
+    name: default123
+    rule_index: 100
+    vserver: ci_dev
+    client_match: 0.0.0.0/0,1.1.1.0/24
+    ro_rule: krb5,krb5i
+    rw_rule: any
+    protocol: nfs,nfs3
+    super_user_security: any
+    anonymous_user_id: 65534
+    allow_suid: true
+    ntfs_unix_security: ignore
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: Modify ExportPolicyRule
-      netapp.ontap.na_ontap_export_policy_rule:
-        state: present
-        name: default123
-        rule_index: 100
-        client_match: 0.0.0.0/0
-        anonymous_user_id: 65521
-        ro_rule: ntlm
-        rw_rule: any
-        protocol: any
-        allow_suid: false
-        ntfs_unix_security: fail
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Modify ExportPolicyRule
+  netapp.ontap.na_ontap_export_policy_rule:
+    state: present
+    name: default123
+    rule_index: 100
+    vserver: ci_dev
+    client_match: 0.0.0.0/0
+    anonymous_user_id: 65521
+    ro_rule: ntlm
+    rw_rule: any
+    protocol: any
+    allow_suid: false
+    ntfs_unix_security: fail
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: rename ExportPolicyRule index
-      netapp.ontap.na_ontap_export_policy_rule:
-        state: present
-        name: default123
-        from_rule_index: 100
-        rule_index: 99
-        client_match: 0.0.0.0/0
-        anonymous_user_id: 65521
-        ro_rule: ntlm
-        rw_rule: any
-        protocol: any
-        allow_suid: false
-        ntfs_unix_security: fail
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-
-    - name: Delete ExportPolicyRule
-      netapp.ontap.na_ontap_export_policy_rule:
-        state: absent
-        name: default123
-        rule_index: 99
-        vserver: ci_dev
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Rename ExportPolicyRule index
+  netapp.ontap.na_ontap_export_policy_rule:
+    state: present
+    name: default123
+    from_rule_index: 100
+    rule_index: 99
+    client_match: 0.0.0.0/0
+    anonymous_user_id: 65521
+    ro_rule: ntlm
+    rw_rule: any
+    protocol: any
+    allow_suid: false
+    ntfs_unix_security: fail
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
+- name: Delete ExportPolicyRule
+  netapp.ontap.na_ontap_export_policy_rule:
+    state: absent
+    name: default123
+    rule_index: 99
+    vserver: ci_dev
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 """
 
 RETURN = """
@@ -243,7 +243,7 @@ class NetAppontapExportRule:
                          choices=['any', 'none', 'never', 'krb5', 'krb5i', 'krb5p', 'ntlm', 'sys']),
             super_user_security=dict(required=False,
                                      type='list', elements='str', default=None,
-                                     choices=['any', 'none', 'never', 'krb5', 'krb5i', 'krb5p', 'ntlm', 'sys']),
+                                     choices=['any', 'none', 'krb5', 'krb5i', 'krb5p', 'ntlm', 'sys']),
             allow_suid=dict(required=False, type='bool'),
             from_rule_index=dict(required=False, type='int'),
             rule_index=dict(required=False, type='int'),
@@ -357,7 +357,7 @@ class NetAppontapExportRule:
         """
         if self.use_rest:
             return self.get_export_policy_rule_rest(rule_index)
-        current, result = None, None
+        result = None
         rule_iter = netapp_utils.zapi.NaElement('export-rule-get-iter')
         query = self.set_query_parameters(rule_index)
         rule_iter.translate_struct(query)
@@ -539,9 +539,6 @@ class NetAppontapExportRule:
                                           % (self.parameters['from_rule_index'], to_native(error)),
                                       exception=traceback.format_exc())
 
-    def autosupport_log(self):
-        netapp_utils.ems_log_event("na_ontap_export_policy_rules", self.server)
-
     def set_export_policy_id_rest(self):
         if self.policy_id is not None:
             return
@@ -697,8 +694,6 @@ class NetAppontapExportRule:
 
     def apply(self):
         ''' Apply required action from the play'''
-        if not self.use_rest:
-            self.autosupport_log()
         current = self.get_export_policy_rule(self.parameters.get('rule_index'))
         cd_action, rename, modify = None, None, None
         cd_action = self.na_helper.get_cd_action(current, self.parameters)
@@ -737,7 +732,8 @@ class NetAppontapExportRule:
             elif modify:
                 self.modify_export_policy_rule(modify, current['rule_index'])
 
-        self.module.exit_json(changed=self.na_helper.changed)
+        result = netapp_utils.generate_result(self.na_helper.changed, cd_action, modify)
+        self.module.exit_json(**result)
 
 
 def main():
