@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2019, NetApp, Inc
+# (c) 2019-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 '''
@@ -19,11 +19,13 @@ DOCUMENTATION = """
 module: na_ontap_quota_policy
 short_description: NetApp Ontap create, assign, rename or delete quota policy
 extends_documentation_fragment:
-    - netapp.ontap.netapp.na_ontap
+  - netapp.ontap.netapp.na_ontap_zapi
 version_added: '19.11.0'
 author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
 description:
-- Create, assign, rename or delete the quota policy
+  - Create, assign, rename or delete the quota policy
+  - This module only supports ZAPI and is deprecated.
+  - The final version of ONTAP to support ZAPI is 9.12.1.
 options:
   state:
     description:
@@ -60,37 +62,36 @@ options:
 """
 
 EXAMPLES = """
-    - name: Create quota policy
-      na_ontap_quota_policy:
-        state: present
-        vserver: SVM1
-        name: ansible_policy
-        hostname: "{{ hostname }}"
-        username: "{{ username }}"
-        password: "{{ password }}"
+- name: Create quota policy
+  netapp.ontap.na_ontap_quota_policy:
+    state: present
+    vserver: SVM1
+    name: ansible_policy
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: Rename quota policy
-      na_ontap_quota_policy:
-        state: present
-        vserver: SVM1
-        name: new_ansible
-        from_name: ansible
-        hostname: "{{ hostname }}"
-        username: "{{ username }}"
-        password: "{{ password }}"
+- name: Rename quota policy
+  netapp.ontap.na_ontap_quota_policy:
+    state: present
+    vserver: SVM1
+    name: new_ansible
+    from_name: ansible
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
-    - name: Delete quota policy
-      na_ontap_quota_policy:
-        state: absent
-        vserver: SVM1
-        name: ansible_policy
-        hostname: "{{ hostname }}"
-        username: "{{ username }}"
-        password: "{{ password }}"
+- name: Delete quota policy
+  netapp.ontap.na_ontap_quota_policy:
+    state: absent
+    vserver: SVM1
+    name: ansible_policy
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 """
 
 RETURN = """
-
 """
 
 import traceback
@@ -114,7 +115,7 @@ class NetAppOntapQuotaPolicy(object):
             Initialize the ONTAP quota policy class
         """
 
-        self.argument_spec = netapp_utils.na_ontap_host_argument_spec()
+        self.argument_spec = netapp_utils.na_ontap_zapi_only_spec()
         self.argument_spec.update(dict(
             state=dict(required=False, choices=['present', 'absent'], default='present'),
             vserver=dict(required=True, type='str'),
@@ -205,7 +206,6 @@ class NetAppOntapQuotaPolicy(object):
                                   exception=traceback.format_exc())
 
     def apply(self):
-        netapp_utils.ems_log_event("na_ontap_quota_policy", self.server)
         current = self.get_quota_policy()
         # rename and create are mutually exclusive
         rename, cd_action = None, None
