@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2018-2022, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+
 # (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 from __future__ import absolute_import, division, print_function
@@ -120,131 +120,131 @@ options:
 '''
 
 EXAMPLES = """
-    - name: Create quota rule in ZAPI.
-      netapp.ontap.na_ontap_quotas:
-        state: present
-        vserver: ansible
-        volume: ansible
-        quota_target: user1
-        type: user
-        policy: ansible
-        file_limit: 2
-        disk_limit: 3
-        set_quota_status: True
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: Resize quota
-      netapp.ontap.na_ontap_quotas:
-        state: present
-        vserver: ansible
-        volume: ansible
-        quota_target: user1
-        type: user
-        policy: ansible
-        file_limit: 2
-        disk_limit: 3
-        set_quota_status: True
-        activate_quota_on_change: resize
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: Reinitialize quota
-      netapp.ontap.na_ontap_quotas:
-        state: present
-        vserver: ansible
-        volume: ansible
-        quota_target: user1
-        type: user
-        policy: ansible
-        file_limit: 2
-        disk_limit: 3
-        set_quota_status: True
-        activate_quota_on_change: reinitialize
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: modify quota
-      netapp.ontap.na_ontap_quotas:
-        state: present
-        vserver: ansible
-        volume: ansible
-        quota_target: user1
-        type: user
-        policy: ansible
-        file_limit: 2
-        disk_limit: 3
-        threshold: 3
-        set_quota_status: False
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: Delete quota
-      netapp.ontap.na_ontap_quotas:
-        state: absent
-        vserver: ansible
-        volume: ansible
-        quota_target: /vol/ansible
-        type: user
-        policy: ansible
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: Add/Set quota rule for type user in REST.
-      netapp.ontap.na_ontap_quotas:
-        state: present
-        vserver: ansible
-        volume: ansible
-        quota_target: "user1,user2"
-        qtree: qtree
-        type: user
-        file_limit: 2
-        disk_limit: 3
-        set_quota_status: True
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: Modify quota reset file limit and modify disk limit.
-      netapp.ontap.na_ontap_quotas:
-        state: present
-        vserver: ansible
-        volume: ansible
-        quota_target: "user1,user2"
-        qtree: qtree
-        type: user
-        file_limit: "-"
-        disk_limit: 100
-        set_quota_status: True
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: Add/Set quota rule for type group in REST.
-      netapp.ontap.na_ontap_quotas:
-        state: present
-        vserver: ansible
-        volume: ansible
-        quota_target: group1
-        qtree: qtree
-        type: group
-        file_limit: 2
-        disk_limit: 3
-        set_quota_status: True
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-    - name: Add/Set quota rule for type qtree in REST.
-      netapp.ontap.na_ontap_quotas:
-        state: present
-        vserver: ansible
-        volume: ansible
-        quota_target: qtree1
-        type: qtree
-        file_limit: 2
-        disk_limit: 3
-        set_quota_status: True
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Create quota rule in ZAPI.
+  netapp.ontap.na_ontap_quotas:
+    state: present
+    vserver: ansible
+    volume: ansible
+    quota_target: user1
+    type: user
+    policy: ansible
+    file_limit: 2
+    disk_limit: 3
+    set_quota_status: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+- name: Resize quota
+  netapp.ontap.na_ontap_quotas:
+    state: present
+    vserver: ansible
+    volume: ansible
+    quota_target: user1
+    type: user
+    policy: ansible
+    file_limit: 2
+    disk_limit: 3
+    set_quota_status: true
+    activate_quota_on_change: resize
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+- name: Reinitialize quota
+  netapp.ontap.na_ontap_quotas:
+    state: present
+    vserver: ansible
+    volume: ansible
+    quota_target: user1
+    type: user
+    policy: ansible
+    file_limit: 2
+    disk_limit: 3
+    set_quota_status: true
+    activate_quota_on_change: reinitialize
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+- name: Modify quota
+  netapp.ontap.na_ontap_quotas:
+    state: present
+    vserver: ansible
+    volume: ansible
+    quota_target: user1
+    type: user
+    policy: ansible
+    file_limit: 2
+    disk_limit: 3
+    threshold: 3
+    set_quota_status: false
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+- name: Delete quota
+  netapp.ontap.na_ontap_quotas:
+    state: absent
+    vserver: ansible
+    volume: ansible
+    quota_target: /vol/ansible
+    type: user
+    policy: ansible
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+- name: Add/Set quota rule for type user in REST.
+  netapp.ontap.na_ontap_quotas:
+    state: present
+    vserver: ansible
+    volume: ansible
+    quota_target: "user1,user2"
+    qtree: qtree
+    type: user
+    file_limit: 2
+    disk_limit: 3
+    set_quota_status: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+- name: Modify quota reset file limit and modify disk limit.
+  netapp.ontap.na_ontap_quotas:
+    state: present
+    vserver: ansible
+    volume: ansible
+    quota_target: "user1,user2"
+    qtree: qtree
+    type: user
+    file_limit: "-"
+    disk_limit: 100
+    set_quota_status: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+- name: Add/Set quota rule for type group in REST.
+  netapp.ontap.na_ontap_quotas:
+    state: present
+    vserver: ansible
+    volume: ansible
+    quota_target: group1
+    qtree: qtree
+    type: group
+    file_limit: 2
+    disk_limit: 3
+    set_quota_status: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+- name: Add/Set quota rule for type qtree in REST.
+  netapp.ontap.na_ontap_quotas:
+    state: present
+    vserver: ansible
+    volume: ansible
+    quota_target: qtree1
+    type: qtree
+    file_limit: 2
+    disk_limit: 3
+    set_quota_status: true
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 """
 
 RETURN = """
@@ -594,15 +594,26 @@ class NetAppONTAPQuotas:
                            'files.soft_limit,'
                            'volume.uuid,'
                            'users.name,'
+                           'users.id,'
                            'group.name,'}
 
         # set qtree name in query for type user and group if not ''.
         if self.parameters['qtree']:
             query['qtree.name'] = self.parameters['qtree']
+        users_names, users_ids = [], []
         if self.parameters.get('quota_target'):
             type = self.parameters['type']
-            field_name = 'users.name' if type == 'user' else 'group.name' if type == 'group' else 'qtree.name'
-            query[field_name] = self.parameters['quota_target']
+            if type == 'user':
+                users_names = [target for target in self.parameters['quota_target'].split(',') if not target.isdigit()]
+                users_ids = [target for target in self.parameters['quota_target'].split(',') if target.isdigit()]
+                if users_names:
+                    query['users.name'] = ",".join(users_names)
+                if users_ids:
+                    query['users.id'] = ",".join(users_ids)
+            else:
+                field_name = 'group.name' if type == 'group' else 'qtree.name'
+                query[field_name] = self.parameters['quota_target']
+
         api = 'storage/quota/rules'
         # If type: user, get quota rules api returns users which has name starts with input target user names.
         # Example of users list in a record:
@@ -622,9 +633,11 @@ class NetAppONTAPQuotas:
                     if desired_qtree != current_qtree:
                         continue
                     if type == 'user':
-                        desired_users = self.parameters['quota_target'].split(',')
-                        current_users = [user['name'] for user in item['users']]
-                        if set(current_users) == set(desired_users):
+                        current_users = {}
+                        current_users['names'] = [user['name'] for user in item['users'] if user.get('name')]
+                        current_users['ids'] = [user['id'] for user in item['users'] if user.get('id')]
+                        if set(current_users['names']) == set(users_names) and \
+                                set(current_users['ids']) == set(users_ids):
                             record = item
                             break
                     elif item['group']['name'] == self.parameters['quota_target']:
@@ -685,7 +698,10 @@ class NetAppONTAPQuotas:
         api = 'storage/quota/rules'
         response, error = rest_generic.post_async(self.rest_api, api, body, query)
         if error:
-            if '5308568' in error:
+            if "job reported error:" in error and "entry doesn't exist" in error:
+                # ignore RBAC issue with FSx - BURT1525998
+                self.module.warn('Ignoring job status, assuming success.')
+            elif '5308568' in error:
                 # code: 5308568 requires quota to be disabled/enabled to take effect.
                 # code: 5308571 - rule created, but to make it active reinitialize quota.
                 # reinitialize will disable/enable quota.
@@ -696,7 +712,8 @@ class NetAppONTAPQuotas:
                 self.module.fail_json(msg="Error on creating quotas rule: %s" % error)
             # fetch volume uuid as response will be None if above code error occurs.
             self.volume_uuid = self.get_quota_status_or_volume_id_rest(get_volume=True)
-        if response:
+        # skip fetching volume uuid from response if volume_uuid already populated.
+        if not self.volume_uuid and response:
             record, error = rrh.check_for_0_or_1_records(api, response, error, query)
             if not error and record and not record['volume']['uuid']:
                 error = 'volume uuid key not present in %s:' % record
@@ -789,6 +806,7 @@ class NetAppONTAPQuotas:
         start_msg = "Quota policy rule %s opertation succeeded. " % action
         end_msg = "reinitialize(disable and enable again) the quota for volume %s " \
                   "in SVM %s." % (self.parameters['volume'], self.parameters['vserver'])
+        msg = 'unexpected code: %s' % code
         if code == '5308572':
             msg = "However the rule is still being enforced. To stop enforcing, "
         if code in ['5308568', '5308569', '5308567']:
