@@ -11,47 +11,21 @@ A lookup function designed to return data from the NetBox application
 
 from __future__ import absolute_import, division, print_function
 
-import os
-import functools
-from pprint import pformat
-
-from ansible.errors import AnsibleError
-from ansible.plugins.lookup import LookupBase
-from ansible.parsing.splitter import parse_kv, split_args
-from ansible.utils.display import Display
-from ansible.module_utils.six import raise_from
-
-try:
-    import pynetbox
-except ImportError as imp_exc:
-    PYNETBOX_LIBRARY_IMPORT_ERROR = imp_exc
-else:
-    PYNETBOX_LIBRARY_IMPORT_ERROR = None
-
-try:
-    import requests
-except ImportError as imp_exc:
-    REQUESTS_LIBRARY_IMPORT_ERROR = imp_exc
-else:
-    REQUESTS_LIBRARY_IMPORT_ERROR = None
-
-
 __metaclass__ = type
 
 DOCUMENTATION = """
-    lookup: nb_lookup
     author: Chris Mills (@cpmills1975)
-    version_added: "2.9"
+    name: nb_lookup
+    version_added: "0.1.0"
     short_description: Queries and returns elements from NetBox
     description:
         - Queries NetBox via its API to return virtually any information
           capable of being held in NetBox.
-        - If wanting to obtain the plaintext attribute of a secret, I(private_key) or I(key_file) must be provided.
     options:
         _terms:
             description:
                 - The NetBox object type to query
-            required: True
+            required: true
         api_endpoint:
             description:
                 - The URL to the NetBox instance to query
@@ -59,15 +33,15 @@ DOCUMENTATION = """
                 # in order of precendence
                 - name: NETBOX_API
                 - name: NETBOX_URL
-            required: True
+            required: true
         api_filter:
             description:
                 - The api_filter to use. Filters should be key value pairs separated by a space.
-            required: False
+            required: false
         plugin:
             description:
                 - The NetBox plugin to query
-            required: False
+            required: false
         token:
             description:
                 - The API token created through NetBox
@@ -76,25 +50,32 @@ DOCUMENTATION = """
                 # in order of precendence
                 - name: NETBOX_TOKEN
                 - name: NETBOX_API_TOKEN
-            required: False
+            required: false
+        headers:
+            description: Dictionary of headers to be passed to the NetBox API.
+            default: {}
+            env:
+                - name: NETBOX_HEADERS
         validate_certs:
             description:
                 - Whether or not to validate SSL of the NetBox instance
-            required: False
-            default: True
+            required: false
+            default: true
         private_key:
             description:
+                - (DEPRECATED) - NetBox 2.11 and earlier only
                 - The private key as a string. Mutually exclusive with I(key_file).
-            required: False
+            required: false
         key_file:
             description:
+                - (DEPRECATED) - NetBox 2.11 and earlier only
                 - The location of the private key tied to user account. Mutually exclusive with I(private_key).
-            required: False
+            required: false
         raw_data:
             type: bool
             description:
                 - Whether to return raw API data with the lookup/query or whether to return a key/value dict
-            required: False
+            required: false
     requirements:
         - pynetbox
 """
@@ -111,10 +92,7 @@ tasks:
                     api_endpoint='http://localhost/',
                     token='<redacted>') }}"
 
-# This example uses an API Filter
-
-tasks:
-  # query a list of devices
+    # This example uses an API Filter
   - name: Obtain list of devices from NetBox
     debug:
       msg: >
@@ -124,24 +102,20 @@ tasks:
                     api_endpoint='http://localhost/',
                     api_filter='role=management tag=Dell'),
                     token='<redacted>') }}"
-
-# Obtain a secret for R1-device
-tasks:
-  - name: "Obtain secrets for R1-Device"
+    # This example uses an API Filter with a variable and jinja concatenation
+  - name: Set hostname fact
+    set_fact:
+      hostname: "my-server"
+  - name: Obtain details of a single device from NetBox
     debug:
-      msg: "{{ query('netbox.netbox.nb_lookup', 'secrets', api_filter='device=R1-Device', api_endpoint='http://localhost/', token='<redacted>', key_file='~/.ssh/id_rsa') }}"
-
-# Fetch bgp sessions for R1-device
-tasks:
-  - name: "Obtain bgp sessions for R1-Device"
-    debug:
-      msg: "{{ query('netbox.netbox.nb_lookup', 'bgp_sessions',
-                     api_filter='device=R1-Device',
-                     api_endpoint='http://localhost/',
-                     token='<redacted>',
-                     plugin='mycustomstuff') }}"
-
-      msg: "{{ query('netbox.netbox.nb_lookup', 'secrets', api_filter='device=R1-Device', api_endpoint='http://localhost/', token='<redacted>', key_file='~/.ssh/id_rsa') }}"
+      msg: >
+        "Device {{item.0.value.display}} (ID: {{item.0.key}}) was
+         manufactured by {{ item.0.value.device_type.manufacturer.name }}"
+    loop:
+      - '{{ query("netbox.netbox.nb_lookup", "devices",
+        api_endpoint="http://localhost/",
+        api_filter="name=" ~hostname,
+        token="<redacted>") }}'
 """
 
 RETURN = """
@@ -151,6 +125,41 @@ RETURN = """
     type: list
 """
 
+import os
+import functools
+import json
+from pprint import pformat
+
+from ansible.errors import AnsibleError
+from ansible.plugins.lookup import LookupBase
+from ansible.parsing.splitter import parse_kv, split_args
+from ansible.utils.display import Display
+from ansible.module_utils.six import raise_from
+from importlib.metadata import version
+
+try:
+    import pynetbox
+except ImportError as imp_exc:
+    PYNETBOX_LIBRARY_IMPORT_ERROR = imp_exc
+else:
+    PYNETBOX_LIBRARY_IMPORT_ERROR = None
+
+try:
+    import requests
+except ImportError as imp_exc:
+    REQUESTS_LIBRARY_IMPORT_ERROR = imp_exc
+else:
+    REQUESTS_LIBRARY_IMPORT_ERROR = None
+
+try:
+    from packaging.version import Version
+
+    HAS_PACKAGING = True
+    PACKAGING_IMPORT_ERROR = ""
+except ImportError as imp_exc:
+    PACKAGING_IMPORT_ERROR = imp_exc
+    HAS_PACKAGING = False
+
 
 def get_endpoint(netbox, term):
     """
@@ -169,6 +178,7 @@ def get_endpoint(netbox, term):
         "circuits": {"endpoint": netbox.circuits.circuits},
         "circuit-providers": {"endpoint": netbox.circuits.providers},
         "cables": {"endpoint": netbox.dcim.cables},
+        "cable-terminations": {"endpoint": netbox.dcim.cable_terminations},
         "cluster-groups": {"endpoint": netbox.virtualization.cluster_groups},
         "cluster-types": {"endpoint": netbox.virtualization.cluster_types},
         "clusters": {"endpoint": netbox.virtualization.clusters},
@@ -188,6 +198,9 @@ def get_endpoint(netbox, term):
         "console-server-ports": {"endpoint": netbox.dcim.console_server_ports},
         "content-types": {"endpoint": netbox.extras.content_types},
         "custom-fields": {"endpoint": netbox.extras.custom_fields},
+        "custom-field-choice-sets": {
+            "endpoint": netbox.extras.custom_field_choice_sets
+        },
         "custom-links": {"endpoint": netbox.extras.custom_links},
         "device-bay-templates": {"endpoint": netbox.dcim.device_bay_templates},
         "device-bays": {"endpoint": netbox.dcim.device_bays},
@@ -206,12 +219,19 @@ def get_endpoint(netbox, term):
         "interface-templates": {"endpoint": netbox.dcim.interface_templates},
         "interfaces": {"endpoint": netbox.dcim.interfaces},
         "inventory-items": {"endpoint": netbox.dcim.inventory_items},
+        "inventory-item-roles": {"endpoint": netbox.dcim.inventory_item_roles},
+        "inventory-item-templates": {"endpoint": netbox.dcim.inventory_item_templates},
         "ip-addresses": {"endpoint": netbox.ipam.ip_addresses},
         "ip-ranges": {"endpoint": netbox.ipam.ip_ranges},
         "job-results": {"endpoint": netbox.extras.job_results},
         "journal-entries": {"endpoint": netbox.extras.journal_entries},
         "locations": {"endpoint": netbox.dcim.locations},
         "manufacturers": {"endpoint": netbox.dcim.manufacturers},
+        "module-bays": {"endpoint": netbox.dcim.module_bays},
+        "module-bay-templates": {"endpoint": netbox.dcim.module_bay_templates},
+        "module-bay-types": {"endpoint": netbox.dcim.module_bay_types},
+        "module-types": {"endpoint": netbox.dcim.module_types},
+        "modules": {"endpoint": netbox.dcim.modules},
         "object-changes": {"endpoint": netbox.extras.object_changes},
         "permissions": {"endpoint": netbox.users.permissions},
         "platforms": {"endpoint": netbox.dcim.platforms},
@@ -236,9 +256,8 @@ def get_endpoint(netbox, term):
         "rirs": {"endpoint": netbox.ipam.rirs},
         "roles": {"endpoint": netbox.ipam.roles},
         "route-targets": {"endpoint": netbox.ipam.route_targets},
-        "secret-roles": {"endpoint": netbox.secrets.secret_roles},
-        "secrets": {"endpoint": netbox.secrets.secrets},
         "services": {"endpoint": netbox.ipam.services},
+        "service-templates": {"endpoint": netbox.ipam.service_templates},
         "site-groups": {"endpoint": netbox.dcim.site_groups},
         "sites": {"endpoint": netbox.dcim.sites},
         "tags": {"endpoint": netbox.extras.tags},
@@ -248,6 +267,7 @@ def get_endpoint(netbox, term):
         "topology-maps": {"endpoint": netbox.extras.topology_maps},
         "users": {"endpoint": netbox.users.users},
         "virtual-chassis": {"endpoint": netbox.dcim.virtual_chassis},
+        "virtual-disks": {"endpoint": netbox.virtualization.virtual_disks},
         "virtual-machines": {"endpoint": netbox.virtualization.virtual_machines},
         "virtualization-interfaces": {"endpoint": netbox.virtualization.interfaces},
         "vlan-groups": {"endpoint": netbox.ipam.vlan_groups},
@@ -256,16 +276,19 @@ def get_endpoint(netbox, term):
         "webhooks": {"endpoint": netbox.extras.webhooks},
     }
 
-    major, minor, patch = map(int, pynetbox.__version__.split("."))
+    major, minor, patch = tuple(map(int, pynetbox.__version__.split(".")))
+    netbox_versiontuple = tuple(map(int, netbox.version.split(".")))
 
-    if major >= 6 and minor >= 4 and patch >= 0:
+    if (major, minor, patch) >= (6, 4):
         netbox_endpoint_map["wireless-lan-groups"] = {
             "endpoint": netbox.wireless.wireless_lan_groups
         }
         netbox_endpoint_map["wireless-lan-groups"] = {
             "endpoint": netbox.wireless.wireless_lan_groups
         }
-        netbox_endpoint_map["wireless-lan"] = {"endpoint": netbox.wireless.wireless_lan}
+        netbox_endpoint_map["wireless-lans"] = {
+            "endpoint": netbox.wireless.wireless_lans
+        }
         netbox_endpoint_map["wireless-links"] = {
             "endpoint": netbox.wireless.wireless_links
         }
@@ -277,6 +300,34 @@ def get_endpoint(netbox, term):
                 % (major, minor, patch)
             )
 
+    if (major, minor, patch) < (7, 0, 1):
+        netbox_endpoint_map["secret-roles"] = {"endpoint": netbox.secrets.secret_roles}
+        netbox_endpoint_map["secrets"] = {"endpoint": netbox.secrets.secrets}
+
+    if netbox_versiontuple >= (3, 7):
+        if (major, minor, patch) >= (7, 3):
+            netbox_endpoint_map["l2vpn-terminations"] = {
+                "endpoint": netbox.vpn.l2vpn_terminations
+            }
+            netbox_endpoint_map["l2vpns"] = {"endpoint": netbox.vpn.l2vpns}
+            netbox_endpoint_map["tunnel-terminations"] = {
+                "endpoint": netbox.vpn.tunnel_terminations
+            }
+            netbox_endpoint_map["tunnels"] = {"endpoint": netbox.vpn.tunnels}
+
+        else:
+            if "l2vpn" in term:
+                Display().v(
+                    "pynetbox version %d.%d.%d does not support vpn app; please update to v7.3.0 or newer."
+                    % (major, minor, patch)
+                )
+
+    else:
+        netbox_endpoint_map["l2vpn-terminations"] = {
+            "endpoint": netbox.ipam.l2vpn_terminations
+        }
+        netbox_endpoint_map["l2vpns"] = {"endpoint": netbox.ipam.l2vpns}
+
     return netbox_endpoint_map[term]["endpoint"]
 
 
@@ -380,6 +431,7 @@ class LookupModule(LookupBase):
             or os.getenv("NETBOX_API")
             or os.getenv("NETBOX_URL")
         )
+        netbox_headers = kwargs.get("headers") or os.getenv("NETBOX_HEADERS") or {}
         netbox_ssl_verify = kwargs.get("validate_certs", True)
         netbox_private_key = kwargs.get("private_key")
         netbox_private_key_file = kwargs.get("key_file")
@@ -390,16 +442,26 @@ class LookupModule(LookupBase):
         if not isinstance(terms, list):
             terms = [terms]
 
+        if isinstance(netbox_headers, str):
+            netbox_headers = json.loads(netbox_headers)
+
         try:
             session = requests.Session()
+            session.headers = netbox_headers
             session.verify = netbox_ssl_verify
 
-            netbox = pynetbox.api(
-                netbox_api_endpoint,
-                token=netbox_api_token if netbox_api_token else None,
-                private_key=netbox_private_key,
-                private_key_file=netbox_private_key_file,
-            )
+            if Version(version("pynetbox")) < Version("7.0.0"):
+                netbox = pynetbox.api(
+                    netbox_api_endpoint,
+                    token=netbox_api_token if netbox_api_token else None,
+                    private_key=netbox_private_key,
+                    private_key_file=netbox_private_key_file,
+                )
+            else:
+                netbox = pynetbox.api(
+                    netbox_api_endpoint,
+                    token=netbox_api_token if netbox_api_token else None,
+                )
             netbox.http_session = session
         except FileNotFoundError:
             raise AnsibleError(
@@ -420,16 +482,16 @@ class LookupModule(LookupBase):
                     )
 
             Display().vvvv(
-                u"NetBox lookup for %s to %s using token %s filter %s"
+                "NetBox lookup for %s to %s using token %s filter %s"
                 % (term, netbox_api_endpoint, netbox_api_token, netbox_api_filter)
             )
 
             if netbox_api_filter:
                 filter = build_filters(netbox_api_filter)
 
-                if "id" in filter:
+                if "id" in filter and len(filter["id"]) == 1:
                     Display().vvvv(
-                        u"Filter is: %s and includes id, will use .get instead of .filter"
+                        "Filter is: %s and includes id, will use .get instead of .filter"
                         % (filter)
                     )
                     try:
