@@ -39,6 +39,7 @@ options:
     description:
     - Sets the local user's access level to the array
     type: str
+    default: readonly
     choices: [ readonly, ops_admin, storage_admin, array_admin ]
   password:
     description:
@@ -54,6 +55,19 @@ options:
     - Token can be exposed using the I(debug) module
     type: bool
     default: false
+  timeout:
+    description:
+      - The duration of API token validity.
+      - Valid values are weeks (w), days(d), hours(h), minutes(m) and seconds(s).
+    type: str
+    default: "0"
+    version_added: "1.34.0"
+  public_key:
+    description:
+      - Public key for SSH access.
+      - To remove existing key use an empty string
+    type: str
+    version_added: "1.34.0"
 extends_documentation_fragment:
 - purestorage.flasharray.purestorage.fa
 """
@@ -65,6 +79,7 @@ EXAMPLES = r"""
     password: apassword
     role: storage_admin
     api: true
+    timeout: 2d
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
   register: result
@@ -72,6 +87,22 @@ EXAMPLES = r"""
   debug:
     msg: "API Token: {{ result['user_info']['user_api'] }}"
 
+- name: Overwrite/add SSH public key for existing user
+  purestorage.flasharray.purefa_user:
+    name: ansible
+    role: array_admin
+    public_key: "{{lookup('file', 'id_rsa.pub') }}"
+    fa_url: 10.10.10.2
+    api_token: e31060a7-21fc-e277-6240-25983c6c4592
+
+- name: Remove existing SSH public key from user
+  purestorage.flasharray.purefa_user:
+    name: ansible
+    role: array_admin
+    public_key: ""
+    fa_url: 10.10.10.2
+    api_token: e31060a7-21fc-e277-6240-25983c6c4592
+
 - name: Change role type for existing user
   purestorage.flasharray.purefa_user:
     name: ansible
@@ -87,10 +118,12 @@ EXAMPLES = r"""
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
 
-- name: Change API token for existing user
+- name: Change API token and token timeout for existing user
   purestorage.flasharray.purefa_user:
     name: ansible
     api: true
+    role: array_admin
+    timeout: 1d
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
   register: result
@@ -103,116 +136,159 @@ RETURN = r"""
 """
 
 
+HAS_PURESTORAGE = True
+try:
+    from pypureclient.flasharray import AdminPost, AdminPatch, AdminRole
+except ImportError:
+    HAS_PURESTORAGE = False
+
 import re
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa import (
-    get_system,
+    get_array,
     purefa_argument_spec,
 )
-
-MIN_REQUIRED_API_VERSION = "1.14"
+from ansible_collections.purestorage.flasharray.plugins.module_utils.common import (
+    convert_time_to_millisecs,
+)
 
 
 def get_user(module, array):
     """Return Local User Account or None"""
     user = None
-    users = array.list_admins()
-    for acct in range(0, len(users)):
-        if users[acct]["name"] == module.params["name"]:
-            user = users[acct]
-    return user
+    res = array.get_admins(names=[module.params["name"]])
+    if res.status_code != 200:
+        return None
+    else:
+        return list(res.items)[0]
 
 
 def create_user(module, array):
     """Create or Update Local User Account"""
-    changed = api_changed = role_changed = passwd_changed = False
+    changed = key_changed = api_changed = role_changed = passwd_changed = False
     user = get_user(module, array)
     role = module.params["role"]
-    user_token = {}
+    ttl = convert_time_to_millisecs(module.params["timeout"])
+    api_token = None
     if not user:
         changed = True
         if not module.check_mode:
-            try:
-                if not role:
-                    role = "readonly"
-                array.create_admin(
-                    module.params["name"], role=role, password=module.params["password"]
-                )
-                if module.params["api"]:
-                    try:
-                        user_token["user_api"] = array.create_api_token(
-                            module.params["name"]
-                        )["api_token"]
-                    except Exception:
-                        array.delete_user(module.params["name"])
-                        module.fail_json(
-                            msg="Local User {0}: Creation failed".format(
-                                module.params["name"]
-                            )
-                        )
-            except Exception:
+            res = array.post_admins(
+                names=[module.params["name"]],
+                admin=AdminPost(
+                    role=AdminRole(name=role),
+                    password=module.params["password"],
+                ),
+            )
+            if res.status_code != 200:
                 module.fail_json(
-                    msg="Local User {0}: Creation failed".format(module.params["name"])
+                    msg="Failed to create user {0}. Error: {1}".format(
+                        module.params["name"], res.errors[0].message
+                    )
                 )
+            if module.params["api"]:
+                ttl = convert_time_to_millisecs(module.params["timeout"])
+                res = array.post_admins_api_tokens(
+                    names=[module.params["name"]], timeout=ttl
+                )
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Failed to create API token. Error: {0}".format(
+                            res.errors[0].message
+                        )
+                    )
+                api_token = list(res.items)[0].api_token.token
+            if module.params["public_key"]:
+                res = array.patch_admin(
+                    names=[module.params["name"]],
+                    admin=AdminPatch(public_key=module.params["public_key"]),
+                )
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Failed to add SSH key. Error: {0}".format(
+                            res.errors[0].message
+                        )
+                    )
     else:
         if module.params["password"] and not module.params["old_password"]:
             module.exit_json(changed=changed)
-        if module.params["password"] and module.params["old_password"]:
-            if module.params["old_password"] and (
-                module.params["password"] != module.params["old_password"]
-            ):
-                passwd_changed = True
-                if not module.check_mode:
-                    try:
-                        array.set_admin(
-                            module.params["name"],
-                            password=module.params["password"],
-                            old_password=module.params["old_password"],
-                        )
-                    except Exception:
-                        module.fail_json(
-                            msg="Local User {0}: Password reset failed. "
-                            "Check old password.".format(module.params["name"])
-                        )
-            else:
-                module.fail_json(
-                    msg="Local User Account {0}: Password change failed - "
-                    "Check both old and new passwords".format(module.params["name"])
+        if (
+            module.params["password"]
+            and module.params["old_password"]
+            and module.params["password"] != module.params["old_password"]
+        ):
+            passwd_changed = True
+            if not module.check_mode:
+                res = array.patch_admins(
+                    names=[module.params["name"]],
+                    admin=AdminPatch(
+                        password=module.params["password"],
+                        old_password=module.params["old_password"],
+                    ),
                 )
+                if res.status_code != 200:
+                    module.fail_json(
+                        msg="Local User {0} password reset failed. Error: {1}"
+                        "Check old password.".format(
+                            module.params["name"], res.errors[0].message
+                        )
+                    )
         if module.params["api"]:
-            try:
-                if not array.get_api_token(module.params["name"])["api_token"] is None:
-                    if not module.check_mode:
-                        array.delete_api_token(module.params["name"])
-                api_changed = True
-                if not module.check_mode:
-                    user_token["user_api"] = array.create_api_token(
-                        module.params["name"]
-                    )["api_token"]
-            except Exception:
+            api_changed = True
+            ttl = convert_time_to_millisecs(module.params["timeout"])
+            res = array.delete_admins_api_tokens(names=[module.params["name"]])
+            if res.status_code != 200:
                 module.fail_json(
-                    msg="Local User {0}: API token change failed".format(
-                        module.params["name"]
+                    msg="Failed to delete original API token. Error: {0}".format(
+                        res.errors[0].message
                     )
                 )
-        if module.params["role"] and module.params["role"] != user["role"]:
+            res = array.post_admins_api_tokens(
+                names=[module.params["name"]], timeout=ttl
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to recreate API token. Error: {0}".format(
+                        res.errors[0].message
+                    )
+                )
+            api_token = list(res.items)[0].api_token.token
+        if (
+            module.params["role"]
+            and module.params["role"] != getattr(user.role, "name", None)
+            and user.is_local
+        ):
             if module.params["name"] != "pureuser":
                 role_changed = True
                 if not module.check_mode:
-                    try:
-                        array.set_admin(
-                            module.params["name"], role=module.params["role"]
-                        )
-                    except Exception:
+                    res = array.patch_admins(
+                        names=[module.params["name"]],
+                        admin=AdminPatch(role=AdminRole(name=module.params["role"])),
+                    )
+                    if res.status_code != 200:
                         module.fail_json(
-                            msg="Local User {0}: Role changed failed".format(
-                                module.params["name"]
+                            msg="Local User {0} role changed failed. Error: {1}".format(
+                                module.params["name"], res.errors[0].message
                             )
                         )
             else:
                 module.warn("Role for 'pureuser' cannot be modified.")
-        changed = bool(passwd_changed or role_changed or api_changed)
-    module.exit_json(changed=changed, user_info=user_token)
+        if module.params["public_key"] is not None and module.params[
+            "public_key"
+        ] != getattr(user, "public_key", ""):
+            key_changed = True
+            res = array.patch_admins(
+                names=[module.params["name"]],
+                admin=AdminPatch(public_key=module.params["public_key"]),
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to change SSH key. Error: {0}".format(
+                        res.errors[0].message
+                    )
+                )
+        changed = bool(passwd_changed or role_changed or api_changed or key_changed)
+    module.exit_json(changed=changed, user_info=api_token)
 
 
 def delete_user(module, array):
@@ -221,12 +297,11 @@ def delete_user(module, array):
     if get_user(module, array):
         changed = True
         if not module.check_mode:
-            try:
-                array.delete_admin(module.params["name"])
-            except Exception:
+            res = array.delete_admins(names=[module.params["name"]])
+            if res.status_code != 200:
                 module.fail_json(
-                    msg="Object Store Account {0}: Deletion failed".format(
-                        module.params["name"]
+                    msg="User Account {0} deletion failed. Error: {1}".format(
+                        module.params["name"], res.errors[0].message
                     )
                 )
     module.exit_json(changed=changed)
@@ -240,25 +315,24 @@ def main():
             role=dict(
                 type="str",
                 choices=["readonly", "ops_admin", "storage_admin", "array_admin"],
+                default="readonly",
             ),
             state=dict(type="str", default="present", choices=["absent", "present"]),
             password=dict(type="str", no_log=True),
             old_password=dict(type="str", no_log=True),
             api=dict(type="bool", default=False),
+            timeout=dict(type="str", default="0"),
+            public_key=dict(type="str", no_log=True),
         )
     )
 
     module = AnsibleModule(argument_spec, supports_check_mode=True)
 
-    state = module.params["state"]
-    array = get_system(module)
-    api_version = array._list_available_rest_versions()
+    if not HAS_PURESTORAGE:
+        module.fail_json(msg="py-pure-client sdk is required for this module")
 
-    if MIN_REQUIRED_API_VERSION not in api_version:
-        module.fail_json(
-            msg="FlashArray REST version not supported. "
-            "Minimum version required: {0}".format(MIN_REQUIRED_API_VERSION)
-        )
+    state = module.params["state"]
+    array = get_array(module)
     pattern = re.compile("^[a-z0-9]([a-z0-9-]{0,30}[a-z0-9])?$")
     if not pattern.match(module.params["name"]):
         module.fail_json(
