@@ -93,7 +93,7 @@ options:
   owner_group:
     description:
       - Owner (user group) of the host.
-      - Mutually excluside with I(owner).
+      - Mutually exclusive with I(owner).
     type: str
     required: false
   provision_method:
@@ -188,6 +188,11 @@ options:
           - Should this interface be used for TFTP of PXELinux (or SSH for image-based hosts)?
           - Each managed hosts needs to have one provision interface.
         type: bool
+      execution:
+        description:
+          - Should this interface be used for Remote Execution?
+          - Each managed hosts should have one remote execution interface.
+        type: bool
       username:
         description:
           - Username for BMC authentication.
@@ -322,11 +327,11 @@ EXAMPLES = '''
     server_url: "https://foreman.example.com"
     name: "new_host"
     interfaces_attributes:
-    - type: "interface"
-      compute_attributes:
-        name: "nic1"
-        network: "969efbe6-f9e0-4383-a19a-a7ee65ad5007"
-        interface: "virtio"
+      - type: "interface"
+        compute_attributes:
+          name: "nic1"
+          network: "969efbe6-f9e0-4383-a19a-a7ee65ad5007"
+          interface: "virtio"
     state: present
 
 - name: "Create a VM with 2 NICs on specific ovirt networks"
@@ -336,19 +341,19 @@ EXAMPLES = '''
     server_url: "https://foreman.example.com"
     name: "new_host"
     interfaces_attributes:
-    - type: "interface"
-      primary: true
-      compute_attributes:
-        name: "nic1"
-        network: "969efbe6-f9e0-4383-a19a-a7ee65ad5007"
-        interface: "virtio"
-    - type: "interface"
-      name: "new_host_nic2"
-      managed: true
-      compute_attributes:
-        name: "nic2"
-        network: "969efbe6-f9e0-4383-a19a-a7ee65ad5008"
-        interface: "e1000"
+      - type: "interface"
+        primary: true
+        compute_attributes:
+          name: "nic1"
+          network: "969efbe6-f9e0-4383-a19a-a7ee65ad5007"
+          interface: "virtio"
+      - type: "interface"
+        name: "new_host_nic2"
+        managed: true
+        compute_attributes:
+          name: "nic2"
+          network: "969efbe6-f9e0-4383-a19a-a7ee65ad5008"
+          interface: "e1000"
     state: present
 
 - name: "Delete a host"
@@ -502,7 +507,7 @@ def main():
                     for volume in module.foreman_params['compute_attributes']['volumes_attributes'].values():
                         if 'storage_pod' in volume:
                             storage_pod = module.find_storage_pod(volume['storage_pod'], compute_resource, cluster)
-                            volume['storage_pod'] = storage_pod['id']
+                            volume['storage_pod'] = storage_pod['name']
                         if 'storage_domain' in volume:
                             storage_domain = module.find_storage_domain(volume['storage_domain'], compute_resource, cluster)
                             volume['storage_domain'] = storage_domain['id']
